@@ -1,9 +1,7 @@
 /*****************************************************************
  * drkonqi - The KDE Crash Handler
  * 
- * $Id: debugger.h,v 1.7 2002/10/29 22:55:44 pfeiffer Exp $
- *
- * Copyright (C) 2000 Hans Petter Bieker <bieker@kde.org>
+ * Copyright (C) 2000-2003 Hans Petter Bieker <bieker@kde.org>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -48,7 +46,7 @@ public:
 
 public slots:
   void slotAppend(const QString &);
-  void slotDone();
+  void slotDone(const QString&);
   void slotSomeError();
 
 protected:
