@@ -41,7 +41,7 @@ KateFileList::KateFileList (KateDocManager *_docManager,
                             KateViewManager *_viewManager,
                             QWidget * parent, const char * name )
     :  KListBox (parent, name)
-    , m_sort( KateFileList::sortByName )
+    , m_sort( KateFileList::sortByID )
 {
   setFocusPolicy ((QWidget::FocusPolicy)0);
 
@@ -58,8 +58,8 @@ KateFileList::KateFileList (KateDocManager *_docManager,
   connect(docManager,SIGNAL(documentCreated(Kate::Document *)),this,SLOT(slotDocumentCreated(Kate::Document *)));
   connect(docManager,SIGNAL(documentDeleted(uint)),this,SLOT(slotDocumentDeleted(uint)));
 
-  // Honour KDE single/double click setting
-  connect(this,SIGNAL(executed(QListBoxItem *)),this,SLOT(slotActivateView(QListBoxItem *)));
+  // do not Honour KDE single/double click setting
+//  connect(this,SIGNAL(executed(QListBoxItem *)),this,SLOT(slotActivateView(QListBoxItem *)));
   connect(this,SIGNAL(highlighted(QListBoxItem *)),this,SLOT(slotActivateView(QListBoxItem *)));
 
   connect(viewManager,SIGNAL(viewChanged()), this,SLOT(slotViewChanged()));
@@ -72,6 +72,18 @@ KateFileList::~KateFileList ()
   delete tooltip;
 }
 
+void KateFileList::keyPressEvent(QKeyEvent *e) {
+  if ( ( e->key() == Key_Return ) || ( e->key() == Key_Enter ) )
+  {
+    e->accept();
+    slotActivateView(item(currentItem()));
+  }
+  else
+  {
+    KListBox::keyPressEvent(e);
+  }
+}
+
 void KateFileList::slotNextDocument()
 {
   int c = currentItem ();
@@ -84,7 +96,7 @@ void KateFileList::slotNextDocument()
   else
     viewManager->activateView( ((KateFileListItem *)item(0))->documentNumber() );
 }
-
+	
 void KateFileList::slotPrevDocument()
 {
   int c = currentItem ();
@@ -246,11 +258,11 @@ void KateFileList::tip( const QPoint &p, QRect &r, QString &str )
   if (info && info->modifiedOnDisc)
   {
     if (info->modifiedOnDiscReason == 1)
-      str += i18n("<b>This file was changed (modified) on disc by another program!</b><br />");
+      str += i18n("<b>This file was changed (modified) on disc by another program.</b><br />");
     else if (info->modifiedOnDiscReason == 2)
-      str += i18n("<b>This file was changed (created) on disc by another program!</b><br />");
+      str += i18n("<b>This file was changed (created) on disc by another program.</b><br />");
     else if (info->modifiedOnDiscReason == 3)
-      str += i18n("<b>This file was changed (deleted) on disc by another program!</b><br />");
+      str += i18n("<b>This file was changed (deleted) on disc by another program.</b><br />");
   }
 
   str += doc->url().prettyURL();
