@@ -67,9 +67,9 @@ protected:
   {
     QPainter p( this );
     p.setPen( colorGroup().shadow() );
-    p.drawLine( e->rect().topLeft(), e->rect().topRight() );
+    p.drawLine( e->rect().left(), 0, e->rect().right(), 0 );
     p.setPen( ((KateViewSpace*)parentWidget())->isActiveSpace() ? colorGroup().light() : colorGroup().midlight() );
-    p.drawLine( e->rect().bottomLeft(), e->rect().bottomRight() );
+    p.drawLine( e->rect().left(), 1, e->rect().right(), 1 );
   }
 };
 //END KVSSBSep
@@ -231,6 +231,7 @@ void KateViewSpace::slotStatusChanged (Kate::View *view, int r, int c, int ovr,
 
 void KateViewSpace::saveConfig ( KConfig* config, int myIndex ,const QString& viewConfGrp)
 {
+  kdDebug()<<"KateViewSpace::saveConfig("<<myIndex<<", "<<viewConfGrp<<") - currentView: "<<currentView()<<")"<<endl;
   QString group = QString(viewConfGrp+"-ViewSpace %1").arg( myIndex );
 
   config->setGroup (group);
@@ -268,7 +269,6 @@ void KateViewSpace::modifiedOnDisc(Kate::Document *, bool, unsigned char)
 void KateViewSpace::restoreConfig ( KateViewManager *viewMan, KConfig* config, const QString &group )
 {
   config->setGroup (group);
-
   QString fn = config->readEntry( "Active View" );
 
   if ( !fn.isEmpty() )
@@ -302,7 +302,7 @@ KateVSStatusBar::KateVSStatusBar ( KateViewSpace *parent, const char *name )
   : KStatusBar( parent, name ),
     m_viewSpace( parent )
 {
-  m_lineColLabel = new QLabel( i18n(" Line: 1 Col: 0 "), this );
+  m_lineColLabel = new QLabel( this );
   addWidget( m_lineColLabel, 0, false );
   m_lineColLabel->setAlignment( Qt::AlignCenter );
   m_lineColLabel->installEventFilter( this );
