@@ -79,18 +79,18 @@ KWrite::KWrite (KTextEditor::Document *doc)
   {
     if ( !(doc = KTextEditor::EditorChooser::createDocument(0,"KTextEditor::Document")) )
     {
-      KMessageBox::error(this, i18n("A KDE text editor component could not be found!\n"
-                                    "Please check your KDE installation."));
+      KMessageBox::error(this, i18n("A KDE text-editor component could not be found;\n"
+                                    "please check your KDE installation."));
       kapp->exit(1);
     }
-    
+
     docList.append(doc);
   }
 
   m_view = doc->createView (this, 0L);
 
   setCentralWidget(m_view);
-  
+
   setupActions();
   setupStatusBar();
 
@@ -100,7 +100,7 @@ KWrite::KWrite (KTextEditor::Document *doc)
   connect(m_view,SIGNAL(viewStatusMsg(const QString &)),this,SLOT(newStatus(const QString &)));
   connect(m_view->document(),SIGNAL(fileNameChanged()),this,SLOT(newCaption()));
   connect(m_view,SIGNAL(dropEventPass(QDropEvent *)),this,SLOT(slotDropEvent(QDropEvent *)));
-  
+
   setXMLFile( "kwriteui.rc" );
   createShellGUI( true );
   guiFactory()->addClient( m_view );
@@ -108,18 +108,18 @@ KWrite::KWrite (KTextEditor::Document *doc)
   // install a working kate part popup dialog thingy
   if (static_cast<Kate::View*>(m_view->qt_cast("Kate::View")))
     static_cast<Kate::View*>(m_view->qt_cast("Kate::View"))->installPopup ((QPopupMenu*)(factory()->container("ktexteditor_popup", this)) );
-  
+
   // call it as last thing, must be sure everything is already set up ;)
   setAutoSaveSettings ("MainWindow Settings");
 
   // init with more usefull size, stolen from konq :)
   if ( !initialGeometrySet() && !kapp->config()->hasGroup("MainWindow Settings"))
     resize( 700, 480 );
-      
+
   readConfig ();
-  
+
   winList.append (this);
-  
+
   show ();
 }
 
@@ -129,10 +129,10 @@ KWrite::~KWrite()
 
   if (m_view->document()->views().count() == 1)
   {
-    docList.remove(m_view->document()); 
+    docList.remove(m_view->document());
     delete m_view->document();
   }
-  
+
   kapp->config()->sync ();
 }
 
@@ -167,6 +167,7 @@ void KWrite::setupActions()
 
   m_paShowPath = new KToggleAction(i18n("Sho&w Path"), 0, this, SLOT(newCaption()),
                     actionCollection(), "set_showPath");
+  m_paShowPath->setCheckedState(i18n("Hide Path"));
   m_paShowPath->setWhatsThis(i18n("Show the complete document path in the window caption"));
   a=KStdAction::keyBindings(this, SLOT(editKeys()), actionCollection());
   a->setWhatsThis(i18n("Configure the application's keyboard shortcut assignments."));
@@ -219,7 +220,7 @@ void KWrite::slotNew()
   if (m_view->document()->isModified() || !m_view->document()->url().isEmpty())
     new KWrite();
   else
-    m_view->document()->openURL("");
+    m_view->document()->openURL(KURL());
 }
 
 void KWrite::slotOpen()
@@ -259,7 +260,7 @@ void KWrite::slotOpen( const KURL& url )
   if (m_view->document()->isModified() || !m_view->document()->url().isEmpty())
   {
     KWrite *t = new KWrite();
-    if (KTextEditor::encodingInterface(m_view->document())) KTextEditor::encodingInterface(m_view->document())->setEncoding(encoding);
+    if (KTextEditor::encodingInterface(t->m_view->document())) KTextEditor::encodingInterface(t->m_view->document())->setEncoding(encoding);
     t->loadURL(url);
   }
   else
@@ -401,12 +402,12 @@ void KWrite::readConfig(KConfig *config)
 
   m_paShowStatusBar->setChecked( config->readBoolEntry("ShowStatusBar") );
   m_paShowPath->setChecked( config->readBoolEntry("ShowPath") );
-  
+
   m_recentFiles->loadEntries(config, "Recent Files");
 
   if (m_view && KTextEditor::configInterface(m_view->document()))
     KTextEditor::configInterface(m_view->document())->readConfig(config);
-    
+
   if( m_paShowStatusBar->isChecked() )
     statusBar()->show();
   else
@@ -419,7 +420,7 @@ void KWrite::writeConfig(KConfig *config)
 
   config->writeEntry("ShowStatusBar",m_paShowStatusBar->isChecked());
   config->writeEntry("ShowPath",m_paShowPath->isChecked());
-  
+
   m_recentFiles->saveEntries(config, "Recent Files");
 
   if (m_view && KTextEditor::configInterface(m_view->document()))
@@ -479,7 +480,7 @@ void KWrite::saveGlobalProperties(KConfig *config) //save documents
      if (KTextEditor::configInterface(doc))
        KTextEditor::configInterface(doc)->writeSessionConfig(config);
   }
-  
+
   for (uint z = 1; z <= winList.count(); z++)
   {
      QString buf = QString("Window %1").arg(z);
@@ -528,8 +529,8 @@ void KWrite::restore()
 
 static KCmdLineOptions options[] =
 {
-  { "stdin",    I18N_NOOP("Read the contents of stdin."), 0},
-  { "+[URL]",   I18N_NOOP("Document to open."), 0 },
+  { "stdin",    I18N_NOOP("Read the contents of stdin"), 0},
+  { "+[URL]",   I18N_NOOP("Document to open"), 0 },
   KCmdLineLastOption
 };
 
@@ -539,14 +540,14 @@ extern "C" int kdemain(int argc, char **argv)
 
   KLocale::setMainCatalogue("kate");         //lukas: set this to have the kwritepart translated using kate message catalog
 
-  KAboutData aboutData ( "kwrite", I18N_NOOP("KWrite"), "4.2.1",
+  KAboutData aboutData ( "kwrite", I18N_NOOP("KWrite"), "4.3",
                          I18N_NOOP( "KWrite - Text Editor" ), KAboutData::License_LGPL_V2,
-                         I18N_NOOP( "(c) 2000-2003 The Kate Authors" ), 0, "http://kate.kde.org" );
+                         I18N_NOOP( "(c) 2000-2004 The Kate Authors" ), 0, "http://kate.kde.org" );
 
   aboutData.addAuthor ("Christoph Cullmann", I18N_NOOP("Maintainer"), "cullmann@kde.org", "http://www.babylon2k.de");
   aboutData.addAuthor ("Anders Lund", I18N_NOOP("Core Developer"), "anders@alweb.dk", "http://www.alweb.dk");
   aboutData.addAuthor ("Joseph Wenninger", I18N_NOOP("Core Developer"), "jowenn@kde.org","http://stud3.tuwien.ac.at/~e9925371");
-  aboutData.addAuthor ("Hamish Rodda",I18N_NOOP("Core Developer"), "meddie@yoyo.its.monash.edu.au");
+  aboutData.addAuthor ("Hamish Rodda",I18N_NOOP("Core Developer"), "rodda@kde.org");
   aboutData.addAuthor ("Waldo Bastian", I18N_NOOP( "The cool buffersystem" ), "bastian@kde.org" );
   aboutData.addAuthor ("Charles Samuels", I18N_NOOP("The Editing Commands"), "charles@kde.org");
   aboutData.addAuthor ("Matt Newell", I18N_NOOP("Testing, ..."), "newellm@proaxis.com");
@@ -571,8 +572,6 @@ extern "C" int kdemain(int argc, char **argv)
   aboutData.addCredit ("Daniel Naber","","");
   aboutData.addCredit ("Roland Pabel",I18N_NOOP("Highlighting for Scheme"),"");
   aboutData.addCredit ("Cristi Dumitrescu",I18N_NOOP("PHP Keyword/Datatype list"),"");
-  aboutData.addCredit ("Carsten Presser", I18N_NOOP("Betatest"), "mord-slime@gmx.de");
-  aboutData.addCredit ("Jens Haupert", I18N_NOOP("Betatest"), "haupert@babylon2k.de");
   aboutData.addCredit ("Carsten Pfeiffer", I18N_NOOP("Very nice help"), "");
   aboutData.addCredit (I18N_NOOP("All people who have contributed and I have forgotten to mention"),"","");
 
@@ -627,23 +626,23 @@ extern "C" int kdemain(int argc, char **argv)
       for ( int z = 0; z < args->count(); z++ )
       {
         KWrite *t = new KWrite();
-      
+
         if (!KIO::NetAccess::mimetype( args->url(z), t ).startsWith(QString ("inode/directory")))
         {
           if (Kate::document (t->view()->document()))
             Kate::Document::setOpenErrorDialogsActivated (false);
-  
+
           t->loadURL( args->url( z ) );
-  
+
           if (Kate::document (t->view()->document()))
             Kate::Document::setOpenErrorDialogsActivated (true);
         }
         else
-          KMessageBox::sorry( t, i18n("The file '%1' could not be opened, it is not a normal file, it is a folder!").arg(args->url(z).url()) );
+          KMessageBox::sorry( t, i18n("The file '%1' could not be opened: it is not a normal file, it is a folder.").arg(args->url(z).url()) );
       }
     }
   }
-  
+
   // no window there, uh, ohh, for example borked session config !!!
   // create at least one !!
   if (KWrite::noWindows())
