@@ -1,30 +1,24 @@
-/***************************************************************************
-                          interfaces.cpp  -  description
-                             -------------------
-    begin                : Mon Jan 15 2001
-    copyright            : (C) 2001 by Christoph Cullmann
-    email                : cullmann@kde.org
- ***************************************************************************/
+/* This file is part of the KDE project
+   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
 
-/***************************************************************************
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License version 2 as published by the Free Software Foundation.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
- ***************************************************************************/
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
  #include "application.h"
- 
+ #include "project.h"
+
 #include "plugin.h"
 #include "plugin.moc"
 
@@ -32,8 +26,8 @@
 
 namespace Kate
 {
-            
-class PrivatePlugin
+
+  class PrivatePlugin
   {
   public:
     PrivatePlugin ()
@@ -42,9 +36,23 @@ class PrivatePlugin
 
     ~PrivatePlugin ()
     {
-    }           
+    }
   };
-  
+
+  class PrivateProjectPlugin
+  {
+  public:
+    PrivateProjectPlugin ()
+    {
+    }
+
+    ~PrivateProjectPlugin ()
+    {
+    }
+
+    Project *m_project;
+  };
+
   class PrivateInitPlugin
   {
   public:
@@ -54,11 +62,11 @@ class PrivatePlugin
 
     ~PrivateInitPlugin ()
     {
-    }    
-    
-    KURL m_configScript;       
+    }
+
+    KURL m_configScript;
   };
-  
+
   class PrivatePluginViewInterface
   {
   public:
@@ -69,29 +77,93 @@ class PrivatePlugin
     ~PrivatePluginViewInterface ()
     {
     }
-    
+
   };
-    
-                        
+
 unsigned int Plugin::globalPluginNumber = 0;
+unsigned int ProjectPlugin::globalProjectPluginNumber = 0;
 unsigned int InitPlugin::globalInitPluginNumber = 0;
 unsigned int PluginViewInterface::globalPluginViewInterfaceNumber = 0;
 
 Plugin::Plugin( Application *application, const char *name ) : QObject (application, name )
 {
   globalPluginNumber++;
-  myPluginNumber = globalPluginNumber; 
+  myPluginNumber = globalPluginNumber;
 }
 
 Plugin::~Plugin()
 {
 }
 
+unsigned int Plugin::pluginNumber () const
+{
+  return myPluginNumber;
+}
+
+Application *Plugin::application () const
+{
+  return Kate::application();
+}
+
+ProjectPlugin::ProjectPlugin( Project *project, const char *name ) : Plugin (Kate::application(), name )
+{
+  globalProjectPluginNumber++;
+  myProjectPluginNumber = globalProjectPluginNumber;
+
+  d = new PrivateProjectPlugin ();
+  d->m_project = project;
+}
+
+ProjectPlugin::~ProjectPlugin()
+{
+  delete d;
+}
+
+unsigned int ProjectPlugin::projectPluginNumber () const
+{
+  return myProjectPluginNumber;
+}
+
+ Project *ProjectPlugin::project () const
+{
+  return d->m_project;
+}
+
+bool ProjectPlugin::save ()
+{
+  return true;
+}
+
+bool ProjectPlugin::queryClose ()
+{
+  return true;
+}
+
+bool ProjectPlugin::close ()
+{
+  return true;
+}
+
+void ProjectPlugin::addDirs (const QString &, QStringList &)
+{
+}
+
+void ProjectPlugin::removeDirs (const QString &, QStringList &)
+{
+}
+
+void ProjectPlugin::addFiles (const QString &, QStringList &)
+{
+}
+
+void ProjectPlugin::removeFiles (const QString &, QStringList &)
+{
+}
 
 InitPlugin :: InitPlugin(Application *application, const char *name):Plugin(application,name)
 {
   globalInitPluginNumber++;
-  myInitPluginNumber = globalInitPluginNumber; 
+  myInitPluginNumber = globalInitPluginNumber;
 
   d = new PrivateInitPlugin ();
   d->m_configScript = KURL();
@@ -105,7 +177,7 @@ InitPlugin::~InitPlugin()
 unsigned int InitPlugin::initPluginNumber () const
 {
   return myInitPluginNumber;
-}    
+}
 
 void InitPlugin::activate(const KURL &initScript)
 {
@@ -128,16 +200,6 @@ int InitPlugin::initKate()
 return 0;
 }
 
-unsigned int Plugin::pluginNumber () const
-{
-  return myPluginNumber;
-}     
-
- Application *Plugin::application () const
-{
-  return Kate::application();
-} 
-
 PluginViewInterface::PluginViewInterface()
 {
   globalPluginViewInterfaceNumber++;
@@ -151,15 +213,20 @@ PluginViewInterface::~PluginViewInterface()
 unsigned int PluginViewInterface::pluginViewInterfaceNumber () const
 {
   return myPluginViewInterfaceNumber;
-}    
+}
 
 Plugin *createPlugin ( const char* libname, Application *application, const char *name, const QStringList &args )
 {
   return KParts::ComponentFactory::createInstanceFromLibrary<Plugin>( libname, application, name, args);
 }
 
+ProjectPlugin *createProjectPlugin ( const char* libname, Project *project, const char *name, const QStringList &args )
+{
+  return KParts::ComponentFactory::createInstanceFromLibrary<ProjectPlugin>( libname, project, name, args);
+}
+
 PluginViewInterface *pluginViewInterface (Plugin *plugin)
-{       
+{
   if (!plugin)
     return 0;
 
