@@ -1,29 +1,21 @@
-/***************************************************************************
-                          interfaces.cpp  -  description
-                             -------------------
-    begin                : Mon Jan 15 2001
-    copyright            : (C) 2001 by Christoph Cullmann
-    email                : cullmann@kde.org
- ***************************************************************************/
+/* This file is part of the KDE project
+   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
 
-/***************************************************************************
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License version 2 as published by the Free Software Foundation.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
- ***************************************************************************/
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
-#include "pluginmanager.h"
 #include "pluginmanager.moc"
 
 #include "plugin.h"
@@ -45,12 +37,12 @@ class PrivatePluginManager
     }
 
     ~PrivatePluginManager ()
-    {    
-    }          
-        
-    KatePluginManager *pluginMan; 
+    {
+    }
+
+    KatePluginManager *pluginMan;
   };
-            
+
 PluginManager::PluginManager (void *pluginManager) : QObject ((KatePluginManager*) pluginManager)
 {
   d = new PrivatePluginManager ();
@@ -90,12 +82,12 @@ class PrivateInitPluginManager
     }
 
     ~PrivateInitPluginManager ()
-    {    
-    }          
-        
-    KateApp *initPluginMan; 
+    {
+    }
+
+    KateApp *initPluginMan;
   };
-            
+
 InitPluginManager::InitPluginManager (void *initPluginManager) : QObject ((KateApp*) initPluginManager)
 {
   d = new PrivateInitPluginManager ();
@@ -111,7 +103,7 @@ void InitPluginManager::performInit(const QString &libname, const KURL &initScri
 {
   d->initPluginMan->performInit (libname, initScript);
 }
-    
+
 InitPlugin *InitPluginManager::initPlugin() const
 {
   return d->initPluginMan->initPlugin();
