@@ -126,6 +126,17 @@ KBellConfig::KBellConfig(QWidget *parent, const char *name):
   connect(m_volume, SIGNAL(valueChanged(int)), SLOT(configChanged()));
   connect(m_pitch, SIGNAL(valueChanged(int)), SLOT(configChanged()));
   connect(m_duration, SIGNAL(valueChanged(int)), SLOT(configChanged()));
+  
+  KAboutData *about =
+    new KAboutData(I18N_NOOP("kcmbell"), I18N_NOOP("KDE Bell Control Module"),
+                  0, 0, KAboutData::License_GPL,
+                  I18N_NOOP("(c) 1997 - 2001 Christian Czezatke, Matthias Elter"));
+
+  about->addAuthor("Christian Czezatke", I18N_NOOP("Original author"), "e9025461@student.tuwien.ac.at");
+  about->addAuthor("Bernd Wuebben", 0, "wuebben@kde.org");
+  about->addAuthor("Matthias Elter", I18N_NOOP("Current maintainer"), "elter@kde.org");
+  about->addAuthor("Carsten Pfeiffer", 0, "pfeiffer@kde.org");
+  setAboutData(about);
 
   load();
 }
@@ -230,27 +241,11 @@ void KBellConfig::defaults()
 QString KBellConfig::quickHelp() const
 {
   return i18n("<h1>System Bell</h1> Here you can customize the sound of the standard system bell,"
-    " i.e. the \"beep\" you always hear when there's something wrong. Note that you can further"
-    " customize this sound using the \"Accessibility\" control module: for example you can choose"
+    " i.e. the \"beep\" you always hear when there is something wrong. Note that you can further"
+    " customize this sound using the \"Accessibility\" control module; for example, you can choose"
     " a sound file to be played instead of the standard bell.");
 }
 
-const KAboutData* KBellConfig::aboutData() const
-{
-
-    KAboutData *about =
-    new KAboutData(I18N_NOOP("kcmbell"), I18N_NOOP("KDE Bell Control Module"),
-                  0, 0, KAboutData::License_GPL,
-                  I18N_NOOP("(c) 1997 - 2001 Christian Czezatke, Matthias Elter"));
-
-    about->addAuthor("Christian Czezatke", I18N_NOOP("Original author"), "e9025461@student.tuwien.ac.at");
-    about->addAuthor("Bernd Wuebben", 0, "wuebben@kde.org");
-    about->addAuthor("Matthias Elter", I18N_NOOP("Current maintainer"), "elter@kde.org");
-    about->addAuthor("Carsten Pfeiffer", 0, "pfeiffer@kde.org");
-
-    return about;
-}
-
 void KBellConfig::useBell( bool on )
 {
   m_volume->setEnabled( on );
