@@ -35,8 +35,10 @@
 
 #include <kio/netaccess.h>
 
+#if defined Q_WS_X11 && !defined K_WS_QTONLY
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
+#endif
 
 #include "../krdb/krdb.h"
 
@@ -366,9 +368,11 @@ void KColorScheme::save()
         flags |= KRdbExportColors;
     else
     {
+#if defined Q_WS_X11 && !defined K_WS_QTONLY
         // Undo the property xrdb has placed on the root window (if any),
         // i.e. remove all entries, including ours
         XDeleteProperty( qt_xdisplay(), qt_xrootwin(), XA_RESOURCE_MANAGER );
+#endif
     }
     runRdb( flags );	// Save the palette to qtrc for KStyles
 
@@ -421,7 +425,7 @@ QString KColorScheme::quickHelp() const
        " predefined color schemes on which you can base your own.<p>"
        " All KDE applications will obey the selected color scheme."
        " Non-KDE applications may also obey some or all of the color"
-       " settings. See the \"Style\" control module for more details.");
+       " settings, if this option is enabled.");
 }
 
 
@@ -580,14 +584,14 @@ void KColorScheme::slotImport()
 {
 	QString location = locateLocal( "data", "kdisplay/color-schemes/" );
 
-	KURL file = KFileDialog::getOpenFileName(QString::null, "*.kcsrc", this);
+	KURL file ( KFileDialog::getOpenFileName(QString::null, "*.kcsrc", this) );
 	if ( file.isEmpty() )
 		return;
 
 	//kdDebug() << "Location: " << location << endl;
-	if (!KIO::NetAccess::file_copy(file, location+file.fileName( false )  ) )
+	if (!KIO::NetAccess::file_copy(file, KURL( location+file.fileName( false ) ) ) )
 	{
-		KMessageBox::error(this, KIO::NetAccess::lastErrorString(),i18n("Import failed!"));
+		KMessageBox::error(this, KIO::NetAccess::lastErrorString(),i18n("Import failed."));
 		return;
 	}
 	else
@@ -847,7 +851,7 @@ void KColorScheme::readSchemeNames()
             "kdisplay/color-schemes/*.kcsrc", false, true);
 
     // And add them
-    for (QStringList::ConstIterator it = list.begin(); it != list.end(); it++) {
+    for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
        KSimpleConfig *config = new KSimpleConfig(*it);
        config->setGroup("Color Scheme");
        QString str = config->readEntry("Name");
