@@ -28,6 +28,7 @@
 #include <kcmodule.h>
 
 #include <ksimpleconfig.h>
+#include <kdeversion.h>
 
 #include <qtabwidget.h>
 #include <qcheckbox.h>
@@ -228,7 +229,9 @@ public:
 
   int buttons();
   QString quickHelp() const;
+#if !KDE_IS_VERSION( 3, 2, 90 )
   const KAboutData* aboutData() const;
+#endif
 
 #ifdef HAVE_SSL
   bool loadCiphers();
@@ -282,6 +285,7 @@ protected:
 
 private:
 
+  void offerImportToKMail( const QString& certFile );
   void setAuthCertLists();
   void genCAList();
 
