@@ -16,25 +16,16 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include <unistd.h>
 
 #include <qlayout.h>
-#include <qgroupbox.h>
-#include <qhbox.h>
 #include <qlabel.h>
-#include <qlistbox.h>
-#include <qtabwidget.h>
 
-#include <kapplication.h>
-#include <kbuttonbox.h>
 #include <dcopclient.h>
 #include <klocale.h>
-#include <kglobal.h>
-#include <kstandarddirs.h>
-#include <kconfig.h>
 
 #include "filteropts.h"
 
@@ -45,7 +36,7 @@ FilterOptions::FilterOptions(QWidget *parent, const char *name)
     QGridLayout *lay = new QGridLayout(this, 1, 1, 10, 5);
     //QGroupBox =
 
-    lay->addWidget(new QLabel(i18n("Under Construction..."), this), 0, 0);
+    lay->addWidget(new QLabel(i18n("Under construction..."), this), 0, 0);
     lay->activate();
 
     // load();
