@@ -22,8 +22,6 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-/* $Id: kuriikwsfiltereng.h,v 1.15 2003/12/16 05:51:09 adawit Exp $ */
-
 #ifndef __KURISearchFILTERENGINE_H__
 #define __KURISearchFILTERENGINE_H__
 
@@ -47,7 +45,7 @@ public:
   
   QString webShortcutQuery (const QString&) const;
   
-  QString autoWebSearchQuery (const QString&, const QString&) const;
+  QString autoWebSearchQuery (const QString&) const;
   
   bool verbose() const { return m_bVerbose; }
 
