@@ -13,7 +13,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 
@@ -22,7 +22,8 @@
 
 #include <kservice.h>
 
-class SearchProvider {
+class SearchProvider 
+{
 public:
     SearchProvider() : m_dirty(false) {};
     SearchProvider(const KService::Ptr service);
