@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: energy.cpp,v 1.30 2003/11/09 13:01:41 coolo Exp $
+ *
  *
  * This file is part of the KDE project, module kcontrol.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -448,7 +448,7 @@ QString KEnergy::quickHelp() const
 
 void KEnergy::openURL(const QString &URL)
 {
-      new KRun(URL);
+      new KRun(KURL( URL ));
 }
 
 #include "energy.moc"
