@@ -50,6 +50,15 @@ IconModule::IconModule(QWidget *parent, const char *name, const QStringList &)
   tab2 = new KIconConfig(this, "effects");
   tab->addTab(tab2, i18n("&Advanced"));
   connect(tab2, SIGNAL(changed(bool)), this, SLOT(moduleChanged(bool)));
+
+  KAboutData* about = new KAboutData("kcmicons", I18N_NOOP("Icons"), "3.0",
+	      I18N_NOOP("Icons Control Panel Module"),
+	      KAboutData::License_GPL,
+ 	      I18N_NOOP("(c) 2000-2003 Geert Jansen"), 0, 0);
+  about->addAuthor("Geert Jansen", 0, "jansen@kde.org");
+  about->addAuthor("Antonio Larrosa Jimenez", 0, "larrosa@kde.org");
+  about->addCredit("Torsten Rahn", 0, "torsten@kde.org");
+  setAboutData( about );
 }
 
 
@@ -83,7 +92,7 @@ QString IconModule::quickHelp() const
 {
   return i18n("<h1>Icons</h1>"
     "This module allows you to choose the icons for your desktop.<p>"
-    "To choose an icon theme, click on its name and apply your choice by pressing the \"Apply\" button below. If you don't want to apply your choice you can press the \"Reset\" button to discard your changes.</p>"
+    "To choose an icon theme, click on its name and apply your choice by pressing the \"Apply\" button below. If you do not want to apply your choice you can press the \"Reset\" button to discard your changes.</p>"
     "<p>By pressing the \"Install New Theme\" button you can install your new icon theme by writing its location in the box or browsing to the location."
     " Press the \"OK\" button to finish the installation.</p>"
     "<p>The \"Remove Theme\" button will only be activated if you select a theme that you installed using this module."
@@ -92,23 +101,5 @@ QString IconModule::quickHelp() const
 }
 
 
-const KAboutData *IconModule::aboutData() const
-{
-    static KAboutData* ab = 0;
-
-    if (!ab)
-    {
-        ab = new KAboutData("kcmicons", I18N_NOOP("Icons"), "3.0",
-                            I18N_NOOP("Icons Control Panel Module"),
-                            KAboutData::License_GPL,
-                            I18N_NOOP("(c) 2000-2003 Geert Jansen"), 0, 0);
-        ab->addAuthor("Geert Jansen", 0, "jansen@kde.org");
-        ab->addAuthor("Antonio Larrosa Jimenez", 0, "larrosa@kde.org");
-        ab->addCredit("Torsten Rahn", 0, "torsten@kde.org");
-    }
-
-    return ab;
-}
-
 
 #include "main.moc"
