@@ -1,6 +1,4 @@
 /*
-	$Id: info.cpp,v 1.67 2003/11/08 23:43:51 mkretz Exp $
-
 	Main Widget for showing system-dependent information.
 	(But all functions in THIS FILE should be system independent !)
 
@@ -357,7 +355,7 @@ void KInfoListWidget::load()
     /*  Delete the user-visible ErrorString, before calling the
         retrieve-function. If the function wants the widget to show
         another string, then it change *GetInfo_ErrorString ! */
-    ErrorString = i18n("No information available about %1!").arg(title)
+    ErrorString = i18n("No information available about %1.").arg(title)
 		    + QString("\n\n") + DEFAULT_ERRORSTRING;
     GetInfo_ErrorString = &ErrorString;  /* save the address of ErrorString */
 
@@ -404,6 +402,16 @@ KInfoListWidget::KInfoListWidget(const QString &_title, QWidget *parent, const c
     : KCModule(parent, name),
       title(_title)
 {
+
+    KAboutData *about =
+    new KAboutData(I18N_NOOP("kcminfo"),
+		I18N_NOOP("KDE Panel System Information Control Module"),
+		0, 0, KAboutData::License_GPL,
+		I18N_NOOP("(c) 1998 - 2002 Helge Deller"));
+
+    about->addAuthor("Helge Deller", 0, "deller@kde.org");
+    setAboutData( about );
+
     setButtons(KCModule::Help);
     getlistbox 	= _getlistbox;
     GetInfo_ErrorString = 0;
@@ -424,20 +432,6 @@ KInfoListWidget::KInfoListWidget(const QString &_title, QWidget *parent, const c
 }
 
 
-const KAboutData* KInfoListWidget::aboutData() const
-{
-
-    KAboutData *about =
-    new KAboutData(I18N_NOOP("kcminfo"),
-		I18N_NOOP("KDE Panel System Information Control Module"),
-		0, 0, KAboutData::License_GPL,
-		I18N_NOOP("(c) 1998 - 2002 Helge Deller"));
-
-    about->addAuthor("Helge Deller", 0, "deller@kde.org");
-
-    return about;
-}
-
 
 /* Helper-function to read output from an external program */
 static int GetInfo_ReadfromPipe( QListView *lBox, const char *FileName, bool WithEmptyLines = true )
