@@ -1,6 +1,4 @@
 /*
- * $Id: info_netbsd.cpp,v 1.8 2003/01/02 23:38:04 bieker Exp $
- *
  * info_netbsd.cpp is part of the KDE program kcminfo.  This displays
  * various information about the NetBSD system it's running on.
  *
@@ -276,7 +274,7 @@ bool GetInfo_Partitions (QListView *lbox)
 	int ok;
 
 	if (!pipe) {
-		kdError(0) << i18n("Ahh couldn't run /sbin/mount!") << endl;
+		kdError(0) << i18n("Unable to run /sbin/mount.") << endl;
 		return false;
 	}
 	t = new QTextStream(pipe, IO_ReadOnly);
