@@ -20,7 +20,6 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  *
- *  $Id: memory.cpp,v 1.58 2003/06/29 19:28:14 reed Exp $ 
  */
 
 #include <sys/param.h>		/* for BSD */
@@ -91,6 +90,16 @@ static QString formatted_unit(t_memsize value)
 KMemoryWidget::KMemoryWidget(QWidget * parent, const char *name)
 :  KCModule(parent, name)
 {
+
+    KAboutData *about =
+    new KAboutData(I18N_NOOP("kcminfo"),
+		I18N_NOOP("KDE Panel Memory Information Control Module"),
+		0, 0, KAboutData::License_GPL,
+		I18N_NOOP("(c) 1998 - 2002 Helge Deller"));
+
+    about->addAuthor("Helge Deller", 0, "deller@gmx.de");
+    setAboutData( about );
+
     QString title, initial_str;
     QLabel *Widget = 0;
     int i, j;
@@ -266,19 +275,6 @@ QString KMemoryWidget::quickHelp() const
 }
 
 
-const KAboutData* KMemoryWidget::aboutData() const
-{
-
-    KAboutData *about =
-    new KAboutData(I18N_NOOP("kcminfo"),
-		I18N_NOOP("KDE Panel Memory Information Control Module"),
-		0, 0, KAboutData::License_GPL,
-		I18N_NOOP("(c) 1998 - 2002 Helge Deller"));
-
-    about->addAuthor("Helge Deller", 0, "deller@gmx.de");
-    return about;
-}
-
 /* Graphical Memory Display */
 bool KMemoryWidget::Display_Graph(int widgetindex,
 				int count,
@@ -462,9 +458,9 @@ void KMemoryWidget::update_Values()
 #include "memory_sgi.cpp"
 #elif defined(__svr4__) && defined(sun)
 #include "memory_solaris.cpp"
-#elif __FreeBSD__
+#elif defined(__FreeBSD__)
 #include "memory_fbsd.cpp"
-#elif hpux
+#elif defined(hpux)
 #include "memory_hpux.cpp"
 #elif defined(__NetBSD__) || defined(__OpenBSD__)
 #include "memory_netbsd.cpp"
