@@ -24,7 +24,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 
@@ -45,6 +45,7 @@
 #include <kcmodule.h>
 
 #include "kmousedlg.h"
+#include "themepage.h"
 
 #define RIGHT_HANDED 0
 #define LEFT_HANDED  1
@@ -58,14 +59,14 @@ class MouseSettings
 public:
   void save(KConfig *);
   void load(KConfig *);
-  void apply();
+  void apply(bool force=false);
 public:
  int num_buttons;
  int middle_button;
  bool handedEnabled;
  bool m_handedNeedsApply;
  int handed;
- int accelRate;
+ double accelRate;
  int thresholdMove;
  int doubleClickInterval;
  int dragStartTime;
@@ -74,9 +75,8 @@ public:
  int autoSelectDelay;
  int visualActivate;
  bool changeCursor;
- bool largeCursor;
- bool whiteCursor;
  int wheelScrollLines;
+ bool reverseScrollPolarity;
 };
 
 class MouseConfig : public KCModule
@@ -98,21 +98,20 @@ private slots:
   void changed();
   /** No descriptions */
   void slotHandedChanged(int val);
+  void slotScrollPolarityChanged();
   void checkAccess();
 
 private:
 
-  int getAccel();
+  double getAccel();
   int getThreshold();
   int getHandedness();
 
-  void setAccel(int);
+  void setAccel(double);
   void setThreshold(int);
   void setHandedness(int);
 
-  void fixCursorFile();
-
-  KIntNumInput *accel;
+  KDoubleNumInput *accel;
   KIntNumInput *thresh;
   KIntNumInput *doubleClickInterval;
   KIntNumInput *dragStartTime;
@@ -132,6 +131,7 @@ private:
   QTabWidget *tabwidget;
   QWidget *tab2;
   KMouseDlg* tab1;
+  ThemePage* themetab;
   MouseSettings *settings;
 
   KConfig *config;
