@@ -22,18 +22,19 @@
 #include <stdlib.h>
 
 #include <qfile.h>
+#include <qxembed.h>
 
 #include <dcopclient.h>
 
-#include <kdebug.h>
-#include <kstandarddirs.h>
-#include <kcmdlineargs.h>
-#include <kdesktopfile.h>
-#include <qxembed.h>
-#include <kiconloader.h>
-#include <kmessagebox.h>
-#include <klibloader.h>
 #include <kaboutdata.h>
+#include <kcmdlineargs.h>
+#include <kdebug.h>
+#include <kdesktopfile.h>
+#include <kiconloader.h>
+#include <klibloader.h>
+#include <kmessagebox.h>
+#include <kstandarddirs.h>
+#include <kstartupinfo.h>
 #include <kwin.h>
 
 #include <kcmultidialog.h>
@@ -53,10 +54,10 @@ using namespace std;
 static KCmdLineOptions options[] =
 {
     { "list", I18N_NOOP("List all possible modules"), 0},
-    { "+module", I18N_NOOP("Configuration module to open."), 0 },
-    { "lang <language>", I18N_NOOP("Specify a particular language."), 0 },
-    { "embed <id>", I18N_NOOP("Window ID to embed into."), 0 },
-    { "silent", I18N_NOOP("Do not display main window."), 0 },
+    { "+module", I18N_NOOP("Configuration module to open"), 0 },
+    { "lang <language>", I18N_NOOP("Specify a particular language"), 0 },
+    { "embed <id>", I18N_NOOP("Window ID to embed into"), 0 },
+    { "silent", I18N_NOOP("Do not display main window"), 0 },
     KCmdLineLastOption
 };
 
@@ -80,6 +81,17 @@ static KService::Ptr locateModule(const QCString& module)
     return service;
 }
 
+KCMShellMultiDialog::KCMShellMultiDialog(QWidget *parent, const char *name, bool modal)
+  : KCMultiDialog(parent, name, modal),
+    DCOPObject("dialog")
+{
+}
+
+void KCMShellMultiDialog::activate( QCString asn_id )
+{
+    KStartupInfo::setNewStartupId( this, asn_id );
+}
+
 void
 kcmApplication::setDCOPName(const QCString &dcopName)
 {
@@ -147,7 +159,7 @@ extern "C" int kdemain(int _argc, char *_argv[])
                           KCONTROL_VERSION,
                           I18N_NOOP("A tool to start single KDE control modules"),
                           KAboutData::License_GPL,
-                          "(c) 1999-2002, The KDE Developers");
+                          "(c) 1999-2004, The KDE Developers");
 
     aboutData.addAuthor("Daniel Molkentin", I18N_NOOP("Current Maintainer"), "molkentin@kde.org");
     aboutData.addAuthor("Matthias Hoelzer-Kluepfel",0, "hoelzer@kde.org");
@@ -163,7 +175,10 @@ extern "C" int kdemain(int _argc, char *_argv[])
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
     KGlobal::iconLoader()->addAppDir( "kcontrol" );
 
-    KGlobal::locale()->setLanguage(args->getOption("lang"));
+    QCString lang = args->getOption("lang");
+    if (! lang.isNull()) {
+	KGlobal::locale()->setLanguage(lang);
+    }
 
     if (args->isSet("list")) {
 
@@ -270,18 +285,33 @@ extern "C" int kdemain(int _argc, char *_argv[])
        return 0;
     }
 
+    QCString dcopName;
+
     // multiple control modules
     KService::List modules;
     for (int i = 0; i < args->count(); i++) {
         KService::Ptr service = locateModule(args->arg(i));
-        if(service)
-            modules.append(service);
+        if (service)
+	{
+	        if (!dcopName.isEmpty())
+		   dcopName += "_";
+		dcopName += args->arg(i);
+		modules.append(service);
+		continue;
+	}
     }
 
     if (modules.count() < 1) return -1;
 
+    app.setDCOPName(dcopName);
+    if (app.isRunning())
+    {
+        app.waitForExit();
+        return 0;
+    }
+
     // create the dialog
-    KCMultiDialog * dlg = new KCMultiDialog(0, 0, true);
+    KCMultiDialog * dlg = new KCMShellMultiDialog(0, 0, true);
 
     // Needed for modules that use d'n'd (not really the right
     // solution for this though, I guess)
