@@ -141,7 +141,7 @@ void ConfigModule::runAsRoot()
   _embedFrame = new QVBox( _module->parentWidget() );
   _embedFrame->setFrameStyle( QFrame::Box | QFrame::Raised );
   QPalette pal( red );
-  pal.setColor( QColorGroup::Background, 
+  pal.setColor( QColorGroup::Background,
 		_module->parentWidget()->colorGroup().background() );
   _embedFrame->setPalette( pal );
   _embedFrame->setLineWidth( 2 );
@@ -197,7 +197,11 @@ void ConfigModule::runAsRoot()
 
       connect(_rootProcess, SIGNAL(processExited(KProcess*)), this, SLOT(rootExited(KProcess*)));
 
-      _rootProcess->start(KProcess::NotifyOnExit);
+      if ( !_rootProcess->start(KProcess::NotifyOnExit) )
+      {
+          delete _rootProcess;
+          _rootProcess = 0L;
+      }
 
       return;
     }
@@ -251,17 +255,21 @@ void ConfigModuleList::readDesktopEntries()
   readDesktopEntriesRecursive( KCGlobal::baseGroup() );
 }
 
-void ConfigModuleList::readDesktopEntriesRecursive(const QString &path)
+bool ConfigModuleList::readDesktopEntriesRecursive(const QString &path)
 {
-  Menu *menu = new Menu;
-  subMenus.insert(path, menu);
 
   KServiceGroup::Ptr group = KServiceGroup::group(path);
 
-  if (!group || !group->isValid()) return;
+  if (!group || !group->isValid()) return false;
 
   KServiceGroup::List list = group->entries(true, true);
 
+  if( list.isEmpty() )
+	  return false;
+
+  Menu *menu = new Menu;
+  subMenus.insert(path, menu);
+
   for( KServiceGroup::List::ConstIterator it = list.begin();
        it != list.end(); it++)
   {
@@ -282,12 +290,12 @@ void ConfigModuleList::readDesktopEntriesRecursive(const QString &path)
         append(module);
         menu->modules.append(module);
      }
-     else if (p->isType(KST_KServiceGroup))
-     {
-        readDesktopEntriesRecursive(p->entryPath());
-        menu->submenus.append(p->entryPath());
-     }
+     else if (p->isType(KST_KServiceGroup) && 
+		     readDesktopEntriesRecursive(p->entryPath()) )
+        	menu->submenus.append(p->entryPath());
+
   }
+  return true;
 }
 
 QPtrList<ConfigModule> ConfigModuleList::modules(const QString &path)
