@@ -134,7 +134,7 @@ void ModuleTreeView::fill(ModuleTreeItem *parent, const QString &parentPath)
 QSize ModuleTreeView::sizeHint() const
 {
     return QListView::sizeHint().boundedTo( 
-	QSize( fontMetrics().width('x')*35, QWIDGETSIZE_MAX) );
+	QSize( fontMetrics().maxWidth()*35, QWIDGETSIZE_MAX) );
 }
 
 void ModuleTreeView::makeSelected(ConfigModule *module)
@@ -182,7 +182,7 @@ void ModuleTreeView::makeVisible(ConfigModule *module)
 
   ModuleTreeItem *item = 0;
   QStringList::ConstIterator it;
-  for (it=groups.begin(); it != groups.end(); it++)
+  for (it=groups.begin(); it != groups.end(); ++it)
   {
      if (item)
         item = static_cast<ModuleTreeItem*>(item->firstChild());
@@ -199,7 +199,7 @@ void ModuleTreeView::makeVisible(ConfigModule *module)
         item = static_cast<ModuleTreeItem*>(item->nextSibling());
      }
      if (!item)
-        break; // Not found (??)
+        break; // Not found (?)
   }
 
   // make the item visible
