@@ -44,6 +44,8 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <locale.h>
+#include <pwd.h>
+#include <grp.h>
 
 typedef KGenericFactory<KDModule, QWidget> KDMFactory;
 K_EXPORT_COMPONENT_FACTORY( kcm_kdm, KDMFactory("kdmconfig") )
@@ -82,15 +84,71 @@ KDModule::KDModule(QWidget *parent, const char *name, const QStringList &)
   , maxshowuid(0)
   , updateOK(false)
 {
+  KAboutData *about =
+  new KAboutData(I18N_NOOP("kcmkdm"), I18N_NOOP("KDE Login Manager Config Module"),
+                0, 0, KAboutData::License_GPL,
+                I18N_NOOP("(c) 1996 - 2002 The KDM Authors"));
+
+  about->addAuthor("Thomas Tanghus", I18N_NOOP("Original author"), "tanghus@earthling.net");
+	about->addAuthor("Steffen Hansen", 0, "hansen@kde.org");
+	about->addAuthor("Oswald Buddenhagen", I18N_NOOP("Current maintainer"), "ossi@kde.org");
+
+  setAboutData( about );
+
   setlocale( LC_COLLATE, "C" );
 
   KGlobal::locale()->insertCatalogue("kcmbackground");
 
+  QStringList sl;
+  QMap<gid_t,QStringList> tgmap;
+  QMap<gid_t,QStringList>::Iterator tgmapi;
+  QMap<gid_t,QStringList>::ConstIterator tgmapci;
+  QMap<QString, QPair<int,QStringList> >::Iterator umapi;
+
   struct passwd *ps;
-  for (setpwent(); (ps = getpwent()); )
-    usermap.insert( QString::fromLocal8Bit( ps->pw_name ), ps->pw_uid );
+  for (setpwent(); (ps = getpwent()); ) {
+    QString un( QFile::decodeName( ps->pw_name ) );
+    if (usermap.find( un ) == usermap.end()) {
+      usermap.insert( un, QPair<int,QStringList>( ps->pw_uid, sl ) );
+      if ((tgmapi = tgmap.find( ps->pw_gid )) != tgmap.end())
+        (*tgmapi).append( un );
+      else
+	tgmap[ps->pw_gid] = un;
+    }
+  }
   endpwent();
 
+  struct group *grp;
+  for (setgrent(); (grp = getgrent()); ) {
+    QString gn( QFile::decodeName( grp->gr_name ) );
+    bool delme = false;
+    if ((tgmapi = tgmap.find( grp->gr_gid )) != tgmap.end()) {
+      if ((*tgmapi).count() == 1 && (*tgmapi).first() == gn)
+        delme = true;
+      else
+        for (QStringList::ConstIterator it = (*tgmapi).begin();
+             it != (*tgmapi).end(); ++it)
+          usermap[*it].second.append( gn );
+      tgmap.remove( tgmapi );
+    }
+    if (!*grp->gr_mem ||
+        (delme && !grp->gr_mem[1] && gn == QFile::decodeName( *grp->gr_mem )))
+      continue;
+    do {
+      QString un( QFile::decodeName( *grp->gr_mem ) );
+      if ((umapi = usermap.find( un )) != usermap.end()) {
+        if ((*umapi).second.find( gn ) == (*umapi).second.end())
+	  (*umapi).second.append( gn );
+      } else
+        kdWarning() << "group '" << gn << "' contains unknown user '" << un << "'" << endl;
+    } while (*++grp->gr_mem);
+  }
+  endgrent();
+
+  for (tgmapci = tgmap.begin(); tgmapci != tgmap.end(); ++tgmapci)
+    kdWarning() << "user(s) '" << tgmapci.data().join(",")
+	<< "' have unknown GID " << tgmapci.key() << endl;
+
   config = new KSimpleConfig( QString::fromLatin1( KDE_CONFDIR "/kdm/kdmrc" ));
 
   QVBoxLayout *top = new QVBoxLayout(this);
@@ -150,7 +208,7 @@ QString KDModule::quickHelp() const
                     "various aspects of the KDE Login Manager. This includes "
                     "the look and feel as well as the users that can be "
                     "selected for login. Note that you can only make changes "
-                    "if you run the module with superuser rights. If you haven't started the KDE "
+                    "if you run the module with superuser rights. If you have not started the KDE "
                     "Control Center with superuser rights (which is absolutely the right thing to "
                     "do, by the way), click on the <em>Modify</em> button to acquire "
                     "superuser rights. You will be asked for the superuser password."
@@ -171,20 +229,6 @@ QString KDModule::quickHelp() const
 		    "Note, that these settings are security holes by their nature, so use them very carefully.");
 }
 
-const KAboutData* KDModule::aboutData() const
-{
-   KAboutData *about =
-   new KAboutData(I18N_NOOP("kcmkdm"), I18N_NOOP("KDE Login Manager Config Module"),
-                  0, 0, KAboutData::License_GPL,
-                  I18N_NOOP("(c) 1996 - 2002 The KDM Authors"));
-
-   about->addAuthor("Thomas Tanghus", I18N_NOOP("Original author"), "tanghus@earthling.net");
-	about->addAuthor("Steffen Hansen", 0, "hansen@kde.org");
-	about->addAuthor("Oswald Buddenhagen", I18N_NOOP("Current maintainer"), "ossi@kde.org");
-
-   return about;
-}
-
 void KDModule::load()
 {
   appearance->load();
@@ -231,13 +275,23 @@ void KDModule::moduleChanged(bool state)
 
 void KDModule::propagateUsers()
 {
+  groupmap.clear();
   emit clearUsers();
   QMap<QString,int> lusers;
-  QMapConstIterator<QString,int> it;
+  QMapConstIterator<QString, QPair<int,QStringList> > it;
+  QStringList::ConstIterator jt;
+  QMap<QString,int>::Iterator gmapi;
   for (it = usermap.begin(); it != usermap.end(); ++it) {
-    int uid = it.data();
-    if (!uid || (uid >= minshowuid && uid <= maxshowuid))
+    int uid = it.data().first;
+    if (!uid || (uid >= minshowuid && uid <= maxshowuid)) {
       lusers[it.key()] = uid;
+      for (jt = it.data().second.begin(); jt != it.data().second.end(); ++jt)
+	if ((gmapi = groupmap.find( *jt )) == groupmap.end()) {
+	  groupmap[*jt] = 1;
+	  lusers['@' + *jt] = -uid;
+	} else
+	  (*gmapi)++;
+    }
   }
   emit addUsers(lusers);
   updateOK = true;
@@ -247,17 +301,35 @@ void KDModule::slotMinMaxUID(int min, int max)
 {
   if (updateOK) {
     QMap<QString,int> alusers, dlusers;
-    QMapConstIterator<QString,int> it;
+    QMapConstIterator<QString, QPair<int,QStringList> > it;
+    QStringList::ConstIterator jt;
+    QMap<QString,int>::Iterator gmapi;
     for (it = usermap.begin(); it != usermap.end(); ++it) {
-      int uid = it.data();
+      int uid = it.data().first;
       if (!uid) continue;
       if ((uid >= minshowuid && uid <= maxshowuid) &&
-	  !(uid >= min && uid <= max))
-          dlusers[it.key()] = uid;
-      else
+	  !(uid >= min && uid <= max)) {
+        dlusers[it.key()] = uid;
+	for (jt = it.data().second.begin();
+	     jt != it.data().second.end(); ++jt) {
+	  gmapi = groupmap.find( *jt );
+	  if (!--(*gmapi)) {
+	    groupmap.remove( gmapi );
+	    dlusers['@' + *jt] = -uid;
+	  }
+	}
+      } else
       if ((uid >= min && uid <= max) &&
-	  !(uid >= minshowuid && uid <= maxshowuid))
-          alusers[it.key()] = uid;
+	  !(uid >= minshowuid && uid <= maxshowuid)) {
+        alusers[it.key()] = uid;
+	for (jt = it.data().second.begin();
+	     jt != it.data().second.end(); ++jt)
+	  if ((gmapi = groupmap.find( *jt )) == groupmap.end()) {
+	    groupmap[*jt] = 1;
+	    alusers['@' + *jt] = -uid;
+	  } else
+	    (*gmapi)++;
+      }
     }
     emit delUsers(dlusers);
     emit addUsers(alusers);
