@@ -4,7 +4,7 @@
 // Author        : Craig Drummond
 // Project       : K Font Installer
 // Creation Date : 31/05/2003
-// Version       : $Revision: 1.7 $ $Date: 2003/11/01 02:07:50 $
+// Version       : $Revision: 1.10 $ $Date: 2004/04/30 21:42:46 $
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
@@ -52,9 +52,9 @@
 #include "FontEngine.h"
 //#include "config-kfile.h"
 
-#define COL_NAME    0
-#define COL_ENABLED 1
-#define COL_FONT    2
+#define COL_NAME 0
+#define COL_FILE 1
+#define COL_SIZE 2
 
 class CKFileFontView::CKFileFontViewPrivate
 {
@@ -76,8 +76,8 @@ CKFileFontView::CKFileFontView(QWidget *parent, const char *name)
     setViewName(i18n("Detailed View"));
 
     addColumn(i18n("Name"));
-    addColumn("", 24);
-    addColumn(i18n("Font"));
+    addColumn(i18n("File"));
+    addColumn(i18n("Size"));
     setShowSortIndicator(true);
     setAllColumnsShowFocus(true);
     setDragEnabled(true);
@@ -317,11 +317,13 @@ void CKFileFontView::slotSortingChanged(int col)
             break;
         // the following columns have no equivalent in QDir, so we set it
         // to QDir::Unsorted and remember the column (itsSortingCol)
-        case COL_FONT:
-        case COL_ENABLED:
+        case COL_FILE:
             // grmbl, QDir::Unsorted == SortByMask.
             sortSpec = (sort & ~QDir::SortByMask);// | QDir::Unsorted;
             break;
+        case COL_SIZE:
+            sortSpec = (sort & ~QDir::SortByMask | QDir::Size);
+            break;
         default:
             break;
     }
@@ -359,18 +361,22 @@ void CKFileFontView::slotSortingChanged(int col)
 
 void CKFileFontView::setSorting(QDir::SortSpec spec)
 {
+    if (spec & QDir::Size)
+        itsSortingCol=COL_SIZE;
+    else
+        itsSortingCol=COL_NAME;
+
     // inversed, because slotSortingChanged will reverse it
     if (spec & QDir::Reversed)
         spec = (QDir::SortSpec) (spec & ~QDir::Reversed);
     else
         spec = (QDir::SortSpec) (spec | QDir::Reversed);
 
-    itsSortingCol = COL_NAME;
     KFileView::setSorting((QDir::SortSpec) spec);
 
     // don't emit sortingChanged() when called via setSorting()
     itsBlockSortingSignal = true; // can't use blockSignals()
-    slotSortingChanged(COL_NAME);
+    slotSortingChanged(itsSortingCol);
     itsBlockSortingSignal = false;
 }
 
@@ -506,12 +512,8 @@ bool CKFileFontView::acceptDrag(QDropEvent *e) const
 
         ok=true;
         for(it=urls.begin(); ok && it!=urls.end(); ++it)
-        {
-            QCString path(QFile::encodeName((*it).path()));
-
-            if(!CFontEngine::isAFont(path) && !CFontEngine::isAAfm(path))
+            if(!CFontEngine::isAFontOrAfm(QFile::encodeName((*it).path())))
                 ok=false;
-        }
     }
 
     return ok;
@@ -623,22 +625,8 @@ void CFontListViewItem::init()
     CFontListViewItem::setPixmap(COL_NAME, itsInf->pixmap(KIcon::SizeSmall));
 
     setText(COL_NAME, itsInf->text());
-
-    if(itsInf->isDir())
-        setText(COL_FONT, "");
-    else
-    {
-        if(CFontEngine::isAAfm(QFile::encodeName(itsInf->url().path())))
-            setText(COL_FONT, i18n("Font metrics file"));
-        else
-        {
-            QString name(CGlobal::fe().createName(itsInf->url().path()));
-
-            setText(COL_FONT, name.isNull() ? i18n("Could not read font name!") : name);
-        }
-    }
-
-    setPixmap(COL_ENABLED, QChar('.')==itsInf->text()[0] ? QPixmap() : KGlobal::iconLoader()->loadIcon("ok", KIcon::Small));
+    setText(COL_FILE, itsInf->isDir() ? "" : itsInf->url().filename());
+    setText(COL_SIZE, itsInf->isDir() ? "" : KGlobal::locale()->formatNumber(itsInf->size(), 0));
 }
 
 void CKFileFontView::virtual_hook(int id, void *data)
