@@ -4,7 +4,7 @@
 // Author        : Craig Drummond
 // Project       : K Font Installer
 // Creation Date : 06/06/2003
-// Version       : $Revision: 1.6.2.3 $ $Date: 2004/05/11 21:20:22 $
+// Version       : $Revision: 1.13 $ $Date: 2004/04/27 20:09:37 $
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
@@ -54,7 +54,7 @@ static bool parseLine(const char *line, QString &ps, QString &fname, bool &isAli
 {
     static const int constMaxLen     = 127;
     static const int constFileMaxLen = 1023;
- 
+
     //
     // Format:
     // "/<psname>  (<filename>) ; "
@@ -199,6 +199,8 @@ static void addAliasEntry(QStringList &list, const QString &x11Name, const QStri
 // Create local may in fact be creating top level Fontmap - if dir==fontmap dir!
 bool CFontmap::createLocal(const QString &dir)
 {
+    KFI_DBUG << "CFontmap::createLocal(" << dir << ')' << endl;
+
     CFile       old(dir);
     QDir        d(dir);
     QStringList entries;
@@ -207,12 +209,12 @@ bool CFontmap::createLocal(const QString &dir)
     if(d.isReadable())
     {
         const QFileInfoList *files=d.entryInfoList();
- 
+
         if(files)
         {
             QFileInfoListIterator it(*files);
             QFileInfo             *fInfo;
- 
+
             for(; NULL!=(fInfo=it.current()); ++it)
                 if("."!=fInfo->fileName() && ".."!=fInfo->fileName() && !fInfo->isDir() &&
                    CFontEngine::hasAfmInfo(QFile::encodeName(fInfo->fileName())))
@@ -220,9 +222,13 @@ bool CFontmap::createLocal(const QString &dir)
                     const QStringList *existing=old.getEntries(fInfo->fileName());
 
                     if(existing && existing->count())
+                    {
+                        KFI_DBUG << "Use existing entries for " << fInfo->fileName() << endl;
                         entries+=(*existing);
+                    }
                     else
                     {
+                        KFI_DBUG << "Need to create entries for " << fInfo->fileName() << endl;
                         int face=0,
                             numFaces=0;
 
@@ -234,7 +240,7 @@ bool CFontmap::createLocal(const QString &dir)
                                 numFaces=CGlobal::fe().getNumFaces();  // Only really for TTC files...
 
                                 //
-                                // Add real 
+                                // Add real
                                 addEntry(entries, CGlobal::fe().getPsName(), fInfo->fileName());
                                 added=true;
 
@@ -278,6 +284,7 @@ bool CFontmap::createLocal(const QString &dir)
 
     if(added || entries.count()!=old.getLineCount())
     {
+        KFI_DBUG << "Output local Fontmap, " << added << ' ' << entries.count() << ' ' << old.getLineCount() << endl;
         ofstream out(QFile::encodeName(dir+"Fontmap"));
 
         if(out)
@@ -289,12 +296,14 @@ bool CFontmap::createLocal(const QString &dir)
             return true;
         }
     }
+
     return false;
 }
 
 void CFontmap::createTopLevel()
 {
-    //              
+    KFI_DBUG << "CFontmap::createTopLevel" << endl;
+    //
     // Cat each sub-folders top-level fontmap file to top-level one...
 
     QStringList xDirs;
@@ -307,7 +316,10 @@ void CFontmap::createTopLevel()
     if(!CMisc::root() && 1==xDirs.count() && xDirs.first()==CGlobal::cfg().getFontmapDir())
     {
         if(!CMisc::fExists(CGlobal::cfg().getFontmapDir()+"Fontmap"))
+        {
+            KFI_DBUG << "Not root, and the 1 and only fonts dir is the GS dir" << endl;
             createLocal(CGlobal::cfg().getFontmapDir());
+        }
     }
     else
     {
@@ -362,6 +374,8 @@ void CFontmap::createTopLevel()
             }
         }
 
+        KFI_DBUG << "Save top-level Fontmap" << endl;
+
         ofstream of(QFile::encodeName(CGlobal::cfg().getFontmapDir()+"Fontmap"));
 
         if(of)
@@ -372,7 +386,7 @@ void CFontmap::createTopLevel()
         CMisc::setTimeStamps(CGlobal::cfg().getFontmapDir());
 
         if(CMisc::root() && !CGlobal::cfg().getGhostscriptFile().isEmpty())  // Now ensure GS's Fontmap file .runlibfile's
-        {                                                                    // our Fontmap file!
+        {                                                                    //  our Fontmap file!
             const int constMaxLineLen=1024;
             const char *constRLF=".runlibfile";
 
@@ -457,6 +471,8 @@ void CFontmap::createTopLevel()
 
                         if(added) // Don't re-write GS's Fontmap unless we've actually added something...
                         {
+                            KFI_DBUG << "Modify GS's Fontmap" << endl;
+
                             ofstream out(QFile::encodeName(CGlobal::cfg().getGhostscriptFile()));
 
                             if(out)
