@@ -16,26 +16,20 @@
  *  along with this program; if not, write to the Free Software
  */
 
-#include <qwhatsthis.h>
 #include <qcheckbox.h>
+#include <qgroupbox.h>
 #include <qheader.h>
-#include <qlabel.h>
-#include <qstring.h>
 #include <qslider.h>
 #include <qradiobutton.h>
-#include <qgroupbox.h>
-#include <qbuttongroup.h>
 
-#include <kconfig.h>
 #include <kcombobox.h>
-#include <kglobal.h>
-#include <knuminput.h>
 #include <klocale.h>
-#include <kstandarddirs.h>
+#include <knuminput.h>
 
 #include "main.h"
 #include "hidingtab_impl.h"
 #include "hidingtab_impl.moc"
+#include "positiontab_impl.h"
 
 
 HidingTab::HidingTab( KickerConfig *kcmKicker, const char* name )
@@ -43,8 +37,6 @@ HidingTab::HidingTab( KickerConfig *kcmKicker, const char* name )
     m_kcm(kcmKicker),
     m_panelInfo(0)
 {
-    m_panelList->setSorting(-1);
-    m_panelList->header()->hide();
     // connections
     connect(m_manual,SIGNAL(toggled(bool)), SIGNAL(changed()));
     connect(m_automatic, SIGNAL(toggled(bool)), SIGNAL(changed()));
@@ -66,52 +58,56 @@ HidingTab::HidingTab( KickerConfig *kcmKicker, const char* name )
 
 void HidingTab::load()
 {
-    m_panelList->clear();
+    m_panelInfo = 0;
     m_kcm->populateExtensionInfoList(m_panelList);
-    if (m_kcm->extensionsInfo().count() == 1)
-    {
-        m_panelList->hide();
-    }
+    m_panelsGroupBox->setHidden(m_panelList->count() < 2);
 
     switchPanel(0);
 }
 
 void HidingTab::extensionAdded(extensionInfo* info)
 {
-    new extensionInfoItem(info, m_panelList, m_panelList->lastItem());
+    m_panelList->insertItem(info->_name);
+    m_panelsGroupBox->setHidden(m_panelList->count() < 2);
 }
 
 void HidingTab::removeExtension(extensionInfo* info)
 {
-    // remove it from the hidingtab
-    extensionInfoItem* extItem = static_cast<extensionInfoItem*>(m_panelList->firstChild());
-
-    while (extItem)
+    int count = m_panelList->count();
+    int extensionCount = m_kcm->extensionsInfo().count();
+    int index = 0;
+    for (; index < count && index < extensionCount; ++index)
     {
-        if (extItem->info() == info)
+        if (m_kcm->extensionsInfo()[index] == info)
         {
-            bool current = extItem->isSelected();
-            delete extItem;
-            if (current)
-            {
-                m_panelList->setSelected(m_panelList->firstChild(), true);
-            }
             break;
         }
+    }
 
-        extItem = static_cast<extensionInfoItem*>(extItem->nextSibling());
+    bool isCurrentlySelected = index == m_panelList->currentItem();
+    m_panelList->removeItem(index);
+    m_panelsGroupBox->setHidden(m_panelList->count() < 2);
+
+    if (isCurrentlySelected)
+    {
+        m_panelList->setCurrentItem(0);
     }
 }
 
-void HidingTab::switchPanel(QListViewItem* panelItem)
+void HidingTab::switchPanel(int panelItem)
 {
     blockSignals(true);
-    extensionInfoItem* listItem = reinterpret_cast<extensionInfoItem*>(panelItem);
+    extensionInfo* panelInfo = (m_kcm->extensionsInfo())[panelItem];
 
-    if (!listItem)
+    if (!panelInfo)
     {
-        m_panelList->setSelected(m_panelList->firstChild(), true);
-        listItem = reinterpret_cast<extensionInfoItem*>(m_panelList->firstChild());
+        m_panelList->setCurrentItem(0);
+        panelInfo = (m_kcm->extensionsInfo())[panelItem];
+
+        if (!panelInfo)
+        {
+            return;
+        }
     }
 
     if (m_panelInfo)
@@ -119,7 +115,7 @@ void HidingTab::switchPanel(QListViewItem* panelItem)
         storeInfo();
     }
 
-    m_panelInfo = listItem->info();
+    m_panelInfo = panelInfo;
 
     if(m_panelInfo->_autohidePanel)
     {
@@ -153,6 +149,8 @@ void HidingTab::switchPanel(QListViewItem* panelItem)
         m_backgroundRaise->setChecked(false);
     }
 
+    panelPositionChanged(m_panelInfo->_position);
+
     backgroundModeClicked();
     blockSignals(false);
 }
@@ -199,6 +197,21 @@ void HidingTab::defaults()
     m_backgroundRaise->setChecked( false );
 }
 
+void HidingTab::panelPositionChanged(int position)
+{
+    if (position == PositionTab::PosTop ||
+        position == PositionTab::PosBottom)
+    {
+        m_lHB->setText(i18n("Show left panel-hiding bu&tton"));
+        m_rHB->setText(i18n("Show right panel-hiding bu&tton"));
+    }
+    else
+    {
+        m_lHB->setText(i18n("Show top panel-hiding bu&tton"));
+        m_rHB->setText(i18n("Show bottom panel-hiding bu&tton"));
+    }
+}
+
 int HidingTab::triggerComboToConfig(int trigger)
 {
     if (trigger == 0)
