@@ -1,6 +1,4 @@
 /*
-    $Id: knotify.cpp,v 1.70.2.1 2004/05/29 13:12:11 villat Exp $
-
     Copyright (C) 2000,2002 Carsten Pfeiffer <pfeiffer@kde.org>
 
     This program is free software; you can redistribute it and/or
@@ -73,6 +71,15 @@ KCMKNotify::KCMKNotify(QWidget *parent, const char *name, const QStringList & )
     connect( m_notifyWidget->m_playerButton, SIGNAL( clicked() ),
              SLOT( slotPlayerSettings()));
 
+    KAboutData* ab = new KAboutData(
+        "kcmnotify", I18N_NOOP("KNotify"), "3.0",
+        I18N_NOOP("System Notification Control Panel Module"),
+        KAboutData::License_GPL, "(c) 2002 Carsten Pfeiffer", 0, 0 );
+    ab->addAuthor( "Carsten Pfeiffer", 0, "pfeiffer@kde.org" );
+    ab->addCredit( "Charles Samuels", I18N_NOOP("Original implementation"),
+	       "charles@altair.dhs.org" );
+    setAboutData( ab );
+
     load();
 }
 
@@ -139,7 +146,7 @@ void KCMKNotify::load()
     for ( ; it != fullpaths.end(); ++it) 
         m_notifyWidget->addApplicationEvents( *it );
 
-    ApplicationList& allApps = m_notifyWidget->allApps();
+    ApplicationList allApps = m_notifyWidget->allApps();
     allApps.sort();
     m_notifyWidget->setEnabled( !allApps.isEmpty() );
 
@@ -185,24 +192,6 @@ QString KCMKNotify::quickHelp() const
                 "</ul>");
 }
 
-const KAboutData *KCMKNotify::aboutData() const
-{
-    static KAboutData* ab = 0;
-
-    if(!ab)
-    {
-        ab = new KAboutData(
-            "kcmnotify", I18N_NOOP("KNotify"), "3.0",
-            I18N_NOOP("System Notification Control Panel Module"),
-            KAboutData::License_GPL, "(c) 2002 Carsten Pfeiffer", 0, 0 );
-        ab->addAuthor( "Carsten Pfeiffer", 0, "pfeiffer@kde.org" );
-        ab->addCredit( "Charles Samuels", I18N_NOOP("Original implementation"),
-                       "charles@altair.dhs.org" );
-    }
-
-    return ab;
-}
-
 ///////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////
 
@@ -224,15 +213,32 @@ PlayerSettingsDialog::PlayerSettingsDialog( QWidget *parent, bool modal )
     hbox->addWidget( cbExternal );
     hbox->addWidget( reqExternal );
 
-    hbox = new QHBoxLayout( topLayout, KDialog::spacingHint() );
-    volumeLabel = new QLabel( i18n( "&Volume: " ), frame );
-    volumeSlider = new QSlider( frame );
-    volumeSlider->setOrientation( Horizontal );
-    volumeSlider->setRange( 0, 100 );
-    volumeLabel->setBuddy( volumeSlider );
-    hbox->addWidget( volumeLabel );
-    hbox->addWidget( volumeSlider );
+    volumeGroupBox = new QGroupBox( frame, "volumeGroupBox" );
+    volumeGroupBox->setTitle( i18n( "Volume" ) );
+    volumeGroupBox->setColumnLayout(0, Qt::Vertical );
+    // Use KDialog::spacingHint() ?
+    volumeGroupBox->layout()->setSpacing( 6 );
+    volumeGroupBox->layout()->setMargin( 11 );
+    QGridLayout *volumeGroupBoxLayout = new QGridLayout( volumeGroupBox->layout() );
+    volumeGroupBoxLayout->setAlignment( Qt::AlignTop );
 
+    volumeSlider = new QSlider( volumeGroupBox, "volumeSlider" );
+    volumeSlider->setOrientation( QSlider::Horizontal );
+    volumeSlider->setRange( 0, 100 );
+    volumeGroupBoxLayout->addMultiCellWidget( volumeSlider, 0, 0, 0, 2 );
+
+    QLabel *minLabel = new QLabel( volumeGroupBox, "minLabel" );
+    minLabel->setText(("0"));
+    volumeGroupBoxLayout->addWidget( minLabel, 1, 0 );
+
+    QLabel *maxLabel = new QLabel( volumeGroupBox, "maxLabel" );
+    maxLabel->setText(("100"));
+    volumeGroupBoxLayout->addWidget( maxLabel, 1, 2 );
+    
+    QSpacerItem *spacer1 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+    volumeGroupBoxLayout->addItem( spacer1, 1, 1 );
+
+    topLayout->addWidget(volumeGroupBox);
     load();
     dataChanged = false;
     enableButton(Apply, false);
@@ -290,8 +296,7 @@ void PlayerSettingsDialog::slotChanged()
 void PlayerSettingsDialog::externalToggled( bool on )
 {
     reqExternal->setEnabled( on );
-    volumeSlider->setEnabled( !on );
-    volumeLabel->setEnabled( !on );
+    volumeGroupBox->setEnabled( !on );
 
     if ( on )
         reqExternal->setFocus();
