@@ -1,6 +1,4 @@
 /*
-    $Id: knotify.h,v 1.27 2003/07/26 10:41:20 mueller Exp $
-
     Copyright (C) 2000,2002 Carsten Pfeiffer <pfeiffer@kde.org>
 
 
@@ -55,7 +53,6 @@ public:
 
     virtual void defaults();
     virtual void save();
-    virtual const KAboutData *aboutData() const;
     virtual QString quickHelp() const;
 
 public slots:
@@ -92,8 +89,8 @@ protected slots:
 private:
     QCheckBox *cbExternal;
     KURLRequester *reqExternal;
+    QGroupBox *volumeGroupBox;
     QSlider *volumeSlider;
-    QLabel *volumeLabel;
     bool dataChanged;
 
 };
