@@ -13,27 +13,19 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 // Behaviour options for konqueror
 
 #include <qcheckbox.h>
-#include <qgroupbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qlineedit.h>
-#include <qspinbox.h>
-#include <qslider.h>
 #include <qwhatsthis.h>
 #include <qvbuttongroup.h>
 #include <qvgroupbox.h>
 #include <qvbox.h>
-#include <qradiobutton.h>
 #include <kconfig.h>
-#include <kdialog.h>
-#include <kglobal.h>
-#include <kiconloader.h>
 #include <klocale.h>
 #include <konq_defaults.h>
 #include <kstandarddirs.h>
@@ -49,10 +41,7 @@ KBehaviourOptions::KBehaviourOptions(KConfig *config, QString group, QWidget *pa
 {
     QLabel * label;
 
-    QVBoxLayout *lay = new QVBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint() );
-
-    kfmclientConfig = new KConfig(QString::fromLatin1("kfmclientrc"), false, false);
-    kfmclientConfig->setGroup(QString::fromLatin1("Settings")); //use these to set the one-process option in kfmclient
+    QVBoxLayout *lay = new QVBoxLayout( this, 0, KDialog::spacingHint() );
 
 	QVGroupBox * miscGb = new QVGroupBox(i18n("Misc Options"), this);
 	lay->addWidget( miscGb );
@@ -70,9 +59,9 @@ KBehaviourOptions::KBehaviourOptions(KConfig *config, QString group, QWidget *pa
 
    // ----
 
-    cbNewWin = new QCheckBox(i18n("&Open directories in separate windows"), vbox);
+    cbNewWin = new QCheckBox(i18n("Open folders in separate &windows"), vbox);
     QWhatsThis::add( cbNewWin, i18n("If this option is checked, Konqueror will open a new window when "
-                                    "you open a directory, rather than showing that directory's contents in the current window."));
+                                    "you open a folder, rather than showing that folders's contents in the current window."));
     connect(cbNewWin, SIGNAL(clicked()), this, SLOT(changed()));
     connect(cbNewWin, SIGNAL(toggled(bool)), SLOT(updateWinPixmap(bool)));
 
@@ -89,7 +78,7 @@ KBehaviourOptions::KBehaviourOptions(KConfig *config, QString group, QWidget *pa
 
     // --
 
-    cbShowTips = new QCheckBox( i18n( "&Show file tips" ), vbox );
+    cbShowTips = new QCheckBox( i18n( "Show file &tips" ), vbox );
     connect(cbShowTips, SIGNAL(clicked()), this, SLOT(changed()));
 
     QWhatsThis::add( cbShowTips, i18n("Here you can control if, when moving the mouse over a file, you want to see a "
@@ -106,12 +95,23 @@ KBehaviourOptions::KBehaviourOptions(KConfig *config, QString group, QWidget *pa
     QWhatsThis::add( fileTips, tipstr );
     QWhatsThis::add( sbToolTip, tipstr );
 */
-    cbShowPreviewsInTips = new QCheckBox( i18n( "&Show previews in file tips" ), vbox );
+
+    QHBox *hboxpreview = new QHBox(vbox);
+    QWidget* spacer = new QWidget( hboxpreview );
+    spacer->setMinimumSize( 20, 0 );
+    spacer->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Minimum );
+
+    cbShowPreviewsInTips = new QCheckBox( i18n( "Show &previews in file tips" ), hboxpreview );
     connect(cbShowPreviewsInTips, SIGNAL(clicked()), this, SLOT(changed()));
 
     QWhatsThis::add( cbShowPreviewsInTips, i18n("Here you can control if you want the "
                           "popup window to contain a larger preview for the file, when moving the mouse over it."));
 
+    cbRenameDirectlyIcon = new QCheckBox(i18n("Rename icons in&line"), vbox);
+    QWhatsThis::add(cbRenameDirectlyIcon, i18n("Checking this option will allow files to be "
+                                               "renamed by clicking directly on the icon name. "));
+    connect(cbRenameDirectlyIcon, SIGNAL(clicked()), this, SLOT(changed()));
+
 	QHBoxLayout *hlay = new QHBoxLayout( lay );
 
     label = new QLabel(i18n("Home &URL:"), this);
@@ -119,89 +119,51 @@ KBehaviourOptions::KBehaviourOptions(KConfig *config, QString group, QWidget *pa
 
 	homeURL = new KURLRequester(this);
 	homeURL->setMode(KFile::Directory);
-	homeURL->setCaption(i18n("Select Home Directory"));
+	homeURL->setCaption(i18n("Select Home Folder"));
 	hlay->addWidget( homeURL );
     connect(homeURL, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
     label->setBuddy(homeURL);
 
-    QString homestr = i18n("This is the URL (e.g. a directory or a web page) where "
+    QString homestr = i18n("This is the URL (e.g. a folder or a web page) where "
                            "Konqueror will jump to when the \"Home\" button is pressed. "
-						   "This usually is your home directory, symbolized by a 'tilde' (~).");
+						   "This is usually your home folder, symbolized by a 'tilde' (~).");
     QWhatsThis::add( label, homestr );
     QWhatsThis::add( homeURL, homestr );
 
+    lay->addItem(new QSpacerItem(0,20,QSizePolicy::Fixed,QSizePolicy::Fixed));
+
+    cbShowDeleteCommand = new QCheckBox( i18n( "Show 'Delete' me&nu entries which bypass the trashcan" ), this );
+    lay->addWidget( cbShowDeleteCommand );
+    connect(cbShowDeleteCommand, SIGNAL(clicked()), this, SLOT(changed()));
+
+    QWhatsThis::add( cbShowDeleteCommand, i18n("Uncheck this if you do not want 'Delete' menu commands to be displayed "
+                                                "on the desktop and in the file manager's menus and context menus."));
 
     QButtonGroup *bg = new QVButtonGroup( i18n("Ask Confirmation For"), this );
     bg->layout()->setSpacing( KDialog::spacingHint() );
     QWhatsThis::add( bg, i18n("This option tells Konqueror whether to ask"
        " for a confirmation when you \"delete\" a file."
-       " <ul><li><em>Move To Trash:</em> moves the file to your trash directory,"
+       " <ul><li><em>Move To Trash:</em> moves the file to your trash folder,"
        " from where it can be recovered very easily.</li>"
        " <li><em>Delete:</em> simply deletes the file.</li>"
-       " <li><em>Shred:</em> not only deletes the file, but overwrites"
-       " the area on the disk where the file is stored, making recovery impossible."
-       " You should not remove confirmation for this method unless you routinely work"
-       " with very confidential information.</li></ul>") );
+       " </li></ul>") );
 
     connect(bg, SIGNAL( clicked( int ) ), SLOT( changed() ));
 
-    cbMoveToTrash = new QCheckBox( i18n("Move to trash"), bg );
+    cbMoveToTrash = new QCheckBox( i18n("&Move to trash"), bg );
 
-    cbDelete = new QCheckBox( i18n("Delete"), bg );
-
-    cbShred = new QCheckBox( i18n("Shred"), bg );
+    cbDelete = new QCheckBox( i18n("D&elete"), bg );
+    connect(cbShowDeleteCommand, SIGNAL(toggled(bool)), cbDelete, SLOT(setEnabled(bool)));
 
     lay->addWidget(bg);
 
-
-    QString opstrg = i18n("With this option activated, only one instance of Konqueror "
-                          "will exist in the memory of your computer at any moment, "
-                          "no matter how many browsing windows you open, "
-                          "thus reducing resource requirements."
-                          "<p>Be aware that this also means that, if something goes wrong, "
-                          "all your browsing windows will be closed simultaneously.");
-    QString opstrl = i18n("With this option activated, only one instance of Konqueror "
-                          "will exist in the memory of your computer at any moment, "
-                          "no matter how many local browsing windows you open, "
-                          "thus reducing resource requirements."
-                          "<p>Be aware that this also means that, if something goes wrong, "
-                          "all your local browsing windows will be closed simultaneously");
-    QString opstrw = i18n("With this option activated, only one instance of Konqueror "
-                          "will exist in the memory of your computer at any moment, "
-                          "no matter how many web browsing windows you open, "
-                          "thus reducing resource requirements."
-                          "<p>Be aware that this also means that, if something goes wrong, "
-                          "all your web browsing windows will be closed simultaneously");
-
-    bgOneProcess = new QVButtonGroup(i18n("Minimize Memory Usage"), this);
-    bgOneProcess->setExclusive( true );
-    connect(bgOneProcess, SIGNAL(clicked(int)), this, SLOT(changed()));
-    {
-        rbOPNever = new QRadioButton(i18n("&Never"), bgOneProcess);
-        QWhatsThis::add( rbOPNever, i18n("Disables the minimization of memory usage and allows you "
-                                         "to make each browsing activity independent from the others"));
-
-        rbOPLocal = new QRadioButton(i18n("For &local browsing only (recommended)"), bgOneProcess);
-        QWhatsThis::add( rbOPLocal, opstrl);
-
-        rbOPWeb = new QRadioButton(i18n("For &Web browsing only"), bgOneProcess);
-        QWhatsThis::add( rbOPWeb, opstrw);
-
-        rbOPAlways = new QRadioButton(i18n("Alwa&ys (use with care)"), bgOneProcess);
-        QWhatsThis::add( rbOPAlways, opstrg);
-
-        rbOPLocal->setChecked(true);
-    }
-
-	lay->addWidget( bgOneProcess );
-	lay->addStretch();
+    lay->addStretch();
 
     load();
 }
 
 KBehaviourOptions::~KBehaviourOptions()
 {
-    delete kfmclientConfig;
 }
 
 void KBehaviourOptions::slotShowTips(bool b)
@@ -218,7 +180,7 @@ void KBehaviourOptions::load()
     cbNewWin->setChecked( g_pConfig->readBoolEntry("AlwaysNewWin", false) );
     updateWinPixmap(cbNewWin->isChecked());
 
-    homeURL->setURL(g_pConfig->readPathEntry("HomeURL"));
+    homeURL->setURL(g_pConfig->readPathEntry("HomeURL", "~"));
 
     bool stips = g_pConfig->readBoolEntry( "ShowFileTips", true );
     cbShowTips->setChecked( stips );
@@ -227,25 +189,14 @@ void KBehaviourOptions::load()
     bool showPreviewsIntips = g_pConfig->readBoolEntry( "ShowPreviewsInFileTips", true );
     cbShowPreviewsInTips->setChecked( showPreviewsIntips );
 
+    cbRenameDirectlyIcon->setChecked( g_pConfig->readBoolEntry("RenameIconDirectly",  DEFAULT_RENAMEICONDIRECTLY ) );
+    cbShowDeleteCommand->setChecked( g_pConfig->readBoolEntry("ShowDeleteCommand", true) );
+
 //    if (!stips) sbToolTip->setEnabled( false );
     if (!stips) cbShowPreviewsInTips->setEnabled( false );
 
 //    sbToolTip->setValue( g_pConfig->readNumEntry( "FileTipItems", 6 ) );
 
-    QString val = kfmclientConfig->readEntry( QString::fromLatin1("StartNewKonqueror"),
-                                              QString::fromLatin1("Web only") );
-    if (val == QString::fromLatin1("Web only"))
-        rbOPLocal->setChecked(true);
-    else if (val == QString::fromLatin1("Local only"))
-        rbOPWeb->setChecked(true);
-    else if (val == QString::fromLatin1("Always") ||
-             val == QString::fromLatin1("true") ||
-             val == QString::fromLatin1("TRUE") ||
-             val == QString::fromLatin1("1"))
-        rbOPNever->setChecked(true);
-    else
-        rbOPAlways->setChecked(true);
-
     KConfig config("uiserverrc");
     config.setGroup( "UIServer" );
 
@@ -254,7 +205,7 @@ void KBehaviourOptions::load()
     g_pConfig->setGroup( "Trash" );
     cbMoveToTrash->setChecked( g_pConfig->readBoolEntry("ConfirmTrash", DEFAULT_CONFIRMTRASH) );
     cbDelete->setChecked( g_pConfig->readBoolEntry("ConfirmDelete", DEFAULT_CONFIRMDELETE) );
-    cbShred->setChecked( g_pConfig->readBoolEntry("ConfirmShred", DEFAULT_CONFIRMSHRED) );
+    cbDelete->setEnabled( cbShowDeleteCommand->isChecked() );
 }
 
 void KBehaviourOptions::defaults()
@@ -263,8 +214,6 @@ void KBehaviourOptions::defaults()
 
     homeURL->setURL("~");
 
-    rbOPLocal->setChecked(true);
-
     cbListProgress->setChecked( false );
 
     cbShowTips->setChecked( true );
@@ -274,9 +223,12 @@ void KBehaviourOptions::defaults()
     cbShowPreviewsInTips->setChecked( true );
     cbShowPreviewsInTips->setEnabled( true );
 
+    cbRenameDirectlyIcon->setChecked( DEFAULT_RENAMEICONDIRECTLY );
+
     cbMoveToTrash->setChecked( DEFAULT_CONFIRMTRASH );
     cbDelete->setChecked( DEFAULT_CONFIRMDELETE );
-    cbShred->setChecked( DEFAULT_CONFIRMSHRED );
+    cbDelete->setEnabled( true );
+    cbShowDeleteCommand->setChecked( true );
 }
 
 void KBehaviourOptions::save()
@@ -284,29 +236,20 @@ void KBehaviourOptions::save()
     g_pConfig->setGroup( groupname );
 
     g_pConfig->writeEntry( "AlwaysNewWin", cbNewWin->isChecked() );
-    g_pConfig->writeEntry( "HomeURL", homeURL->url().isEmpty()? "~" : homeURL->url() );
+    g_pConfig->writePathEntry( "HomeURL", homeURL->url().isEmpty()? QString("~") : homeURL->url() );
 
     g_pConfig->writeEntry( "ShowFileTips", cbShowTips->isChecked() );
     g_pConfig->writeEntry( "ShowPreviewsInFileTips", cbShowPreviewsInTips->isChecked() );
 //    g_pConfig->writeEntry( "FileTipsItems", sbToolTip->value() );
 
-    QString val = QString::fromLatin1("Web only");
-    if (rbOPWeb->isChecked())
-        val = QString::fromLatin1("Local only");
-    else if (rbOPNever->isChecked())
-        val = QString::fromLatin1("Always");
-    else if (rbOPAlways->isChecked())
-        val = QString::fromLatin1("Never");
+    g_pConfig->writeEntry( "RenameIconDirectly", cbRenameDirectlyIcon->isChecked());
+    g_pConfig->writeEntry( "ShowDeleteCommand", cbShowDeleteCommand->isChecked());
 
     g_pConfig->setGroup( "Trash" );
     g_pConfig->writeEntry( "ConfirmTrash", cbMoveToTrash->isChecked());
     g_pConfig->writeEntry( "ConfirmDelete", cbDelete->isChecked());
-    g_pConfig->writeEntry( "ConfirmShred", cbShred->isChecked());
     g_pConfig->sync();
 
-    kfmclientConfig->writeEntry(QString::fromLatin1("StartNewKonqueror"), val);
-    kfmclientConfig->sync();
-
     // UIServer setting
     KConfig config("uiserverrc");
     config.setGroup( "UIServer" );
@@ -320,11 +263,11 @@ void KBehaviourOptions::save()
     }
 
     // Send signal to konqueror
-    // Warning. In case something is added/changed here, keep kfmclient in sync
     QByteArray data;
     if ( !kapp->dcopClient()->isAttached() )
       kapp->dcopClient()->attach();
     kapp->dcopClient()->send( "konqueror*", "KonquerorIface", "reparseConfiguration()", data );
+    kapp->dcopClient()->send( "kdesktop", "KDesktopIface", "configure()", data );
 }
 
 void KBehaviourOptions::updateWinPixmap(bool b)
