@@ -7,7 +7,9 @@
 #include <qlabel.h>
 #include <kcharsets.h>
 #include <kdebug.h>
+#if defined Q_WS_X11 && !defined K_WS_QTONLY
 #include <X11/Xlib.h>
+#endif
 #include <kfontcombo.h>
 #include <knuminput.h>
 #include <kdialog.h>
@@ -208,7 +210,7 @@ KAppearanceOptions::KAppearanceOptions(KConfig *config, QString group, QWidget *
   m_pEncoding->insertStringList( encodings );
   lay->addMultiCellWidget(m_pEncoding,r, r, M, W);
 
-  wtstr = i18n( "Select the default encoding to be used. Normally, you'll be fine with 'Use language encoding' "
+  wtstr = i18n( "Select the default encoding to be used; normally, you will be fine with 'Use language encoding' "
 	       "and should not have to change this.");
   QWhatsThis::add( label, wtstr );
   QWhatsThis::add( m_pEncoding, wtstr );
@@ -313,7 +315,7 @@ void KAppearanceOptions::load()
 #define READ_LIST(x) m_pConfig->readListEntry(x, khtmlrc.readListEntry(x))
 
     SET_GROUP(m_groupname);
-    fSize = READ_NUM( "MediumFontSize", 10 );
+    fSize = READ_NUM( "MediumFontSize", 12 );
     fMinSize = READ_NUM( "MinimumFontSize", HTML_DEFAULT_MIN_FONT_SIZE );
     if (fSize < fMinSize)
       fSize = fMinSize;
