@@ -37,6 +37,22 @@ KMiscHTMLOptions::KMiscHTMLOptions(KConfig *config, QString group, QWidget *pare
     int row = 0;
     QGridLayout *lay = new QGridLayout(this, 10, 2, 0, KDialog::spacingHint());
 
+    // Bookmarks
+
+    QVGroupBox *bgBookmarks = new QVGroupBox( i18n("Boo&kmarks"), this );
+    m_pAdvancedAddBookmarkCheckBox = new QCheckBox(i18n( "Ask for name and folder when adding bookmarks" ), bgBookmarks);
+    QWhatsThis::add( m_pAdvancedAddBookmarkCheckBox, i18n( "If this box is checked, Konqueror will allow you to"
+                                                        " change the title of the bookmark and choose a folder in which to store it when you add a new bookmark." ) );
+    connect(m_pAdvancedAddBookmarkCheckBox, SIGNAL(clicked()), this, SLOT(slotChanged()));
+
+    m_pOnlyMarkedBookmarksCheckBox = new QCheckBox(i18n( "Show only marked bookmarks in bookmark toolbar" ), bgBookmarks);
+    QWhatsThis::add( m_pOnlyMarkedBookmarksCheckBox, i18n( "If this box is checked, Konqueror will show only those"
+                                                         " bookmarks in the bookmark toolbar which you have marked to do so in the bookmark editor." ) );
+    connect(m_pOnlyMarkedBookmarksCheckBox, SIGNAL(clicked()), this, SLOT(slotChanged()));
+
+    lay->addMultiCellWidget( bgBookmarks, row, row, 0, 1 );
+    row++;
+
      // Form completion
 
     QVGroupBox *bgForm = new QVGroupBox( i18n("Form Com&pletion"), this );
@@ -80,25 +96,32 @@ KMiscHTMLOptions::KMiscHTMLOptions(KConfig *config, QString group, QWidget *pare
     lay->addMultiCellWidget( bgTabbedBrowsing, row, row, 0, 1 );
     row++;
 
-    // Misc
+    // Mouse behavior
 
-    cbCursor = new QCheckBox(i18n("Chan&ge cursor over links"), this);
-    lay->addMultiCellWidget(cbCursor, row, row, 0, 1);
-    row++;
+    QVGroupBox *bgMouse = new QVGroupBox( i18n("Mouse Beha&vior"), this );
 
-    QWhatsThis::add( cbCursor, i18n("If this option is set, the shape of the cursor will change "
+    m_cbCursor = new QCheckBox(i18n("Chan&ge cursor over links"), bgMouse );
+    QWhatsThis::add( m_cbCursor, i18n("If this option is set, the shape of the cursor will change "
        "(usually to a hand) if it is moved over a hyperlink.") );
+    connect(m_cbCursor, SIGNAL(clicked()), this, SLOT(slotChanged()));
 
-    connect(cbCursor, SIGNAL(clicked()), this, SLOT(slotChanged()));
+    m_pOpenMiddleClick = new QCheckBox( i18n ("M&iddle click opens URL in selection" ), bgMouse );
+    QWhatsThis::add( m_pOpenMiddleClick, i18n (
+      "If this box is checked, you can open the URL in the selection by middle clicking on a "
+      "Konqueror view." ) );
+    connect(m_pOpenMiddleClick, SIGNAL(clicked()), this, SLOT(slotChanged()));
 
-    m_pBackRightClick = new QCheckBox( i18n( "Right click goes &back in history" ), this );
+    m_pBackRightClick = new QCheckBox( i18n( "Right click goes &back in history" ), bgMouse );
     QWhatsThis::add( m_pBackRightClick, i18n(
       "If this box is checked, you can go back in history by right clicking on a Konqueror view. "
       "To access the context menu, press the right mouse button and move." ) );
-    lay->addMultiCellWidget( m_pBackRightClick, row, row, 0, 1);
-    row++;
     connect(m_pBackRightClick, SIGNAL(clicked()), this, SLOT(slotChanged()));
 
+    lay->addMultiCellWidget( bgMouse, row, row, 0, 1 );
+    row++;
+
+    // Misc
+
     m_pAutoLoadImagesCheckBox = new QCheckBox( i18n( "A&utomatically load images"), this );
     QWhatsThis::add( m_pAutoLoadImagesCheckBox, i18n( "If this box is checked, Konqueror will automatically load any images that are embedded in a web page. Otherwise, it will display placeholders for the images, and you can then manually load the images by clicking on the image button.<br>Unless you have a very slow network connection, you will probably want to check this box to enhance your browsing experience." ) );
     connect(m_pAutoLoadImagesCheckBox, SIGNAL(clicked()), this, SLOT(slotChanged()));
@@ -177,6 +200,7 @@ void KMiscHTMLOptions::load()
 
     // *** load ***
     SET_GROUP( "MainView Settings" );
+    bool bOpenMiddleClick = READ_BOOL( "OpenMiddleClick", true );
     bool bBackRightClick = READ_BOOL( "BackRightClick", false );
     SET_GROUP( "HTML Settings" );
     bool changeCursor = READ_BOOL("ChangeCursor", KDE_DEFAULT_CHANGECURSOR);
@@ -188,9 +212,10 @@ void KMiscHTMLOptions::load()
     bool bAutoRedirect = m_pConfig->readBoolEntry( "AutoDelayedActions", true );
 
     // *** apply to GUI ***
-    cbCursor->setChecked( changeCursor );
+    m_cbCursor->setChecked( changeCursor );
     m_pAutoLoadImagesCheckBox->setChecked( bAutoLoadImages );
     m_pAutoRedirectCheckBox->setChecked( bAutoRedirect );
+    m_pOpenMiddleClick->setChecked( bOpenMiddleClick );
     m_pBackRightClick->setChecked( bBackRightClick );
 
     // we use two keys for link underlining so that this config file
@@ -221,6 +246,11 @@ void KMiscHTMLOptions::load()
     m_pConfig->setGroup("FMSettings");
     m_pShowMMBInTabs->setChecked( m_pConfig->readBoolEntry( "MMBOpensTab", false ) );
     m_pDynamicTabbarHide->setChecked( ! (m_pConfig->readBoolEntry( "AlwaysTabbedMode", false )) );
+
+    KConfig config("kbookmarkrc", true, false);
+    config.setGroup("Bookmarks");
+    m_pAdvancedAddBookmarkCheckBox->setChecked( config.readBoolEntry("AdvancedAddBookmarkDialog", false) );
+    m_pOnlyMarkedBookmarksCheckBox->setChecked( config.readBoolEntry("FilteredToolbar", false) );
 }
 
 void KMiscHTMLOptions::defaults()
@@ -229,14 +259,17 @@ void KMiscHTMLOptions::defaults()
     m_pConfig->setReadDefaults(true);
     load();
     m_pConfig->setReadDefaults(old);
+    m_pAdvancedAddBookmarkCheckBox->setChecked(false);
+    m_pOnlyMarkedBookmarksCheckBox->setChecked(false);
 }
 
 void KMiscHTMLOptions::save()
 {
     m_pConfig->setGroup( "MainView Settings" );
+    m_pConfig->writeEntry( "OpenMiddleClick", m_pOpenMiddleClick->isChecked() );
     m_pConfig->writeEntry( "BackRightClick", m_pBackRightClick->isChecked() );
     m_pConfig->setGroup( "HTML Settings" );
-    m_pConfig->writeEntry( "ChangeCursor", cbCursor->isChecked() );
+    m_pConfig->writeEntry( "ChangeCursor", m_cbCursor->isChecked() );
     m_pConfig->writeEntry( "AutoLoadImages", m_pAutoLoadImagesCheckBox->isChecked() );
     m_pConfig->writeEntry( "AutoDelayedActions", m_pAutoRedirectCheckBox->isChecked() );
     switch(m_pUnderlineCombo->currentItem())
@@ -275,6 +308,12 @@ void KMiscHTMLOptions::save()
     m_pConfig->writeEntry( "AlwaysTabbedMode", !(m_pDynamicTabbarHide->isChecked()) );
     m_pConfig->sync();
 
+    KConfig config("kbookmarkrc", false, false);
+    config.setGroup("Bookmarks");
+    config.writeEntry("AdvancedAddBookmarkDialog", m_pAdvancedAddBookmarkCheckBox->isChecked());
+    config.writeEntry("FilteredToolbar", m_pOnlyMarkedBookmarksCheckBox->isChecked());
+    config.sync();
+
   QByteArray data;
   if ( !kapp->dcopClient()->isAttached() )
     kapp->dcopClient()->attach();
