@@ -18,7 +18,10 @@
 #include <klistview.h>
 #include <kdebug.h>
 #include <kurlrequester.h>
+
+#if defined Q_WS_X11 && !defined K_WS_QTONLY
 #include <X11/Xlib.h>
+#endif
 
 #include "htmlopts.h"
 #include "policydlg.h"
