@@ -208,7 +208,7 @@ static void applyQtSettings( KConfig& kglobals, QSettings& settings )
 
   QStringList paths;
   for (QMap <QString, bool>::ConstIterator it = pathDb.begin();
-         it != pathDb.end(); it++)
+         it != pathDb.end(); ++it)
   {
     QString path = it.key();
     bool fromKDE = it.data();
@@ -349,8 +349,8 @@ static void createGtkrc( bool exportColors, const QColorGroup& cg )
         t << "  text[NORMAL] = " << color( cg.text() ) << endl;
         t << "  text[SELECTED] = " << color( cg.highlightedText() ) << endl;
         t << "  text[INSENSITIVE] = " << color( cg.mid() ) << endl;
-        t << "  text[ACTIVE] = " << color( cg.text() ) << endl;
-        t << "  text[PRELIGHT] = " << color( cg.text() ) << endl;
+        t << "  text[ACTIVE] = " << color( cg.highlightedText() ) << endl;
+        t << "  text[PRELIGHT] = " << color( cg.highlightedText() ) << endl;
         t << endl;
         t << "  fg[NORMAL] = " << color( cg.foreground() ) << endl;
         t << "  fg[SELECTED] = " << color( cg.highlightedText() ) << endl;
@@ -398,9 +398,10 @@ void runRdb( uint flags )
 {
   // Obtain the application palette that is about to be set.
   QPalette newPal = KApplication::createApplicationPalette();
-  bool exportColors     = flags & KRdbExportColors;
-  bool exportQtColors   = flags & KRdbExportQtColors;
-  bool exportQtSettings = flags & KRdbExportQtSettings;
+  bool exportColors      = flags & KRdbExportColors;
+  bool exportQtColors    = flags & KRdbExportQtColors;
+  bool exportQtSettings  = flags & KRdbExportQtSettings;
+  bool exportXftSettings = flags & KRdbExportXftSettings;
 
   KConfig kglobals("kdeglobals", true, false);
   kglobals.setGroup("KDE");
@@ -444,7 +445,7 @@ void runRdb( uint flags )
     QStringList list;
 
     QStringList adPaths = KGlobal::dirs()->findDirs("appdefaults", "");
-    for (QStringList::ConstIterator it = adPaths.begin(); it != adPaths.end(); it++) {
+    for (QStringList::ConstIterator it = adPaths.begin(); it != adPaths.end(); ++it) {
       QDir dSys( *it );
 
       if ( dSys.exists() ) {
@@ -480,6 +481,34 @@ void runRdb( uint flags )
   if (!size.isNull())
     contents += "Xcursor.size: " + size + '\n';
 
+  if (exportXftSettings)
+  {
+    kglobals.setGroup("General");
+
+    QString hintStyle(kglobals.readEntry("XftHintStyle", "hintmedium")),
+            subPixel(kglobals.readEntry("XftSubPixel"));
+
+    contents += "Xft.antialias: ";
+    if(QSettings().readBoolEntry("/qt/useXft"))
+      contents += "1";
+    else
+      contents += "0";
+
+    contents += "\nXft.hinting: ";
+    if(hintStyle.isEmpty())
+      contents += "-1";
+    else
+    {
+      if(hintStyle!="hintnone")
+        contents += "1";
+      else
+        contents += "0";
+      contents += "\nXft.hintstyle: " + hintStyle + '\n';
+    }
+    if(!subPixel.isEmpty())
+      contents += "Xft.rgba: " + subPixel + '\n';
+  }
+
   if (contents.length() > 0)
     tmp.writeBlock( contents.latin1(), contents.length() );
 
