@@ -22,9 +22,10 @@
 
 enum KRdbAction
 {
-   KRdbExportColors     = 0x0001,   // Export colors to non-(KDE/Qt) apps
-   KRdbExportQtColors   = 0x0002,   // Export KDE's colors to qtrc
-   KRdbExportQtSettings = 0x0004    // Export all possible qtrc settings, excluding colors
+   KRdbExportColors      = 0x0001,   // Export colors to non-(KDE/Qt) apps
+   KRdbExportQtColors    = 0x0002,   // Export KDE's colors to qtrc
+   KRdbExportQtSettings  = 0x0004,   // Export all possible qtrc settings, excluding colors
+   KRdbExportXftSettings = 0x0008    // Export KDE's Xft (anti-alias) settings
 };
 
 void runRdb( uint flags );
