@@ -1,7 +1,7 @@
 /*
   main.cpp - A KControl Application
 
-  Copyright 1999-2000 Hans Petter Bieker <bieker@kde.org>
+  Copyright 1999-2003 Hans Petter Bieker <bieker@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -15,18 +15,17 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  */
+ */
 
 #include "toplevel.h"
-#include <klocale.h>
 
-extern "C" { 
-  void *init_kcm_locale() { 
+extern "C" {
+  void *init_kcm_locale() {
     KLocale::setMainCatalogue("kcmlocale");
     return new KLocaleFactory("kcmlocale");
-  } 
+  }
 }
 
 /*
