@@ -31,7 +31,7 @@ class SMServerConfig : public KCModule
   Q_OBJECT
 
 public:
-  SMServerConfig( QWidget *parent=0, const char* name=0 );
+  SMServerConfig( QWidget *parent=0, const char* name=0, const QStringList &list=QStringList() );
   virtual ~SMServerConfig();
 
   void load();
