@@ -9,11 +9,10 @@
  ***************************************************************************/
 
 
-#include <iostream.h>
+#include <iostream>
 
 
 #include <qfile.h>
-#include <qtextstream.h>
 #include <qregexp.h>
 
 
@@ -40,7 +39,6 @@ USBDB::USBDB()
 
       QString line, name;
       int id=0, subid=0, protid=0;
-      int len;
       QRegExp vendor("[0-9a-fA-F]+ ");
       QRegExp product("\\s+[0-9a-fA-F]+ ");
       QRegExp cls("C [0-9a-fA-F][0-9a-fA-F]");
