@@ -1,3 +1,1323 @@
+i18n("Executive");
+i18n("Envelope B5");
+i18n("Envelope #10");
+i18n("Envelope DL");
+i18n("PageRegion");
+i18n("Media Source");
+i18n("Default");
+i18n("Manual Feed");
+i18n("Output Resolution");
+i18n("150 DPI");
+i18n("300 DPI");
+i18n("600 DPI");
+i18n("1200 DPI");
+i18n("2400 DPI");
+i18n("Double-Sided Printing");
+i18n("Off");
+i18n("Long Edge (Standard)");
+i18n("Short Edge (Flip)");
+i18n("US Letter");
+i18n("US Legal");
+i18n("US Executive");
+i18n("US Tabloid");
+i18n("A3");
+i18n("Media Type");
+i18n("Plain Paper");
+i18n("Bond Paper");
+i18n("Special Paper");
+i18n("Transparency");
+i18n("Glossy Paper");
+i18n("Tray");
+i18n("Envelope Feed");
+i18n("Output Mode");
+i18n("CMYK Color");
+i18n("CMY Color");
+i18n("Grayscale");
+i18n("600x300 DPI");
+i18n("CRET Color");
+i18n("Duplexer");
+i18n("Address - 1 1/8 x 3 1/2\"");
+i18n("Large Address - 1 4/10 x 3 1/2\"");
+i18n("Return Address - 3/4 x 2\"");
+i18n("Shipping Address - 2 5/16 x 4\"");
+i18n("Internet Postage 2-Part - 2 1/4 x 7 1/2\"");
+i18n("Internet Postage 3-Part - 2 1/4 x 7\"");
+i18n("File Folder - 9/16 x 3 7/16\"");
+i18n("Hanging Folder - 9/16 x 2\"");
+i18n("3.5\" Disk - 2 1/8 x 2 3/4\"");
+i18n("136 DPI");
+i18n("203 DPI");
+i18n("Output Darkness");
+i18n("Normal");
+i18n("FanFoldUS");
+i18n("60 DPI");
+i18n("120x60 DPI");
+i18n("180 DPI");
+i18n("360x180 DPI");
+i18n("360 DPI");
+i18n("60x72 DPI");
+i18n("120x72 DPI");
+i18n("240x72 DPI");
+i18n("Tray 4");
+i18n("720 DPI");
+i18n("Page Size and Printing Quality");
+i18n("A4, 600x600 DPI");
+i18n("Letter, 600x600 DPI");
+i18n("A4, 1200x600 DPI");
+i18n("B5, 600x600 DPI");
+i18n("B5, 1200x600 DPI");
+i18n("Legal, 600x600 DPI");
+i18n("Legal, 1200x600 DPI");
+i18n("Letter, 1200x600 DPI");
+i18n("High Grade Paper");
+i18n("Back Print Media");
+i18n("Iron-On Transfer Sheet");
+i18n("Hot OHP Media");
+i18n("Post Card");
+i18n("Thick Paper");
+i18n("Printing Mode");
+i18n("BlackOnly");
+i18n("Colour");
+i18n("HalfTone");
+i18n("NoHalfTone");
+i18n("Dithering");
+i18n("FloydSteinberg");
+i18n("NoFloydSteinberg");
+i18n("Banding");
+i18n("NoBanding");
+i18n("Colour Mode");
+i18n("CMY");
+i18n("Colour Correction Mode");
+i18n("FullBlack");
+i18n("Colour correction");
+i18n("NoColourCorrection");
+i18n("ColourCorrection");
+i18n("How often every dot is printed");
+i18n("PrintTwice");
+i18n("PrintOnce");
+i18n("Black Printing Mode");
+i18n("SolidBlack");
+i18n("MixedBlack");
+i18n("Square Dithering");
+i18n("SquareDithering");
+i18n("NoSquareDithering");
+i18n("Do Curl Correction");
+i18n("CurlCorrectionAlways");
+i18n("CurlCorrectionAfterFinal");
+i18n("Curl Correction on current pass");
+i18n("NoCurlCorrectionOnCurrent");
+i18n("CurlCorrectionOnCurrent");
+i18n("Colour Intensity");
+i18n("Line Feed Adjustment");
+i18n("Gamma");
+i18n("0.00");
+i18n("0.05");
+i18n("0.10");
+i18n("0.15");
+i18n("0.20");
+i18n("0.25");
+i18n("0.30");
+i18n("0.35");
+i18n("0.40");
+i18n("0.45");
+i18n("0.50");
+i18n("0.55");
+i18n("0.60");
+i18n("0.65");
+i18n("0.70");
+i18n("0.75");
+i18n("0.80");
+i18n("0.85");
+i18n("0.90");
+i18n("0.95");
+i18n("1.00");
+i18n("1.05");
+i18n("1.10");
+i18n("1.15");
+i18n("1.20");
+i18n("1.25");
+i18n("1.30");
+i18n("1.35");
+i18n("1.40");
+i18n("1.45");
+i18n("1.50");
+i18n("1.55");
+i18n("1.60");
+i18n("1.65");
+i18n("1.70");
+i18n("1.75");
+i18n("1.80");
+i18n("1.85");
+i18n("1.90");
+i18n("1.95");
+i18n("2.00");
+i18n("2.05");
+i18n("2.10");
+i18n("2.15");
+i18n("2.20");
+i18n("2.25");
+i18n("2.30");
+i18n("2.35");
+i18n("2.40");
+i18n("2.45");
+i18n("2.50");
+i18n("2.55");
+i18n("2.60");
+i18n("2.65");
+i18n("2.70");
+i18n("2.75");
+i18n("2.80");
+i18n("2.85");
+i18n("2.90");
+i18n("2.95");
+i18n("3.00");
+i18n("3.05");
+i18n("3.10");
+i18n("3.15");
+i18n("3.20");
+i18n("3.25");
+i18n("3.30");
+i18n("3.35");
+i18n("3.40");
+i18n("3.45");
+i18n("3.50");
+i18n("3.55");
+i18n("3.60");
+i18n("3.65");
+i18n("3.70");
+i18n("3.75");
+i18n("3.80");
+i18n("3.85");
+i18n("3.90");
+i18n("3.95");
+i18n("4.00");
+i18n("Horizontal (X-)Shift (in dots)");
+i18n("Vertical (Y-)Shift (in dots)");
+i18n("Next Job");
+i18n("NextJobOnSameSheet");
+i18n("NextJobOnNewSheet");
+i18n("Next Job is spot colour page");
+i18n("NextSpotColourPage");
+i18n("NextNotSpotColourPage");
+i18n("This Job is spot colour page");
+i18n("ThisSpotColourPage");
+i18n("ThisNotSpotColourPage");
+i18n("Page Size");
+i18n("B5");
+i18n("Manual");
+i18n("Automatic");
+i18n("Cardboard");
+i18n("Coated Film");
+i18n("Fine Paper");
+i18n("Iron Seal");
+i18n("OHP");
+i18n("OHP (MD 2000)");
+i18n("Rebeca Free");
+i18n("Resolution");
+i18n("1200x600 DPI");
+i18n("Color Mode");
+i18n("Colour Depth");
+i18n("Floyd Steinb. High Qual. (32 bpp)");
+i18n("Floyd Steinberg Simple (8 bpp)");
+i18n("Monochrome (1 bpp)");
+i18n("Simple Colour (4 bpp)");
+i18n("On");
+i18n("Duplex");
+i18n("DoubleSided");
+i18n("SingleSided");
+i18n("Black color saving");
+i18n("EcoBlack");
+i18n("NormalBlack");
+i18n("Black Level");
+i18n("Cyan Level");
+i18n("Magenta Level");
+i18n("Yellow Level");
+i18n("B4 (JIS)");
+i18n("B6 (JIS)");
+i18n("Envelope You 4");
+i18n("Hagaki");
+i18n("Ledger");
+i18n("Oufuku");
+i18n("600x600 DPI");
+i18n("300x300 DPI");
+i18n("3x5");
+i18n("4x6");
+i18n("5x7");
+i18n("5x8");
+i18n("6x8");
+i18n("8x10");
+i18n("8x12");
+i18n("11x14");
+i18n("13x19");
+i18n("16x20");
+i18n("16x24");
+i18n("60x60 dpi");
+i18n("60x72 dpi");
+i18n("60x180 dpi");
+i18n("60x216 dpi");
+i18n("120x60 dpi");
+i18n("120x72 dpi");
+i18n("120x180 dpi");
+i18n("120x216 dpi");
+i18n("180x60 dpi");
+i18n("180x72 dpi");
+i18n("180x180 dpi");
+i18n("180x216 dpi");
+i18n("240x60 dpi");
+i18n("240x72 dpi");
+i18n("240x180 dpi");
+i18n("240x216 dpi");
+i18n("360x60 dpi");
+i18n("360x72 dpi");
+i18n("360x180 dpi");
+i18n("360x216 dpi");
+i18n("11x17");
+i18n("Photo Paper");
+i18n("HP Premium Paper");
+i18n("Transparency Paper");
+i18n("Print Quality");
+i18n("Draft Quality");
+i18n("Normal Quality");
+i18n("Presentation Quality");
+i18n("Monochrome");
+i18n("Dithering Pixels Per Inch");
+i18n("Generic DeskJet");
+i18n("Standard Tray");
+i18n("Banner Printing");
+i18n("Envelope Feeder");
+i18n("Manual Feeder");
+i18n("Quick-Dry Glossy");
+i18n("Quick-Dry Transparency");
+i18n("Quality");
+i18n("Default Setting");
+i18n("Draft");
+i18n("Presentation");
+i18n("Ink Drying Time (sec)");
+i18n("Memory Limit (Bytes)");
+i18n("Black Levels");
+i18n("2 Levels");
+i18n("3 Levels");
+i18n("4 Levels");
+i18n("No Black");
+i18n("CMY Levels");
+i18n("No CMY");
+i18n("Printout Mode");
+i18n("Draft (Color cartridge)");
+i18n("Draft Grayscale (Black + color cartridge)");
+i18n("Normal (Color cartridge)");
+i18n("Normal Grayscale (Black + color cartridge)");
+i18n("High Quality Grayscale (Black + color cartridge)");
+i18n("Photo (Photo + color cartridge, photo paper)");
+i18n("Photo/4x6 inch index card");
+i18n("Photo with tear-off tab");
+i18n("3x5 inch index card");
+i18n("5x8 inch index card");
+i18n("A6");
+i18n("A6 with tear-off tab");
+i18n("Envelope C6");
+i18n("American Foolscap");
+i18n("Oufuku-Hagaki");
+i18n("16K");
+i18n("Executive (JIS)");
+i18n("Resolution, Quality, Ink Type, Media Type");
+i18n("Controlled by 'Printout Mode'");
+i18n("300 dpi, Color, Color Cartr.");
+i18n("300 dpi, Color, Black + Color Cartr.");
+i18n("300 dpi, Draft, Color, Color Cartr.");
+i18n("300 dpi, Draft, Color, Black + Color Cartr.");
+i18n("300 dpi, Draft, Grayscale, Black + Color Cartr.");
+i18n("300 dpi, Grayscale, Black + Color Cartr.");
+i18n("300 dpi, Photo, Photo + Color Cartr., Premium Paper");
+i18n("600x300 dpi, Best, Grayscale, Black + Color Cartr.");
+i18n("Normal Color");
+i18n("Best Quality Color");
+i18n("Black and White");
+i18n("Floyd-Steinberg Color");
+i18n("Floyd-Steinberg Color (Low Memory)");
+i18n("Floyd-Steinberg Gray");
+i18n("Black correction (Cyan reduction)");
+i18n("Ink Reduction");
+i18n("25 %");
+i18n("50 %");
+i18n("No");
+i18n("Draft (Economy)");
+i18n("Draft Grayscale (Economy)");
+i18n("Normal Grayscale");
+i18n("High Quality");
+i18n("High Quality Grayscale");
+i18n("Photo");
+i18n("Photo Grayscale");
+i18n("C5");
+i18n("Commercial 10");
+i18n("DL");
+i18n("B5 ISO");
+i18n("B6 ISO");
+i18n("B7 ISO");
+i18n("B8 ISO");
+i18n("B9 ISO");
+i18n("B10 ISO");
+i18n("Monarch Envelope");
+i18n("Postcard");
+i18n("C7-6");
+i18n("Japanese long envelope #4");
+i18n("Hagaki Card");
+i18n("Small paperback");
+i18n("Penguin small paperback");
+i18n("A2 Invitation");
+i18n("Epson 4x6 Photo Paper");
+i18n("Japanese long envelope #3");
+i18n("B6-C4");
+i18n("Penguin large paperback");
+i18n("Crown Quarto");
+i18n("Large Crown Quarto");
+i18n("RA4");
+i18n("American foolscap");
+i18n("Bond");
+i18n("Glossy Photo");
+i18n("Transparencies");
+i18n("Ink Type");
+i18n("Color + Photo Cartridges");
+i18n("Four Color Standard");
+i18n("stpGamma");
+i18n("Density");
+i18n("0.12");
+i18n("0.14");
+i18n("0.16");
+i18n("0.18");
+i18n("0.22");
+i18n("0.24");
+i18n("0.26");
+i18n("0.28");
+i18n("0.32");
+i18n("0.34");
+i18n("0.36");
+i18n("0.38");
+i18n("0.42");
+i18n("0.44");
+i18n("0.46");
+i18n("0.48");
+i18n("0.52");
+i18n("0.54");
+i18n("0.56");
+i18n("0.58");
+i18n("0.62");
+i18n("0.64");
+i18n("0.66");
+i18n("0.68");
+i18n("0.72");
+i18n("0.74");
+i18n("0.76");
+i18n("0.78");
+i18n("0.82");
+i18n("0.84");
+i18n("0.86");
+i18n("0.88");
+i18n("0.92");
+i18n("0.94");
+i18n("0.96");
+i18n("0.98");
+i18n("1.02");
+i18n("1.04");
+i18n("1.06");
+i18n("1.08");
+i18n("1.12");
+i18n("1.14");
+i18n("1.16");
+i18n("1.18");
+i18n("1.22");
+i18n("1.24");
+i18n("1.26");
+i18n("1.28");
+i18n("1.32");
+i18n("1.34");
+i18n("1.36");
+i18n("1.38");
+i18n("1.42");
+i18n("1.44");
+i18n("1.46");
+i18n("1.48");
+i18n("1.52");
+i18n("1.54");
+i18n("1.56");
+i18n("1.58");
+i18n("1.62");
+i18n("1.64");
+i18n("1.66");
+i18n("1.68");
+i18n("1.72");
+i18n("1.74");
+i18n("1.76");
+i18n("1.78");
+i18n("1.82");
+i18n("1.84");
+i18n("1.86");
+i18n("1.88");
+i18n("1.92");
+i18n("1.94");
+i18n("1.96");
+i18n("1.98");
+i18n("stpBrightness");
+i18n("0.02");
+i18n("0.04");
+i18n("0.06");
+i18n("0.08");
+i18n("stpSaturation");
+i18n("0.0");
+i18n("0.1");
+i18n("0.2");
+i18n("0.3");
+i18n("0.4");
+i18n("0.5");
+i18n("0.6");
+i18n("0.7");
+i18n("0.8");
+i18n("0.9");
+i18n("1.0");
+i18n("1.1");
+i18n("1.2");
+i18n("1.3");
+i18n("1.4");
+i18n("1.5");
+i18n("1.6");
+i18n("1.7");
+i18n("1.8");
+i18n("1.9");
+i18n("2.0");
+i18n("2.1");
+i18n("2.2");
+i18n("2.3");
+i18n("2.4");
+i18n("2.5");
+i18n("2.6");
+i18n("2.7");
+i18n("2.8");
+i18n("2.9");
+i18n("3.0");
+i18n("3.1");
+i18n("3.2");
+i18n("3.3");
+i18n("3.4");
+i18n("3.5");
+i18n("3.6");
+i18n("3.7");
+i18n("3.8");
+i18n("3.9");
+i18n("4.0");
+i18n("4.1");
+i18n("4.2");
+i18n("4.3");
+i18n("4.4");
+i18n("4.5");
+i18n("4.6");
+i18n("4.7");
+i18n("4.8");
+i18n("4.9");
+i18n("5.0");
+i18n("5.1");
+i18n("5.2");
+i18n("5.3");
+i18n("5.4");
+i18n("5.5");
+i18n("5.6");
+i18n("5.7");
+i18n("5.8");
+i18n("5.9");
+i18n("6.0");
+i18n("6.1");
+i18n("6.2");
+i18n("6.3");
+i18n("6.4");
+i18n("6.5");
+i18n("6.6");
+i18n("6.7");
+i18n("6.8");
+i18n("6.9");
+i18n("7.0");
+i18n("7.1");
+i18n("7.2");
+i18n("7.3");
+i18n("7.4");
+i18n("7.5");
+i18n("7.6");
+i18n("7.7");
+i18n("7.8");
+i18n("7.9");
+i18n("8.0");
+i18n("8.1");
+i18n("8.2");
+i18n("8.3");
+i18n("8.4");
+i18n("8.5");
+i18n("8.6");
+i18n("8.7");
+i18n("8.8");
+i18n("8.9");
+i18n("9.0");
+i18n("Contrast Level");
+i18n("150 x 150 DPI");
+i18n("300 x 300 DPI");
+i18n("600 x 300 DPI");
+i18n("600 x 600 DPI");
+i18n("Output Type");
+i18n("Gray Scale");
+i18n("Continuous-tone photographs");
+i18n("Line art");
+i18n("Primarily solid colors or smooth gradients");
+i18n("Dither Algorithm");
+i18n("EvenTone");
+i18n("Fast");
+i18n("Raw CMYK");
+i18n("Not capable");
+i18n("Printer Default");
+i18n("GhostScript pre-filtering");
+i18n("Embed GhostScript fonts only");
+i18n("Convert to PS level 1");
+i18n("Convert to PS level 2");
+i18n("No pre-filtering");
+i18n("160x72 dpi");
+i18n("160x144 dpi");
+i18n("320x216 dpi");
+i18n("Input Slot");
+i18n("Standard");
+i18n("Printer default");
+i18n("PageSize");
+i18n("Tabloid");
+i18n("SRA4");
+i18n("C4");
+i18n("ArchA");
+i18n("European foolscap");
+i18n("Large Crown Octavo");
+i18n("Japanese Kaku envelope #4");
+i18n("ColorModel");
+i18n("Black & White");
+i18n("Back Print Film");
+i18n("Fabric Sheets");
+i18n("Envelope");
+i18n("High Resolution Paper");
+i18n("T-Shirt Transfers");
+i18n("High Gloss Film");
+i18n("Glossy Photo Paper");
+i18n("Glossy Photo Cards");
+i18n("Photo Paper Pro");
+i18n("Other");
+i18n("Auto Sheet Feeder");
+i18n("Manual with Pause");
+i18n("Manual without Pause");
+i18n("90x90 DPI");
+i18n("180x180 DPI");
+i18n("360x360 DPI");
+i18n("360x360 DPI DMT");
+i18n("720x360 DPI");
+i18n("Line Art");
+i18n("Solid Colors");
+i18n("Photograph");
+i18n("Black");
+i18n("Brightness");
+i18n("0.000");
+i18n("0.050");
+i18n("0.100");
+i18n("0.150");
+i18n("0.200");
+i18n("0.250");
+i18n("0.300");
+i18n("0.350");
+i18n("0.400");
+i18n("0.450");
+i18n("0.500");
+i18n("0.550");
+i18n("0.600");
+i18n("0.650");
+i18n("0.700");
+i18n("0.750");
+i18n("0.800");
+i18n("0.850");
+i18n("0.900");
+i18n("0.950");
+i18n("1.000");
+i18n("1.050");
+i18n("1.100");
+i18n("1.150");
+i18n("1.200");
+i18n("1.250");
+i18n("1.300");
+i18n("1.350");
+i18n("1.400");
+i18n("1.450");
+i18n("1.500");
+i18n("1.550");
+i18n("1.600");
+i18n("1.650");
+i18n("1.700");
+i18n("1.750");
+i18n("1.800");
+i18n("1.850");
+i18n("1.900");
+i18n("1.950");
+i18n("2.000");
+i18n("Contrast");
+i18n("2.050");
+i18n("2.100");
+i18n("2.150");
+i18n("2.200");
+i18n("2.250");
+i18n("2.300");
+i18n("2.350");
+i18n("2.400");
+i18n("2.450");
+i18n("2.500");
+i18n("2.550");
+i18n("2.600");
+i18n("2.650");
+i18n("2.700");
+i18n("2.750");
+i18n("2.800");
+i18n("2.850");
+i18n("2.900");
+i18n("2.950");
+i18n("3.000");
+i18n("3.050");
+i18n("3.100");
+i18n("3.150");
+i18n("3.200");
+i18n("3.250");
+i18n("3.300");
+i18n("3.350");
+i18n("3.400");
+i18n("3.450");
+i18n("3.500");
+i18n("3.550");
+i18n("3.600");
+i18n("3.650");
+i18n("3.700");
+i18n("3.750");
+i18n("3.800");
+i18n("3.850");
+i18n("3.900");
+i18n("3.950");
+i18n("4.000");
+i18n("Cyan");
+i18n("Magenta");
+i18n("Yellow");
+i18n("Saturation");
+i18n("4.050");
+i18n("4.100");
+i18n("4.150");
+i18n("4.200");
+i18n("4.250");
+i18n("4.300");
+i18n("4.350");
+i18n("4.400");
+i18n("4.450");
+i18n("4.500");
+i18n("4.550");
+i18n("4.600");
+i18n("4.650");
+i18n("4.700");
+i18n("4.750");
+i18n("4.800");
+i18n("4.850");
+i18n("4.900");
+i18n("4.950");
+i18n("5.000");
+i18n("5.050");
+i18n("5.100");
+i18n("5.150");
+i18n("5.200");
+i18n("5.250");
+i18n("5.300");
+i18n("5.350");
+i18n("5.400");
+i18n("5.450");
+i18n("5.500");
+i18n("5.550");
+i18n("5.600");
+i18n("5.650");
+i18n("5.700");
+i18n("5.750");
+i18n("5.800");
+i18n("5.850");
+i18n("5.900");
+i18n("5.950");
+i18n("6.000");
+i18n("6.050");
+i18n("6.100");
+i18n("6.150");
+i18n("6.200");
+i18n("6.250");
+i18n("6.300");
+i18n("6.350");
+i18n("6.400");
+i18n("6.450");
+i18n("6.500");
+i18n("6.550");
+i18n("6.600");
+i18n("6.650");
+i18n("6.700");
+i18n("6.750");
+i18n("6.800");
+i18n("6.850");
+i18n("6.900");
+i18n("6.950");
+i18n("7.000");
+i18n("7.050");
+i18n("7.100");
+i18n("7.150");
+i18n("7.200");
+i18n("7.250");
+i18n("7.300");
+i18n("7.350");
+i18n("7.400");
+i18n("7.450");
+i18n("7.500");
+i18n("7.550");
+i18n("7.600");
+i18n("7.650");
+i18n("7.700");
+i18n("7.750");
+i18n("7.800");
+i18n("7.850");
+i18n("7.900");
+i18n("7.950");
+i18n("8.000");
+i18n("8.050");
+i18n("8.100");
+i18n("8.150");
+i18n("8.200");
+i18n("8.250");
+i18n("8.300");
+i18n("8.350");
+i18n("8.400");
+i18n("8.450");
+i18n("8.500");
+i18n("8.550");
+i18n("8.600");
+i18n("8.650");
+i18n("8.700");
+i18n("8.750");
+i18n("8.800");
+i18n("8.850");
+i18n("8.900");
+i18n("8.950");
+i18n("9.000");
+i18n("720x720 DPI");
+i18n("1440x720 DPI");
+i18n("Photo CcMmY Color");
+i18n("Photo CcMmYK Color");
+i18n("1200x1200 DPI");
+i18n("12x18");
+i18n("Super B 13x19");
+i18n("20x24");
+i18n("20x30");
+i18n("22x30");
+i18n("24x30");
+i18n("24x36");
+i18n("30x40");
+i18n("A0");
+i18n("A1");
+i18n("A2");
+i18n("RA0");
+i18n("RA1");
+i18n("RA2");
+i18n("RA3");
+i18n("SRA0");
+i18n("SRA1");
+i18n("SRA2");
+i18n("B0 ISO");
+i18n("B1 ISO");
+i18n("B2 ISO");
+i18n("B3 ISO");
+i18n("B0 JIS");
+i18n("B1 JIS");
+i18n("B2 JIS");
+i18n("B3 JIS");
+i18n("C0");
+i18n("C1");
+i18n("C2");
+i18n("C3");
+i18n("ArchA Transverse");
+i18n("ArchB");
+i18n("ArchB Transverse");
+i18n("ArchC");
+i18n("ArchC Transverse");
+i18n("ArchD");
+i18n("ArchD Transverse");
+i18n("ArchE");
+i18n("Plain Paper Fast Load");
+i18n("Glossy Film");
+i18n("Envelopes");
+i18n("Back Light Film");
+i18n("Matte Paper");
+i18n("Inkjet Paper");
+i18n("Photo Quality Inkjet Paper");
+i18n("Premium Glossy Photo Paper");
+i18n("Premium Luster Photo Paper");
+i18n("Photo Quality Glossy Paper");
+i18n("Ilford Heavy Paper");
+i18n("ColorLife Paper");
+i18n("Roll Feed");
+i18n("360 x 90 DPI Fast Economy Draft");
+i18n("360 x 120 DPI Economy Draft");
+i18n("180 DPI Economy Draft");
+i18n("360 x 240 DPI Draft");
+i18n("360 x 180 DPI Draft");
+i18n("360 DPI Microweave");
+i18n("360 DPI Microweave Unidirectional");
+i18n("360 DPI Unidirectional");
+i18n("360 DPI Full Overlap");
+i18n("360 DPI Full Overlap Unidirectional");
+i18n("360 DPI FOL2");
+i18n("360 DPI FOL2 Unidirectional");
+i18n("360 DPI MW2");
+i18n("360 DPI MW2 Unidirectional");
+i18n("720 x 360 DPI");
+i18n("720 x 360 DPI Unidirectional");
+i18n("720 x 360 DPI Microweave");
+i18n("720 x 360 DPI Microweave Unidirectional");
+i18n("720 x 360 DPI FOL");
+i18n("720 x 360 DPI FOL Unidirectional");
+i18n("720 x 360 DPI FOL2");
+i18n("720 x 360 DPI FOL2 Unidirectional");
+i18n("720 x 360 DPI MW2");
+i18n("720 x 360 DPI MW2 Unidirectional");
+i18n("720 DPI Microweave");
+i18n("720 DPI Microweave Unidirectional");
+i18n("720 DPI Full Overlap");
+i18n("720 DPI Full Overlap Unidirectional");
+i18n("720 DPI Four Pass");
+i18n("720 DPI Four Pass Unidirectional");
+i18n("1440 x 720 DPI Microweave");
+i18n("1440 x 720 DPI Microweave Unidirectional");
+i18n("1440 x 720 DPI FOL");
+i18n("1440 x 720 DPI FOL Unidirectional");
+i18n("1440 x 720 DPI Four Pass");
+i18n("1440 x 720 DPI Four Pass Unidirectional");
+i18n("Six Color Photo");
+i18n("Five Color Photo Composite");
+i18n("Three Color Composite");
+i18n("Quadtone");
+i18n("720 DPI Unidirectional");
+i18n("720 DPI High Quality");
+i18n("720 DPI High Quality Unidirectional");
+i18n("720 DPI Highest Quality");
+i18n("1440 x 720 DPI");
+i18n("1440 x 720 DPI Unidirectional");
+i18n("1440 x 720 DPI Highest Quality");
+i18n("2880 x 720 DPI");
+i18n("2880 x 720 DPI Unidirectional");
+i18n("Roll Feed (cut each page)");
+i18n("Roll Feed (do not cut)");
+i18n("1440 x 1440 DPI");
+i18n("1440 x 1440 DPI Highest Quality");
+i18n("2880 x 1440 DPI");
+i18n("Seven Color Photo");
+i18n("Two Level Grayscale");
+i18n("Cut Sheet Bin 1");
+i18n("Cut Sheet Bin 2");
+i18n("Cut Sheet Autoselect");
+i18n("Manual Selection");
+i18n("2880 x 720 DPI Microweave");
+i18n("2880 x 720 DPI Microweave Unidirectional");
+i18n("2880 x 720 DPI FOL");
+i18n("2880 x 720 DPI FOL Unidirectional");
+i18n("2880 x 720 DPI Four Pass");
+i18n("2880 x 720 DPI Four Pass Unidirectional");
+i18n("1440 x 1440 DPI Microweave");
+i18n("1440 x 1440 DPI Microweave Unidirectional");
+i18n("1440 x 1440 DPI FOL");
+i18n("1440 x 1440 DPI FOL Unidirectional");
+i18n("1440 x 1440 DPI Four Pass");
+i18n("1440 x 1440 DPI Four Pass Unidirectional");
+i18n("2880 x 1440 DPI Microweave");
+i18n("2880 x 1440 DPI Microweave Unidirectional");
+i18n("2880 x 1440 DPI FOL");
+i18n("2880 x 1440 DPI FOL Unidirectional");
+i18n("2880 x 1440 DPI Four Pass");
+i18n("2880 x 1440 DPI Four Pass Unidirectional");
+i18n("Seven Color Enhanced");
+i18n("Six Color Enhanced Composite");
+i18n("Plain");
+i18n("300 DPI x 600 DPI");
+i18n("600 DPI high quality");
+i18n("600 DPI Unidirectional");
+i18n("1200 DPI high quality");
+i18n("1200 DPI highest quality");
+i18n("1200 DPI  Unidirectional");
+i18n("2400 DPI x 1200 DPI");
+i18n("2400 DPI x 1200 DPI high quality");
+i18n("2400 DPI x 1200 DPI highest quality");
+i18n("600x600 DPI monochrome");
+i18n("Quick-dry Photo");
+i18n("Quick-dry Transparency");
+i18n("Portable Sheet Feeder");
+i18n("Desktop Sheet Feeder");
+i18n("Color + Black Cartridges");
+i18n("Upper Tray");
+i18n("Lower Tray");
+i18n("Dual");
+i18n("Thicker Paper");
+i18n("Thin Paper");
+i18n("Toner Saving");
+i18n("High (50%)");
+i18n("Low (25%)");
+i18n("Standard printing");
+i18n("Floyd-Steinberg dithered printing");
+i18n("Tray 5");
+i18n("2400x600 DPI");
+i18n("Draft Grayscale");
+i18n("Printer Model");
+i18n("HP LaserJet II series");
+i18n("HP LaserJet III series");
+i18n("8K");
+i18n("Large Capacity Tray");
+i18n("Multi Purpose Tray");
+i18n("300 dpi, Draft, Grayscale, Black Cartr.");
+i18n("300 dpi, Grayscale, Black Cartr.");
+i18n("600 dpi, Grayscale, Black Cartr.");
+i18n("180x360 dpi");
+i18n("360x360 dpi");
+i18n("180 x 180 DPI");
+i18n("360 x 360 DPI");
+i18n("Plain paper");
+i18n("Bond paper");
+i18n("Media Weight");
+i18n("Normal paper");
+i18n("Thick paper");
+i18n("90 DPI");
+i18n("Ghostscript Bits Per Pixel");
+i18n("Monochrome (1bpp)");
+i18n("CMYK with Ghostscript dithering (8bpp)");
+i18n("CMYK with Ghostscript FS dithering (16bpp)");
+i18n("CMYK with FS dithering (24 bpp)");
+i18n("CMYK with FS dithering (32 bpp)");
+i18n("Color Model");
+i18n("Four-color CMYK");
+i18n("Greyscale");
+i18n("Three-color RGB");
+i18n("Colours to be used");
+i18n("Cyan only");
+i18n("Cyan, Black");
+i18n("Cyan, Magenta");
+i18n("Cyan, Magenta, Black");
+i18n("Cyan, Magenta, Yellow");
+i18n("Cyan, Magenta, Yellow, Black");
+i18n("Cyan, Yellow");
+i18n("Cyan, Yellow, Black");
+i18n("Black only");
+i18n("Black for any colour");
+i18n("Magenta only");
+i18n("Magenta, Black");
+i18n("Magenta, Yellow");
+i18n("Magenta, Yellow, Black");
+i18n("Yellow only");
+i18n("Yellow, Black");
+i18n("90 x 90 DPI");
+i18n("Resolution, Media Type");
+i18n("360x360dpi, back print film");
+i18n("360x360dpi, coated paper");
+i18n("360x360dpi, fabric sheet");
+i18n("360x360dpi, glossy paper");
+i18n("360x360dpi, high gloss film");
+i18n("360x360dpi, high resolution paper");
+i18n("360x360dpi, plain paper");
+i18n("360x360dpi, plain paper, high speed");
+i18n("360x360dpi, transparency film");
+i18n("Very High Quality");
+i18n("Very High Quality Grayscale");
+i18n("720 x 720 DPI");
+i18n("360 dpi");
+i18n("720 dpi");
+i18n("Low Quality");
+i18n("720x720dpi, back print film");
+i18n("720x720dpi, coated paper");
+i18n("720x720dpi, glossy paper");
+i18n("720x720dpi, high-gloss paper");
+i18n("720x720dpi, high resolution paper");
+i18n("720x720dpi, plain paper");
+i18n("720x720dpi, transparency film");
+i18n("1200 x 600 DPI");
+i18n("Resolution, Quality, Media Type");
+i18n("600x600dpi, iron-on transfer sheets, normal quality");
+i18n("600x600dpi, plain paper, normal quality");
+i18n("600x600dpi, transparencies, normal quality");
+i18n("1200x1200dpi, glossy photo cards, high quality");
+i18n("1200x1200dpi, high gloss photo paper, high quality");
+i18n("1200x1200dpi, professional photo paper, highest quality");
+i18n("1200 x 1200 DPI");
+i18n("Number of Copies");
+i18n("REt Setting");
+i18n("Halftoning");
+i18n("HP LaserJet 4L");
+i18n("Shift output horizontally (in 1/300 inch)");
+i18n("Shift output vertically (in 1/300 inch)");
+i18n("Full Paint");
+i18n("FullPaint");
+i18n("PartialPaint");
+i18n("Printer's paper size");
+i18n("IgnoreSize");
+i18n("RequireSize");
+i18n("240x240 DPI");
+i18n("300x300 dpi");
+i18n("300x600 dpi");
+i18n("600x600 dpi");
+i18n("600x1200 dpi");
+i18n("1200x1200 dpi");
+i18n("Head Separation");
+i18n("300x600 DPI");
+i18n("300x1200 DPI");
+i18n("600x1200 DPI");
+i18n("1200x300 DPI");
+i18n("Photo Quality Colour (6-ink)");
+i18n("Normal Quality Colour (4-ink)");
+i18n("Bidirectional printing");
+i18n("off");
+i18n("on");
+i18n("Horz. align. betw. cartr.");
+i18n("Vert. align. betw. cartr.");
+i18n("Distance even/odd nozzles left cartr.");
+i18n("Distance even/odd nozzles right cartr.");
+i18n("Number of passes per line");
+i18n("Paper Source");
+i18n("Tray 8");
+i18n("Tray 9");
+i18n("Tray 10");
+i18n("Tray 11");
+i18n("Tray 12");
+i18n("Tray 13");
+i18n("Tray 14");
+i18n("Tray 15");
+i18n("Page Output");
+i18n("FaceUp");
+i18n("FaceDown");
+i18n("Thick Paper/Card Board");
+i18n("Toner Density");
+i18n("TonerSaving");
+i18n("Output Order");
+i18n("Collate");
+i18n("Orientation");
+i18n("Landscape");
+i18n("Portrait");
+i18n("RIT Control");
+i18n("RITOff");
+i18n("RITOn");
+i18n("Monochrome, fast");
+i18n("Monochrome, Floyd-Steinberg");
+i18n("Head motion");
+i18n("Unidirectional");
+i18n("Bidirectional");
+i18n("Weaving");
+i18n("Microweave (Printer internal)");
+i18n("Softweave (Driver internal)");
+i18n("ESC/P2 Encoding");
+i18n("Delta Row");
+i18n("Run Length");
+i18n("Uncompressed");
+i18n("Preconfiguration file");
+i18n("stcolor");
+i18n("none");
+i18n("Initialization values for dithering");
+i18n("Uniform");
+i18n("Random");
+i18n("360 x 120 DPI");
+i18n("360 x 240 DPI");
+i18n("360 x 180 DPI");
+i18n("360 x 90 DPI");
+i18n("360x360dpi, 4-bit, PostScript halftoning, weaved");
+i18n("360x360dpi, 32-bit CMYK");
+i18n("720x720dpi, 32-bit CMYK, weaved");
+i18n("Colour, Floyd-Steinberg, CMYK, better");
+i18n("Colour, fast, CMYK");
+i18n("Colour, modif. Floyd-Steinberg, CMYK, faster");
+i18n("Colour, fast, RGB");
+i18n("Colour, Floyd-Steinberg, RGB");
+i18n("Colour, Floyd-Steinberg, CMYK, simpler");
+i18n("Colour, Stefan-Singer algorithm, RGB");
+i18n("360 dpi, plain paper");
+i18n("720 dpi, plain paper");
+i18n("1440x720dpi, inkjet paper");
+i18n("Resolution, Color Mode, Media Type");
+i18n("360x360dpi, plain paper, grayscale");
+i18n("720x720dpi, inkjet paper");
+i18n("720x720dpi, plain paper, grayscale");
+i18n("1440x720dpi, inkjet paper, grayscale");
+i18n("360x360dpi, plain paper low quality");
+i18n("360x360dpi");
+i18n("720x720dpi");
+i18n("F4");
+i18n("Government Legal");
+i18n("Government Letter");
+i18n("Half Letter");
+i18n("TonerSave");
+i18n("Dpi");
+i18n("600x300 dpi (Class600)");
+i18n("1200x600 dpi (Class1200)");
+i18n("Ritech");
+i18n("Resolution, Color Mode");
+i18n("180x180dpi, Grayscale, plain paper");
+i18n("360x360dpi, Color, plain paper");
+i18n("360x360dpi, Grayscale, plain paper");
+i18n("360x720 DPI");
+i18n("400x400 DPI");
+i18n("300 dpi, Best, Color, Black + Color Cartr.");
+i18n("600 dpi, Best, Color, Black + Color Cartr.");
+i18n("600 dpi, Grayscale, Black + Color Cartr.");
+i18n("Super B");
+i18n("Manual Feeding");
+i18n("Paper type");
+i18n("Glossy film");
+i18n("Special paper");
+i18n("Transparency film");
+i18n("Printing Quality");
+i18n("RET (Resolution Enhancement)");
+i18n("Draft (auto-detect paper type)");
+i18n("Photo (on photo paper)");
+i18n("300 dpi, Photo, Black + Color Cartr., Photo Paper");
+i18n("600 dpi, Color, Black + Color Cartr.");
+i18n("600 dpi, Photo, Black + Color Cartr., Photo Paper");
+i18n("Draft Grayscale (auto-detect paper type)");
+i18n("Normal (auto-detect paper type)");
+i18n("Normal Grayscale (auto-detect paper type)");
+i18n("High Quality (auto-detect paper type)");
+i18n("High Quality Grayscale (auto-detect paper type)");
+i18n("1200 dpi, Photo, Black + Color Cartr., Photo Paper");
+i18n("Binding for Double-Sided Pr.");
+i18n("Long Edge");
+i18n("Short Edge");
+i18n("Auto");
+i18n("Contone (4096 colors)");
+i18n("2A");
+i18n("4A");
+i18n("Arch A");
+i18n("Arch B");
+i18n("Arch C");
+i18n("Arch D");
+i18n("Arch E");
+i18n("B0 (ISO)");
+i18n("B1 (ISO)");
+i18n("B2 (ISO)");
+i18n("B3 (ISO)");
+i18n("B4 (ISO)");
+i18n("B5 (ISO)");
+i18n("B0 (JIS)");
+i18n("B1 (JIS)");
+i18n("B2 (JIS)");
+i18n("B3 (JIS)");
+i18n("Super A");
+i18n("Tabloid Extra");
+i18n("EconoFast Mode");
+i18n("Color (Color Cartridge, for photos)");
+i18n("Color (both cartridges, for text with images)");
+i18n("Grayscale (black cartridge)");
+i18n("Dithering Algorithm");
+i18n("Floyd Steinberg (higher quality)");
+i18n("Ordered (faster)");
+i18n("Off (better quality)");
+i18n("On (faster)");
+i18n("Black ink density adjustment.");
+i18n("Bottom Margin");
+i18n("Left Margin");
+i18n("Right Margin");
+i18n("Top Margin");
+i18n("X Offset");
+i18n("Y Offset");
+i18n("Gamma Correction File");
+i18n("Default (/etc/pnm2ppa.gamma)");
+i18n("Normal Quality (/etc/pnm2ppa.gamma_normal)");
+i18n("Best Quality (/etc/pnm2ppa.gamma_best)");
+i18n("None");
+i18n("GhostScript Rendering Format");
+i18n("Gamma Correction");
+i18n("Gamma Black");
+i18n("Gamma Cyan");
+i18n("Gamma Magenta");
+i18n("Gamma Yellow");
+i18n("Draft Grayscale (Black cartridge)");
+i18n("Normal Grayscale (Black cartridge)");
+i18n("High Quality Grayscale (Black cartridge)");
+i18n("600x300 dpi, Best, Grayscale, Black Cartr.");
+i18n("300 dpi, Color, Full Bleed, Black + Color Cartr.");
+i18n("600 dpi, Color, Full Bleed, Black + Color Cartr.");
+i18n("1200 dpi, Photo, Full Bleed, Black + Color Cartr., Photo Paper");
+i18n("Photo (Color cartridge, on photo paper)");
+i18n("300 dpi, Photo, Color Cartr., Photo Paper");
+i18n("600 dpi, Photo, Color Cartr., Photo Paper");
+i18n("Glossy");
+i18n("Paper");
+i18n("Behaviour when Toner Low");
+i18n("Output Bin");
+i18n("Upper");
+i18n("Lower");
+i18n("MP Tray");
+i18n("300 dpi, Color, Full Bleed, Color Cartr.");
+i18n("600 dpi, Color, Color Cartr.");
+i18n("600 dpi, Color, Full Bleed, Color Cartr.");
+i18n("1200 dpi, Photo, Color Cartr., Photo Paper");
+i18n("1200 dpi, Photo, Full Bleed, Color Cartr., Photo Paper");
+i18n("150 dpi, Best, Color, Black + Color Cartr.");
+i18n("150 dpi, Color, Black + Color Cartr.");
+i18n("150 dpi, Draft, Color, Black + Color Cartr.");
+i18n("150 dpi, Draft, Grayscale, Black + Color Cartr.");
+i18n("150 dpi, Grayscale, Black + Color Cartr.");
+i18n("2400x1200 DPI");
+i18n("High Quality (Color cartridge)");
+i18n("Cover for HP DeskJet 3425");
+i18n("75x75 dpi");
+i18n("150x150 dpi");
+i18n("Black cartridge");
+i18n("Color cartridge");
+i18n("Folio");
+i18n("Normal Paper");
+i18n("Card Stock");
+i18n("Adhesive Labels");
+i18n("Pre-printed paper");
+i18n("Allow use of 'Reprint' button");
+i18n("Yes");
+i18n("Altitude Correction");
+i18n("High Altitude (Low Air Pressure)");
+i18n("Low Altitude (High Air Pressure)");
+i18n("Reprint Page after Paper Jam");
+i18n("Page Timeout");
+i18n("15 sec");
+i18n("30 sec");
+i18n("45 sec");
+i18n("Idle time to start power save mode (min)");
+i18n("5 min");
+i18n("10 min");
+i18n("15 min");
+i18n("30 min");
+i18n("45 min");
+i18n("60 min");
+i18n("Use Power Saving Mode");
+i18n("Dithering PPI");
+i18n("300 x 600 DPI");
+i18n("2400 x 1200 DPI");
+i18n("2-passes x-weaving");
+i18n("3-passes x-weaving");
+i18n("320x320 DPI");
+i18n("160x160 DPI");
+i18n("Darkness");
+i18n("Darkest");
+i18n("Lightest");
+i18n("Black toner saving");
+i18n("DeskJet");
+i18n("DeskJet 310");
+i18n("DeskJet 320");
+i18n("DeskJet 340");
+i18n("DeskJet 400");
+i18n("DeskJet 600");
+i18n("DeskJet 660C");
+i18n("DeskJet 670C");
+i18n("DeskJet 680C");
+i18n("DeskJet 690C");
+i18n("DeskJet 870C");
+i18n("DeskJet 890C");
+i18n("DeskJet 970C with Duplexer");
+i18n("DeskJet 1120C");
+i18n("DeskJet Plus");
+i18n("DeskJet Portable");
+i18n("Olivetti (Black sent after CMY)");
+i18n("Unspecified Model");
+i18n("Unspecified Old Model");
+i18n("Configure Every Page");
 i18n("Media Size");
 i18n("Letter");
 i18n("Legal");
@@ -331,54 +1651,6 @@ i18n("Proof and Hold");
 i18n("Stored Job");
 i18n("Private Job");
 i18n("PIN (for Private Job)");
-i18n("0067");
-i18n("0089");
-i18n("0403");
-i18n("0989");
-i18n("1073");
-i18n("1100");
-i18n("1117");
-i18n("1299");
-i18n("1362");
-i18n("1465");
-i18n("1518");
-i18n("1636");
-i18n("2065");
-i18n("2080");
-i18n("2213");
-i18n("2226");
-i18n("2377");
-i18n("2400");
-i18n("2486");
-i18n("2846");
-i18n("2951");
-i18n("3246");
-i18n("3429");
-i18n("3559");
-i18n("3767");
-i18n("4114");
-i18n("4447");
-i18n("4743");
-i18n("4757");
-i18n("5161");
-i18n("5200");
-i18n("5333");
-i18n("5696");
-i18n("5952");
-i18n("5975");
-i18n("6250");
-i18n("6582");
-i18n("7286");
-i18n("7846");
-i18n("7921");
-i18n("8455");
-i18n("8509");
-i18n("8601");
-i18n("8643");
-i18n("8865");
-i18n("8941");
-i18n("9531");
-i18n("9835");
 i18n("User Specified PIN");
 i18n("User Name");
 i18n("Use file sharing name");
@@ -414,18 +1686,6 @@ i18n("First Only");
 i18n("Watermark Text");
 i18n("Custom");
 i18n("Watermark Size (points)");
-i18n("24");
-i18n("30");
-i18n("36");
-i18n("42");
-i18n("48");
-i18n("54");
-i18n("60");
-i18n("66");
-i18n("72");
-i18n("78");
-i18n("84");
-i18n("90");
 i18n("90<A1>");
 i18n("75<A1>");
 i18n("60<A1>");
@@ -464,29 +1724,6 @@ i18n("2000 sheet input Tray 4");
 i18n("Multi-Bin Mailbox");
 i18n("Printer hard disk");
 i18n("Printer Memory");
-i18n("32");
-i18n("40");
-i18n("56");
-i18n("64");
-i18n("80");
-i18n("88");
-i18n("96");
-i18n("104");
-i18n("112");
-i18n("120");
-i18n("128");
-i18n("136");
-i18n("144");
-i18n("152");
-i18n("160");
-i18n("168");
-i18n("176");
-i18n("184");
-i18n("192");
-i18n("200");
-i18n("208");
-i18n("224");
-i18n("256");
 i18n("Multi-Bin Mailbox Mode");
 i18n("Mailbox");
 i18n("Stacking");
@@ -554,14 +1791,6 @@ i18n("8 Bin Mailbox (Mailbox mode)");
 i18n("8 Bin Mailbox (Stacker-Separator-Collator)");
 i18n("HP 3000-Sheet Stapler-Stacker");
 i18n("HP 3000-Sheet Stacker");
-i18n("288");
-i18n("320");
-i18n("352");
-i18n("384");
-i18n("416");
-i18n("448");
-i18n("480");
-i18n("512");
 i18n("Enabled");
 i18n("Disabled");
 i18n("Color Treatment");
@@ -652,7 +1881,6 @@ i18n(" 6");
 i18n(" 7");
 i18n(" 8");
 i18n(" 9");
-i18n("10");
 i18n("12 - 15 MB");
 i18n("16 - 19 MB");
 i18n(" Tray 5");
@@ -757,50 +1985,7 @@ i18n("24 - 27 MB");
 i18n("11x17 (Oversize 11.7x17.7)");
 i18n("System Name (if available)");
 i18n(" 1");
-i18n("11");
-i18n("12");
-i18n("13");
-i18n("14");
-i18n("15");
-i18n("16");
-i18n("17");
-i18n("18");
-i18n("19");
-i18n("20");
-i18n("21");
-i18n("22");
-i18n("23");
-i18n("25");
-i18n("26");
-i18n("27");
-i18n("28");
-i18n("29");
-i18n("31");
-i18n("33");
-i18n("34");
-i18n("35");
-i18n("37");
-i18n("38");
-i18n("39");
-i18n("41");
-i18n("43");
-i18n("44");
-i18n("45");
-i18n("46");
-i18n("47");
-i18n("49");
-i18n("50");
 i18n("PIN digit 1 (for Private Job)");
-i18n("0");
-i18n("1");
-i18n("2");
-i18n("3");
-i18n("4");
-i18n("5");
-i18n("6");
-i18n("7");
-i18n("8");
-i18n("9");
 i18n("PIN digit 2 (for Private Job)");
 i18n("PIN digit 3 (for Private Job)");
 i18n("PIN digit 4 (for Private Job)");
