@@ -25,6 +25,7 @@
 #include <kurl.h>
 
 class KListBox;
+class KListView;
 class QLineEdit;
 class QTextEdit;
 class FaxCtrl;
@@ -33,11 +34,21 @@ class KOpenWithHandler;
 class QTimeEdit;
 class QComboBox;
 class QPushButton;
+class QListViewItem;
 
 class KdeprintFax : public KMainWindow
 {
 	Q_OBJECT
 public:
+	struct FaxItem
+	{
+		QString number;
+		QString name;
+		QString enterprise;
+	};
+	typedef QValueList<FaxItem> FaxItemList;
+	typedef QValueList<FaxItem>::ConstIterator FaxItemListIterator;
+
 	KdeprintFax(QWidget *parent = 0, const char *name = 0);
 	~KdeprintFax();
 
@@ -45,9 +56,11 @@ public:
 	void setPhone(QString phone);
 	void sendFax( bool quitAfterSend );
 	QStringList files();
-	QString number() const;
-	QString name() const;
-	QString enterprise() const;
+	int faxCount() const;
+	//QString number( int i = 0 ) const;
+	//QString name( int i = 0 ) const;
+	//QString enterprise( int i = 0 ) const;
+	FaxItemList faxList() const;
 	QString comment() const;
 	QString time() const;
 	QString subject() const;
@@ -69,17 +82,23 @@ protected slots:
 	void slotMoveUp();
 	void slotMoveDown();
 	void slotCurrentChanged();
-    void slotConfigureKeys();
+	void slotFaxSelectionChanged();
+	void slotFaxRemove();
+	void slotFaxAdd();
+	void slotFaxExecuted( QListViewItem* );
 
 protected:
 	void initActions();
 	void dragEnterEvent(QDragEnterEvent*);
 	void dropEvent(QDropEvent*);
 	void updateState();
+	bool manualFaxDialog( QString& number, QString& name, QString& enterprise );
+	//QListViewItem* faxItem( int i = 0 ) const;
 
 private:
 	KListBox	*m_files;
-	QLineEdit	*m_number, *m_name, *m_enterprise, *m_subject;
+	KListView   *m_numbers;
+	QLineEdit	*m_subject;
 	QTextEdit	*m_comment;
 	FaxCtrl		*m_faxctrl;
 	QLabel		*m_msglabel;
@@ -87,6 +106,7 @@ private:
 	QTimeEdit	*m_time;
 	QComboBox	*m_timecombo;
 	QPushButton *m_upbtn, *m_downbtn;
+	QPushButton *m_newbtn, *m_abbtn, *m_delbtn;
 	bool m_quitAfterSend;
 };
 
