@@ -1,6 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -78,7 +78,7 @@ void JobTray::mousePressEvent(QMouseEvent *e)
 			{
 				KMJobViewer	*view = list.at(choice);
 				if (view->isVisible())
-					KWin::setActiveWindow(view->winId());
+					KWin::activateWindow(view->winId());
 				else
 					view->show();
 			}
@@ -166,6 +166,7 @@ void KJobViewerApp::slotJobsShown(KMJobViewer *view, bool hasJobs)
 {
 	if (!hasJobs && !view->isVisible() && !view->isSticky())
 	{
+		kdDebug() << "removing view: " << view->printer() << endl;
 		// the window is hidden and doesn't have any job shown -> destroy it
 		// closing won't have any effect as the KMJobViewer overload closeEvent()
 		m_views.remove(view->printer());
@@ -199,7 +200,7 @@ void KJobViewerApp::slotPrinterChanged(KMJobViewer *view, const QString& prname)
 	if (other)
 	{
 		if (other->isVisible())
-			KWin::setActiveWindow(other->winId());
+			KWin::activateWindow(other->winId());
 		else
 			other->show();
 	}
