@@ -50,6 +50,13 @@ KCMPrintMgr::KCMPrintMgr(QWidget *parent, const char *name)
 	QVBoxLayout	*main_ = new QVBoxLayout(this, 0, 0);
 	main_->addWidget(m_mainview);
 	main_->activate();
+	
+	KAboutData *about =
+	  new KAboutData(I18N_NOOP("kcmprintmgr"), I18N_NOOP("KDE Printing Management"),
+                  0, 0, KAboutData::License_GPL,
+                  I18N_NOOP("(c) 2000 - 2002 Michael Goffioul"));
+	about->addAuthor("Michael Goffioul", 0, "kdeprint@swing.be");
+	setAboutData(about);
 }
 
 QString KCMPrintMgr::quickHelp() const
@@ -65,20 +72,6 @@ QString KCMPrintMgr::quickHelp() const
                "a CUPS based printing system.");
 }
 
-const KAboutData* KCMPrintMgr::aboutData() const
-{
-
-    KAboutData *about =
-    new KAboutData(I18N_NOOP("kcmprintmgr"), I18N_NOOP("KDE Printing Management"),
-                  0, 0, KAboutData::License_GPL,
-                  I18N_NOOP("(c) 2000 - 2002 Michael Goffioul"));
-
-    about->addAuthor("Michael Goffioul", 0, "kdeprint@swing.be");
-
-    return about;
-}
-
 KCMPrintMgr::~KCMPrintMgr()
 {
-
 }
