@@ -1,6 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -21,12 +21,18 @@
 #define KIO_PRINT_H
 
 #include <kio/slavebase.h>
+#include <kio/global.h>
 #include <qstring.h>
+#include <qbuffer.h>
 
 class KMPrinter;
+namespace KIO {
+	class Job;
+}
 
-class KIO_Print : public KIO::SlaveBase
+class KIO_Print : public QObject, public KIO::SlaveBase
 {
+	Q_OBJECT
 public:
 	KIO_Print(const QCString& pool, const QCString& app);
 
@@ -34,8 +40,18 @@ public:
 	void get(const KURL& url);
 	void stat(const KURL& url);
 
+protected slots:
+	void slotResult( KIO::Job* );
+	void slotData( KIO::Job*, const QByteArray& );
+	void slotTotalSize( KIO::Job*, KIO::filesize_t );
+	void slotProcessedSize( KIO::Job*, KIO::filesize_t );
+
 private:
 	void listRoot();
+	void listDirDB( const KURL& );
+	void statDB( const KURL& );
+	bool getDBFile( const KURL& );
+	void getDB( const KURL& );
 	void showClassInfo(KMPrinter*);
 	void showPrinterInfo(KMPrinter*);
 	void showSpecialInfo(KMPrinter*);
@@ -45,6 +61,10 @@ private:
 	void showDriver(KMPrinter*);
 
 	bool loadTemplate(const QString& filename, QString& buffer);
+
+	QBuffer m_httpBuffer;
+	int     m_httpError;
+	QString m_httpErrorTxt;
 };
 
 #endif
