@@ -6,6 +6,7 @@
 #define __KBackgroundIface_h__
 
 #include <dcopobject.h>
+#include <qcolor.h>
 
 class KBackgroundIface : virtual public DCOPObject
 {
@@ -38,11 +39,31 @@ k_dcop:
      * @param mode The tiling mode. */
     virtual void setWallpaper(QString wallpaper, int mode) = 0;
 
+    /** Set color.
+     * @param c The color.
+     * @param isColorA true for foreground and false for background color. */
+    virtual void setColor(const QColor &c, bool isColorA) = 0;
+
     /** Change the wallpaper in "multi mode". */
     virtual void changeWallpaper() = 0;
 
     /** Enable/disable desktop background. */
     virtual void setBackgroundEnabled(const bool enable) = 0;
+
+    /** Return the current wallpaper for specified desk.
+     * @param desk desktop number, or 0 for the current visible desktop.
+     */
+    virtual QString currentWallpaper( int desk ) = 0;
+
+    /** Return the wallpaper list for specified desk.
+     * @param desk desktop number, or 0 for the current visible desktop.
+     */
+    virtual QStringList wallpaperList(int desk) = 0;
+
+    /** Return the wallpaper files for specified desk.
+     * @param desk desktop number, or 0 for the current visible desktop.
+     */
+    virtual QStringList wallpaperFiles(int desk) = 0;
 };
 
 #endif // __KBackgroundIface_h__
