@@ -1,6 +1,4 @@
 /* vi: ts=8 sts=4 sw=4
- *
- * $Id: bgmanager.h,v 1.28 2003/04/09 10:36:04 lunakl Exp $
  *
  * This file is part of the KDE project, module kdesktop.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -66,8 +64,11 @@ public:
     void setWallpaper(QString wallpaper, int mode);
     void setWallpaper(QString wallpaper);
     void changeWallpaper();
+    QString currentWallpaper(int desk);
     void setColor(const QColor & c, bool isColorA = true);
     void setBackgroundEnabled(const bool enable);
+    QStringList wallpaperList(int desk);
+    QStringList wallpaperFiles(int desk);
 
 signals:
     void initDone();
@@ -79,6 +80,7 @@ private slots:
     void slotChangeNumberOfDesktops(int);
     void repaintBackground();
     void desktopResized();
+    void clearRoot();
     
 private:
     void applyCommon(bool common);
@@ -87,6 +89,7 @@ private:
 
     int realDesktop();
     int effectiveDesktop();
+    int validateDesk(int desk);
 
     void renderBackground(int desk);
     void exportBackground(int pixmap, int desk);
