@@ -39,6 +39,7 @@
 #include <kdebug.h>
 #include <kstandarddirs.h>
 #include <kimageio.h>
+#include <kinputdialog.h>
 #include <kipc.h>
 #include <klocale.h>
 #include <kio/netaccess.h>
@@ -64,24 +65,27 @@
 #include <X11/Xatom.h>
 // ----
 
-class KRootWidget : public QObject
+KRootWidget::KRootWidget() : QObject()
 {
-public:
-   KRootWidget() : QObject() {
      kapp->desktop()->installEventFilter(this);
-   }
-   
-   bool eventFilter ( QObject *, QEvent * e )
-   {
+}
+
+bool KRootWidget::eventFilter ( QObject *, QEvent * e )
+{
      if (e->type() == QEvent::MouseButtonPress)
-     { 
-       QMouseEvent *me = (QMouseEvent *) e;
+     {
+       QMouseEvent *me = static_cast<QMouseEvent *>(e);
        KRootWm::self()->mousePressed( me->globalPos(), me->button() );
        return true;
      }
+     else if (e->type() == QEvent::Wheel)
+     {
+       QWheelEvent *we = static_cast<QWheelEvent *>(e);
+       emit wheelRolled(we->delta());
+       return true;
+     }
      return false; // Don't filter.
-   }
-};
+}
 
 // -----------------------------------------------------------------------------
 #define DEFAULT_DELETEACTION 1
@@ -89,24 +93,23 @@ public:
 // for multihead - from main.cc
 extern int kdesktop_screen_number;
 
+KDesktop::WheelDirection KDesktop::m_eWheelDirection = KDesktop::m_eDefaultWheelDirection;
+const char* KDesktop::m_wheelDirectionStrings[2] = { "Forward", "Reverse" };
+
 KDesktop::KDesktop( bool x_root_hack, bool auto_start, bool wait_for_kded ) :
+    DCOPObject( "KDesktopIface" ),
     QWidget( 0L, "desktop", WResizeNoErase | ( x_root_hack ? (WStyle_Customize | WStyle_NoBorder) : 0) ),
     // those two WStyle_ break kdesktop when the root-hack isn't used (no Dnd)
-
-    DCOPObject( "KDesktopIface" ), startup_id( NULL )
+   startup_id( NULL )
 {
   m_bAutoStart = auto_start;
   m_bWaitForKded = wait_for_kded;
   m_miniCli = 0; // created on demand
-  m_show_iconview = false;
   keys = 0; // created later
   KGlobal::locale()->insertCatalogue("kdesktop");
   KGlobal::locale()->insertCatalogue("libkonq"); // needed for apps using libkonq
 
   setCaption( "KDE Desktop");
-  KWin::setOnAllDesktops( winId(), true );
-  KWin::setType( winId(), NET::Desktop );
-  KWin::setState( winId(), NET::SkipPager );
 
   setAcceptDrops(true); // WStyle_Customize seems to disable that
   m_pKwinmodule = new KWinModule( this );
@@ -158,11 +161,19 @@ KDesktop::KDesktop( bool x_root_hack, bool auto_start, bool wait_for_kded ) :
   initRoot();
 
   QTimer::singleShot(0, this, SLOT( slotStart() ));
+
+#if (QT_VERSION-0 >= 0x030200) // XRANDR support
+  connect( kapp->desktop(), SIGNAL( resized( int )), SLOT( desktopResized()));
+#endif
 }
 
 void
 KDesktop::initRoot()
 {
+  Display *dpy = qt_xdisplay();
+  Window root = RootWindow(dpy, kdesktop_screen_number);
+  XDefineCursor(dpy, root, cursor().handle());
+
   KConfigGroup configGroup(KGlobal::config(), "General");
   m_bDesktopEnabled = configGroup.readBoolEntry("Enabled", true);
   if (!m_bDesktopEnabled && !m_pRootWidget)
@@ -171,15 +182,17 @@ KDesktop::initRoot()
      delete bgMgr;
      bgMgr = 0;
      if ( m_pIconView )
-        m_pIconView->slotSaveIconPositions();
+        m_pIconView->saveIconPositions();
      delete m_pIconView;
      m_pIconView = 0;
-     Display *dpy = qt_xdisplay();
-     Window root = RootWindow(dpy, kdesktop_screen_number);
-     XSelectInput(dpy, root, ButtonPressMask | PropertyChangeMask | StructureNotifyMask | SubstructureNotifyMask);
-     XDefineCursor(dpy, root, cursor().handle());
+
+     XWindowAttributes attrs;
+     XGetWindowAttributes(dpy, root, &attrs);
+     XSelectInput(dpy, root, attrs.your_event_mask | ButtonPressMask);
 
      m_pRootWidget = new KRootWidget;
+     connect(m_pRootWidget, SIGNAL(wheelRolled(int)), this, SLOT(slotSwitchDesktops(int)));
+
      // Geert Jansen: backgroundmanager belongs here
      // TODO tell KBackgroundManager if we change widget()
      bgMgr = new KBackgroundManager( m_pIconView, m_pKwinmodule );
@@ -188,7 +201,7 @@ KDesktop::initRoot()
      {
         delete KRootWm::self();
         KRootWm* krootwm = new KRootWm( this ); // handler for root menu (used by kdesktop on RMB click)
-        keys->setSlot("Lock Screen", krootwm, SLOT(slotLock()));
+        keys->setSlot("Lock Session", krootwm, SLOT(slotLock()));
         keys->updateConnections();
      }
   }
@@ -205,6 +218,8 @@ KDesktop::initRoot()
               this, SLOT( handleColorDropEvent( QDropEvent * ) ) );
      connect( m_pIconView, SIGNAL( newWallpaper( const KURL & ) ),
               this, SLOT( slotNewWallpaper( const KURL & ) ) );
+     connect( m_pIconView, SIGNAL( wheelRolled( int ) ),
+              this, SLOT( slotSwitchDesktops( int ) ) );
 
      // All the QScrollView/QWidget-specific stuff should go here, so that we can use
      // another qscrollview/widget instead of the iconview and use the same code
@@ -216,8 +231,7 @@ KDesktop::initRoot()
      m_pIconView->setFocusPolicy( StrongFocus );
      m_pIconView->viewport()->setFocusPolicy( StrongFocus );
      m_pIconView->setGeometry( geometry() );
-     if (m_show_iconview && !m_bInit)
-         m_pIconView->show();
+     m_pIconView->show();
 
      // Geert Jansen: backgroundmanager belongs here
      // TODO tell KBackgroundManager if we change widget()
@@ -232,10 +246,14 @@ KDesktop::initRoot()
         m_pIconView->start();
         delete KRootWm::self();
         KRootWm* krootwm = new KRootWm( this ); // handler for root menu (used by kdesktop on RMB click)
-        keys->setSlot("Lock Screen", krootwm, SLOT(slotLock()));
+        keys->setSlot("Lock Session", krootwm, SLOT(slotLock()));
         keys->updateConnections();
      }
    }
+
+   KWin::setType( winId(), NET::Desktop );
+   KWin::setState( winId(), NET::SkipPager );
+   KWin::setOnAllDesktops( winId(), true );
 }
 
 void
@@ -283,7 +301,7 @@ KDesktop::slotStart()
   // Global keys
   keys = new KGlobalAccel( this );
   (void) new KRootWm( this );
- 
+
 #include "kdesktopbindings.cpp"
 
   keys->readSettings();
@@ -313,6 +331,8 @@ KDesktop::slotStart()
    }
 
   connect(kapp, SIGNAL(appearanceChanged()), SLOT(slotConfigure()));
+
+  QTimer::singleShot(300, this, SLOT( slotUpAndRunning() ));
 }
 
 // -----------------------------------------------------------------------------
@@ -355,6 +375,14 @@ void KDesktop::initConfig()
     config->setGroup( "General" );
     set_vroot = config->readBoolEntry( "SetVRoot", false );
     slotSetVRoot(); // start timer
+
+    config->setGroup("Mouse Buttons");
+    m_bWheelSwitchesWorkspace = config->readBoolEntry("WheelSwitchesWorkspace", false);
+
+    const char* forward_string = m_wheelDirectionStrings[Forward];
+    const char* default_dir_string = m_wheelDirectionStrings[m_eDefaultWheelDirection];
+    m_eWheelDirection =
+            (config->readEntry("WheelDirection", default_dir_string) == forward_string) ? Forward : Reverse;
 }
 
 // -----------------------------------------------------------------------------
@@ -393,25 +421,23 @@ void KDesktop::popupExecuteCommand()
       info.setDesktop( currentDesktop );
 
   if ( m_miniCli->isVisible() ) {
-      KWin::setActiveWindow( m_miniCli->winId() );
+      KWin::forceActiveWindow( m_miniCli->winId() );
   } else {
-      QDesktopWidget *desktop = KApplication::desktop();
-      QRect rect = desktop->screenGeometry(desktop->screenNumber(QCursor::pos()));
+      QRect rect = KGlobalSettings::desktopGeometry(QCursor::pos());
       m_miniCli->move(rect.x() + (rect.width() - m_miniCli->width())/2,
                       rect.y() + (rect.height() - m_miniCli->height())/4);
-      m_miniCli->exec();
+      m_miniCli->show(); // non-modal
   }
 }
 
 void KDesktop::slotShowWindowList()
 {
-     KWin::setActiveWindow( winId() );
      KRootWm::self()->slotWindowList();
 }
 
 void KDesktop::slotShowTaskManager()
 {
-    kdDebug(1204) << "Launching KSysGuard..." << endl;
+    //kdDebug(1204) << "Launching KSysGuard..." << endl;
     KProcess* p = new KProcess;
     Q_CHECK_PTR(p);
 
@@ -558,7 +584,7 @@ void KDesktop::slotSetVRoot()
     if (!m_pIconView)
         return;
 
-    if (KWin::info(winId()).mappingState == NET::Withdrawn) {
+    if (KWin::windowInfo(winId()).mappingState() == NET::Withdrawn) {
         QTimer::singleShot(100, this, SLOT(slotSetVRoot()));
         return;
     }
@@ -592,7 +618,7 @@ void KDesktop::slotSetVRoot()
 void KDesktop::slotShutdown()
 {
     if ( m_pIconView )
-        m_pIconView->slotSaveIconPositions();
+        m_pIconView->saveIconPositions();
     if ( m_miniCli )
         m_miniCli->saveConfig();
 }
@@ -619,6 +645,21 @@ void KDesktop::updateWorkArea()
     }
 }
 
+void KDesktop::slotSwitchDesktops(int delta)
+{
+    if(m_bWheelSwitchesWorkspace && KWin::numberOfDesktops() > 1)
+    {
+      int newDesk, curDesk = KWin::currentDesktop();
+
+      if( (delta < 0 && m_eWheelDirection == Forward) || (delta > 0 && m_eWheelDirection == Reverse) )
+        newDesk = curDesk % KWin::numberOfDesktops() + 1;
+      else
+        newDesk = ( KWin::numberOfDesktops() + curDesk - 2 ) % KWin::numberOfDesktops() + 1;
+
+      KWin::setCurrentDesktop( newDesk );
+    }
+}
+
 void KDesktop::handleColorDropEvent(QDropEvent * e)
 {
     KPopupMenu popup;
@@ -631,7 +672,7 @@ void KDesktop::handleColorDropEvent(QDropEvent * e)
     switch (result) {
       case 1: bgMgr->setColor(c, true); break;
       case 2: bgMgr->setColor(c, false); break;
-      default: break;
+      default: return;
     }
     bgMgr->setWallpaper(0,0);
 }
@@ -639,10 +680,45 @@ void KDesktop::handleColorDropEvent(QDropEvent * e)
 void KDesktop::handleImageDropEvent(QDropEvent * e)
 {
     KPopupMenu popup;
-    popup.insertItem( SmallIconSet("background"),i18n("Set as &Wallpaper"), 1);
+    popup.insertItem(SmallIconSet("filesave"),i18n("&Save to Desktop..."), 1);
+    if (m_pIconView && m_pIconView->maySetWallpaper())
+       popup.insertItem(SmallIconSet("background"),i18n("Set as &Wallpaper"), 2);
+    popup.insertSeparator();
+    popup.insertItem(SmallIconSet("cancel"), i18n("&Cancel"));
     int result = popup.exec(e->pos());
 
     if (result == 1)
+    {
+        bool ok = true;
+        QString filename = KInputDialog::getText(QString::null, i18n("Enter a name for the image below:"), QString::null, &ok, m_pIconView);
+
+        if (!ok)
+        {
+            return;
+        }
+
+        if (filename.isEmpty())
+        {
+            filename = i18n("image.png");
+        }
+        else if (filename.right(4).lower() != ".png")
+        {
+            filename += ".png";
+        }
+
+        QImage i;
+        QImageDrag::decode(e, i);
+        KTempFile tmpFile(QString::null, filename);
+        i.save(tmpFile.name(), "PNG");
+        // We pass 0 as parent window because passing the desktop is not a good idea
+        KURL src;
+        src.setPath( tmpFile.name() );
+        KURL dest( KDIconView::desktopURL() );
+        dest.addPath( filename );
+        KIO::NetAccess::copy( src, dest, 0 );
+        tmpFile.unlink();
+    }
+    else if (result == 2)
     {
         QImage i;
         QImageDrag::decode(e, i);
@@ -658,7 +734,8 @@ void KDesktop::slotNewWallpaper(const KURL &url)
     // This is called when a file containing an image is dropped
     // (called by KonqOperations)
     QString tmpFile;
-    KIO::NetAccess::download( url, tmpFile );
+    // We pass 0 as parent window because passing the desktop is not a good idea
+    KIO::NetAccess::download( url, tmpFile, 0 );
     bgMgr->setWallpaper(tmpFile);
 }
 
@@ -669,7 +746,7 @@ void KDesktop::logout()
             KApplication::ShutdownTypeNone );
 }
 
-void KDesktop::logout( KApplication::ShutdownConfirm confirm, 
+void KDesktop::logout( KApplication::ShutdownConfirm confirm,
                        KApplication::ShutdownType sdtype )
 {
     if( !kapp->requestShutDown( confirm, sdtype ) )
@@ -683,7 +760,7 @@ void KDesktop::logout( KApplication::ShutdownConfirm confirm,
 void KDesktop::slotLogout()
 {
     logout( KApplication::ShutdownConfirmDefault,
-            KApplication::ShutdownTypeNone );
+            KApplication::ShutdownTypeDefault );
 }
 
 void KDesktop::slotLogoutNoCnf()
@@ -692,24 +769,12 @@ void KDesktop::slotLogoutNoCnf()
             KApplication::ShutdownTypeNone );
 }
 
-void KDesktop::slotHalt()
-{
-    logout( KApplication::ShutdownConfirmDefault,
-            KApplication::ShutdownTypeHalt );
-}
-
 void KDesktop::slotHaltNoCnf()
 {
     logout( KApplication::ShutdownConfirmNo,
             KApplication::ShutdownTypeHalt );
 }
 
-void KDesktop::slotReboot()
-{
-    logout( KApplication::ShutdownConfirmDefault,
-            KApplication::ShutdownTypeReboot );
-}
-
 void KDesktop::slotRebootNoCnf()
 {
     logout( KApplication::ShutdownConfirmNo,
@@ -730,6 +795,12 @@ void KDesktop::setVRoot( bool enable )
     slotSetVRoot();
 }
 
+void KDesktop::clearCommandHistory()
+{
+    if ( m_miniCli )
+        m_miniCli->clearHistory();
+}
+
 void KDesktop::setIconsEnabled( bool enable )
 {
     if ( enable == m_bDesktopEnabled )
@@ -744,12 +815,23 @@ void KDesktop::setIconsEnabled( bool enable )
     if (!enable) {
         delete m_pIconView;
         m_pIconView = 0;
-        m_show_iconview = false;
-    } else
-        m_show_iconview = true;
+    }
     configure();
 }
 
+void KDesktop::desktopResized()
+{
+    resize( kapp->desktop()->size());
+}
+
+void KDesktop::switchDesktops( int delta )
+{
+    bool old = m_bWheelSwitchesWorkspace;
+    m_bWheelSwitchesWorkspace = true;
+    slotSwitchDesktops(delta);
+    m_bWheelSwitchesWorkspace = old;
+}
+
 bool KDesktop::event(QEvent * e)
 {
     if ( e->type() == QEvent::WindowDeactivate)
