@@ -62,9 +62,13 @@ public:
      */
     virtual void configure();
 
+    /**
+     * Enable or disable "blank only" mode.  This is useful for
+     * laptops where one might not want a cpu thirsty screensaver
+     * draining the battery.
+     */
+    virtual void setBlankOnly( bool blankOnly );
 
-protected:
-    virtual bool x11Event(XEvent *);
 
 protected slots:
     void idleTimeout();
@@ -79,6 +83,8 @@ protected:
 protected:
     enum State { Waiting, Saving };
     bool        mEnabled;
+    bool	mDPMS;
+
     State       mState;
     XAutoLock   *mXAutoLock;
     KProcess    mLockProcess;
@@ -89,6 +95,8 @@ protected:
     int         mXInterval;
     int         mXBlanking;
     int         mXExposures;
+
+    bool	mBlankOnly;  // only use the blanker, not the defined saver
 };
 
 #endif
