@@ -73,7 +73,7 @@ Minicli::Minicli( QWidget *parent, const char *name)
         :KDialog( parent, name ),
          m_autoCheckedRunInTerm(false)
 {
-  setCaption( i18n("Run Command") );
+  setPlainCaption( i18n("Run Command") );
   KWin::setIcons( winId(), DesktopIcon("run"), SmallIcon("run") );
 
   QVBoxLayout* mainLayout = new QVBoxLayout( this, 0, KDialog::spacingHint() );
@@ -81,7 +81,7 @@ Minicli::Minicli( QWidget *parent, const char *name)
   mainLayout->addWidget(m_dlg);
 
   m_dlg->lbRunIcon->setPixmap(DesktopIcon("kmenu"));
-  m_dlg->lbComment->setAlignment( Qt::WordBreak );  
+  m_dlg->lbComment->setAlignment( Qt::WordBreak );
 
   m_dlg->cbCommand->setDuplicatesEnabled( false );
   m_dlg->cbCommand->setTrapReturnKey( true );
@@ -170,6 +170,8 @@ void Minicli::show()
   setMaxCommandBoxWidth();
   KWin::setState( winId(), NET::StaysOnTop );
   setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
+  adjustSize();
+  setFixedSize(size());
   KDialog::show();
   adjustSize();
   setFixedSize(size());
@@ -234,15 +236,15 @@ void Minicli::saveConfig()
   config->writePathEntry( "History", m_dlg->cbCommand->historyItems() );
   config->writePathEntry( "TerminalApps", m_terminalAppList );
   config->writePathEntry( "CompletionItems", m_dlg->cbCommand->completionObject()->items() );
-  
-  // Ensure that the current default completion mode will be used the next 
+
+  // Ensure that the current default completion mode will be used the next
   // time we read from the config file. That means do not store the default
   // completion mode...
   if( m_dlg->cbCommand->completionMode() == KGlobalSettings::completionMode() )
     config->deleteEntry("CompletionMode");
   else
     config->writeEntry( "CompletionMode", m_dlg->cbCommand->completionMode() );
-    
+
   config->sync();
 }
 
@@ -366,10 +368,11 @@ int Minicli::runCommand()
     return 1;
 
   QString cmd;
-  if ( m_filterData->uri().isLocalFile() && !m_filterData->uri().hasRef() )
-    cmd = m_filterData->uri().path();
+  KURL uri = m_filterData->uri();
+  if ( uri.isLocalFile() && !uri.hasRef() && uri.query().isEmpty() )
+    cmd = uri.path();
   else
-    cmd = m_filterData->uri().url();
+    cmd = uri.url();
 
   // Determine whether the application should be run through
   // the command line (terminal) interface...
@@ -400,7 +403,7 @@ int Minicli::runCommand()
       pw = getpwuid(getuid());
       if (pw == 0L)
       {
-          KMessageBox::error( this, i18n("You don't exist!\n"));
+          KMessageBox::error( this, i18n("You do not exist.\n"));
         return 1;
       }
     }
@@ -425,7 +428,7 @@ int Minicli::runCommand()
 
       if (proc_checkpwd.checkInstall(m_dlg->lePassword->password()) != 0)
       {
-          KMessageBox::sorry(this, i18n("Incorrect password! Please try again."));
+          KMessageBox::sorry(this, i18n("Incorrect password; please try again."));
         return 1;
       }
     }
@@ -513,7 +516,7 @@ int Minicli::runCommand()
           {
             // Look for desktop file
             KService::Ptr service = KService::serviceByDesktopName(cmd);
-            if (service)
+            if (service && service->isValid() && service->type() == "Application")
             {
               KRun::run(*service, KURL::List());
               return 0;
@@ -529,17 +532,14 @@ int Minicli::runCommand()
             if( m_filterData->hasArgsAndOptions() )
               cmd += m_filterData->argsAndOptions();
 
-            //kdDebug(1207) << "Command to execute: " << cmd << endl;
-            //kdDebug(1207) << "Executable name: " << exec << endl;
-
             break;
           }
           else
           {
-              KMessageBox::sorry( this, i18n("<center><b>%1</b></center>\n"
-                                        "You do not have permission to execute "
-                                        "this command!")
-                                        .arg( QStyleSheet::convertFromPlainText(cmd) ));
+            KMessageBox::sorry( this, i18n("<center><b>%1</b></center>\n"
+                                      "You do not have permission to execute "
+                                      "this command.")
+                                      .arg( QStyleSheet::convertFromPlainText(cmd) ));
             return 1;
           }
         }
@@ -549,21 +549,22 @@ int Minicli::runCommand()
         {
           // Look for desktop file
           KService::Ptr service = KService::serviceByDesktopName(cmd);
-          if (service)
-          {
-            KRun::run(*service, KURL::List());
-            return 0;
-          }
-          service = KService::serviceByName(cmd);
-          if (service)
+          if (service && service->isValid() && service->type() == "Application")
           {
             KRun::run(*service, KURL::List());
             return 0;
           }
 
-            KMessageBox::sorry( this, i18n("<center><b>%1</b></center>\n"
-                                      "Could not run the specified command!")
-                                      .arg( QStyleSheet::convertFromPlainText(cmd) ));
+          service = KService::serviceByName(cmd);
+          if (service && service->isValid() && service->type() == "Application")
+          {
+            KRun::run(*service, KURL::List());
+            return 0;
+          }
+
+          KMessageBox::sorry( this, i18n("<center><b>%1</b></center>\n"
+                                    "Could not run the specified command.")
+                                    .arg( QStyleSheet::convertFromPlainText(cmd) ));
           return 1;
         }
       }
@@ -573,8 +574,8 @@ int Minicli::runCommand()
       return 0;
     else
     {
-        KMessageBox::sorry( this, i18n("<center><b>%1</b></center>\n"
-                                  "The specified command does not exist!").arg(cmd) );
+      KMessageBox::sorry( this, i18n("<center><b>%1</b></center>\n"
+                                "The specified command does not exist.").arg(cmd) );
       return 1; // Let the user try again...
     }
   }
@@ -771,13 +772,10 @@ void Minicli::slotTerminal(bool enable)
     m_iconName = QString::fromLatin1( "konsole" );
     setIcon();
   }
-  else
+  else if (!m_prevIconName.isEmpty())
   {
-    if (!m_prevIconName.isEmpty())
-    {
       m_iconName = m_prevIconName;
       setIcon();
-    }
   }
 }
 
@@ -821,7 +819,7 @@ void Minicli::slotRealtime(bool enabled)
                 i18n("Running a realtime application can be very dangerous. "
                     "If the application misbehaves, the system might hang "
                     "unrecoverably.\nAre you sure you want to continue?"),
-                i18n("Warning - Run Command"))
+                i18n("Warning - Run Command"), KGuiItem(i18n("&Run Realtime")))
         != KMessageBox::Continue )
     {
       m_iScheduler = StubProcess::SchedNormal;
@@ -849,7 +847,7 @@ void Minicli::slotPriority(int priority)
 QString Minicli::calculate(const QString &exp)
 {
    QString result;
-   QString cmd = QString("echo $[%1]").arg(exp);
+   QString cmd = QString("echo $((%1))").arg(exp);
    FILE *fs = popen(QFile::encodeName(cmd).data(), "r");
    if (fs)
    {
