@@ -27,11 +27,13 @@
 #include <qfile.h>
 #include <qdatastream.h>
 #include <qregexp.h>
+#include <qtimer.h>
 #include <kmessagebox.h>
 #include <kapplication.h>
 #include <kdebug.h>
 //#include <ktopwidget.h>
 #include <kmainwindow.h>
+#include <kpassivepopup.h>
 
 #include "widgets.h"
 
@@ -40,6 +42,7 @@
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <kfiledialog.h>
+#include <kicondialog.h>
 
 using namespace std;
 
@@ -64,15 +67,17 @@ static KCmdLineOptions options[] =
     { "menu <text> [tag item] [tag item] ...", I18N_NOOP("Menu dialog"), 0 },
     { "checklist <text> [tag item status] ...", I18N_NOOP("Check List dialog"), 0 },
     { "radiolist <text> [tag item status] ...", I18N_NOOP("Radio List dialog"), 0 },
+    { "passivepopup <text> <timeout>", I18N_NOOP("Passive Popup"), 0 },
     { "getopenfilename [startDir] [filter]", I18N_NOOP("File dialog to open an existing file"), 0 },
     { "getsavefilename [startDir] [filter]", I18N_NOOP("File dialog to save a file"), 0 },
     { "getexistingdirectory [startDir]", I18N_NOOP("File dialog to select an existing directory"), 0 },
     { "getopenurl [startDir] [filter]", I18N_NOOP("File dialog to open an existing URL"), 0 },
     { "getsaveurl [startDir] [filter]", I18N_NOOP("File dialog to save a URL"), 0 },
+    { "geticon [group] [context]", I18N_NOOP("Icon chooser dialog"), 0 },
+    { "progressbar <text> [totalsteps]", I18N_NOOP("Progress bar dialog, returns a DCOP reference for communication"), 0},
 
     // TODO gauge stuff, reading values from stdin
 
-
     { "title <text>", I18N_NOOP("Dialog title"), 0 },
     { "separate-output", I18N_NOOP("Return list items on separate lines (for checklist option)"), 0 },
     { "print-winid", I18N_NOOP("Outputs the winId of each dialog"), 0 },
@@ -119,17 +124,7 @@ bool WinIdEmbedder::eventFilter(QObject *o, QEvent *e)
     return QObject::eventFilter(o, e);
 }
 
-// string to int, with default value
-int convert(const QString &val, int def)
-{
-  bool ok;
-  int result = val.toInt(&ok);
-  if (!ok)
-    result = def;
-  return result;
-}
-
-int directCommand(KCmdLineArgs *args)
+static int directCommand(KCmdLineArgs *args)
 {
     QString title;
     bool separateOutput = FALSE;
@@ -225,7 +220,7 @@ int directCommand(KCmdLineArgs *args)
         if ( type == KMessageBox::WarningContinueCancel ) {
             /* TODO configurable button texts*/
             ret = KMessageBox::messageBox( 0, type, text, title, KStdGuiItem::cont(),
-                KStdGuiItem::no(), dontagain ); 
+                KStdGuiItem::no(), dontagain );
         } else {
             ret = KMessageBox::messageBox( 0, type, text, title /*, TODO configurable button texts*/,
                 KStdGuiItem::yes(), KStdGuiItem::no(), dontagain );
@@ -261,6 +256,28 @@ int directCommand(KCmdLineArgs *args)
       return retcode ? 0 : 1;
     }
 
+    // --passivepopup
+    if (args->isSet("passivepopup"))
+      {
+        int duration = 0;
+        if (args->count() > 0)
+            duration = 1000 * QString::fromLocal8Bit(args->arg(0)).toInt();
+        if (duration == 0)
+            duration = 10000;
+	KPassivePopup *popup = KPassivePopup::message( title,
+						       QString::fromLocal8Bit( args->getOption("passivepopup") ),
+						       0, // icon
+						       0UL, // parent
+						       0, // name
+						       duration );
+	QTimer *timer = new QTimer();
+	QObject::connect( timer, SIGNAL( timeout() ), kapp, SLOT( quit() ) );
+	QObject::connect( popup, SIGNAL( clicked() ), kapp, SLOT( quit() ) );
+	timer->start( duration, TRUE );
+	kapp->exec();
+	return 0;
+      }
+
     // --textbox file [width] [height]
     if (args->isSet("textbox"))
     {
@@ -425,6 +442,64 @@ int directCommand(KCmdLineArgs *args)
         return 1; // cancelled
     }
 
+    // geticon [group] [context]
+    if (args->isSet("geticon")) {
+        QString groupStr, contextStr;
+        groupStr = QString::fromLocal8Bit(args->getOption("geticon"));
+        if (args->count() >= 1)  {
+            contextStr = QString::fromLocal8Bit(args->arg(0));
+        }
+        KIcon::Group group = KIcon::NoGroup;
+        if ( groupStr == QString::fromLatin1( "Desktop" ) )
+            group = KIcon::Desktop;
+        else if ( groupStr == QString::fromLatin1( "Toolbar" ) )
+            group = KIcon::Toolbar;
+        else if ( groupStr == QString::fromLatin1( "MainToolbar" ) )
+            group = KIcon::MainToolbar;
+        else if ( groupStr == QString::fromLatin1( "Small" ) )
+            group = KIcon::Small;
+        else if ( groupStr == QString::fromLatin1( "Panel" ) )
+            group = KIcon::Panel;
+        else if ( groupStr == QString::fromLatin1( "User" ) )
+            group = KIcon::User;
+        KIcon::Context context = KIcon::Any;
+        // From kicontheme.cpp
+        if ( contextStr == QString::fromLatin1( "Devices" ) )
+            context = KIcon::Device;
+        else if ( contextStr == QString::fromLatin1( "MimeTypes" ) )
+            context = KIcon::MimeType;
+        else if ( contextStr == QString::fromLatin1( "FileSystems" ) )
+            context = KIcon::FileSystem;
+        else if ( contextStr == QString::fromLatin1( "Applications" ) )
+            context = KIcon::Application;
+        else if ( contextStr == QString::fromLatin1( "Actions" ) )
+            context = KIcon::Action;
+
+        QString result = KIconDialog::getIcon( group, context, false, 0, false, 0, title );
+        if (!result.isEmpty())  {
+            cout << result.local8Bit().data() << endl;
+            return 0;
+        }
+        return 1; // cancelled
+    }
+
+    // --progressbar text totalsteps
+    if (args->isSet("progressbar"))
+    {
+       cout << "DCOPRef(kdialog-" << getpid() << ",ProgressDialog)" << endl;
+       if (fork())
+           exit(0);
+       close(1);
+
+       int totalsteps = 100;
+       QString text = QString::fromLocal8Bit(args->getOption("progressbar"));
+
+       if (args->count() == 1)
+           totalsteps = QString::fromLocal8Bit(args->arg(0)).toInt();
+
+       return Widgets::progressBar(0, title, text, totalsteps) ? 1 : 0;
+    }
+
     KCmdLineArgs::usage();
     return -2; // NOTREACHED
 }
@@ -433,9 +508,10 @@ int directCommand(KCmdLineArgs *args)
 int main(int argc, char *argv[])
 {
   KAboutData aboutData( "kdialog", I18N_NOOP("KDialog"),
-                        "0.9.5", I18N_NOOP( "KDialog can be used to show nice dialog boxes from shell scripts" ), KAboutData::License_BSD,
+                        "1.0", I18N_NOOP( "KDialog can be used to show nice dialog boxes from shell scripts" ), KAboutData::License_GPL,
                         "(C) 2000, Nick Thompson");
   aboutData.addAuthor("David Faure", I18N_NOOP("Current maintainer"),"faure@kde.org");
+  aboutData.addAuthor("Brad Hards", 0, "bradh@frogmouth.net");
   aboutData.addAuthor("Nick Thompson",0, 0/*"nickthompson@lucent.com" bounces*/);
   aboutData.addAuthor("Matthias Hölzer",0,"hoelzer@kde.org");
   aboutData.addAuthor("David Gümbel",0,"david.guembel@gmx.net");
