@@ -1,7 +1,7 @@
-/* $TOG: dm.c /main/73 1998/04/09 15:12:03 barstow $ */
 /*
 
 Copyright 1988, 1998  The Open Group
+Copyright 2000-2004 Oswald Buddenhagen <ossi@kde.org>
 
 Permission to use, copy, modify, distribute, and sell this software and its
 documentation for any purpose is hereby granted without fee, provided that
@@ -15,18 +15,17 @@ in all copies or substantial portions of the Software.
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-IN NO EVENT SHALL THE OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR
+IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-Except as contained in this notice, the name of The Open Group shall
+Except as contained in this notice, the name of a copyright holder shall
 not be used in advertising or otherwise to promote the sale, use or
 other dealings in this Software without prior written authorization
-from The Open Group.
+from the copyright holder.
 
 */
-/* $XFree86: xc/programs/xdm/dm.c,v 3.10 2000/04/27 16:26:50 eich Exp $ */
 
 /*
  * xdm - display manager daemon
@@ -42,9 +41,6 @@ from The Open Group.
 
 #include <stdio.h>
 #include <string.h>
-#ifdef __NetBSD__
-# include <sys/param.h>
-#endif
 
 #ifndef sigmask
 # define sigmask(m)  (1 << ((m - 1)))
@@ -93,17 +89,17 @@ from The Open Group.
 # endif
 # define LOGSTAT_FILE UTMPX_FILE
 #endif
-#ifdef linux
+#ifdef HAVE_VTS
 # include <sys/ioctl.h>
-# include <linux/vt.h>
+# include <sys/vt.h>
 #endif
 
-#if defined(SVR4) && !defined(SCO)
+#if defined(SVR4) && !defined(SCO) && !defined(sun)
 extern FILE    *fdopen();
 #endif
 
 static SIGVAL	SigHandler (int n);
-static void	RescanConfigs (void);
+static int	ScanConfigs (int force);
 static void	StartDisplays (void);
 #define XS_KEEP 0
 #define XS_RESTART 1
@@ -112,8 +108,6 @@ static void	ExitDisplay (struct display *d, int endState, int serverCmd, int goo
 static void	rStopDisplay (struct display *d, int endState);
 static int	CheckUtmp (void);
 static void	SwitchToTty (struct display *d);
-static void	openFifo (int *fifofd, char **fifoPath, const char *dname);
-static void	closeFifo (int *fifofd, const char *fifoPath);
 static void	stoppen (int force);
 static void	ReapChildren (void);
 static void	MainLoop (void);
@@ -127,11 +121,10 @@ static int TitleLen;
 
 static int StorePid (void);
 
-static int fifoFd = -1;
-static char *fifoPath;
-
 static int sdAction, Stopping;
 
+time_t now;
+
 char *prog, *progpath;
 
 int
@@ -149,6 +142,10 @@ main (int argc, char **argv)
 	dup2 (fd, 0);
 	close (fd);
     }
+    if (fcntl (1, F_GETFD) < 0)
+	dup2 (0, 1);
+    if (fcntl (2, F_GETFD) < 0)
+	dup2 (0, 2);
 
     if (argv[0][0] == '/') {
 	if (!StrDup (&progpath, argv[0]))
@@ -228,7 +225,10 @@ main (int argc, char **argv)
      */
     noDaemonMode = getppid();
     errorLogFile = 0;
-    opts = 0; *extStrArr (&opts) = (char *)"";
+    if (!(opts = Malloc (2 * sizeof(char *))))
+	return 1;
+    opts[0] = (char *)"";
+    opts[1] = 0;
     while (*++argv) {
 	if (**argv != '-')
 	    break;
@@ -237,12 +237,12 @@ main (int argc, char **argv)
 	    pt++;
 	if (!strcmp (pt, "help") || !strcmp (pt, "h")) {
 	    printf ("Usage: %s [options] [tty]\n"
-"  -daemon        - daemonize even when stared by init\n"
-"  -nodaemon      - don't daemonize even when stared from command line\n"
-"  -config <file> - use alternative master configuration file\n"
-"  -xrm <res>     - override frontend-specific resource\n"
-"  -debug <num>   - debug option bitfield\n"
-"  -error <file>  - use alternative log file\n", prog);
+"  -daemon        - Daemonize even when started by init\n"
+"  -nodaemon      - Don't daemonize even when started from command line\n"
+"  -config <file> - Use alternative master configuration file\n"
+"  -xrm <res>     - Override frontend-specific resource\n"
+"  -debug <num>   - Debug option bitfield\n"
+"  -error <file>  - Use alternative log file\n", prog);
 	    exit (0);
 	} else if (!strcmp (pt, "daemon"))
 	    noDaemonMode = 0;
@@ -251,7 +251,7 @@ main (int argc, char **argv)
 	else if (argv[1] && !strcmp (pt, "config"))
 	    StrDup (opts, *++argv);
 	else if (argv[1] && !strcmp (pt, "xrm"))
-	    StrDup (extStrArr (&opts), *++argv);
+	    opts = addStrArr (opts, *++argv, -1);
 	else if (argv[1] && !strcmp (pt, "debug"))
 	    sscanf (*++argv, "%i", &debugLevel);
 	else if (argv[1] && (!strcmp (pt, "error") || !strcmp (pt, "logfile")))
@@ -279,7 +279,7 @@ main (int argc, char **argv)
     /*
      * Step 1 - load configuration parameters
      */
-    if (!InitResources (opts) || !LoadDMResources (TRUE))
+    if (!InitResources (opts) || !ScanConfigs (FALSE))
 	LogPanic ("Config reader failed. Aborting ...\n");
 
     /* SUPPRESS 560 */
@@ -304,7 +304,6 @@ main (int argc, char **argv)
 
 #ifdef XDMCP
     init_session_id ();
-    CreateWellKnownSockets ();
 #else
     Debug ("not compiled for XDMCP\n");
 #endif
@@ -317,19 +316,17 @@ main (int argc, char **argv)
     (void) Signal (SIGINT, SigHandler);
     (void) Signal (SIGHUP, SigHandler);
     (void) Signal (SIGCHLD, SigHandler);
-    (void) Signal (SIGALRM, SigHandler);
     (void) Signal (SIGUSR1, SigHandler);
 
     /*
      * Step 2 - run a sub-daemon for each entry
      */
-    openFifo (&fifoFd, &fifoPath, 0);
 #ifdef XDMCP
-    ScanAccessDatabase (0);
+    UpdateListenSockets ();
 #endif
-    ScanServers (0);
+    openCtrl (0);
     MainLoop ();
-    closeFifo (&fifoFd, fifoPath);
+    closeCtrl (0);
     if (sdAction)
     {
 	if (Fork() <= 0)
@@ -346,10 +343,9 @@ main (int argc, char **argv)
 	    sigemptyset(&mask);
 	    sigaddset(&mask, SIGCHLD);
 	    sigaddset(&mask, SIGHUP);
-	    sigaddset(&mask, SIGALRM);
 	    sigsuspend(&mask);
 #else
-	    sigpause (sigmask (SIGCHLD) | sigmask (SIGHUP) | sigmask (SIGALRM));
+	    sigpause (sigmask (SIGCHLD) | sigmask (SIGHUP));
 #endif
 	}
     }
@@ -382,13 +378,13 @@ struct utmps {
 #define TIME_RELOG 10
 
 static struct utmps *utmpList;
+static time_t utmpTimeout = TO_INF;
 
 static int
 CheckUtmp (void)
 {
     static time_t modtim;
-    int nck, nextChk;
-    time_t now;
+    time_t nck;
     struct utmps *utp, **utpp;
     struct stat st;
 #ifdef BSD_UTMP
@@ -406,7 +402,6 @@ CheckUtmp (void)
     }
     if (!utmpList)
 	return 1;
-    time(&now);
     if (modtim != st.st_mtime)
     {
 #ifdef BSD_UTMP
@@ -472,14 +467,12 @@ CheckUtmp (void)
 #endif
 	modtim = st.st_mtime;
     }
-    nextChk = 1000;
     for (utpp = &utmpList; (utp = *utpp); )
     {
 	if (utp->state == UtWait)
 	{
-	    time_t remains = utp->time + (utp->hadSess ? TIME_RELOG : TIME_LOG) 
-			     - now;
-	    if (remains <= 0)
+	    time_t ends = utp->time + (utp->hadSess ? TIME_RELOG : TIME_LOG);
+	    if (ends <= now)
 	    {
 		struct display *d = utp->d;
 		Debug ("console login for %s at %." UT_LINESIZE_S "s timed out\n", 
@@ -490,20 +483,18 @@ CheckUtmp (void)
 		continue;
 	    }
 	    else
-		nck = remains;
+		nck = ends;
 	}
 	else
 #ifdef BSD_UTMP
-	    nck = (TIME_RELOG + 5) / 3;
+	    nck = (TIME_RELOG + 5) / 3 + now;
 #else
-	    nck = TIME_RELOG;
+	    nck = TIME_RELOG + now;
 #endif
-	if (nck < nextChk)
-	    nextChk = nck;
+	if (nck < utmpTimeout)
+	    utmpTimeout = nck;
 	utpp = &(*utpp)->next;
     }
-    if (nextChk < 1000)
-	alarm (nextChk);
     return 1;
 }
 
@@ -520,9 +511,8 @@ SwitchToTty (struct display *d)
 	d->status = notRunning;
 	return;
     }
-    if (!(utp = malloc (sizeof(*utp))))
+    if (!(utp = Malloc (sizeof(*utp))))
     {
-	LogOutOfMem("SwitchToTty");
 	d->status = notRunning;
 	return;
     }
@@ -532,7 +522,7 @@ SwitchToTty (struct display *d)
     utp->hadSess = 0;
     utp->next = utmpList;
     utmpList = utp;
-#ifdef linux	/* chvt */
+#ifdef HAVE_VTS	/* chvt */
     if (!memcmp(d->console, "tty", 3))
     {
 	int con = open ("/dev/console", O_RDONLY);
@@ -553,7 +543,7 @@ SwitchToTty (struct display *d)
     d->status = textMode;
 }
 
-static void
+void
 SwitchToX (struct display *d)
 {
     struct utmps *utp, **utpp;
@@ -569,6 +559,7 @@ SwitchToX (struct display *d)
 }
 
 
+#ifdef XDMCP
 static void
 StartRemoteLogin (struct display *d)
 {
@@ -582,24 +573,24 @@ StartRemoteLogin (struct display *d)
     switch (pid = Fork ()) {
     case 0:
 	argv = d->serverArgv;
-	if (d->authFile) {
-	    argv = addStrArr (argv, "-auth", 5);
-	    argv = addStrArr (argv, d->authFile, -1);
-	}
-	argv = addStrArr (argv, "-once", 5);
-	argv = addStrArr (argv, "-query", 6);
-	argv = addStrArr (argv, d->remoteHost, -1);
-	if (!argv) {
-	    LogError ("StartRemoteLogin: no arguments\n");
+	if (!(argv = addStrArr (argv, "-once", 5)) ||
+	    !(argv = addStrArr (argv, "-query", 6)) ||
+	    !(argv = addStrArr (argv, d->remoteHost, -1)))
 	    exit (1);
+#ifdef HAVE_VTS
+	if (d->serverVT && !d->reqSrvVT) {
+	    char vtstr[8];
+	    if (!(argv = addStrArr (argv, vtstr, sprintf (vtstr, "vt%d",
+							  d->serverVT))))
+		exit (1);
 	}
+#endif
 	Debug ("exec %\"[s\n", argv);
 	(void) execv (argv[0], argv);
 	LogError ("X server %\"s cannot be executed\n", argv[0]);
 	exit (1);
     case -1:
-	LogError ("Forking X server for remote login failed: %s",
-		  SysErrorMsg());
+	LogError ("Forking X server for remote login failed: %m");
 	d->status = notRunning;
 	return;
     default:
@@ -610,12 +601,13 @@ StartRemoteLogin (struct display *d)
 
     d->status = remoteLogin;
 }
+#endif
 
 
 static void
 StopInactiveDisplay (struct display *d)
 {
-    if (d->userSess < 0)
+    if (d->status != remoteLogin && d->userSess < 0)
 	StopDisplay (d);
 }
 
@@ -623,7 +615,8 @@ static void
 stoppen (int force)
 {
 #ifdef XDMCP
-    DestroyWellKnownSockets ();
+    request_port = 0;
+    UpdateListenSockets ();
 #endif
     if (force)
 	ForEachDisplay (StopDisplay);
@@ -633,7 +626,7 @@ stoppen (int force)
 }
 
 
-static void
+void
 doShutdown (int how, int when)
 {
     switch (when) {
@@ -652,80 +645,15 @@ doShutdown (int how, int when)
     sdAction = how;
 }
 
-
-static void
-openFifo (int *fifofd, char **fifopath, const char *dname)
-{
-    if (*fifoDir && *fifofd < 0) {
-	if (mkdir (fifoDir, 0755)) {
-	    if (errno != EEXIST) {
-		LogError ("mkdir %\"s failed; no control FiFos will be available\n", 
-			  fifoDir);
-		return;
-	    }
-	} else
-	    chmod (fifoDir, 0755); /* override umask */
-	if (!*fifopath)
-	    if (!StrApp (fifopath, fifoDir, dname ? "/xdmctl-" : "/xdmctl", 
-			 dname, (char *)0))
-		LogOutOfMem("openFifo");
-	if (*fifopath) {
-	    unlink (*fifopath);
-	    if (mkfifo (*fifopath, 0) < 0)
-		LogError ("Cannot create control FiFo %\"s\n", *fifopath);
-	    else {
-		chown (*fifopath, -1, fifoGroup);
-		chmod (*fifopath, 0620);
-		if ((*fifofd = open (*fifopath, O_RDWR | O_NONBLOCK)) >= 0) {
-		    RegisterCloseOnFork (*fifofd);
-		    RegisterInput (*fifofd);
-		    return;
-		}
-		unlink (*fifopath);
-		LogError ("Cannot open control FiFo %\"s\n", *fifopath);
-	    }
-	    free (*fifopath);
-	    *fifopath = 0;
-	}
-    }
-}
-
-static void
-closeFifo (int *fifofd, const char *fifopath)
-{
-    if (*fifofd >= 0) {
-	UnregisterInput (*fifofd);
-	CloseNClearCloseOnFork (*fifofd);
-	*fifofd = -1;
-	unlink (fifopath);
-    }
-}
-
-static char **
-splitCmd (const char *string, int len)
-{
-    const char *word;
-    char **argv;
-
-    argv = initStrArr (0);
-    for (word = string; ; string++, len--)
-	if (!len || *string == '\t') {
-	    argv = addStrArr (argv, word, string - word);
-	    if (!len)
-		return argv;
-	    word = string + 1;
-	}
-}
-
-static void
+void
 setNLogin (struct display *d, 
 	   const char *nuser, const char *npass, char *nargs, int rl)
 {
     struct disphist *he = d->hstent;
-    ReStr (&he->nuser, nuser);
-    ReStr (&he->npass, npass);
-    ReStr (&he->nargs, nargs);
-    he->rLogin = rl;
+    he->rLogin =
+       (ReStr (&he->nuser, nuser) &&
+	ReStr (&he->npass, npass) &&
+	ReStr (&he->nargs, nargs)) ? rl : 0;
     Debug ("set next login for %s, level %d\n", nuser, rl);
 }
 
@@ -733,7 +661,7 @@ static void
 processDPipe (struct display *d)
 {
     char *user, *pass, *args;
-    int cmd, how;
+    int cmd;
     GTalk dpytalk;
 #ifdef XDMCP
     int ct, len;
@@ -754,6 +682,8 @@ processDPipe (struct display *d)
     switch (cmd) {
     case D_User:
 	d->userSess = GRecvInt ();
+	d->userName = GRecvStr ();
+	d->sessName = GRecvStr ();
 	break;
     case D_ReLogin:
 	user = GRecvStr ();
@@ -764,11 +694,6 @@ processDPipe (struct display *d)
 	free (pass);
 	free (user);
 	break;
-    case D_Shutdown:
-	how = GRecvInt ();
-	doShutdown (how, GRecvInt ());
-	/* XXX after this all displays could be gone */
-	break;
 #ifdef XDMCP
     case D_ChooseHost:
 	ca.data = (unsigned char *)GRecvArr (&len);
@@ -796,160 +721,48 @@ processDPipe (struct display *d)
     }
 }
 
-static int
-parseSd (char **ar, int *how, int *when, int wdef)
+static void
+processGPipe (struct display *d)
 {
-    if (strcmp (ar[0], "shutdown"))
-	return 0;
-    *how = 0;
-    if (!ar[1] || (!ar[2] && wdef < 0)) {
-	LogInfo ("Missing argument(s) to FiFo command \"shutdown\"\n");
-	return 1;
+    int cmd, how;
+    GTalk dpytalk;
+
+    dpytalk.pipe = &d->gpipe;
+    if (Setjmp (dpytalk.errjmp)) {
+	StopDisplay (d);
+	return;
     }
-    if (ar[2]) {
-	if (!strcmp (ar[2], "forcenow"))
-	    *when = SHUT_FORCENOW;
-	else if (!strcmp (ar[2], "trynow"))
-	    *when = SHUT_TRYNOW;
-	else if (!strcmp (ar[2], "schedule"))
-	    *when = SHUT_SCHEDULE;
-	else {
-	    LogInfo ("Invalid mode spec %\"s to FiFo command \"shutdown\"\n", ar[2]);
-	    return 1;
-	}
-    } else
-	*when = wdef;
-    if (!strcmp (ar[1], "reboot"))
-	*how = SHUT_REBOOT;
-    else if (!strcmp (ar[1], "halt"))
-	*how = SHUT_HALT;
-    else
-	LogInfo ("Invalid type spec %\"s to FiFo command \"shutdown\"\n", ar[1]);
-    return 1;
-}
-
-static void
-processDFifo (const char *buf, int len, void *ptr)
-{
-    struct display *d = (struct display *)ptr;
-    char **ar = splitCmd (buf, len);
-    int how, when;
-
-    if (!ar[0])
+    GSet (&dpytalk);
+    if (!GRecvCmd (&cmd)) {
+	/* process already exited */
+	UnregisterInput (d->gpipe.rfd);
 	return;
-    if (parseSd (ar, &how, &when, d->defSdMode))
-    {
-	if (!how)
-	    return;
-	if (d->allowShutdown == SHUT_NONE ||
-	    (d->allowShutdown == SHUT_ROOT && d->userSess))
-	{
-	    LogInfo ("Display %s attempted FiFo command \"shutdown\"\n", d->name);
-	    return;
-	}
-	if (when == SHUT_FORCENOW &&
-	    (d->allowNuke == SHUT_NONE ||
-	    (d->allowNuke == SHUT_ROOT && d->userSess)))
-	{
-	    LogInfo ("Display %s attempted FiFo command \"shutdown forcenow\"\n",
-		     d->name);
-	    return;
-	}
-	d->hstent->sd_how = how;
-	d->hstent->sd_when = when;
-    } else if (!strcmp (ar[0], "lock")) {
-	d->hstent->lock = 1;
-#ifdef AUTO_RESERVE
-	if (AllLocalDisplaysLocked (0))
-	    StartReserveDisplay (0);
-#endif
-    } else if (!strcmp (ar[0], "unlock")) {
-	d->hstent->lock = 0;
-#ifdef AUTO_RESERVE
-	ReapReserveDisplays ();
-#endif
-    } else if (!strcmp (ar[0], "reserve")) {
-	if ((d->displayType & d_location) == dLocal) {
-	    int lt = 0;
-	    if (ar[1])
-		lt = atoi (ar[1]);
-	    StartReserveDisplay (lt ? lt : 60); /* XXX maybe make configurable? */
-	} else
-	    LogInfo ("Remote display %s attempted FiFo command \"reserve\"\n", d->name);
-    } else if (!strcmp (ar[0], "suicide")) {
-	if (d->status == running && d->pid != -1) {
-	    TerminateProcess (d->pid, SIGTERM);
-	    d->status = raiser;
-	}
-    } else
-	LogInfo ("Invalid FiFo command %\"s from display %s\n", ar[0], d->name);
-    freeStrArr (ar);
+    }
+    switch (cmd) {
+    case G_Shutdown:
+	how = GRecvInt ();
+	doShutdown (how, GRecvInt ());
+	break;
+    default:
+	LogError ("Internal error: unknown G_* command %d\n", cmd);
+	StopDisplay (d);
+	break;
+    }
 }
 
-static void
-processFifo (const char *buf, int len, void *ptr ATTR_UNUSED)
+
+static int
+ScanConfigs (int force)
 {
-    struct display *d;
-    char **ar = splitCmd (buf, len), *args, *asp, *adp;
-    int how, when;
-
-    if (!ar[0])
-	return;
-    if (parseSd (ar, &how, &when, -1)) {
-	if (!how)
-	    return;
-	if (!fifoAllowShutdown)
-	{
-	    LogInfo ("System shutdown via command FiFo forbidden\n");
-	    return;
-	}
-	if (when == SHUT_FORCENOW && !fifoAllowNuke)
-	{
-	    LogInfo ("Forced system shutdown via command FiFo forbidden\n");
-	    return;
-	}
-	doShutdown (how, when);
-    } else if (!strcmp (ar[0], "login")) {
-	if (arrLen (ar) < 5) {
-	    LogInfo ("Missing argument(s) to FiFo command %s\"\n", ar[0]);
-	    return;
-	}
-	if (!(d = FindDisplayByName (ar[1]))) {
-	    LogInfo ("Display %s in FiFo command %\"s not found\n", ar[1], ar[0]);
-	    return;
-	}
-	if (ar[5] && StrDup (&args, ar[5])) {
-	    for (asp = adp = args; *asp; asp++, adp++)
-		if (*asp == '\\')
-		    switch (*++asp) {
-		    case 0: asp--; /* fallthrough */
-		    case '\\': *adp = '\\'; break;
-		    case 'n': *adp = '\n'; break;
-		    case 't': *adp = '\t'; break;
-		    default: *adp++ = '\\'; *adp = *asp; break;
-		    }
-		else
-		    *adp = *asp;
-	    *adp = 0;
-	    setNLogin (d, ar[3], ar[4], args, 2);
-	    free (args);
-	} else
-	    setNLogin (d, ar[3], ar[4], 0, 2);
-	if (d->status == running && d->pid != -1) {
-	    if (d->userSess < 0 || !strcmp (ar[2], "now")) {
-		TerminateProcess (d->pid, SIGTERM);
-		d->status = raiser;
-	    }
-	} else if (d->status == reserve)
-	    d->status = notRunning;
-	else if (d->status == textMode && !strcmp (ar[2], "now"))
-	    SwitchToX (d);
-    } else
-	LogInfo ("Invalid FiFo command %\"s\n", ar[0]);
-    freeStrArr (ar);
+    if (!LoadDMResources (force))
+	return FALSE;
+    ScanServers (force);
+#ifdef XDMCP
+    ScanAccessDatabase (force);
+#endif
+    return TRUE;
 }
 
-
 static void
 MarkDisplay (struct display *d)
 {
@@ -957,25 +770,14 @@ MarkDisplay (struct display *d)
 }
 
 static void
-RescanConfigs (void)
+RescanConfigs (int force)
 {
-    LogInfo ("Rescanning all config files\n");
-    LoadDMResources (1);
-    ForEachDisplay (MarkDisplay);
-    ScanServers (1);
+    if (ScanConfigs (force)) {
 #ifdef XDMCP
-    ScanAccessDatabase (1);
-#endif
-}
-
-static void
-RescanIfMod (void)
-{
-    LoadDMResources (0);
-    ScanServers (0);
-#ifdef XDMCP
-    ScanAccessDatabase (0);
+	UpdateListenSockets ();
 #endif
+	updateCtrl ();
+    }
 }
 
 
@@ -994,23 +796,25 @@ ReapChildren (void)
     {
 	Debug ("manager wait returns  pid %d  sig %d  core %d  code %d\n",
 	       pid, waitSig(status), waitCore(status), waitCode(status));
-	if (autoRescan)
-	    RescanIfMod ();
 	/* SUPPRESS 560 */
 	if ((d = FindDisplayByPid (pid))) {
 	    d->pid = -1;
 	    UnregisterInput (d->pipe.rfd);
 	    GClosen (&d->pipe);
-	    closeFifo (&d->fifofd, d->fifoPath);
+	    UnregisterInput (d->gpipe.rfd);
+	    GClosen (&d->gpipe);
+	    closeCtrl (d);
 	    switch (waitVal (status)) {
 	    case EX_TEXTLOGIN:
 		Debug ("display exited with EX_TEXTLOGIN\n");
 		ExitDisplay (d, DS_TEXTMODE, 0, 0);
 		break;
+#ifdef XDMCP
 	    case EX_REMOTE:
 		Debug ("display exited with EX_REMOTE\n");
 		ExitDisplay (d, DS_REMOTE, 0, 0);
 		break;
+#endif
 #ifdef AUTO_RESERVE
 	    case EX_RESERVE:
 		Debug ("display exited with EX_RESERVE\n");
@@ -1094,6 +898,41 @@ ReapChildren (void)
 	    {
 	    case zombie:
 		Debug ("zombie X server for display %s reaped\n", d->name);
+#ifdef HAVE_VTS
+		if (d->serverVT && d->zstatus != DS_REMOTE)
+		{
+		    if (d->follower)
+		    {
+			d->follower->serverVT = d->serverVT;
+			d->follower = 0;
+		    }
+		    else
+		    {
+			int con = open ("/dev/console", O_RDONLY);
+			if (con >= 0)
+			{
+			    struct vt_stat vtstat;
+			    ioctl (con, VT_GETSTATE, &vtstat);
+			    if (vtstat.v_active == d->serverVT) {
+				int vt = 1;
+				struct display *di;
+				for (di = displays; di; di = di->next)
+				    if (di != d && di->serverVT)
+					vt = di->serverVT;
+				for (di = displays; di; di = di->next)
+				    if (di != d && di->serverVT &&
+					(di->userSess >= 0 ||
+					 di->status == remoteLogin))
+					vt = di->serverVT;
+				ioctl (con, VT_ACTIVATE, vt);
+			    }
+			    ioctl (con, VT_DISALLOCATE, d->serverVT);
+			    close (con);
+			}
+		    }
+		    d->serverVT = 0;
+		}
+#endif
 		rStopDisplay (d, d->zstatus);
 		break;
 	    case phoenix:
@@ -1194,29 +1033,52 @@ static void
 MainLoop (void)
 {
     struct display *d;
+    struct timeval *tvp, tv;
+    time_t to;
     int nready;
     char buf;
     FD_TYPE reads;
 
     Debug ("MainLoop\n");
+    time (&now);
     while (
 #ifdef XDMCP
-	   AnyWellKnownSockets() ||
+	   AnyListenSockets() ||
 #endif
 	   (Stopping ? AnyRunningDisplays() : AnyDisplaysLeft ()))
     {
 	if (!Stopping)
 	    StartDisplays ();
 	reads = WellKnownSocketsMask;
-#ifdef hpux
-	nready = select (WellKnownSocketsMax + 1, (int*)reads.fds_bits, 0, 0, 0);
-#else
-	nready = select (WellKnownSocketsMax + 1, &reads, 0, 0, 0);
-#endif
+	to = TO_INF;
+	if (serverTimeout < to)
+	    to = serverTimeout;
+	if (utmpTimeout < to)
+	    to = utmpTimeout;
+	if (to == TO_INF)
+	    tvp = 0;
+	else {
+	    to -= now;
+	    if (to < 0)
+		to = 0;
+	    tv.tv_sec = to;
+	    tv.tv_usec = 0;
+	    tvp = &tv;
+	}
+	nready = select (WellKnownSocketsMax + 1, &reads, 0, 0, tvp);
 	Debug ("select returns %d\n", nready);
+	time (&now);
 #if !defined(ARC4_RANDOM) && !defined(DEV_RANDOM)
 	AddTimerEntropy ();
 #endif
+	if (now >= serverTimeout) {
+	    serverTimeout = TO_INF;
+	    StartServerTimeout ();
+	}
+	if (now >= utmpTimeout) {
+	    utmpTimeout = TO_INF;
+	    CheckUtmp ();
+	}
 	if (nready > 0)
 	{
 	    /*
@@ -1237,16 +1099,14 @@ MainLoop (void)
 		    stoppen (TRUE);
 		    break;
 		case SIGHUP:
-		    RescanConfigs ();
+		    LogInfo ("Rescanning all config files\n");
+		    ForEachDisplay (MarkDisplay);
+		    RescanConfigs (TRUE);
 		    break;
 		case SIGCHLD:
 		    ReapChildren ();
-		    break;
-		case SIGALRM:
-		    if (startingServer && startingServer->serverStatus != ignore)
-			StartServerTimeout ();
-		    else
-			CheckUtmp ();
+		    if (!Stopping && autoRescan)
+			RescanConfigs (FALSE);
 		    break;
 		case SIGUSR1:
 		    if (startingServer && startingServer->serverStatus == starting)
@@ -1256,30 +1116,27 @@ MainLoop (void)
 		continue;
 	    }
 #ifdef XDMCP
-	    if (xdmcpFd >= 0 && FD_ISSET (xdmcpFd, &reads))
-	    {
-		ProcessRequestSocket ();
+	    if (ProcessListenSockets (&reads))
 		continue;
-	    }
 #endif	/* XDMCP */
-	    if (fifoFd >= 0 && FD_ISSET (fifoFd, &reads))
-	    {
-		FdGetsCall (fifoFd, processFifo, 0);
+	    if (handleCtrl (&reads, 0))
 		continue;
-	    }
 	    /* Must be last (because of the breaks)! */
+	  again:
 	    for (d = displays; d; d = d->next)
 	    {
-		if (d->fifofd >= 0 && FD_ISSET (d->fifofd, &reads))
-		{
-		    FdGetsCall (d->fifofd, processDFifo, d);
-		    break;
-		}
+		if (handleCtrl (&reads, d))
+		    goto again;
 		if (d->pipe.rfd >= 0 && FD_ISSET (d->pipe.rfd, &reads))
 		{
 		    processDPipe (d);
 		    break;
 		}
+		if (d->gpipe.rfd >= 0 && FD_ISSET (d->gpipe.rfd, &reads))
+		{
+		    processGPipe (d);
+		    break;
+		}
 	    }
 	}
     }
@@ -1288,22 +1145,112 @@ MainLoop (void)
 static void
 CheckDisplayStatus (struct display *d)
 {
-    if ((d->displayType & d_origin) == dFromFile)
+    if ((d->displayType & d_origin) == dFromFile && !d->stillThere)
+	StopDisplay (d);
+}
+
+static void
+KickDisplay (struct display *d)
+{
+    if (d->status == notRunning)
+	StartDisplay (d);
+    if (d->serverStatus == awaiting && !startingServer)
+	StartServer (d);
+}
+
+#ifdef HAVE_VTS
+static int active_vts;
+
+static int
+GetBusyVTs (void)
+{
+    struct vt_stat vtstat;
+    int con;
+
+    if (active_vts == -1)
     {
-	if (d->stillThere) {
-	    if (d->status == notRunning)
-		StartDisplay (d);
-	    if (d->serverStatus == awaiting && !startingServer)
-		StartServer (d);
-	} else
-	    StopDisplay (d);
+	vtstat.v_state = 0;
+	if ((con = open ("/dev/console", O_RDONLY)) >= 0)
+	{
+	    ioctl (con, VT_GETSTATE, &vtstat);
+	    close (con);
+	}
+	active_vts = vtstat.v_state;
+    }
+    return active_vts;
+}
+
+static void
+AllocateVT (struct display *d)
+{
+    struct display *cd;
+    int i, tvt, volun;
+
+    if ((d->displayType & d_location) == dLocal &&
+	d->status == notRunning && !d->serverVT)
+    {
+	if (d->reqSrvVT && d->reqSrvVT < 16)
+	    d->serverVT = d->reqSrvVT;
+	else
+	{
+	    for (i = tvt = 0;;)
+	    {
+                if (serverVTs[i])
+                {
+		    tvt = atoi (serverVTs[i++]);
+		    volun = 0;
+		    if (tvt < 0)
+		    {
+			tvt = -tvt;
+			volun = 1;
+		    }
+		    if (!tvt || tvt >= 16)
+			continue;
+		}
+		else
+		{
+		    if (++tvt >= 16)
+			break;
+		    volun = 1;
+		}
+		for (cd = displays; cd; cd = cd->next)
+		{
+		    if (cd->reqSrvVT == tvt && /* protect from lusers */
+			(cd->status != zombie || cd->zstatus != DS_REMOVE))
+			goto next;
+		    if (cd->serverVT == tvt)
+		    {
+			if (cd->status != zombie || cd->zstatus == DS_REMOTE)
+			    goto next;
+			if (!cd->follower)
+			{
+			    d->serverVT = -1;
+			    cd->follower = d;
+			    return;
+			}
+		    }
+		}
+		if (!volun || !((1 << tvt) & GetBusyVTs ()))
+		{
+		    d->serverVT = tvt;
+		    return;
+		}
+	  next: ;
+	    }
+	}
     }
 }
+#endif
 
 static void
 StartDisplays (void)
 {
     ForEachDisplay (CheckDisplayStatus);
+#ifdef HAVE_VTS
+    active_vts = -1;
+    ForEachDisplayRev (AllocateVT);
+#endif
+    ForEachDisplay (KickDisplay);
     CloseGetter ();
 }
 
@@ -1317,6 +1264,11 @@ StartDisplay (struct display *d)
 	return;
     }
 
+#ifdef HAVE_VTS
+    if (d->serverVT < 0)
+	return;
+#endif
+
     if (!LoadDisplayResources (d))
     {
 	LogError ("Unable to read configuration for display %s; stopping it.\n", 
@@ -1364,23 +1316,15 @@ StartDisplay (struct display *d)
 void
 StartDisplayP2 (struct display *d)
 {
-    char	*cname;
+    char	*cname, *cgname;
     int		pid;
 
-    openFifo (&d->fifofd, &d->fifoPath, d->name);
-#ifdef nofork_session
-    if (!nofork_session) {
-#endif
-	Debug ("forking session\n");
-	ASPrintf (&cname, "sub-daemon for display %s", d->name);
-	pid = GFork (&d->pipe, "master daemon", cname);
-#ifdef nofork_session
-    } else {
-	Debug ("not forking session\n");
-	CloseGetter ();
-	pid = -2;
-    }
-#endif
+    openCtrl (d);
+    Debug ("forking session\n");
+    ASPrintf (&cname, "sub-daemon for display %s", d->name);
+    ASPrintf (&cgname, "greeter for display %s", d->name);
+    pid = GFork (&d->pipe, "master daemon", cname,
+		 &d->gpipe, cgname);
     switch (pid)
     {
     case 0:
@@ -1388,15 +1332,9 @@ StartDisplayP2 (struct display *d)
 	if (debugLevel & DEBUG_WSESS)
 	    sleep (100);
 	mstrtalk.pipe = &d->pipe;
-#ifdef nofork_session
-    case -2:
-#endif
 	(void) Signal (SIGPIPE, SIG_IGN);
 	SetAuthorization (d);
 	WaitForServer (d);
-#ifdef nofork_session
-	if (!pid)
-#endif
 	if ((d->displayType & d_location) == dLocal) {
 	    GSet (&mstrtalk);
 	    GSendInt (D_XConnOk);
@@ -1404,14 +1342,16 @@ StartDisplayP2 (struct display *d)
 	ManageSession (d);
 	/* NOTREACHED */
     case -1:
-	closeFifo (&d->fifofd, d->fifoPath);
+	closeCtrl (d);
 	d->status = notRunning;
 	break;
     default:
 	Debug ("forked session, pid %d\n", pid);
 
 	/* (void) fcntl (d->pipe.rfd, F_SETFL, O_NONBLOCK); */
+	/* (void) fcntl (d->gpipe.rfd, F_SETFL, O_NONBLOCK); */
 	RegisterInput (d->pipe.rfd);
+	RegisterInput (d->gpipe.rfd);
 
 	d->pid = pid;
 	d->hstent->lock = d->hstent->rLogin = d->hstent->goodExit = 
@@ -1444,8 +1384,10 @@ rStopDisplay (struct display *d, int endState)
 	SwitchToTty (d);
     else if (endState == DS_RESERVE)
 	d->status = reserve;
+#ifdef XDMCP
     else if (endState == DS_REMOTE)
 	StartRemoteLogin (d);
+#endif
     else
     {
 	SwitchToX (d);
@@ -1479,6 +1421,12 @@ ExitDisplay (
 	   d->name, endState, serverCmd, goodExit);
 
     d->userSess = -1;
+    if (d->userName)
+	free (d->userName);
+    d->userName = 0;
+    if (d->sessName)
+	free (d->sessName);
+    d->sessName = 0;
     he = d->hstent;
     time (&he->lastExit);
     he->goodExit = goodExit;
