@@ -1,7 +1,7 @@
-/* $TOG: krb5auth.c /main/5 1998/02/09 13:55:32 kaleb $ */
 /*
 
 Copyright 1994, 1998  The Open Group
+Copyright 2003 Oswald Buddenhagen <ossi@kde.org>
 
 Permission to use, copy, modify, distribute, and sell this software and its
 documentation for any purpose is hereby granted without fee, provided that
@@ -15,26 +15,21 @@ in all copies or substantial portions of the Software.
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-IN NO EVENT SHALL THE OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR
+IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-Except as contained in this notice, the name of The Open Group shall
+Except as contained in this notice, the name of a copyright holder shall
 not be used in advertising or otherwise to promote the sale, use or
 other dealings in this Software without prior written authorization
-from The Open Group.
+from the copyright holder.
 
 */
-/* $XFree86: xc/programs/xdm/krb5auth.c,v 1.2 1998/10/10 15:25:35 dawes Exp $ */
 
 /*
  * xdm - display manager daemon
  * Author:  Stephen Gildea, The Open Group
- */
-
-/*
- * krb5auth
  *
  * generate Kerberos Version 5 authorization records
  */
@@ -75,7 +70,7 @@ Krb5CCacheName (const char *dname)
     if (!tmpdir)
 	tmpdir = "/tmp";
     dnl = strlen (dname);
-    name = malloc (strlen(tmpdir) + dnl + 20);
+    name = Malloc (strlen(tmpdir) + dnl + 20);
     if (!name)
 	return NULL;
     nl = sprintf (name, "FILE:%s/K5C", tmpdir);
@@ -89,7 +84,7 @@ Krb5GetAuthFor (unsigned short namelen, const char *name, const char *dname)
     Xauth *new;
     char *filename;
 
-    if (!(new = (Xauth *) malloc (sizeof *new)))
+    if (!(new = (Xauth *) Malloc (sizeof *new)))
 	return (Xauth *) 0;
     new->family = FamilyWild;
     new->address_length = 0;
@@ -120,7 +115,7 @@ Krb5GetAuthFor (unsigned short namelen, const char *name, const char *dname)
 	new->data_length = 0;
     }
 
-    if (!(new->name = (char *) malloc (namelen)))
+    if (!(new->name = (char *) Malloc (namelen)))
     {
 	free ((char *) new->data);
 	free ((char *) new);
