@@ -1,7 +1,7 @@
-/* $TOG: netaddr.c /main/9 1998/02/09 13:55:43 kaleb $ */
 /*
 
 Copyright 1991, 1998  The Open Group
+Copyright 2002 Sun Microsystems, Inc.  All rights reserved.
 
 Permission to use, copy, modify, distribute, and sell this software and its
 documentation for any purpose is hereby granted without fee, provided that
@@ -15,21 +15,21 @@ in all copies or substantial portions of the Software.
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-IN NO EVENT SHALL THE OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR
+IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-Except as contained in this notice, the name of The Open Group shall
+Except as contained in this notice, the name of a copyright holder shall
 not be used in advertising or otherwise to promote the sale, use or
 other dealings in this Software without prior written authorization
-from The Open Group.
+from the copyright holder.
 
 */
-/* $XFree86: xc/programs/xdm/netaddr.c,v 3.4 1998/10/10 15:25:36 dawes Exp $ */
 
 /*
- * xdm - X display manager
+ * xdm - display manager daemon
+ * Author:  Keith Packard, MIT X Consortium
  *
  * netaddr.c - Interpretation of XdmcpNetaddr object.
  */
@@ -42,15 +42,6 @@ from The Open Group.
 
 #include <X11/X.h>		/* FamilyInternet, etc. */
 
-#ifdef UNIXCONN
-#ifndef X_NO_SYS_UN
-#ifndef Lynx
-#include <sys/un.h>		/* struct sockaddr_un */
-#else
-#include <un.h>			/* struct sockaddr_un */
-#endif
-#endif
-#endif
 #ifdef DNETCONN
 #include <netdnet/dn.h>		/* struct sockaddr_dn */
 #endif
@@ -84,6 +75,11 @@ char * NetaddrPort(XdmcpNetaddr netaddrp, int *lenp)
     case AF_INET:
 	*lenp = 2;
 	return (char *)&(((struct sockaddr_in *)netaddrp)->sin_port);
+#if defined(IPv6) && defined(AF_INET6)
+    case AF_INET6:
+	*lenp = 2;
+	return (char *)&(((struct sockaddr_in6 *)netaddrp)->sin6_port);
+#endif
     default:
 	*lenp = 0;
 	return NULL;
@@ -111,6 +107,19 @@ char * NetaddrAddress(XdmcpNetaddr netaddrp, int *lenp)
     case AF_INET:
 	*lenp = sizeof (struct in_addr);
 	return (char *) &(((struct sockaddr_in *)netaddrp)->sin_addr);
+#if defined(IPv6) && defined(AF_INET6)
+    case AF_INET6:
+    {
+	struct in6_addr *a = &(((struct sockaddr_in6 *)netaddrp)->sin6_addr);
+	if (IN6_IS_ADDR_V4MAPPED(a)) {
+	    *lenp = sizeof (struct in_addr);
+	    return ((char *) &(a->s6_addr))+12;
+	} else {
+	    *lenp = sizeof (struct in6_addr);
+	    return (char *) &(a->s6_addr);
+	}
+    }
+#endif
 #endif
 #ifdef DNETCONN
     case AF_DECnet:
@@ -162,6 +171,14 @@ int ConvertAddr (XdmcpNetaddr saddr, int *len, char **addr)
       case AF_INET:
 	retval = FamilyInternet;
 	break;
+#if defined(IPv6) && defined(AF_INET6)
+      case AF_INET6:
+	if (*len == sizeof(struct in_addr)) 
+	    retval = FamilyInternet;
+	else  
+	    retval = FamilyInternet6;
+	break;
+#endif
 #endif
 #ifdef DNETCONN
       case AF_DECnet:
@@ -229,6 +246,19 @@ PrintSockAddr (char *buf, struct sockaddr *a, int len)
 	sprintf (buf, "family AF_INET, port %d, host %d.%d.%d.%d",
 		 (p[0] << 8) + p[1], t[0], t[1], t[2], t[3]);
 	break;
+#endif
+#if defined(IPv6) && defined(AF_INET6)
+    case AF_INET6:
+	{
+	char astr[INET6_ADDRSTRLEN] = "";
+	
+	inet_ntop(a->sa_family, &((struct sockaddr_in6 *) a)->sin6_addr,
+	  astr, sizeof(astr));
+	p = (unsigned char *) &((struct sockaddr_in6 *) a)->sin6_port;
+		
+	Debug ("port %d, host %s\n", (p[0] << 8) + p[1], astr);
+	break;
+	}
 #endif
     default:
 	sprintf (buf, "unknown family %d", a->sa_family);
