@@ -1,7 +1,7 @@
-/* $TOG: policy.c /main/13 1998/02/09 13:55:49 kaleb $ */
 /*
 
 Copyright 1988, 1998  The Open Group
+Copyright 2001 Oswald Buddenhagen <ossi@kde.org>
 
 Permission to use, copy, modify, distribute, and sell this software and its
 documentation for any purpose is hereby granted without fee, provided that
@@ -15,15 +15,15 @@ in all copies or substantial portions of the Software.
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-IN NO EVENT SHALL THE OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR
+IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-Except as contained in this notice, the name of The Open Group shall
+Except as contained in this notice, the name of a copyright holder shall
 not be used in advertising or otherwise to promote the sale, use or
 other dealings in this Software without prior written authorization
-from The Open Group.
+from the copyright holder.
 
 */
 
@@ -33,7 +33,6 @@ from The Open Group.
  *
  * policy.c.  Implement site-dependent policy for XDMCP connections
  */
-/* $XFree86: xc/programs/xdm/policy.c,v 3.4 1998/12/06 06:08:48 dawes Exp $ */
 
 #ifdef XDMCP
 
@@ -78,10 +77,10 @@ ChooseAuthentication (ARRAYofARRAY8Ptr authenticationNames)
 
 int
 CheckAuthentication (
-    struct protoDisplay	*pdpy,
-    ARRAY8Ptr		displayID,
-    ARRAY8Ptr		name,
-    ARRAY8Ptr		data)
+    struct protoDisplay	*pdpy ATTR_UNUSED,
+    ARRAY8Ptr		displayID ATTR_UNUSED,
+    ARRAY8Ptr		name ATTR_UNUSED,
+    ARRAY8Ptr		data ATTR_UNUSED)
 {
 #ifdef HASXDMAUTH
     if (name->length && !memcmp ((char *)name->data, "XDM-AUTHENTICATION-1", 20))
@@ -240,7 +239,7 @@ Willing (
 #endif
     }
     status->length = strlen (statusBuf);
-    status->data = (CARD8Ptr) malloc (status->length);
+    status->data = (CARD8Ptr) Malloc (status->length);
     if (!status->data)
 	status->length = 0;
     else
@@ -261,10 +260,31 @@ Accept (
 /*ARGSUSED*/
 int
 SelectConnectionTypeIndex (
-    ARRAY16Ptr	     connectionTypes ATTR_UNUSED,
+    ARRAY16Ptr	     connectionTypes,
     ARRAYofARRAY8Ptr connectionAddresses ATTR_UNUSED)
 {
-    return 0;
+    int i;
+
+    /* 
+     * Select one supported connection type 
+     */
+
+    for (i = 0; i < connectionTypes->length; i++) {
+	switch (connectionTypes->data[i]) {
+	  case FamilyLocal:
+#if defined(TCPCONN)
+	  case FamilyInternet:
+# if defined(IPv6) && defined(AF_INET6) 
+	  case FamilyInternet6:
+# endif /* IPv6 */
+#endif /* TCPCONN */
+#if defined(DNETCONN)
+	  case FamilyDECnet:
+#endif /* DNETCONN */
+	    return i;
+	}
+    } /* for */
+    return -1;
 }
 
 #endif /* XDMCP */
