@@ -1,6 +1,6 @@
 /*
 
-Copyright 1988, 1998  The Open Group
+Copyright 2001,2002,2004 Oswald Buddenhagen <ossi@kde.org>
 
 Permission to use, copy, modify, distribute, and sell this software and its
 documentation for any purpose is hereby granted without fee, provided that
@@ -14,25 +14,23 @@ in all copies or substantial portions of the Software.
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-IN NO EVENT SHALL THE OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR
+IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-Except as contained in this notice, the name of The Open Group shall
+Except as contained in this notice, the name of a copyright holder shall
 not be used in advertising or otherwise to promote the sale, use or
 other dealings in this Software without prior written authorization
-from The Open Group.
+from the copyright holder.
 
 */
-/* $XFree86: $ */
 
 /*
  * xdm - display manager daemon
  * Author:  Keith Packard, MIT X Consortium
  *
  * printf.c - working horse of error.c
- *
  */
 
 /*
@@ -62,11 +60,10 @@ from The Open Group.
  *     - , -> short for |','
  *     - { -> short for ('{')' }'<' '|''
  *   - the pointer to the array is the last argument to the format
- *
+ * - the %m conversion from syslog() is supported
  */
 
 /**************************************************************
- * (C) 2001-2002 Oswald Buddenhagen <ossi@kde.org>
  * Partially stolen from OpenSSH's OpenBSD compat directory.
  * (C) Patrick Powell, Brandon Long, Thomas Roessler, 
  *     Michael Elkins, Ben Lindstrom
@@ -298,7 +295,7 @@ DoPr (OutCh dopr_outch, void *bp, const char *format, va_list args)
     void *arptr;
 #endif
     unsigned long value;
-    int radix, min, max, flags, cflags;
+    int radix, min, max, flags, cflags, errn;
 #ifdef PRINT_ARRAYS
     int arlen;
     unsigned aridx;
@@ -313,6 +310,7 @@ DoPr (OutCh dopr_outch, void *bp, const char *format, va_list args)
 # endif
     radix = 0;
 #endif
+    errn = errno;
     for (;;) {
 	for (;;) {
 	    NCHR;
@@ -431,6 +429,9 @@ DoPr (OutCh dopr_outch, void *bp, const char *format, va_list args)
 	case '%':
 	    dopr_outch (bp, ch);
 	    break;
+	case 'm':
+	    fmtstr (dopr_outch, bp, strerror (errn), flags, min, max);
+	    break;
 	case 'c':
 	    dopr_outch (bp, va_arg (args, int));
 	    break;
@@ -546,6 +547,12 @@ DoPr (OutCh dopr_outch, void *bp, const char *format, va_list args)
  */
 #ifndef NO_LOGGER
 
+#include <stdio.h>
+#include <time.h>	/* XXX this will break on stone-age systems */
+#ifndef Time_t
+# define Time_t time_t
+#endif
+
 #ifdef USE_SYSLOG
 # include <syslog.h>
 # ifdef LOG_NAME
@@ -555,12 +562,9 @@ DoPr (OutCh dopr_outch, void *bp, const char *format, va_list args)
 # endif
 static int lognums[] = { LOG_DEBUG, LOG_INFO, LOG_ERR, LOG_CRIT };
 #else
-# include <stdio.h>
-# include <time.h>	/* XXX this will break on stone-age systems */
-# ifndef Time_t
-#  define Time_t time_t
-# endif
 # define InitLog() while(0)
+#endif
+
 static const char *lognams[] = { "debug", "info", "error", "panic" };
 
 static void
@@ -570,26 +574,43 @@ logTime (char *dbuf)
     (void) time (&tim);
     strftime (dbuf, 20, "%b %e %H:%M:%S", localtime (&tim));
 }
+
+#if defined(LOG_DEBUG_MASK) || defined(USE_SYSLOG)
+STATIC int debugLevel;
 #endif
 
+#define OOMSTR "Out of memory. Expect problems.\n"
+
 STATIC void
-LogOutOfMem (const char *fkt)
+LogOutOfMem (void)
 {
+    static Time_t last;
+    time_t tnow;
+
+    time (&tnow);
+    if (last + 100 > tnow) {	/* don't log bursts */
+	last = tnow;
+	return;
+    }
+    last = tnow;
 #ifdef USE_SYSLOG
-    syslog (LOG_CRIT, "Out of memory in %s()", fkt);
-#else
-    int el;
-    char dbuf[24], sbuf[128];
-    logTime (dbuf);
-    el = sprintf (sbuf, "%s "
-# ifdef LOG_NAME
-	LOG_NAME "[%ld]: Out of memory in %s()\n", dbuf, 
-# else
-	"%s[%ld]: Out of memory in %s()\n", dbuf, prog, 
-# endif
-	(long)getpid(), fkt);
-    write (2, sbuf, el);
+    if (!(debugLevel & DEBUG_NOSYSLOG))
+	syslog (LOG_CRIT, OOMSTR);
+    else
 #endif
+    {
+	int el;
+	char dbuf[24], sbuf[128];
+	logTime (dbuf);
+	el = sprintf (sbuf, "%s "
+#ifdef LOG_NAME
+	    LOG_NAME "[%ld]: " OOMSTR, dbuf, 
+#else
+	    "%s[%ld]: " OOMSTR, dbuf, prog, 
+#endif
+	    (long)getpid());
+	write (2, sbuf, el);
+    }
 }
 
 typedef struct {
@@ -603,11 +624,14 @@ OutChLFlush (OCLBuf *oclbp)
 {
     if (oclbp->clen) {
 #ifdef USE_SYSLOG
-	syslog (lognums[oclbp->type], "%.*s", oclbp->clen, oclbp->buf);
-#else
-	oclbp->buf[oclbp->clen] = '\n';
-	write (2, oclbp->buf, oclbp->clen + 1);
+	if (!(debugLevel & DEBUG_NOSYSLOG))
+	    syslog (lognums[oclbp->type], "%.*s", oclbp->clen, oclbp->buf);
+	else
 #endif
+	{
+	    oclbp->buf[oclbp->clen] = '\n';
+	    write (2, oclbp->buf, oclbp->clen + 1);
+	}
 	oclbp->clen = 0;
     }
 }
@@ -622,41 +646,38 @@ OutChL (void *bp, char c)
     if (c == '\n')
 	OutChLFlush (oclbp);
     else {
-#ifndef USE_SYSLOG
 	if (oclbp->clen >= oclbp->blen - 1) {
-#else
-	if (oclbp->clen >= oclbp->blen) {
-#endif
 	    if (oclbp->buf == oclbp->lmbuf) {
 		OutChLFlush (oclbp);
 		oclbp->buf = 0;
 		oclbp->blen = 0;
 	    }
 	    nlen = oclbp->blen * 3 / 2 + 128;
-	    nbuf = realloc (oclbp->buf, nlen);
+	    nbuf = Realloc (oclbp->buf, nlen);
 	    if (nbuf) {
 		oclbp->buf = nbuf;
 		oclbp->blen = nlen;
 	    } else {
-		LogOutOfMem ("Logger");
 		OutChLFlush (oclbp);
 		oclbp->buf = oclbp->lmbuf;
 		oclbp->blen = sizeof(oclbp->lmbuf);
 	    }
 	}
-#ifndef USE_SYSLOG
+#ifdef USE_SYSLOG
+	if (!oclbp->clen && (debugLevel & DEBUG_NOSYSLOG)) {
+#else
 	if (!oclbp->clen) {
+#endif
 	    char dbuf[24];
 	    logTime (dbuf);
 	    oclbp->clen = sprintf (oclbp->buf, "%s "
-# ifdef LOG_NAME
+#ifdef LOG_NAME
 		LOG_NAME "[%ld] %s: ", dbuf, 
-# else
+#else
 		"%s[%ld] %s: ", dbuf, prog, 
-# endif
+#endif
 	    (long)getpid(), lognams[oclbp->type]);
 	}
-#endif
 	oclbp->buf[oclbp->clen++] = c;
     }
 }
@@ -676,8 +697,6 @@ Logger (int type, const char *fmt, va_list args)
 }
 
 #ifdef LOG_DEBUG_MASK
-STATIC int debugLevel;
-
 STATIC void
 Debug (const char *fmt, ...)
 {
@@ -751,9 +770,8 @@ OutCh_OCF (void *bp, char c)
 	if (ocfbp->blen < 0)	
 	    return;
 	nlen = ocfbp->blen * 3 / 2 + 100;
-	nbuf = realloc (ocfbp->buf, nlen);
+	nbuf = Realloc (ocfbp->buf, nlen);
 	if (!nbuf) {
-	    LogOutOfMem ("FdPrintf");
 	    free (ocfbp->buf);
 	    ocfbp->blen = -1;
 	    ocfbp->buf = 0;
@@ -804,13 +822,12 @@ OutCh_OCA (void *bp, char c)
 	if (ocabp->blen < 0)	
 	    return;
 	nlen = ocabp->blen * 3 / 2 + 100;
-	nbuf = realloc (ocabp->buf, nlen);
+	nbuf = Realloc (ocabp->buf, nlen);
 	if (!nbuf) {
 	    free (ocabp->buf);
 	    ocabp->blen = -1;
 	    ocabp->buf = 0;
 	    ocabp->clen = 0;
-	    LogOutOfMem ("VASPrintf");
 	    return;
 	}
 	ocabp->blen = nlen;
@@ -826,7 +843,7 @@ VASPrintf (char **strp, const char *fmt, va_list args)
 
     DoPr(OutCh_OCA, &ocab, fmt, args);
     OutCh_OCA(&ocab, 0);
-    *strp = realloc (ocab.buf, ocab.clen);
+    *strp = Realloc (ocab.buf, ocab.clen);
     if (!*strp)
 	*strp = ocab.buf;
     return ocab.tlen;
