@@ -1,7 +1,7 @@
-/* $TOG: session.c /main/79 1998/02/09 13:56:17 kaleb $ */
 /*
 
 Copyright 1988, 1998  The Open Group
+Copyright 2001-2004 Oswald Buddenhagen <ossi@kde.org>
 
 Permission to use, copy, modify, distribute, and sell this software and its
 documentation for any purpose is hereby granted without fee, provided that
@@ -15,24 +15,23 @@ in all copies or substantial portions of the Software.
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-IN NO EVENT SHALL THE OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR
+IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-Except as contained in this notice, the name of The Open Group shall
+Except as contained in this notice, the name of a copyright holder shall
 not be used in advertising or otherwise to promote the sale, use or
 other dealings in this Software without prior written authorization
-from The Open Group.
+from the copyright holder.
 
 */
-/* $XFree86: xc/programs/xdm/session.c,v 3.23 2000/06/17 00:27:34 dawes Exp $ */
 
 /*
  * xdm - display manager daemon
  * Author:  Keith Packard, MIT X Consortium
  *
- * session.c
+ * subdaemon and external process management and communication
  */
 
 #define NEED_SIGNAL
@@ -42,6 +41,12 @@ from The Open Group.
 #include <ctype.h>
 #include <stdio.h>
 #include <stdarg.h>
+#ifndef X_NOT_POSIX
+# include <unistd.h>
+# ifdef _POSIX_PRIORITY_SCHEDULING
+#  include <sched.h>
+# endif
+#endif
 
 
 SIGVAL (*Signal (int sig, SIGFUNC handler))(int)
@@ -84,6 +89,12 @@ RegisterCloseOnFork (int fd)
 	max = fd;
 }
 
+void
+ClearCloseOnFork (int fd)
+{
+    FD_CLR (fd, &CloseMask);
+}
+
 void
 CloseNClearCloseOnFork (int fd)
 {
@@ -156,7 +167,7 @@ Wait4 (int pid)
 #endif
 	if (errno != EINTR)
 	{
-	    Debug ("Wait4(%d) failed: %s\n", pid, SysErrorMsg() );
+	    Debug ("Wait4(%d) failed: %m\n", pid);
 	    return 0;
 	}
     return waitVal (result);
@@ -176,6 +187,7 @@ execute (char **argv, char **env)
     if (errno != ENOENT) {
 	char	*e, **newargv;
 	FILE	*f;
+	int	nu;
 	char	program[1024];
 
 	/*
@@ -200,9 +212,14 @@ execute (char **argv, char **env)
 	    newargv = parseArgs (0, program + 2);
 	else
 	    newargv = addStrArr (0, "/bin/sh", 7);
-	mergeStrArrs (&newargv, argv);
-	Debug ("shell script execution: %[s\n", newargv);
-	execve (newargv[0], newargv, env);
+	if (!newargv)
+	    return;
+	nu = arrLen (newargv);
+	if (!(argv = xCopyStrArr (nu, argv)))
+	    return;
+	memcpy (argv, newargv, sizeof(char *) * nu);
+	Debug ("shell script execution: %[s\n", argv);
+	execve (argv[0], argv, env);
     }
 }
 
@@ -214,16 +231,50 @@ runAndWait (char **args, char **env)
     switch (pid = Fork ()) {
     case 0:
 	execute (args, env);
-	LogError ("Can't execute %\"s: %s\n", args[0], SysErrorMsg());
+	LogError ("Can't execute %\"s: %m\n", args[0]);
 	exit (1);
     case -1:
-	LogError ("Can't fork to execute %\"s: %s\n", args[0], SysErrorMsg());
+	LogError ("Can't fork to execute %\"s: %m\n", args[0]);
 	return 1;
     }
     ret = Wait4 (pid);
     return waitVal (ret);
 }
 
+static char *
+locate (const char *exe)
+{
+    int len;
+    char *path, *pathe, *name, *thenam, nambuf[PATH_MAX+1];
+
+    if (!(path = getenv ("PATH"))) {
+	LogError ("Can't execute %'s: $PATH not set.\n", exe);
+	return 0;
+    }
+    len = strlen (exe);
+    name = nambuf + PATH_MAX - len;
+    memcpy (name, exe, len + 1);
+    *--name = '/';
+    do {
+	if (!(pathe = strchr (path, ':')))
+	    pathe = path + strlen (path);
+	len = pathe - path;
+	if (len && !(len == 1 && *path == '.')) {
+	    thenam = name - len;
+	    if (thenam >= nambuf) {
+		memcpy (thenam, path, len);
+		if (!access (thenam, X_OK)) {
+		    StrDup (&name, thenam);
+		    return name;
+		}
+	    }
+	}
+	path = pathe;
+    } while (*path++ != '\0');
+    LogError ("Can't execute %'s: not in $PATH.\n", exe);
+    return 0;
+}
+
 
 static GTalk *curtalk;
 
@@ -234,32 +285,52 @@ GSet (GTalk *tlk)
 }
 
 int
-GFork (GPipe *pajp, const char *pname, char *cname)
+GFork (GPipe *pajp, const char *pname, char *cname,
+       GPipe *ogp, char *cgname)
 {
-    int opipe[2], ipipe[2], pid;
+    int opipe[2], ipipe[2], ogpipe[2], igpipe[2], pid;
 
-    if (pipe (opipe)) {
-	LogError ("Cannot start %s, pipe() failed", cname);
-	if (cname)
-	     free (cname);
-	return -1;
-    }
-    if (pipe (ipipe)) {
-	close (opipe[0]);
-	close (opipe[1]);
-	LogError ("Cannot start %s, pipe() failed", cname);
-	if (cname)
-	     free (cname);
-	return -1;
+    if (pipe (opipe))
+	goto badp1;
+    if (pipe (ipipe))
+	goto badp2;
+    if (ogp) {
+	if (pipe (ogpipe))
+	    goto badp3;
+	if (pipe (igpipe)) {
+	    close (ogpipe[0]);
+	    close (ogpipe[1]);
+	  badp3:
+	    close (ipipe[0]);
+	    close (ipipe[1]);
+	  badp2:
+	    close (opipe[0]);
+	    close (opipe[1]);
+	  badp1:
+	    LogError ("Cannot start %s, pipe() failed", cname);
+	    if (cname)
+		free (cname);
+	    return -1;
+	}
     }
     RegisterCloseOnFork (opipe[1]);
     RegisterCloseOnFork (ipipe[0]);
+    if (ogp) {
+	RegisterCloseOnFork (ogpipe[1]);
+	RegisterCloseOnFork (igpipe[0]);
+    }
     switch (pid = Fork()) {
     case -1:
 	close (opipe[0]);
 	close (ipipe[1]);
 	CloseNClearCloseOnFork (opipe[1]);
 	CloseNClearCloseOnFork (ipipe[0]);
+	if (ogp) {
+	    close (ogpipe[0]);
+	    close (igpipe[1]);
+	    CloseNClearCloseOnFork (ogpipe[1]);
+	    CloseNClearCloseOnFork (igpipe[0]);
+	}
 	LogError ("Cannot start %s, fork() failed\n", cname);
 	if (cname)
 	     free (cname);
@@ -270,6 +341,13 @@ GFork (GPipe *pajp, const char *pname, char *cname)
 	pajp->rfd = opipe[0];
 	RegisterCloseOnFork (opipe[0]);
 	pajp->who = (char *)pname;
+	if (ogp) {
+	    ogp->wfd = igpipe[1];
+	    RegisterCloseOnFork (igpipe[1]);
+	    ogp->rfd = ogpipe[0];
+	    RegisterCloseOnFork (ogpipe[0]);
+	    ogp->who = (char *)pname;
+	}
 	break;
     default:
 	close (opipe[0]);
@@ -277,13 +355,21 @@ GFork (GPipe *pajp, const char *pname, char *cname)
 	pajp->rfd = ipipe[0];
 	pajp->wfd = opipe[1];
 	pajp->who = cname;
+	if (ogp) {
+	    close (ogpipe[0]);
+	    close (igpipe[1]);
+	    ogp->rfd = igpipe[0];
+	    ogp->wfd = ogpipe[1];
+	    ogp->who = cgname;
+	}
 	break;
     }
     return pid;
 }
 
 int
-GOpen (GProc *proc, char **argv, const char *what, char **env, char *cname)
+GOpen (GProc *proc, char **argv, const char *what, char **env, char *cname,
+       GPipe *gp)
 {
     char **margv;
     int pip[2];
@@ -297,14 +383,12 @@ GOpen (GProc *proc, char **argv, const char *what, char **env, char *cname)
 	return -1;
     }
     if (!(margv = xCopyStrArr (1, argv))) {
-	LogOutOfMem ("GOpen");
 	if (cname)
 	     free (cname);
 	return -1;
     }
     if (!StrApp (margv, progpath, what, (char *)0)) {
 	free (margv);
-	LogOutOfMem ("GOpen");
 	if (cname)
 	     free (cname);
 	return -1;
@@ -315,9 +399,20 @@ GOpen (GProc *proc, char **argv, const char *what, char **env, char *cname)
 	     free (cname);
 	goto fail;
     }
-    switch (proc->pid = GFork (&proc->pipe, 0, cname)) {
-    case -1:
+    if (gp) {
+	ClearCloseOnFork (gp->rfd);
+	ClearCloseOnFork (gp->wfd);
+    }
+    proc->pid = GFork (&proc->pipe, 0, cname, 0, 0);
+    if (proc->pid) {
 	close (pip[1]);
+	if (gp) {
+	    RegisterCloseOnFork (gp->rfd);
+	    RegisterCloseOnFork (gp->wfd);
+	}
+    }
+    switch (proc->pid) {
+    case -1:
       fail1:
 	close (pip[0]);
       fail:
@@ -328,14 +423,28 @@ GOpen (GProc *proc, char **argv, const char *what, char **env, char *cname)
 	(void) Signal (SIGPIPE, SIG_IGN);
 	close (pip[0]);
 	fcntl (pip[1], F_SETFD, FD_CLOEXEC);
-	sprintf (coninfo, "CONINFO=%d %d", proc->pipe.rfd, proc->pipe.wfd);
+	if (gp)
+	    sprintf (coninfo, "CONINFO=%d %d %d %d",
+			      proc->pipe.rfd, proc->pipe.wfd, gp->rfd, gp->wfd);
+	else
+	    sprintf (coninfo, "CONINFO=%d %d", proc->pipe.rfd, proc->pipe.wfd);
 	env = putEnv (coninfo, env);
-	execute (margv, env);
+	if (debugLevel & DEBUG_VALGRIND) {
+	    char **nmargv = xCopyStrArr (3, margv);
+	    nmargv[0] = locate ("valgrind");
+	    nmargv[1] = (char *)"--tool=memcheck";
+	    nmargv[2] = (char *)"--num-callers=8";
+	    execute (nmargv, env);
+	} else if (debugLevel & DEBUG_STRACE) {
+	    char **nmargv = xCopyStrArr (1, margv);
+	    nmargv[0] = locate ("strace");
+	    execute (nmargv, env);
+	} else
+	    execute (margv, env);
 	write (pip[1], "", 1);
 	exit (1);
     default:
 	(void) Signal (SIGPIPE, SIG_IGN);
-	close (pip[1]);
 	if (Reader (pip[0], coninfo, 1)) {
 	    Wait4 (proc->pid);
 	    LogError ("Cannot execute %\"s (%s)\n", margv[0], cname);
@@ -369,7 +478,7 @@ GClosen (GPipe *pajp)
 }
 
 int
-GClose (GProc *proc, int force)
+GClose (GProc *proc, GPipe *gp, int force)
 {
     int	ret;
 
@@ -378,6 +487,8 @@ GClose (GProc *proc, int force)
 	return 0;
     }
     iGClosen (&proc->pipe);
+    if (gp)
+	GClosen (gp);
     if (force)
 	TerminateProcess (proc->pid, SIGTERM);
     ret = Wait4 (proc->pid);
@@ -411,18 +522,14 @@ GRead (void *buf, int len)
 static void
 GWrite (const void *buf, int len)
 {
-#if 0
-    int ret;
-    do {
-	ret = write (curtalk->pipe->wfd, buf, len);
-    } while (ret < 0 && errno == EINTR);
-    if (ret != len) {
-#else
-    if (write (curtalk->pipe->wfd, buf, len) != len) {
-#endif
+    if (Writer (curtalk->pipe->wfd, buf, len) != len) {
 	LogError ("Cannot write to %s\n", curtalk->pipe->who);
 	GErr ();
     }
+#ifdef _POSIX_PRIORITY_SCHEDULING
+    if ((debugLevel & DEBUG_HLPCON))
+	sched_yield ();
+#endif
 }
 
 void
@@ -474,11 +581,8 @@ iGRecvArr (int *rlen)
     GDebug (" -> %d bytes\n", len);
     if (!len)
 	return (char *)0;
-    if (!(buf = malloc (len)))
-    {
-	LogOutOfMem ("GRecvArr");
+    if (!(buf = Malloc (len)))
 	GErr ();
-    }
     GRead (buf, len);
     return buf;
 }
@@ -595,11 +699,8 @@ GRecvStrArr (int *rnum)
     *rnum = num;
     if (!num)
 	return (char **)0;
-    if (!(argv = malloc (num * sizeof(char *))))
-    {
-	LogOutOfMem ("GRecvStrArr");
+    if (!(argv = Malloc (num * sizeof(char *))))
 	GErr ();
-    }
     for (cargv = argv; --num >= 0; cargv++)
 	*cargv = GRecvStr ();
     return argv;
