@@ -1,7 +1,6 @@
 /*
- * $TOG: protodpy.c /main/16 1998/02/09 13:55:55 kaleb $
- *
-Copyright 1989, 1998  The Open Group
+
+Copyright 1988, 1998  The Open Group
 
 Permission to use, copy, modify, distribute, and sell this software and its
 documentation for any purpose is hereby granted without fee, provided that
@@ -9,26 +8,27 @@ the above copyright notice appear in all copies and that both that
 copyright notice and this permission notice appear in supporting
 documentation.
 
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
+The above copyright notice and this permission notice shall be included
+in all copies or substantial portions of the Software.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
-OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
-AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
-CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+OTHER DEALINGS IN THE SOFTWARE.
 
-Except as contained in this notice, the name of The Open Group shall not be
-used in advertising or otherwise to promote the sale, use or other dealings
-in this Software without prior written authorization from The Open Group.
- *
- * Author:  Keith Packard, MIT X Consortium
- */
-/* $XFree86: xc/programs/xdm/protodpy.c,v 1.2 1998/10/10 15:25:37 dawes Exp $ */
+Except as contained in this notice, the name of a copyright holder shall
+not be used in advertising or otherwise to promote the sale, use or
+other dealings in this Software without prior written authorization
+from the copyright holder.
+
+*/
 
 /*
- * protodpy.c
+ * xdm - display manager daemon
+ * Author:  Keith Packard, MIT X Consortium
  *
  * manage a collection of proto-displays.  These are displays for
  * which sessionID's have been generated, but no session has been
@@ -78,7 +78,7 @@ FindProtoDisplay (
 }
 
 static void
-TimeoutProtoDisplays (Time_t now)
+TimeoutProtoDisplays (void)
 {
     struct protoDisplay	*pdpy, *next;
 
@@ -100,15 +100,13 @@ NewProtoDisplay (
     CARD32	    sessionID)
 {
     struct protoDisplay	*pdpy;
-    Time_t date;
 
     Debug ("NewProtoDisplay\n");
-    time (&date);
-    TimeoutProtoDisplays (date);
-    pdpy = (struct protoDisplay *) malloc (sizeof *pdpy);
+    TimeoutProtoDisplays ();
+    pdpy = (struct protoDisplay *) Malloc (sizeof *pdpy);
     if (!pdpy)
 	return NULL;
-    pdpy->address = (XdmcpNetaddr) malloc (addrlen);
+    pdpy->address = (XdmcpNetaddr) Malloc (addrlen);
     if (!pdpy->address)
     {
 	free ((char *) pdpy);
@@ -118,7 +116,7 @@ NewProtoDisplay (
     memmove( pdpy->address, address, addrlen);
     pdpy->displayNumber = displayNumber;
     pdpy->connectionType = connectionType;
-    pdpy->date = date;
+    pdpy->date = now;
     if (!XdmcpCopyARRAY8 (connectionAddress, &pdpy->connectionAddress))
     {
 	free ((char *) pdpy->address);
