@@ -1,7 +1,7 @@
-/* $TOG: xdmauth.c /main/14 1998/02/09 13:56:44 kaleb $ */
 /*
 
 Copyright 1988, 1998  The Open Group
+Copyright 2001,2003 Oswald Buddenhagen <ossi@kde.org>
 
 Permission to use, copy, modify, distribute, and sell this software and its
 documentation for any purpose is hereby granted without fee, provided that
@@ -15,24 +15,22 @@ in all copies or substantial portions of the Software.
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-IN NO EVENT SHALL THE OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR
+IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-Except as contained in this notice, the name of The Open Group shall
+Except as contained in this notice, the name of a copyright holder shall
 not be used in advertising or otherwise to promote the sale, use or
 other dealings in this Software without prior written authorization
-from The Open Group.
+from the copyright holder.
 
 */
-/* $XFree86: xc/programs/xdm/xdmauth.c,v 1.3 2000/06/07 22:03:16 tsi Exp $ */
+
 /*
  * xdm - display manager daemon
  * Author:  Keith Packard, MIT X Consortium
  *
- * xdmauth
- *
  * generate authorization data for XDM-AUTHORIZATION-1 as per XDMCP spec
  */
 
@@ -72,7 +70,7 @@ XdmGetAuthHelper (
     int	    includeRho)
 {
     Xauth   *new;
-    new = (Xauth *) malloc (sizeof (Xauth));
+    new = (Xauth *) Malloc (sizeof (Xauth));
 
     if (!new)
 	return (Xauth *) 0;
@@ -86,13 +84,13 @@ XdmGetAuthHelper (
     else
 	new->data_length = 8;
 
-    new->data = (char *) malloc (new->data_length);
+    new->data = (char *) Malloc (new->data_length);
     if (!new->data)
     {
 	free ((char *) new);
 	return (Xauth *) 0;
     }
-    new->name = (char *) malloc (namelen);
+    new->name = (char *) Malloc (namelen);
     if (!new->name)
     {
 	free ((char *) new->data);
@@ -140,7 +138,7 @@ XdmGetXdmcpAuth (
     xdmcpauth = XdmGetAuthHelper (authorizationNameLen, authorizationName, FALSE);
     if (!xdmcpauth)
 	return;
-    fileauth = (Xauth *) malloc (sizeof (Xauth));
+    fileauth = (Xauth *) Malloc (sizeof (Xauth));
     if (!fileauth)
     {
 	XauDisposeAuth(xdmcpauth);
@@ -148,8 +146,8 @@ XdmGetXdmcpAuth (
     }
     /* build the file auth from the XDMCP auth */
     *fileauth = *xdmcpauth;
-    fileauth->name = malloc (xdmcpauth->name_length);
-    fileauth->data = malloc (16);
+    fileauth->name = Malloc (xdmcpauth->name_length);
+    fileauth->data = Malloc (16);
     fileauth->data_length = 16;
     if (!fileauth->name || !fileauth->data)
     {
