@@ -21,7 +21,7 @@
 
     */
 
-#include "kdm_config.h"
+#include <config.h>
 
 #include <stdio.h>
 #include <unistd.h>
@@ -32,11 +32,14 @@
 #include <ctype.h>
 #include <errno.h>
 #include <netdb.h>
+#include <netinet/in.h>
 #include <grp.h>
+#ifdef _POSIX_PRIORITY_SCHEDULING
+# include <sched.h>
+#endif
 
-#define KDMCONF KDE_CONFDIR "/kdm"
-#define KDMDATA KDE_DATADIR "/kdm"
-
+#include <greet.h>
+#include "config.ci"
 
 /*
  * Section/Entry definition structs
@@ -105,9 +108,8 @@ typedef struct ValArr {
 } ValArr;
 
 
-#ifdef HAVE_VSYSLOG
-# define USE_SYSLOG
-#endif
+static void *Malloc (size_t size);
+static void *Realloc (void *ptr, size_t size);
 
 #define LOG_NAME "kdm_config"
 #define LOG_DEBUG_MASK DEBUG_CONFIG
@@ -116,6 +118,27 @@ typedef struct ValArr {
 #include <printf.c>
 
 
+static void *
+Malloc (size_t size)
+{
+    void *ret;
+
+    if (!(ret = malloc (size)))
+	LogOutOfMem ();
+    return ret;
+}
+
+static void *
+Realloc (void *ptr, size_t size)
+{
+    void *ret;
+
+    if (!(ret = realloc (ptr, size)) && size)
+	LogOutOfMem ();
+    return ret;
+}
+
+
 static void
 MkDSpec (DSpec *spec, const char *dname, const char *dclass)
 {
@@ -164,6 +187,10 @@ GWrite (const void *buf, int count)
 {
     if (write (wfd, buf, count) != count)
 	LogPanic ("Can't write to core\n");
+#ifdef _POSIX_PRIORITY_SCHEDULING
+    if ((debugLevel & DEBUG_HLPCON))
+	sched_yield ();
+#endif
 }
 
 static void
@@ -192,12 +219,14 @@ GSendNStr (const char *buf, int len)
     GWrite ("", 1);
 }
 
+#ifdef XDMCP
 static void
 GSendArr (int len, const char *data)
 {
     GWrite (&len, sizeof(len));
     GWrite (data, len);
 }
+#endif
 
 static int
 GRecvCmd (int *val)
@@ -267,8 +296,7 @@ readFile (File *file, const char *fn, const char *what)
 # endif
 #endif
     {
-	if (!(file->buf = malloc (flen + 1))) {
-	    LogOutOfMem ("readFile");
+	if (!(file->buf = Malloc (flen + 1))) {
 	    close (fd);
 	    return 0;
 	}
@@ -288,10 +316,8 @@ readFile (File *file, const char *fn, const char *what)
 static int
 copyBuf (File *file, const char *buf, int len)
 {
-    if (!(file->buf = malloc (len + 1))) {
-	LogOutOfMem ("copyBuf");
+    if (!(file->buf = Malloc (len + 1)))
 	return 0;
-    }
     memcpy (file->buf, buf, len);
     file->eof = (file->cur = file->buf) + len;
 #if defined(HAVE_MMAP) && defined(WANT_CLOSE)
@@ -313,8 +339,7 @@ freeBuf (File *file)
 }
 #endif
 
-static Value VnoPassEnable, VautoLoginEnable, VxdmcpEnable,
-	VXaccess, VXservers, Vdummy;
+CONF_READ_VARS
 
 #define C_MTYPE_MASK	0x30000000
 # define C_PATH		0x10000000	/* C_TYPE_STR is a path spec */
@@ -324,12 +349,7 @@ static Value VnoPassEnable, VautoLoginEnable, VxdmcpEnable,
 #define C_INTERNAL	0x40000000	/* don't expose to core */
 #define C_CONFIG	0x80000000	/* process only for finding deps */
 
-#define C_noPassEnable		( C_TYPE_INT | C_INTERNAL | 0x2000 )
-#define C_autoLoginEnable	( C_TYPE_INT | C_INTERNAL | 0x2001 )
-#define C_xdmcpEnable		( C_TYPE_INT | C_INTERNAL | 0x2002 )
-#define C_accessFile		( C_TYPE_STR | C_INTERNAL | C_CONFIG | 0x2003 )
-#define C_servers		( C_TYPE_STR | C_INTERNAL | C_CONFIG | 0x2004 )
-
+#ifdef XDMCP
 static int
 PrequestPort (Value *retval)
 {
@@ -339,6 +359,7 @@ PrequestPort (Value *retval)
     }
     return 0;
 }
+#endif
 
 static Value
     emptyStr = { "", 1 },
@@ -365,199 +386,7 @@ PautoLoginX (Value *retval)
     return 0;
 }
 
-#ifndef HALT_CMD
-# ifdef BSD
-#  define HALT_CMD	"/sbin/shutdown -h now"
-#  define REBOOT_CMD	"/sbin/shutdown -r now"
-# elif defined(__SVR4)
-#  define HALT_CMD	"/usr/sbin/halt"
-#  define REBOOT_CMD	"/usr/sbin/reboot"
-# else
-#  define HALT_CMD	"/sbin/halt"
-#  define REBOOT_CMD	"/sbin/reboot"
-# endif
-#endif
-
-#ifndef DEF_USER_PATH
-#  if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__linux__)
-#    define DEF_USER_PATH "/usr/local/bin:/usr/bin:/bin:" XBINDIR ":/usr/games"
-#  else
-#    define DEF_USER_PATH "/usr/local/bin:/usr/bin:/bin:" XBINDIR ":/usr/games:/usr/ucb"
-#  endif
-#endif
-#ifndef DEF_SYSTEM_PATH
-#  if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__linux__)
-#    define DEF_SYSTEM_PATH "/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:" XBINDIR
-#  else
-#    define DEF_SYSTEM_PATH "/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:" XBINDIR ":/etc:/usr/ucb"
-#  endif
-#endif
-
-#ifndef DEF_AUTH_NAME
-# if 0 /*def HASXDMAUTH*/
-#  define DEF_AUTH_NAME	"XDM-AUTHORIZATION-1,MIT-MAGIC-COOKIE-1"
-# else
-#  define DEF_AUTH_NAME	"MIT-MAGIC-COOKIE-1"
-# endif
-#endif
-
-#ifdef __linux__
-# define DEF_SERVER_LINE ":0 local@tty1 " XBINDIR "/X vt7"
-#elif defined(__sun) || defined(__sun__)
-# define DEF_SERVER_LINE ":0 local@console " XBINDIR "/X"
-#elif defined(_AIX)
-# define DEF_SERVER_LINE ":0 local@lft0 " XBINDIR "/X"
-#else
-# define DEF_SERVER_LINE ":0 local " XBINDIR "/X"
-#endif
-
-static const char
-    *loginmode[] = { "LocalOnly", "DefaultLocal", "DefaultRemote", "RemoteOnly", 0 },
-    *logoarea[] = { "None", "Logo", "Clock", 0 },
-    *showusers[] = { "NotHidden", "Selected", "None", 0 },
-    *facesource[] = { "AdminOnly", "PreferAdmin", "PreferUser", "UserOnly", 0 },
-    *preseluser[] = { "None", "Previous", "Default", 0 },
-    *echomode[] = { "OneStar", "ThreeStars", "NoEcho", 0 },
-    *sd_who[] = { "None", "Root", "All", 0 },
-    *sd_mode[] = { "Schedule", "TryNow", "ForceNow", 0 },
-    *numlock[] = { "Off", "On", "Keep", 0 };
-
-Ent entsGeneral[] = {
-{ "ConfigVersion",	C_INTERNAL | C_TYPE_STR,&Vdummy,	"" },
-{ "Xservers",		C_servers,		&VXservers,	DEF_SERVER_LINE },
-{ "PidFile",		C_pidFile,		0,	"" },
-{ "LockPidFile",	C_lockPidFile | C_BOOL,	0,	"true" },
-{ "AuthDir",		C_authDir | C_PATH,	0,	"/var/run/xauth" },
-{ "AutoRescan",		C_autoRescan | C_BOOL,	0,	"true" },
-{ "ExportList",		C_exportList,		0,	"" },
-{ "RandomFile",		C_randomFile,		0,	"/dev/mem" },
-{ "RandomDevice",	C_randomDevice,		0,	"" },
-{ "FifoDir",		C_fifoDir | C_PATH,	0,	"/var/run/xdmctl" },
-{ "FifoGroup",		C_fifoGroup | C_GRP,	0,	"0" },
-{ "DataDir",		C_dataDir | C_PATH,	0,	"/var/lib/kdm" },
-{ "DmrcDir",		C_dmrcDir | C_PATH,	0,	"" },
-};
-
-Ent entsXdmcp[] = {
-{ "Enable",		C_xdmcpEnable | C_BOOL,	&VxdmcpEnable,	"true" },
-{ "Port",		C_requestPort,		(void *)PrequestPort,	"177" },
-{ "KeyFile",		C_keyFile,		0,	"" },
-{ "Xaccess",		C_accessFile,		&VXaccess,	KDMCONF "/Xaccess" },
-{ "ChoiceTimeout",	C_choiceTimeout,	0,	"15" },
-{ "RemoveDomainname",	C_removeDomainname | C_BOOL, 0,	"true" },
-{ "SourceAddress",	C_sourceAddress | C_BOOL, 0,	"false" },
-{ "Willing",		C_willing,		0,	"" },
-};
-
-Ent entsShutdown[] = {
-{ "HaltCmd",		C_cmdHalt,		0,	HALT_CMD },
-{ "RebootCmd",		C_cmdReboot,		0,	REBOOT_CMD },
-{ "AllowFifo",		C_fifoAllowShutdown | C_BOOL,	0,	"false" },
-{ "AllowFifoNow",	C_fifoAllowNuke | C_BOOL,	0,	"true" },
-#ifdef __linux__
-{ "UseLilo",		C_useLilo | C_BOOL,	0,	"false" },
-{ "LiloCmd",		C_liloCmd,		0,	"/sbin/lilo" },
-{ "LiloMap",		C_liloMap,		0,	"/boot/map" },
-#endif
-};
-
-Ent entsCore[] = {
-{ "ServerAttempts",	C_serverAttempts,	0,	"1" },
-{ "ServerTimeout",	C_serverTimeout,	0,	"15" },
-{ "OpenDelay",		C_openDelay,		0,	"15" },
-{ "OpenRepeat",		C_openRepeat,		0,	"5" },
-{ "OpenTimeout",	C_openTimeout,		0,	"120" },
-{ "StartAttempts",	C_startAttempts,	0,	"4" },
-{ "PingInterval",	C_pingInterval,		0,	"5" },
-{ "PingTimeout",	C_pingTimeout,		0,	"5" },
-{ "TerminateServer",	C_terminateServer | C_BOOL, 0,	"false" },
-{ "ResetSignal",	C_resetSignal,		0,	"1" },	/* SIGHUP */
-{ "TermSignal",		C_termSignal,		0,	"15" },	/* SIGTERM */
-{ "ResetForAuth",	C_resetForAuth | C_BOOL, 0,	"false" },
-{ "Authorize",		C_authorize | C_BOOL,	0,	"true" },
-{ "AuthNames",		C_authNames,		0,	DEF_AUTH_NAME },
-{ "AuthFile",		C_clientAuthFile,	0,	"" },
-{ "Resources",		C_resources,		0,	"" },
-{ "Xrdb",		C_xrdb,			0,	XBINDIR "/xrdb" },
-{ "Setup",		C_setup,		0,	"" },
-{ "Startup",		C_startup,		0,	"" },
-{ "Reset",		C_reset,		0,	"" },
-{ "Session",		C_session,		0,	XBINDIR "/xterm -ls -T" },
-{ "UserPath",		C_userPath,		0,	DEF_USER_PATH },
-{ "SystemPath",		C_systemPath,		0,	DEF_SYSTEM_PATH },
-{ "SystemShell",	C_systemShell,		0,	"/bin/sh" },
-{ "FailsafeClient",	C_failsafeClient,	0,	XBINDIR "/xterm" },
-{ "UserAuthDir",	C_userAuthDir | C_PATH,	0,	"/tmp" },
-{ "NoPassEnable",	C_noPassEnable | C_BOOL, &VnoPassEnable, "false" },
-{ "NoPassUsers",	C_noPassUsers,	(void *)PnoPassUsers,	"" },
-{ "AutoLoginEnable",	C_autoLoginEnable | C_BOOL, &VautoLoginEnable, "false" },
-{ "AutoLoginUser",	C_autoUser,	(void *)PautoLoginX,	"" },
-{ "AutoLoginPass",	C_autoPass,	(void *)PautoLoginX,	"" },
-{ "AutoReLogin",	C_autoReLogin | C_BOOL,	0,	"false" },
-{ "AllowNullPasswd",	C_allowNullPasswd | C_BOOL, 0,	"true" },
-{ "AllowRootLogin",	C_allowRootLogin | C_BOOL, 0,	"true" },
-{ "AllowShutdown",	C_allowShutdown | C_ENUM, sd_who, "All" },
-{ "AllowSdForceNow",	C_allowNuke | C_ENUM, sd_who,	"All" },
-{ "DefaultSdMode",	C_defSdMode | C_ENUM, sd_mode,	"Schedule" },
-{ "InteractiveSd",	C_interactiveSd | C_BOOL, 0,	"true" },
-{ "SessionsDirs",	C_sessionsDirs,		0,	KDMDATA "/sessions" },
-};
-
-Ent entsGreeter[] = {
-{ "GUIStyle",		C_GUIStyle, 		0,	"" },
-{ "ColorScheme",	C_ColorScheme,		0,	"" },
-{ "LogoArea",		C_LogoArea | C_ENUM, logoarea,	"Logo" },
-{ "LogoPixmap",		C_LogoPixmap,		0,	"" },
-{ "GreeterPosFixed",	C_GreeterPosFixed | C_BOOL, 0,	"false" },
-{ "GreeterPosX",	C_GreeterPosX,		0,	"0" },
-{ "GreeterPosY",	C_GreeterPosY,		0,	"0" },
-{ "GreeterScreen",	C_GreeterScreen,	0,	"0" },
-{ "StdFont",		C_StdFont,		0,	"helvetica,12,5,0,50,0" },
-{ "FailFont",		C_FailFont,		0,	"helvetica,12,5,0,75,0" },
-{ "GreetString",	C_GreetString,		0,	"Welcome to %s at %n" },
-{ "GreetFont",		C_GreetFont,		0,	"charter,24,5,0,50,0" },
-{ "AntiAliasing",	C_AntiAliasing | C_BOOL,0,	"false" },
-{ "NumLock",		C_NumLock | C_ENUM, numlock,	"Keep" },
-{ "Language",		C_Language,		0,	"en_US" },
-{ "ShowUsers",		C_ShowUsers | C_ENUM, showusers, "NotHidden" },
-{ "SelectedUsers",	C_SelectedUsers,	0,	"" },
-{ "HiddenUsers",	C_HiddenUsers,		0,	"" },
-{ "MinShowUID",		C_MinShowUID,		0,	"0" },
-{ "MaxShowUID",		C_MaxShowUID,		0,	"65535" },
-{ "SortUsers",		C_SortUsers | C_BOOL,	0,	"true" },
-{ "FaceSource",		C_FaceSource | C_ENUM, facesource, "AdminOnly" },
-{ "FaceDir",		C_FaceDir,		0,	KDMDATA "/faces" },
-{ "PreselectUser",	C_PreselectUser | C_ENUM, preseluser, "None" },
-{ "DefaultUser",	C_DefaultUser,		0,	"" },
-{ "FocusPasswd",	C_FocusPasswd | C_BOOL, 0,	"false" },
-{ "EchoMode",		C_EchoMode | C_ENUM, echomode,	"OneStar" },
-{ "GrabServer",		C_grabServer | C_BOOL,	0,	"false" },
-{ "GrabTimeout",	C_grabTimeout,		0,	"3" },
-{ "AuthComplain",	C_authComplain | C_BOOL, 0,	"true" },
-{ "UseBackground",	C_UseBackground | C_BOOL, 0,	"true" },
-{ "BackgroundCfg",	C_BackgroundCfg,	0,	KDMCONF "/backgroundrc" },
-{ "LoginMode",		C_loginMode | C_ENUM,	loginmode,	"LocalOnly" },
-{ "ChooserHosts",	C_chooserHosts,		0,	"*" },
-{ "ForgingSeed",	C_ForgingSeed,		0,	"0" },
-#ifdef WITH_KDM_XCONSOLE
-{ "ShowLog",		C_ShowLog | C_BOOL,	0,	"false" },
-{ "LogSource",		C_LogSource,		0,	"" },
-#endif
-{ "PluginsLogin",	C_PluginsLogin,		0,	"classic" },
-{ "PluginsShutdown",	C_PluginsShutdown,	0,	"classic" },
-{ "PluginOptions",	C_PluginOptions,	0,	"" },
-{ "AllowConsole",	C_AllowConsole | C_BOOL,0,	"true" },
-{ "AllowClose", 	C_AllowClose | C_BOOL,	0,	"true" },
-};
-
-Sect
- secGeneral	= { "General",	entsGeneral, as(entsGeneral) },
- secXdmcp	= { "Xdmcp",	entsXdmcp, as(entsXdmcp) },
- secShutdown	= { "Shutdown",	entsShutdown, as(entsShutdown) },
- sec_Core	= { "-Core",	entsCore, as(entsCore) },
- sec_Greeter	= { "-Greeter",	entsGreeter, as(entsGreeter) },
- *allSects[]	= { &secGeneral, &secXdmcp, &secShutdown,
-		    &sec_Core, &sec_Greeter };
+CONF_READ_ENTRIES
 
 static const char *kdmrc = KDMCONF "/kdmrc";
 
@@ -677,10 +506,8 @@ Debug ("parsing config ...\n");
 		      nlen, nstr, kdmrc, line);
 	    continue;
 	  newsec:
-	    if (!(cursec = malloc (sizeof(*cursec)))) {
-		LogOutOfMem ("ReadConf");
+	    if (!(cursec = Malloc (sizeof(*cursec))))
 		return;
-	    }
 	    cursec->name = nstr;
 	    cursec->nlen = nlen;
 	    cursec->dname = dstr;
@@ -774,10 +601,8 @@ Debug ("parsing config ...\n");
 			  ce->name, cursec->nlen, cursec->name, kdmrc);
 		goto keyfnd;
 	    }
-	if (!(curent = malloc (sizeof (*curent)))) {
-	    LogOutOfMem ("ReadConf");
+	if (!(curent = Malloc (sizeof (*curent))))
 	    return;
-	}
 	curent->keyid = ce->id;
 	curent->line = line;
 	curent->val = st;
@@ -915,10 +740,8 @@ CvtValue (Ent *et, Value *retval, int vallen, const char *val, char **eopts)
 		    retval->len--;
 	    return 0;
 	case C_TYPE_ARGV:
-	    if (!(ents = malloc (sizeof(Value) * (esiz = 10)))) {
-		LogOutOfMem ("CvtValue");
+	    if (!(ents = Malloc (sizeof(Value) * (esiz = 10))))
 		return 0;
-	    }
 	    for (nents = 0, tlen = 0, i = 0; ; i++) {
 		for (; i < vallen && isspace (val[i]); i++);
 		for (b = i; i < vallen && val[i] != ','; i++);
@@ -926,13 +749,11 @@ CvtValue (Ent *et, Value *retval, int vallen, const char *val, char **eopts)
 		    break;
 		for (e = i; e > b && isspace (val[e - 1]); e--);
 		if (esiz < nents + 2) {
-		    Value *entsn = realloc (ents, 
+		    Value *entsn = Realloc (ents, 
 					sizeof(Value) * (esiz = esiz * 2 + 1));
-		    if (!nents) {
-			LogOutOfMem ("CvtValue");
+		    if (!nents)
 			break;
-		    } else
-			ents = entsn;
+		    ents = entsn;
 		}
 		ents[nents].ptr = val + b;
 		ents[nents].len = e - b;
@@ -978,11 +799,9 @@ AddValue (ValArr *va, int id, Value *val)
 
 /*    Debug ("Addig value %#x\n", id);*/
     if (va->nents == va->esiz) {
-	va->ents = realloc (va->ents, sizeof(Val) * (va->esiz += 50));
-	if (!va->ents) {
-	    LogOutOfMem ("AddValue");
+	va->ents = Realloc (va->ents, sizeof(Val) * (va->esiz += 50));
+	if (!va->ents)
 	    return 0;
-	}
     }
     va->ents[va->nents].id = id;
     va->ents[va->nents].val = *val;
@@ -1125,11 +944,14 @@ ReadWord (File *file, int *len, int EOFatEOL)
 }
 
 
+#ifdef XDMCP
 #define ALIAS_CHARACTER	    '%'
 #define NEGATE_CHARACTER    '!'
 #define CHOOSER_STRING	    "CHOOSER"
 #define BROADCAST_STRING    "BROADCAST"
 #define NOBROADCAST_STRING  "NOBROADCAST"
+#define LISTEN_STRING	    "LISTEN"
+#define WILDCARD_STRING	    "*"
 
 typedef struct hostEntry {
     struct hostEntry	*next;
@@ -1145,6 +967,13 @@ typedef struct hostEntry {
     } entry;
 } HostEntry;
 
+typedef struct listenEntry {
+    struct listenEntry	*next;
+    int		iface;
+    int		mcasts;
+    int		nmcasts;
+} ListenEntry;
+
 typedef struct aliasEntry {
     struct aliasEntry	*next;
     char	*name;
@@ -1175,28 +1004,36 @@ HasGlobCharacters (char *s)
 	}
 }
 
+#define PARSE_ALL	0
+#define PARSE_NO_BCAST	1
+#define PARSE_NO_PAT	2
+#define PARSE_NO_ALIAS	3
+
 static int
 ParseHost (int *nHosts, HostEntry ***hostPtr, int *nChars, 
-	   char *hostOrAlias, int len)
+	   char *hostOrAlias, int len, int parse)
 {
+#if defined(IPv6) && defined(AF_INET6)
+    struct addrinfo *ai;
+#else
     struct hostent  *hostent;
+#endif
+    void *addr;
+    int addr_type, addr_len;
 
-    if (!(**hostPtr = (HostEntry *) malloc (sizeof (HostEntry))))
-    {
-	LogOutOfMem ("ParseHost");
+    if (!(**hostPtr = (HostEntry *) Malloc (sizeof (HostEntry))))
 	return 0;
-    }
-    if (!strcmp (hostOrAlias, BROADCAST_STRING))
+    if (!(parse & PARSE_NO_BCAST) && !strcmp (hostOrAlias, BROADCAST_STRING))
     {
 	(**hostPtr)->type = HOST_BROADCAST;
     }
-    else if (*hostOrAlias == ALIAS_CHARACTER)
+    else if (!(parse & PARSE_NO_ALIAS) && *hostOrAlias == ALIAS_CHARACTER)
     {
 	(**hostPtr)->type = HOST_ALIAS;
 	(**hostPtr)->entry.aliasPattern = hostOrAlias + 1;
 	*nChars += len;
     }
-    else if (HasGlobCharacters (hostOrAlias))
+    else if (!(parse & PARSE_NO_PAT) && HasGlobCharacters (hostOrAlias))
     {
 	(**hostPtr)->type = HOST_PATTERN;
 	(**hostPtr)->entry.hostPattern = hostOrAlias;
@@ -1205,24 +1042,43 @@ ParseHost (int *nHosts, HostEntry ***hostPtr, int *nChars,
     else
     {
 	(**hostPtr)->type = HOST_ADDRESS;
+#if defined(IPv6) && defined(AF_INET6)
+	if (getaddrinfo (hostOrAlias, NULL, NULL, &ai))
+#else
 	if (!(hostent = gethostbyname (hostOrAlias)))
+#endif
 	{
 	    LogError ("Host \"%s\" not found\n", hostOrAlias);
 	    free ((char *) (**hostPtr));
 	    return 0;
 	}
+#if defined(IPv6) && defined(AF_INET6)
+	addr_type = ai->ai_addr->sa_family;
+	if (ai->ai_family == AF_INET) {
+	    addr = &((struct sockaddr_in *)ai->ai_addr)->sin_addr;
+	    addr_len = sizeof(struct in_addr);
+	} else /*if (ai->ai_addr->sa_family == AF_INET6)*/ {
+	    addr = &((struct sockaddr_in6 *)ai->ai_addr)->sin6_addr;
+	    addr_len = sizeof(struct in6_addr);
+	}
+#else
+	addr_type = hostent->h_addrtype;
+	addr = hostent->h_addr;
+	addr_len = hostent->h_length;
+#endif
 	if (!((**hostPtr)->entry.displayAddress.hostAddress = 
-	      malloc (hostent->h_length)))
+	      Malloc (addr_len)))
 	{
-	    LogOutOfMem ("ParseHost");
 	    free ((char *) (**hostPtr));
 	    return 0;
 	}
-	memcpy ((**hostPtr)->entry.displayAddress.hostAddress, 
-		hostent->h_addr, hostent->h_length);
-	*nChars += hostent->h_length;
-	(**hostPtr)->entry.displayAddress.hostAddrLen = hostent->h_length;
-	(**hostPtr)->entry.displayAddress.connectionType = hostent->h_addrtype;
+	memcpy ((**hostPtr)->entry.displayAddress.hostAddress, addr, addr_len);
+	*nChars += addr_len;
+	(**hostPtr)->entry.displayAddress.hostAddrLen = addr_len;
+	(**hostPtr)->entry.displayAddress.connectionType = addr_type;
+#if defined(IPv6) && defined(AF_INET6)
+	freeaddrinfo (ai);
+#endif
     }
     *hostPtr = &(**hostPtr)->next;
     (*nHosts)++;
@@ -1235,22 +1091,21 @@ ReadAccessFile (const char *fname)
     HostEntry		*hostList, **hostPtr = &hostList;
     AliasEntry		*aliasList, **aliasPtr = &aliasList;
     AclEntry		*acList, **acPtr = &acList;
+    ListenEntry		*listenList, **listenPtr = &listenList;
     char		*displayOrAlias, *hostOrAlias;
     File		file;
-    int			nHosts, nAliases, nAcls, nChars, error;
+    int			nHosts, nAliases, nAcls, nListens, nChars, error;
     int			i, len;
 
-    nHosts = nAliases = nAcls = nChars = error = 0;
+    nHosts = nAliases = nAcls = nListens = nChars = error = 0;
     if (!readFile (&file, fname, "XDMCP access control"))
 	goto sendacl;
     while ((displayOrAlias = ReadWord (&file, &len, FALSE)))
     {
 	if (*displayOrAlias == ALIAS_CHARACTER)
 	{
-	    if (!(*aliasPtr = (AliasEntry *) malloc (sizeof (AliasEntry))))
+	    if (!(*aliasPtr = (AliasEntry *) Malloc (sizeof (AliasEntry))))
 	    {
-	      oom:
-		LogOutOfMem ("ReadAccessFile");
 		error = 1;
 		break;
 	    }
@@ -1260,17 +1115,47 @@ ReadAccessFile (const char *fname)
 	    (*aliasPtr)->nhosts = 0;
 	    while ((hostOrAlias = ReadWord (&file, &len, TRUE)))
 	    {
-		if (!ParseHost (&nHosts, &hostPtr, &nChars, hostOrAlias, len))
+		if (!ParseHost (&nHosts, &hostPtr, &nChars, hostOrAlias, len,
+				PARSE_NO_BCAST|PARSE_NO_PAT))
 		    goto sktoeol;
 		(*aliasPtr)->nhosts++;
 	    }
 	    aliasPtr = &(*aliasPtr)->next;
 	    nAliases++;
 	}
+	else if (!strcmp (displayOrAlias, LISTEN_STRING))
+	{
+	    if (!(*listenPtr = (ListenEntry *) Malloc (sizeof (ListenEntry))))
+	    {
+		error = 1;
+		break;
+	    }
+	    (*listenPtr)->iface = nHosts;
+	    if (!(hostOrAlias = ReadWord (&file, &len, TRUE)) ||
+		!strcmp (hostOrAlias, WILDCARD_STRING) ||
+		!ParseHost (&nHosts, &hostPtr, &nChars, hostOrAlias, len,
+			    PARSE_NO_BCAST|PARSE_NO_PAT|PARSE_NO_ALIAS))
+	    {
+		(*listenPtr)->iface = -1;
+	    }
+	    (*listenPtr)->mcasts = nHosts;
+	    (*listenPtr)->nmcasts = 0;
+	    while ((hostOrAlias = ReadWord (&file, &len, TRUE)))
+	    {
+		if (ParseHost (&nHosts, &hostPtr, &nChars, hostOrAlias, len,
+			       PARSE_NO_BCAST|PARSE_NO_PAT|PARSE_NO_ALIAS))
+		    (*listenPtr)->nmcasts++;
+	    }
+	    listenPtr = &(*listenPtr)->next;
+	    nListens++;
+	}
 	else
 	{
-	    if (!(*acPtr = (AclEntry *) malloc (sizeof (AclEntry))))
-		goto oom;
+	    if (!(*acPtr = (AclEntry *) Malloc (sizeof (AclEntry))))
+	    {
+		error = 1;
+		break;
+	    }
 	    (*acPtr)->flags = 0;
 	    if (*displayOrAlias == NEGATE_CHARACTER)
 	    {
@@ -1279,10 +1164,12 @@ ReadAccessFile (const char *fname)
 	    }
 	    (*acPtr)->entries = nHosts;
 	    (*acPtr)->nentries = 1;
-	    if (!ParseHost (&nHosts, &hostPtr, &nChars, displayOrAlias, len))
+	    if (!ParseHost (&nHosts, &hostPtr, &nChars, displayOrAlias, len,
+			    PARSE_NO_BCAST))
 	    {
-		if ((*acPtr)->flags & a_notAllowed) {
-	      sktoeol:
+		if ((*acPtr)->flags & a_notAllowed)
+		{
+		  sktoeol:
 		    error = 1;
 		}
 		while (ReadWord (&file, &len, TRUE));
@@ -1299,7 +1186,7 @@ ReadAccessFile (const char *fname)
 		else
 		{
 		    if (ParseHost (&nHosts, &hostPtr, &nChars, 
-				   hostOrAlias, len))
+				   hostOrAlias, len, PARSE_NO_PAT))
 			(*acPtr)->nhosts++;
 		}
 	    }
@@ -1308,12 +1195,31 @@ ReadAccessFile (const char *fname)
 	}
     }
 
+    if (!nListens) {
+	if (!(*listenPtr = (ListenEntry *) Malloc (sizeof (ListenEntry))))
+	    error = 1;
+	else {
+	    (*listenPtr)->iface = -1;
+	    (*listenPtr)->mcasts = nHosts;
+	    (*listenPtr)->nmcasts = 0;
+#if defined(IPv6) && defined(AF_INET6) && defined(XDM_DEFAULT_MCAST_ADDR6)
+	    if (ParseHost (&nHosts, &hostPtr, &nChars,
+			   XDM_DEFAULT_MCAST_ADDR6,
+			   sizeof(XDM_DEFAULT_MCAST_ADDR6)-1,
+			   PARSE_ALL))
+		(*listenPtr)->nmcasts++;
+#endif
+	    nListens++;
+	}
+    }
+
     if (error) {
-	nHosts = nAliases = nAcls = nChars = 0;
+	nHosts = nAliases = nAcls = nListens = nChars = 0;
       sendacl:
 	LogError ("No XDMCP requests will be granted\n");
     }
     GSendInt (nHosts);
+    GSendInt (nListens);
     GSendInt (nAliases);
     GSendInt (nAcls);
     GSendInt (nChars);
@@ -1333,6 +1239,11 @@ ReadAccessFile (const char *fname)
 	    break;
 	}
     }
+    for (i = 0; i < nListens; i++, listenList = listenList->next) {
+	GSendInt (listenList->iface);
+	GSendInt (listenList->mcasts);
+	GSendInt (listenList->nmcasts);
+    }
     for (i = 0; i < nAliases; i++, aliasList = aliasList->next) {
 	GSendStr (aliasList->name);
 	GSendInt (aliasList->hosts);
@@ -1346,6 +1257,7 @@ ReadAccessFile (const char *fname)
 	GSendInt (acList->flags);
     }
 }
+#endif
 
 
 static struct displayMatch {
@@ -1411,10 +1323,8 @@ ReadServersFile (const char *fname)
   haveit:
     while ((word = ReadWord (&file, &len, FALSE))) {
 Debug ("read display name %s\n", word);
-	if (!(*serverPtr = (ServerEntry *) malloc (sizeof (ServerEntry)))) {
-	    LogOutOfMem ("ReadServerFile");
+	if (!(*serverPtr = (ServerEntry *) Malloc (sizeof (ServerEntry))))
 	    break;
-	}
 	(*serverPtr)->name = word;
 	/*
 	 * extended syntax; if the second argument doesn't
@@ -1454,10 +1364,8 @@ Debug ("display is reserve\n");
 	argp = &(*serverPtr)->argv;
 	while (word) {
 Debug ("read server arg %s\n", word);
-	    if (!(*argp = (ArgV *) malloc (sizeof (ArgV)))) {
-		LogOutOfMem ("ReadServerFile");
+	    if (!(*argp = (ArgV *) Malloc (sizeof (ArgV))))
 		goto sendxs;
-	    }
 	    (*argp)->str = word;
 	    argp = &(*argp)->next;
 	    (*serverPtr)->argc++;
@@ -1497,10 +1405,6 @@ Debug ("read server arg %s\n", word);
 }
 
 
-#ifdef HAVE_PAM
-Value pamservice = { KDM_PAM_SERVICE, sizeof(KDM_PAM_SERVICE) };
-#endif
-
 int main(int argc ATTR_UNUSED, char **argv)
 {
     DSpec dspec;
@@ -1537,12 +1441,18 @@ int main(int argc ATTR_UNUSED, char **argv)
 /*	    Debug ("GC_Files\n");*/
 	    ReadConf ();
 	    CopyValues (0, &secGeneral, 0, C_CONFIG);
+#ifdef XDMCP
 	    CopyValues (0, &secXdmcp, 0, C_CONFIG);
 	    GSendInt ((VXservers.ptr[0] == '/') ? 3 : 2);
+#else
+	    GSendInt ((VXservers.ptr[0] == '/') ? 2 : 1);
+#endif
 	    GSendStr (kdmrc);
 		GSendInt (-1);
+#ifdef XDMCP
 	    GSendNStr (VXaccess.ptr, VXaccess.len - 1);
 		GSendInt (0);
+#endif
 	    if (VXservers.ptr[0] == '/') {
 		GSendNStr (VXservers.ptr, VXservers.len - 1);
 		    GSendInt (0);
@@ -1553,11 +1463,17 @@ int main(int argc ATTR_UNUSED, char **argv)
 		case GC_gDisplay:
 		    GSendInt (0);
 		    break;
+#ifdef XDMCP
 		case GC_gXaccess:
 		    GSendInt (1);
 		    break;
+#endif
 		case GC_gXservers:
+#ifdef XDMCP
 		    GSendInt ((VXservers.ptr[0] == '/') ? 2 : 0);
+#else
+		    GSendInt ((VXservers.ptr[0] == '/') ? 1 : 0);
+#endif
 		    break;
 		default:
 		    GSendInt (-1);
@@ -1574,11 +1490,10 @@ int main(int argc ATTR_UNUSED, char **argv)
 /*		Debug ("GC_gGlobal\n");*/
 		ReadConf ();
 		CopyValues (&va, &secGeneral, 0, 0);
+#ifdef XDMCP
 		CopyValues (&va, &secXdmcp, 0, 0);
-		CopyValues (&va, &secShutdown, 0, 0);
-#ifdef HAVE_PAM
-		AddValue (&va, C_PAMService, &pamservice);
 #endif
+		CopyValues (&va, &secShutdown, 0, 0);
 		SendValues (&va);
 		break;
 	    case GC_gDisplay:
@@ -1599,9 +1514,11 @@ int main(int argc ATTR_UNUSED, char **argv)
 	    case GC_gXservers:
 		ReadServersFile (cfgfile);
 		break;
+#ifdef XDMCP
 	    case GC_gXaccess:
 		ReadAccessFile (cfgfile);
 		break;
+#endif
 	    default:
 		Debug ("Unsupported config cathegory %#x\n", what);
 	    }
