@@ -32,6 +32,7 @@
 extern "C" {
 #endif
 
+void GSet (int master);
 void GSendInt (int val);
 void GSendStr (const char *buf);
 /*void GSendNStr (const char *buf, int len);*/
@@ -45,11 +46,12 @@ int GetCfgInt (int id);
 char *GetCfgStr (int id);
 char **GetCfgStrArr (int id, int *len);
 
+void freeStrArr (char **arr);
+
 void Debug (const char *fmt, ...);
 void LogInfo (const char *fmt, ...);
 void LogError (const char *fmt, ...);
 void LogPanic (const char *fmt, ...) ATTR_NORETURN;
-void LogOutOfMem (const char *fkt);
 
 struct _XDisplay;
 
@@ -66,7 +68,6 @@ void setCursor( struct _XDisplay *mdpy, int window, int shape );
 extern int rfd;			/* for select() loops */
 
 extern char *dname;		/* d->name */
-extern int dgrabServer;		/* d->grabServer */
 
 #ifdef __cplusplus
 }
