@@ -27,7 +27,6 @@
 #include "kdmconfig.h"
 #include "kdmclock.h"
 #include "kdm_greet.h"
-#include "kdm_config.h"
 
 #include <kapplication.h>
 #include <klocale.h>
@@ -48,8 +47,10 @@
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
+#include <qtooltip.h>
 
 #include <pwd.h>
+#include <grp.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <sys/types.h>
@@ -98,6 +99,7 @@ KGreeter::KGreeter()
   : inherited()
   , dName( dname )
   , userView( 0 )
+  , userList( 0 )
   , clock( 0 )
   , pixLabel( 0 )
   , nNormals( 0 )
@@ -107,43 +109,58 @@ KGreeter::KGreeter()
   , prevValid( true )
   , needLoad( false )
 {
-    stsFile = new KSimpleConfig( kdmcfg->_stsFile );
+    stsFile = new KSimpleConfig( _stsFile );
     stsFile->setGroup( "PrevUser" );
 
 #ifdef WITH_KDM_XCONSOLE
-    QGridLayout* main_grid = new QGridLayout( 1, 1, 10 );
-    layout->addLayout( main_grid, 0, 0 );
+    QBoxLayout *main_box = new QHBoxLayout( 10 );
+    layout->addLayout( main_box, 0, 0 );
 #else
-    QGridLayout* main_grid = new QGridLayout( winFrame, 1, 1, 10, 10 );
+    QBoxLayout *main_box = new QHBoxLayout( winFrame, 10, 10 );
 #endif
 
-    grid = new QGridLayout( 1, 1, 5 );
-    main_grid->addLayout( grid, 2, 1 );
-
-    if (!kdmcfg->_greetString.isEmpty()) {
-	QLabel* welcomeLabel = new QLabel( kdmcfg->_greetString, winFrame );
-	welcomeLabel->setAlignment( AlignCenter );
-	welcomeLabel->setFont( kdmcfg->_greetFont );
-	main_grid->addWidget( welcomeLabel, 0, 1 );
-    }
-    if (kdmcfg->_showUsers != SHOW_NONE) {
+    if (_userList) {
 	userView = new UserListView( winFrame );
-	insertUsers( userView );
-	main_grid->addMultiCellWidget(userView, 0, 3, 0, 0);
+	main_box->addWidget(userView);
 	connect( userView, SIGNAL(clicked( QListViewItem * )),
 		 SLOT(slotUserClicked( QListViewItem * )) );
 	connect( userView, SIGNAL(doubleClicked( QListViewItem * )),
 		 SLOT(accept()) );
     }
 
-    switch (kdmcfg->_logoArea) {
+    QBoxLayout *inner_box = new QVBoxLayout( main_box, 10 );
+
+    if (!_authorized && _authComplain) {
+	QLabel* complainLabel = new QLabel(
+	    i18n("Warning: this is an unsecured session"), winFrame );
+	QToolTip::add( complainLabel,
+	    i18n("This display requires no X authorization.\n"
+		 "This means that anybody can connect to it,\n"
+		  "open windows on it or intercept your input.") );
+	complainLabel->setAlignment( AlignCenter );
+	complainLabel->setFont( _failFont );
+	complainLabel->setPaletteForegroundColor( Qt::red );
+	inner_box->addWidget( complainLabel );
+    }
+    if (!_greetString.isEmpty()) {
+	QLabel* welcomeLabel = new QLabel( _greetString, winFrame );
+	welcomeLabel->setAlignment( AlignCenter );
+	welcomeLabel->setFont( _greetFont );
+	inner_box->addWidget( welcomeLabel );
+    }
+    if (_userCompletion)
+	userList = new QStringList;
+    if (userView || userList)
+	insertUsers();
+
+    switch (_logoArea) {
 	case LOGO_CLOCK:
 	    clock = new KdmClock( winFrame, "clock" );
 	    break;
 	case LOGO_LOGO:
 	    {
 		QPixmap pixmap;
-		if (pixmap.load( kdmcfg->_logo )) {
+		if (pixmap.load( _logo )) {
 		    pixLabel = new QLabel( winFrame );
 		    pixLabel->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ) );
 		    pixLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
@@ -155,35 +172,18 @@ KGreeter::KGreeter()
 	    break;
     }
 
-    if (kdmcfg->_showUsers != SHOW_NONE) {
+    if (userView) {
 	if (clock)
-	    main_grid->addWidget( clock, 1, 1, AlignCenter );
+	    inner_box->addWidget( clock, 0, AlignCenter );
 	else if (pixLabel)
-	    main_grid->addWidget( pixLabel, 1, 1, AlignCenter );
+	    inner_box->addWidget( pixLabel, 0, AlignCenter );
     } else {
-#if 0
 	if (clock)
-	    main_grid->addMultiCellWidget( clock, 0,3, 2,2, AlignCenter );
+	    main_box->addWidget( clock, 0, AlignCenter );
 	else if (pixLabel)
-	    main_grid->addMultiCellWidget( pixLabel, 0,3, 2,2, AlignCenter );
-#else
-	if (clock)
-	    grid->addMultiCellWidget( clock, 0,3, 4,4, AlignTop );
-	else if (pixLabel)
-	    grid->addMultiCellWidget( pixLabel, 0,3, 4,4, AlignTop );
-#endif
+	    main_box->addWidget( pixLabel, 0, AlignCenter );
     }
 
-    KSeparator* sep = new KSeparator( KSeparator::HLine, winFrame );
-#if 0
-    grid->addMultiCellWidget( sep, 4,4, 0,3 );
-#else
-    grid->addMultiCellWidget( sep, 4,4, 0,
-	(kdmcfg->_showUsers != SHOW_NONE || 
-	 kdmcfg->_logoArea == LOGO_NONE) ? 3 : 4 );
-#endif
-    grid->setColStretch( 3, 1 );
-
     goButton = new QPushButton( i18n("L&ogin"), winFrame );
     goButton->setDefault( true );
     connect( goButton, SIGNAL( clicked()), SLOT(accept()) );
@@ -192,14 +192,6 @@ KGreeter::KGreeter()
     QPushButton *menuButton = new QPushButton( i18n("&Menu"), winFrame );
     //helpButton
 
-    QBoxLayout* hbox2 = new QHBoxLayout( 10 );
-    main_grid->addItem( hbox2, 3, 1 );
-    hbox2->addWidget( goButton );
-    hbox2->addWidget( clearButton );
-    hbox2->addStretch( 1 );
-    hbox2->addWidget( menuButton );
-    hbox2->addStretch( 1 );
-
     QWidget *prec;
     if (userView)
 	prec = userView;
@@ -211,14 +203,23 @@ KGreeter::KGreeter()
 	prec = menuButton;
     if (curPlugin < 0) {
 	curPlugin = 0;
-	pluginList = KGVerify::init( kdmcfg->_pluginsLogin );
+	pluginList = KGVerify::init( _pluginsLogin );
     }
     verify = new KGVerify( this, winFrame, prec, QString::null,
 			   pluginList, KGreeterPlugin::Authenticate,
 			   KGreeterPlugin::Login );
-    grid->addMultiCellLayout( verify->getLayout(), 0,3, 0,3, AlignCenter );
+    inner_box->addLayout( verify->getLayout() );
     verify->selectPlugin( curPlugin );
 
+    inner_box->addWidget( new KSeparator( KSeparator::HLine, winFrame ) );
+
+    QBoxLayout* hbox2 = new QHBoxLayout( inner_box, 10 );
+    hbox2->addWidget( goButton );
+    hbox2->addWidget( clearButton );
+    hbox2->addStretch( 1 );
+    hbox2->addWidget( menuButton );
+    hbox2->addStretch( 1 );
+
     sessMenu = new QPopupMenu( winFrame );
     connect( sessMenu, SIGNAL(activated(int)),
 	     SLOT(slotSessionSelected(int)) );
@@ -254,6 +255,7 @@ KGreeter::KGreeter()
 KGreeter::~KGreeter()
 {
     hide();
+    delete userList;
     delete verify;
     delete stsFile;
 }
@@ -275,15 +277,20 @@ public:
 };
 
 void
-KGreeter::insertUser( UserListView *listview, const QImage &default_pix,
+KGreeter::insertUser( const QImage &default_pix,
 		      const QString &username, struct passwd *ps )
 {
+    if (userList)
+	userList->append( username );
+    if (!userView)
+	return;
+
     int dp = 0, nd = 0;
-    if (kdmcfg->_faceSource == FACE_USER_ONLY ||
-	kdmcfg->_faceSource == FACE_PREFER_USER)
+    if (_faceSource == FACE_USER_ONLY ||
+	_faceSource == FACE_PREFER_USER)
 	dp = 1;
-    if (kdmcfg->_faceSource != FACE_USER_ONLY &&
-	kdmcfg->_faceSource != FACE_ADMIN_ONLY)
+    if (_faceSource != FACE_USER_ONLY &&
+	_faceSource != FACE_ADMIN_ONLY)
 	nd = 1;
     QImage p;
     // XXX remove seteuid-voodoo when we run as nobody
@@ -291,7 +298,7 @@ KGreeter::insertUser( UserListView *listview, const QImage &default_pix,
     do {
 	QString fn = dp ?
 		     QFile::decodeName( ps->pw_dir ) + "/.face" :
-		     kdmcfg->_faceDir + '/' + username + ".face";
+		     _faceDir + '/' + username + ".face";
 	if (p.load( fn + ".icon" ) || p.load( fn )) {
 	    QSize ns( 48, 48 );
 	    if (p.size() != ns)
@@ -306,51 +313,116 @@ KGreeter::insertUser( UserListView *listview, const QImage &default_pix,
     QString realname = KStringHandler::from8Bit( ps->pw_gecos );
     realname.truncate( realname.find( ',' ) );
     if (realname.isEmpty() || realname == username)
-	new UserListViewItem( listview, username, QPixmap( p ), username );
+	new UserListViewItem( userView, username, QPixmap( p ), username );
     else {
 	realname.append( "\n" ).append( username );
-	new UserListViewItem( listview, realname, QPixmap( p ), username );
+	new UserListViewItem( userView, realname, QPixmap( p ), username );
     }
 }
 
+class KCStringList : public QValueList<QCString> {
+public:
+    bool contains( const char *str ) const
+    {
+	for (ConstIterator it = begin(); it != end(); ++it)
+	    if (*it == str)
+		return true;
+	return false;
+    }
+};
+
+class UserList {
+public:
+    UserList( char **in );
+    bool hasUser( const char *str ) const { return users.contains( str ); }
+    bool hasGroup( gid_t gid ) const
+	{ return groups.find( gid ) != groups.end(); }
+    bool hasGroups() const { return !groups.isEmpty(); }
+    KCStringList users;
+private:
+    QValueList<gid_t> groups;
+};
+
+UserList::UserList( char **in )
+{
+    struct group *grp;
+
+    for (; *in; in++)
+	if (**in == '@') {
+	    if ((grp = getgrnam( *in + 1 ))) {
+		for (; *grp->gr_mem; grp->gr_mem++)
+		    users.append( *grp->gr_mem );
+		groups.append( grp->gr_gid );
+	    }
+	} else
+	    users.append( *in );
+}
+
 void
-KGreeter::insertUsers( UserListView *listview )
+KGreeter::insertUsers()
 {
     QImage default_pix;
-    if (!default_pix.load( kdmcfg->_faceDir + "/.default.face.icon" ))
-	if (!default_pix.load( kdmcfg->_faceDir + "/.default.face" ))
-	    LogError("Can't open default user face\n");
-    QSize ns( 48, 48 );
-    if (default_pix.size() != ns)
-	default_pix =
-	  default_pix.convertDepth( 32 ).smoothScale( ns, QImage::ScaleMin );
+    if (userView) {
+	if (!default_pix.load( _faceDir + "/.default.face.icon" ))
+	    if (!default_pix.load( _faceDir + "/.default.face" ))
+		LogError("Can't open default user face\n");
+	QSize ns( 48, 48 );
+	if (default_pix.size() != ns)
+	    default_pix =
+	      default_pix.convertDepth( 32 ).smoothScale( ns, QImage::ScaleMin );
+    }
     struct passwd *ps;
-    if (kdmcfg->_showUsers == SHOW_ALL) {
-	QDict<int> users( 1000 );
+    if (_showUsers == SHOW_ALL) {
+	UserList noUsers( _noUsers );
+	QDict<int> dupes( 1000 );
 	for (setpwent(); (ps = getpwent()) != 0;) {
-	    // usernames are stored in the same encoding as files
-	    QString username = QFile::decodeName( ps->pw_name );
 	    if (*ps->pw_dir && *ps->pw_shell &&
-		(ps->pw_uid >= (unsigned)kdmcfg->_lowUserId ||
-		 !ps->pw_uid && kdmcfg->_showRoot) &&
-		ps->pw_uid <= (unsigned)kdmcfg->_highUserId &&
-		!kdmcfg->_noUsers.contains( username ) &&
-		!users.find( username )
+		(ps->pw_uid >= (unsigned)_lowUserId ||
+		 !ps->pw_uid && _showRoot) &&
+		ps->pw_uid <= (unsigned)_highUserId &&
+		!noUsers.hasUser( ps->pw_name ) &&
+		!noUsers.hasGroup( ps->pw_gid )
 	    ) {
-		// we might have a real user, insert him/her
-		users.insert( username, (int *)-1 );
-		insertUser( listview, default_pix, username, ps );
+		QString username( QFile::decodeName( ps->pw_name ) );
+		if (!dupes.find( username )) {
+		    dupes.insert( username, (int *)-1 );
+		    insertUser( default_pix, username, ps );
+		}
 	    }
 	}
     } else {
-	QStringList::ConstIterator it = kdmcfg->_users.begin();
-	for (; it != kdmcfg->_users.end(); ++it)
-	    if ((ps = getpwnam( (*it).latin1() )))
-		insertUser( listview, default_pix, *it, ps );
+	UserList users( _users );
+	if (users.hasGroups()) {
+	    QDict<int> dupes( 1000 );
+	    for (setpwent(); (ps = getpwent()) != 0;) {
+		if (*ps->pw_dir && *ps->pw_shell &&
+		    (ps->pw_uid >= (unsigned)_lowUserId ||
+		     !ps->pw_uid && _showRoot) &&
+		    ps->pw_uid <= (unsigned)_highUserId &&
+		    (users.hasUser( ps->pw_name ) ||
+		     users.hasGroup( ps->pw_gid ))
+		) {
+		    QString username( QFile::decodeName( ps->pw_name ) );
+		    if (!dupes.find( username )) {
+			dupes.insert( username, (int *)-1 );
+			insertUser( default_pix, username, ps );
+		    }
+		}
+	    }
+	} else {
+	    KCStringList::ConstIterator it = users.users.begin();
+	    for (; it != users.users.end(); ++it)
+		if ((ps = getpwnam( (*it).data() )))
+		    insertUser( default_pix, QFile::decodeName( *it ), ps );
+	}
     }
     endpwent();
-    if (kdmcfg->_sortUsers)
-	listview->sort();
+    if (_sortUsers) {
+	if (userView)
+	    userView->sort();
+	if (userList)
+	    userList->sort();
+    }
 }
 
 void
@@ -370,9 +442,7 @@ KGreeter::putSession(const QString &type, const QString &name, bool hid, const c
 void
 KGreeter::insertSessions()
 {
-    for (QStringList::ConstIterator dit = kdmcfg->_sessionsDirs.begin();
-	 dit != kdmcfg->_sessionsDirs.end(); ++dit)
-    {
+    for (char **dit = _sessionsDirs; *dit; ++dit) {
 	QStringList ents = QDir( *dit ).entryList();
 	for (QStringList::ConstIterator it = ents.begin(); it != ents.end(); ++it)
 	    if ((*it).endsWith( ".desktop" )) {
@@ -512,9 +582,10 @@ KGreeter::slotLoadPrevWM()
 	GSendStr( "Session" );
 	sess = GRecvStr();
 	if (!sess) {		/* no such user */
-	    if (kdmcfg->_showUsers == SHOW_NONE) { // don't fake if user list shown
+	    if (!userView && !userList) { // don't fake if user list shown
+		prevValid = false;
 		/* simple crc32 */
-		for (crc = kdmcfg->_forgingSeed, i = 0; i < len; i++) {
+		for (crc = _forgingSeed, i = 0; i < len; i++) {
 		    by = (crc & 255) ^ name[i];
 		    for (b = 0; b < 8; b++)
 			by = (by >> 1) ^ (-(by & 1) & 0xedb88320);
@@ -553,23 +624,23 @@ KGreeter::slotLoadPrevWM()
 void // private
 KGreeter::pluginSetup()
 {
-    int field;
+    int field = 0;
     QString ent;
 
     if (verify->isPluginLocal()) {
-        if (kdmcfg->_preselUser != PRESEL_PREV)
+        if (_preselUser != PRESEL_PREV)
 	    stsFile->deleteEntry( dName, false );
-	if (kdmcfg->_preselUser != PRESEL_NONE) {
-	    ent = kdmcfg->_preselUser == PRESEL_PREV ?
-		    stsFile->readEntry( dName ) : kdmcfg->_defaultUser;
-	    field = kdmcfg->_focusPasswd;
+	if (_preselUser != PRESEL_NONE) {
+	    ent = _preselUser == PRESEL_PREV ?
+		    stsFile->readEntry( dName ) : _defaultUser;
+	    field = _focusPasswd;
 	}
     } else {
 	QString pn( verify->pluginName() ), dn( dName + '_' + pn );
-        if (kdmcfg->_preselUser != PRESEL_PREV)
+        if (_preselUser != PRESEL_PREV)
 	    stsFile->deleteEntry( dn, false );
-	if (kdmcfg->_preselUser != PRESEL_NONE) {
-	    ent = kdmcfg->_preselUser == PRESEL_PREV ?
+	if (_preselUser != PRESEL_NONE) {
+	    ent = _preselUser == PRESEL_PREV ?
 		    stsFile->readEntry( dn ) :
 		    verify->getConf( 0, (pn + ".DefaultEntity").latin1(), QVariant( "" ) ).toString();
 	    field = verify->getConf( 0, (pn + ".FocusField").latin1(), QVariant( 0 ) ).toInt();
@@ -583,6 +654,8 @@ KGreeter::pluginSetup()
 	else
 	    userView->hide();
     }
+    if (userList)
+	verify->loadUsers( *userList );
     adjustGeometry();
 }
 
@@ -596,7 +669,7 @@ KGreeter::verifyPluginChanged( int id )
 void
 KGreeter::verifyOk()
 {
-    if (kdmcfg->_preselUser == PRESEL_PREV)
+    if (_preselUser == PRESEL_PREV)
 	stsFile->writeEntry(
 		verify->isPluginLocal() ?
 			dName :
