@@ -63,11 +63,11 @@ KfindTabWidget::KfindTabWidget(QWidget *parent, const char *name)
     QLabel * namedL = new QLabel(nameBox, i18n("&Named:"), pages[0], "named");
     QToolTip::add( namedL, i18n("You can use wildcard matching and \";\" for separating multiple names") );
     dirBox  = new KComboBox(TRUE, pages[0], "combo2");
-    QLabel * lookinL = new QLabel(dirBox, i18n("&Look in:"), pages[0], "named");
+    QLabel * lookinL = new QLabel(dirBox, i18n("Look &in:"), pages[0], "named");
     subdirsCb  = new QCheckBox(i18n("Include &subfolders"), pages[0]);
     caseSensCb  = new QCheckBox(i18n("Case s&ensitive search"), pages[0]);
     browseB    = new QPushButton(i18n("&Browse..."), pages[0]);
-    useLocateCb = new QCheckBox(i18n("Use files index"), pages[0]);
+    useLocateCb = new QCheckBox(i18n("&Use files index"), pages[0]);
 
     // Setup
 
@@ -107,7 +107,7 @@ KfindTabWidget::KfindTabWidget(QWidget *parent, const char *name)
     QWhatsThis::add(namedL,nameWhatsThis);
     const QString whatsfileindex
         = i18n("<qt>This lets you use the files' index created by the <i>slocate</i> "
-               "package to speed-up the search. Don't forget to update the index from time to time "
+               "package to speed-up the search; remember to update the index from time to time "
                "(using <i>updatedb</i>)."
                "</qt>");
     QWhatsThis::add(useLocateCb,whatsfileindex);
@@ -247,6 +247,8 @@ KfindTabWidget::KfindTabWidget(QWidget *parent, const char *name)
     textEdit=new KLineEdit(pages[2], "textEdit" );
     QLabel * textL   =new QLabel(textEdit, i18n("C&ontaining text:"), pages[2], "text");
 
+    connect( textEdit, SIGNAL(returnPressed(const QString &)), SIGNAL( startSearch()));
+
     const QString containingtext
       = i18n("<qt>If specified, only files that contain this text"
 	      " are found. Note that not all file types from the list"
@@ -285,13 +287,13 @@ KfindTabWidget::KfindTabWidget(QWidget *parent, const char *name)
     typeBox->insertItem(i18n("Special Files (Sockets, Device Files...)"));
     typeBox->insertItem(i18n("Executable Files"));
     typeBox->insertItem(i18n("SUID Executable Files"));
-    typeBox->insertItem(i18n("All images"));
-    typeBox->insertItem(i18n("All video"));
-    typeBox->insertItem(i18n("All sounds"));
+    typeBox->insertItem(i18n("All Images"));
+    typeBox->insertItem(i18n("All Video"));
+    typeBox->insertItem(i18n("All Sounds"));
 
     initMimeTypes();
     initSpecialMimeTypes();
-    
+
     for ( KMimeType::List::ConstIterator it = m_types.begin();
           it != m_types.end(); ++it )
     {
@@ -555,9 +557,9 @@ bool KfindTabWidget::isDateValid()
   QString str;
   if ( ! fromDate->getDate(&hi1).isValid() ||
        ! toDate->getDate(&hi2).isValid() )
-    str = i18n("The date is not valid!");
+    str = i18n("The date is not valid.");
   else if ( hi1 > hi2 )
-    str = i18n("Invalid date range!");
+    str = i18n("Invalid date range.");
   else if ( QDate::currentDate() < hi1 )
     str = i18n("Unable to search dates in the future.");
 
@@ -703,7 +705,7 @@ void KfindTabWidget::setQuery(KQuery *query)
       case -1:
         query->setMimeType( m_AudioTypes );
         break;
-      default: 
+      default:
         query->setMimeType( m_types[id]->name() );
      }
   }
