@@ -311,7 +311,7 @@ void Navigator::selectItem( const KURL &url )
   NavigatorItem *item;
   item = static_cast<NavigatorItem *>( mContentsTree->selectedItem() );
   if ( item && mSelected ) {
-    KURL currentURL = item->entry()->url();
+    KURL currentURL ( item->entry()->url() );
     if ( (currentURL == url) || (currentURL == alternativeURL) ) {
       kdDebug() << "URL already shown." << endl;
       return;
@@ -369,7 +369,7 @@ void Navigator::slotItemSelected( QListViewItem *currentItem )
   if ( item->childCount() > 0 || item->isExpandable() )
     item->setOpen( !item->isOpen() );
 
-  KURL url = item->entry()->url();
+  KURL url ( item->entry()->url() );
 
   if ( url.protocol() == "khelpcenter" ) {
       mView->closeURL();
