@@ -17,7 +17,7 @@ class KHTMLPart;
 
 namespace KHC {
 
-class SearchFormatter;
+class Formatter;
 class SearchEngine;
 class View;
 
@@ -65,18 +65,23 @@ class SearchEngine : public QObject
     bool search( QString words, QString method = "and", int matches = 5,
                  QString scope = "" );
 
-    SearchFormatter *formatter(); 
-    View *view();
+    Formatter *formatter() const; 
+    View *view() const;
 
     QString substituteSearchQuery( const QString &query );
 
     void finishSearch();
 
+    QString errorLog() const;
+
+    bool isRunning() const;
+
   signals:
     void searchFinished();
 
   protected slots:
     void searchStdout(KProcess *proc, char *buffer, int buflen);
+    void searchStderr(KProcess *proc, char *buffer, int buflen);
     void searchExited(KProcess *proc);
 
   protected:
@@ -87,8 +92,9 @@ class SearchEngine : public QObject
     bool mSearchRunning;
     QString mSearchResult;
 
+    QString mStderr;
+
     View *mView;
-    SearchFormatter *mFormatter;
     
     QString mWords;
     int mMatches;
