@@ -30,33 +30,36 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kservice.h>
 #include <kservicegroup.h>
 
+#include <kdebug.h>
 #include "quickaddappsmenu.h"
 
-QuickAddAppsMenu :: QuickAddAppsMenu(const QString &label, const QString &relPath, QObject *target, QWidget *parent, const char *name)
+QuickAddAppsMenu::QuickAddAppsMenu(const QString &label, const QString &relPath, QWidget *target, QWidget *parent, const char *name, const QString &sender)
    : PanelServiceMenu(label, relPath, parent, name)
 {
-   targetObject = target;
-   connect(this, SIGNAL(addApp(QString)), target, SLOT(slotAddApp(QString)));
+   _targetObject = target;
+   _sender = sender;
+   connect(this, SIGNAL(addAppBefore(QString,QString)), target, SLOT(addAppBefore(QString,QString)));
 }
 
-QuickAddAppsMenu :: QuickAddAppsMenu(QObject *target, QWidget *parent, const char *name)
-  : PanelServiceMenu(QString::null, QString::null, parent, name)
+QuickAddAppsMenu::QuickAddAppsMenu(QWidget *target, QWidget *parent, const QString &sender, const char *name)
+   : PanelServiceMenu(QString::null, QString::null, parent, name)
 {
-   targetObject = target;
-   connect(this, SIGNAL(addApp(QString)), target, SLOT(slotAddApp(QString)));
+   _targetObject = target;
+   _sender = sender;
+   connect(this, SIGNAL(addAppBefore(QString,QString)), target, SLOT(addAppBefore(QString,QString)));
 }
 
-void QuickAddAppsMenu :: slotExec(int id)
+void QuickAddAppsMenu::slotExec(int id)
 {
    if (!entryMap_.contains(id)) return;
    KSycocaEntry * e = entryMap_[id];
    KService::Ptr service = static_cast<KService *>(e);
-   emit addApp(locate("apps", service->desktopEntryPath()));
+   emit addAppBefore(locate("apps", service->desktopEntryPath()),_sender);
 }
 
 
-PanelServiceMenu *QuickAddAppsMenu :: newSubMenu(const QString &label, const QString &relPath, QWidget *parent, const char *name)
+PanelServiceMenu *QuickAddAppsMenu::newSubMenu(const QString &label, const QString &relPath, QWidget *parent, const char *name)
 {
-   return new QuickAddAppsMenu(label, relPath, targetObject, parent, name);
+   return new QuickAddAppsMenu(label, relPath, _targetObject, parent, name, _sender);
 }
 #include "quickaddappsmenu.moc"
