@@ -164,7 +164,7 @@ void RunApplet::resizeEvent(QResizeEvent*)
     setButtonText();
 }
 
-void RunApplet::popupDirectionChange(KPanelApplet::Direction)
+void RunApplet::positionChange(KPanelApplet::Position)
 {
     setButtonText();
 }
@@ -173,7 +173,7 @@ void RunApplet::setButtonText()
 {
     QString t;
 
-    if (popupDirection() == Left)
+    if (position() == pLeft)
 	{
 	    if (width() >= 42)
 		t = i18n("< Run");
@@ -204,7 +204,7 @@ int RunApplet::heightForWidth(int ) const
 void RunApplet::popup_combo()
 {
     QPoint p;
-    if (popupDirection() == Left)
+    if (position() == pLeft)
 	p = mapToGlobal(QPoint(-_input->width()-1, 0));
     else
 	p = mapToGlobal(QPoint(width()+1, 0));
