@@ -38,6 +38,7 @@ class TrayEmbed;
 class SystemTrayApplet : public KPanelApplet
 {
     Q_OBJECT
+    typedef QPtrList<TrayEmbed> TrayEmbedList;
 
 public:
 
@@ -47,15 +48,12 @@ public:
 
     int widthForHeight(int h) const;
     int heightForWidth(int w) const;
+    int maxIconWidth() const;
+    int maxIconHeight() const;
 
 protected:
     void resizeEvent( QResizeEvent* );
 
-    void mousePressEvent(QMouseEvent*);
-    void mouseReleaseEvent(QMouseEvent*);
-    void mouseDoubleClickEvent(QMouseEvent*);
-    void mouseMoveEvent(QMouseEvent*);
-    void propagateMouseEvent(QMouseEvent*);
     bool x11Event( XEvent *e );
     void enterEvent( QEvent * );
     void leaveEvent( QEvent * );
@@ -68,7 +66,7 @@ protected slots:
 
 private:
     void embedWindow( WId w, bool kde_tray );
-    QPtrList<TrayEmbed> m_Wins;
+    TrayEmbedList m_Wins;
     KWinModule *kwin_module;
     Atom net_system_tray_selection;
     Atom net_system_tray_opcode;
