@@ -122,7 +122,7 @@ void NonKDEAppButton::dropEvent(QDropEvent *ev)
       result = KRun::runCommand(pathStr + " " + cmdStr + " " + execStr, pathStr, iconStr);
 
     if(!result)
-      KMessageBox::error(this, i18n("Cannot execute non-KDE application!"),
+      KMessageBox::error(this, i18n("Cannot execute non-KDE application."),
                          i18n("Kicker Error"));
   }
   PanelButton::dropEvent(ev);
@@ -142,7 +142,7 @@ void NonKDEAppButton::slotExec()
   else
     result = KRun::runCommand(pathStr + " " + cmdStr, pathStr, iconStr);
   if(!result)
-    KMessageBox::error(this, i18n("Cannot execute non-KDE application!"),
+    KMessageBox::error(this, i18n("Cannot execute non-KDE application."),
                        i18n("Kicker Error"));
 }
 
