@@ -31,8 +31,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <kiconloader.h>
 #include <kurl.h>
+#include <algorithm>
 
 #include "global.h"
+class KConfigGroup;
 
 class PanelButtonBase : public QButton
 {
@@ -43,7 +45,7 @@ public:
 
     virtual void configure();
 
-    bool isValid() { return _valid; }
+    bool isValid() const { return _valid; };
     void setTile(const QString&, const QColor& color = QColor());
     void setIcon(const QString&);
     void setIconURL(const KURL& url);
@@ -62,6 +64,12 @@ public:
     static void setZoomEnabled(bool b);
     void setBackground();
 
+    bool conserveSpace() const;
+    int maxButtonDim() const;
+    int maxIconDim() const;
+    int iconMargin(int iconDim) const;
+    virtual int preferredDimension(int panelDim) const;
+
 signals:
     void iconChanged();
 
@@ -84,6 +92,7 @@ protected:
     virtual void dragLeaveEvent(QDragLeaveEvent *);
     virtual void dropEvent(QDropEvent *);
 
+    virtual std::pair<int,int> preferredIconSizes(int proposed_size=-1) const;
     virtual QString defaultIcon() const { return "unknown"; };
 
     void setArrowDirection(Position dir);
