@@ -43,16 +43,16 @@ class AppletHandle : public QWidget
 
   bool eventFilter (QObject *, QEvent *);
 
-  int widthForHeight( int h );
-  int heightForWidth( int w );
+  int widthForHeight( int h ) const;
+  int heightForWidth( int w ) const;
 
   Orientation orientation() const { return _parent->orientation(); }
   Direction popupDirection() const { return _parent->popupDirection(); }
 
-  bool onMenuButton(const QPoint& point);
+  bool onMenuButton(const QPoint& point) const;
 
  signals:
-  void moveApplet( QPoint moveOffset );
+  void moveApplet( const QPoint& moveOffset );
   void removeApplet();
   void showAppletMenu();
 
