@@ -27,16 +27,20 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qlayout.h>
 #include <qhbox.h>
 #include <qfile.h>
+#include <qtimer.h>
+#include <qtooltip.h>
 
+#include <dcopclient.h>
 #include <kapplication.h>
-#include <kpopupmenu.h>
+#include <kconfig.h>
 #include <kdebug.h>
 #include <kglobal.h>
-#include <kconfig.h>
+#include <klocale.h>
+#include <kmessagebox.h>
 #include <kpanelapplet.h>
+#include <kpopupmenu.h>
 #include <kprocess.h>
 #include <kstandarddirs.h>
-#include <dcopclient.h>
 
 #include "global.h"
 #include "kicker.h"
@@ -47,6 +51,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "appletinfo.h"
 #include "popupposition.h"
 
+#include "containerarea.h"
 #include "container_applet.h"
 #include "container_applet.moc"
 
@@ -59,10 +64,14 @@ AppletContainer::AppletContainer( const AppletInfo& info, QPopupMenu* opMenu, QW
   , _heightForWidthHint(0)
   , _firstuse( TRUE )
 {
+    setBackgroundOrigin( AncestorOrigin );
+
     // setup handle
     _handle = new AppletHandle(this);
     if (Kicker::kicker()->isImmutable() || !kapp->authorizeKAction("kicker_rmb"))
        _handle->hide();
+    else
+        QToolTip::add( _handle, info.name() );
 
     connect( Kicker::kicker(), SIGNAL(configurationChanged()),
              this, SLOT(slotReconfigure()));
@@ -72,17 +81,18 @@ AppletContainer::AppletContainer( const AppletInfo& info, QPopupMenu* opMenu, QW
 
     //setup appletframe
     _appletframe = new QHBox(this);
+    _appletframe->setBackgroundOrigin( AncestorOrigin );
     _appletframe->setFrameStyle(QFrame::NoFrame);
     _appletframe->installEventFilter(this);
 
     if (orientation() == Horizontal)
-	{
-	    _layout = new QBoxLayout(this, QBoxLayout::LeftToRight, 0, 0);
-	}
+    {
+        _layout = new QBoxLayout(this, QBoxLayout::LeftToRight, 0, 0);
+    }
     else
-	{
-	    _layout = new QBoxLayout(this, QBoxLayout::TopToBottom, 0, 0);
-	}
+    {
+        _layout = new QBoxLayout(this, QBoxLayout::TopToBottom, 0, 0);
+    }
 
     _layout->setResizeMode( QLayout::FreeResize );
 
@@ -96,6 +106,10 @@ void AppletContainer::configure()
     KConfig *config = KGlobal::config();
     config->setGroup("General");
     _handle->setFadeOutHandle(config->readBoolEntry("FadeOutAppletHandles", false));
+    if (config->readBoolEntry("HideAppletHandles", false) || Kicker::kicker()->isImmutable() || !kapp->authorizeKAction("kicker_rmb"))
+        _handle->hide();
+    else
+        _handle->show();
 }
 
 void AppletContainer::slotReconfigure()
@@ -110,7 +124,6 @@ void AppletContainer::slotSetPopupDirection(Direction d)
     _firstuse = FALSE;
     BaseContainer::slotSetPopupDirection(d);
 
-
     resetLayout();
 }
 
@@ -217,8 +230,8 @@ void AppletContainer::doSaveConfiguration( KConfigGroup& config,
 
 QPopupMenu* AppletContainer::createOpMenu() const
 {
-    QPopupMenu* opMenu = new PanelAppletOpMenu(_actions, appletOpMenu(), _info.name(), 
-                                               _info.icon(), 
+    QPopupMenu* opMenu = new PanelAppletOpMenu(_actions, appletOpMenu(), const_cast<QPopupMenu*>(appletsOwnMenu()),
+                                               _info.name(), _info.icon(),
                                                const_cast<AppletContainer*>(this));
     connect(opMenu, SIGNAL(escapePressed()),
             _handle, SLOT(toggleMenuButtonOff()));
@@ -232,7 +245,15 @@ InternalAppletContainer::InternalAppletContainer( const AppletInfo& info, QPopup
     _configFile = info.configFile();
     _applet = PluginLoader::pluginLoader()->loadApplet( info, _appletframe );
 
-    if (!_applet) return;
+    if (!_applet) 
+    {
+        _valid = false;
+        KMessageBox::error(this, 
+                           i18n("The %1 applet could not be loaded. Please check your installation.").arg(info.name()), 
+                           i18n("Applet Loading Error"));
+        return;
+    }
+    _valid = true;
 
     // FIXME: Do we really want to do this here?
     _applet->setPosition(  (KPanelApplet::Position)directionToPosition( popupDirection() ) );
@@ -248,11 +269,25 @@ InternalAppletContainer::InternalAppletContainer( const AppletInfo& info, QPopup
              this, SLOT(slotAlignmentChange(Alignment)) );
 }
 
+const QPopupMenu* InternalAppletContainer::appletsOwnMenu() const
+{
+    if (!_applet)
+    {
+        return 0;
+    }
+
+    return _applet->customMenu();
+}
 
 InternalAppletContainer::~InternalAppletContainer()
 {
 }
 
+void InternalAppletContainer::slotDelayedDestruct()
+{
+    delete this;
+}
+
 void InternalAppletContainer::slotSetPopupDirection(Direction d)
 {
     if (!_firstuse && _dir == d) return;
@@ -265,6 +300,7 @@ void InternalAppletContainer::slotSetPopupDirection(Direction d)
 
 void InternalAppletContainer::slotAlignmentChange( Alignment a )
 {
+    if (!_applet) return;
     _applet->setAlignment( (KPanelApplet::Alignment)a );
 }
 
@@ -276,7 +312,9 @@ int InternalAppletContainer::widthForHeight(int h) const
 	else
 	    return h + _handle->widthForHeight(h);
     }
-    return _applet->widthForHeight(h) + _handle->widthForHeight(h);
+    return _applet->widthForHeight(h) + ( _handle->isVisible()
+                                        ? _handle->widthForHeight(h)
+                                        : 0 );
 }
 
 int InternalAppletContainer::heightForWidth(int w) const
@@ -287,7 +325,9 @@ int InternalAppletContainer::heightForWidth(int w) const
 	else
 	    return w + _handle->heightForWidth(w);
     }
-    return _applet->heightForWidth(w) + _handle->heightForWidth(w);
+    return _applet->heightForWidth(w) + ( _handle->isVisible()
+                                        ? _handle->heightForWidth(w)
+                                        : 0 );
 }
 
 void InternalAppletContainer::about()
@@ -314,6 +354,56 @@ void InternalAppletContainer::reportBug()
     _applet->action( KPanelApplet::ReportBug );
 }
 
+void InternalAppletContainer::setBackground()
+{
+    // can happen in perverse moments when an applet isn't loaded but the contanier
+    // get's asked to update it's bground anyways
+    if (!_applet)
+        return;
+
+    if( !Panel::the()->containerArea()->transparent() ) {
+        setBackgroundOrigin(AncestorOrigin);
+        _applet->unsetPalette();
+        _applet->repaint();
+        _handle->unsetPalette();
+        _handle->repaint();
+        return;
+    }
+    
+    int srcx = x();
+    int srcy = y();
+
+    KConfig *config = KGlobal::config();
+    config->setGroup("General");
+
+    ContainerArea* area = static_cast<ContainerArea*>(parent()->parent());
+    const QPixmap* containerBG = area->completeBackgroundPixmap();
+
+    if( !containerBG ) return;
+    if( containerBG->isNull() ) return;
+    
+    if (!config->readBoolEntry("HideAppletHandles", false)) 
+        if( orientation() == Horizontal ) 
+            srcx += _handle->width();
+        else
+            srcy += _handle->height();
+
+    QPixmap p( _applet->width(), _applet->height() );
+    copyBlt( &p, 0, 0, containerBG, srcx, srcy, _applet->width(), _applet->height());
+    _applet->blockSignals(true);
+    _applet->setBackgroundOrigin(WidgetOrigin);
+    _applet->setPaletteBackgroundPixmap(p);
+    repaint();
+    _applet->blockSignals(false);
+
+    // and let's not forget the handle
+    QPixmap handle_p( _handle->width(), _handle->height() );       
+    copyBlt( &handle_p, 0, 0, 
+             containerBG, x(), y(), 
+              _handle->width(), _handle->height());
+    _handle->setPaletteBackgroundPixmap(handle_p);
+}
+
 ExternalAppletContainer::ExternalAppletContainer( const AppletInfo& info, QPopupMenu* opMenu, QWidget *parent)
   : AppletContainer(info, opMenu, parent)
 , DCOPObject(QCString("ExternalAppletContainer_") + QString::number( (ulong) this ).latin1() )
@@ -324,17 +414,16 @@ ExternalAppletContainer::ExternalAppletContainer( const AppletInfo& info, QPopup
 
     // init QXEmbed
     _embed = new QXEmbed( _appletframe );
+    _embed->setBackgroundOrigin(AncestorOrigin);
     connect ( _embed, SIGNAL( embeddedWindowDestroyed() ),
-	      this, SIGNAL( embeddedWindowDestroyed() ) );
+              this, SIGNAL( embeddedWindowDestroyed() ) );
 
-    KProcess process;
-    process << "appletproxy"
-	    << QCString("--configfile")
-	    << info.configFile()
-	    << QCString("--callbackid")
-	    << objId()
-	    << info.desktopFile();
-    process.start(KProcess::DontCare);
+    QStringList args;
+    args << "--caption" << info.name()
+         << "--configfile" << info.configFile()
+         << "--callbackid" << objId()
+         << info.desktopFile();
+    KApplication::kdeinitExec( "appletproxy", args );
 
     connect( this, SIGNAL(alignmentChange(Alignment)),
              this, SLOT(slotAlignmentChange(Alignment)) );
@@ -408,7 +497,7 @@ int ExternalAppletContainer::widthForHeight(int h) const
 {
     int w = h;
     if (_widthForHeightHint > 0)
-	w = _widthForHeightHint;
+        w = _widthForHeightHint;
 
     if (!_isdocked) return w;
 
@@ -421,18 +510,20 @@ int ExternalAppletContainer::widthForHeight(int h) const
     dataStream << h;
 
     if (dcop->call( _app, "AppletProxy", "widthForHeight(int)", data, replyType, replyData ) )
-	{
-	    QDataStream reply( replyData, IO_ReadOnly );
-	    reply >> w;
-	}
-    return w + _handle->widthForHeight(h);
+    {
+        QDataStream reply( replyData, IO_ReadOnly );
+        reply >> w;
+    }
+    return w + ( _handle->isVisible()
+               ? _handle->widthForHeight(h)
+               : 0 );
 }
 
 int ExternalAppletContainer::heightForWidth(int w) const
 {
     int h = w;
     if (_heightForWidthHint > 0)
-	h = _heightForWidthHint;
+        h = _heightForWidthHint;
 
     if (!_isdocked) return h;
 
@@ -445,11 +536,13 @@ int ExternalAppletContainer::heightForWidth(int w) const
     dataStream << w;
 
     if (dcop->call( _app, "AppletProxy", "heightForWidth(int)", data, replyType, replyData ) )
-	{
-	    QDataStream reply( replyData, IO_ReadOnly );
-	    reply >> h;
-	}
-    return h + _handle->heightForWidth(w);
+    {
+        QDataStream reply( replyData, IO_ReadOnly );
+        reply >> h;
+    }
+    return h + ( _handle->isVisible()
+               ? _handle->heightForWidth(w)
+               : 0 );
 }
 
 bool ExternalAppletContainer::process(const QCString &fun, const QByteArray &data,
@@ -479,6 +572,12 @@ bool ExternalAppletContainer::process(const QCString &fun, const QByteArray &dat
 	    activateWindow();
 	    return(true);
 	}
+    else if(fun == "getBackground()")
+	{
+	    setBackground();
+	    return(true);
+	}
+
     return true;
 }
 
@@ -510,3 +609,76 @@ void ExternalAppletContainer::dockRequest(QCString app, int actions, int type)
     emit docked(this);
     emit updateLayout();
 }
+
+void ExternalAppletContainer::setBackground()
+{   
+    QPixmap* p; 
+    if( Panel::the()->containerArea()->transparent() ) {
+    
+        // Compute background and send it to the proxy
+        int srcx = x();
+        int srcy = y();
+
+        KConfig *config = KGlobal::config();
+        config->setGroup("General");
+    
+        if (!config->readBoolEntry("HideAppletHandles", false)) 
+            if( orientation() == Horizontal ) 
+                srcx += _handle->width();
+            else
+                srcy += _handle->height();
+
+        ContainerArea* area = static_cast<ContainerArea*>(parent()->parent());
+        const QPixmap* containerBG = area->completeBackgroundPixmap();
+
+        if( !containerBG ) return;
+        if( containerBG->isNull() ) {
+            p = new QPixmap(0,0);
+            _handle->unsetPalette();
+        }
+        else {
+            int awidth  = _appletframe->width();
+            int aheight = _appletframe->height();
+
+            p = new QPixmap( awidth, aheight );
+            copyBlt( p, 0, 0, containerBG, srcx, srcy, awidth, aheight);
+
+            // and let's not forget the handle
+            QPixmap handle_p( _handle->width(), _handle->height() );       
+            copyBlt( &handle_p, 0, 0, 
+                     containerBG, x(), y(), 
+                     _handle->width(), _handle->height());
+            _handle->setPaletteBackgroundPixmap(handle_p);
+        }
+    }
+    else if( Panel::the()->containerArea()->useBackgroundTheme() ) {
+        
+        ContainerArea* area = static_cast<ContainerArea*>(parent()); 
+        const QPixmap* containerBG = area->paletteBackgroundPixmap();
+        
+        if( !containerBG ) {
+            p = new QPixmap(0,0);
+            _handle->unsetPalette();
+        }
+        else {
+            p = new QPixmap(*containerBG);
+            _handle->setPaletteBackgroundPixmap(*p);
+        }
+    } 
+    else {   // plain background
+        
+        p = new QPixmap(0,0);
+        _handle->unsetPalette();	 
+    }
+
+    _handle->repaint();
+    
+    QByteArray data;
+    QDataStream dataStream( data, IO_WriteOnly );
+    dataStream << *p;
+    kapp->dcopClient()->send( _app, 
+                              "AppletProxy", 
+                              "setBackground(QPixmap)", 
+                              data);
+    delete p;
+}
