@@ -26,6 +26,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <kpanelapplet.h>
 #include <dcopobject.h>
+#include <kwin.h>
 
 #include "appletinfo.h"
 #include "container_base.h"
@@ -68,7 +69,7 @@ public slots:
     void removeApplet();
     void showAppletMenu();
     void slotReconfigure();
-    void activateWindow() { setActiveWindow(); }
+    void activateWindow() { KWin::forceActiveWindow( topLevelWidget()->winId()); }
 
 protected:
     virtual void doLoadConfiguration( KConfigGroup& );
@@ -97,7 +98,7 @@ public:
     int widthForHeight(int height) const;
     int heightForWidth(int width)  const;
 
-    virtual bool isValid() { return _valid; }
+    virtual bool isValid() const { return _valid; }
 
     void about();
     void help();
