@@ -124,38 +124,6 @@ void ExtensionManager::loadContainerConfig()
     }
 }
 
-Position ExtensionManager::initialPosition(Position prefered)
-{
-    // Guess a good position
-    bool positions[::Bottom+1];
-    for(int i = 0; i <= (int) ::Bottom; i++)
-       positions[i] = true;
-       
-    positions[(int) Panel::the()->position()] = false;
-
-    for(ExtensionContainer *c = _containers.first(); c; c = _containers.next())
-    {
-       positions[(int) c->position()] = false;
-    }
-    Position pos = prefered;
-    if (positions[(int)pos])
-       return pos;
-       
-    pos = (Position) (pos ^ 1);
-    if (positions[(int)pos])
-       return pos;
-
-    pos = (Position) (pos ^ 3);
-    if (positions[(int)pos])
-       return pos;
-
-    pos = (Position) (pos ^ 1);
-    if (positions[(int)pos])
-       return pos;
-    
-    return prefered;
-}
-
 void ExtensionManager::addExtension( const QString& desktopFile )
 {
     ExtensionContainer *e = PluginManager::pluginManager()->createExtensionContainer(
@@ -163,8 +131,11 @@ void ExtensionManager::addExtension( const QString& desktopFile )
         false,            // is startup
         QString::null  ); // no config
 
+    kdDebug(1210) << "ExtensionManager::addExtension" << endl;
+
     if(e) {
         e->readConfig();
+	kdDebug(1210)<<"after e->readConfig(): pos="<<e->position()<<endl;
         addContainer(e);
         e->show();
         saveContainerConfig();
@@ -173,7 +144,8 @@ void ExtensionManager::addExtension( const QString& desktopFile )
 
 void ExtensionManager::addContainer(ExtensionContainer* e)
 {
-    assert( e );
+    if (!e)
+	return;
 
     setUniqueId(e);
     _containers.append(e);
@@ -186,14 +158,14 @@ void ExtensionManager::addContainer(ExtensionContainer* e)
 		SLOT( embeddedWindowDestroyed()));
 }
 
-void ExtensionManager::removeContainer(ExtensionContainer *a)
+void ExtensionManager::removeContainer(ExtensionContainer* e)
 {
-    if (a) {
-	a->removeSessionConfigFile();
-	_containers.removeRef(a);
-	a->deleteLater(); // Wait till we return to the main event loop
-    }
+    if (!e)
+	return;
 
+    e->removeSessionConfigFile();
+    _containers.removeRef(e);
+    e->deleteLater(); // Wait till we return to the main event loop
     saveContainerConfig(true);
 }
 
