@@ -25,6 +25,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #define __pglobal_h__
 
 #include <qmap.h>
+#include <kurl.h>
 
 enum Position { Left = 0, Right, Top, Bottom };
 enum Direction { dUp = 0, dDown, dLeft, dRight };
@@ -34,5 +35,7 @@ enum Alignment { LeftTop = 0, Center, RightBottom };
 Position directionToPosition( Direction d );
 Direction positionToDirection( Position p );
 int sizeValue(Size s);
+QString copyDesktopFile(const KURL&url);
+QString newDesktopFile(const KURL&url);
 
 #endif // __pglobal_h__
