@@ -145,7 +145,7 @@ void Kicker::slotKMenuAccel()
 		kMenu->popup(p);
 
 		// when the cursor is in the area where the menu pops up,
-		// the item under the cursor gets selected. The single shot 
+		// the item under the cursor gets selected. The single shot
 		// avoids this from happening by allowing the item to be selected
 		// when the event loop is enterred, and then resetting it.
 		QTimer::singleShot(0, this, SLOT(slotSetKMenuItemActive()));
@@ -208,6 +208,20 @@ void Kicker::configure()
     PanelManager::the()->readConfig();
 }
 
+
+int Kicker::maxButtonDim() const
+{   return 2*iconMargin(maxIconDim())+maxIconDim(); }
+
+int Kicker::maxIconDim() const
+{   return MAX_ICON_DIMENSION;}
+
+
+int Kicker::iconMargin(int iconDim) const
+{    return iconDim/16; }
+
+bool Kicker::conserveSpace() const
+{   return true;}
+
 void Kicker::restart()
 {
     // do this on a timer to give us time to return true
