@@ -25,7 +25,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #define __kicker_h__
 
 #include <kuniqueapplication.h>
-
+#include <kicontheme.h>
 class PanelKMenu;
 class KGlobalAccel;
 class PanelPopupButton;
@@ -50,6 +50,21 @@ k_dcop:
     void showKMenu();
 
 public:
+    // "dimension" refers to the height of a horizontal panel, or the
+    // width of a vertical panel
+    enum { MIN_DIMENSION=24,              // minumum panel dimension
+           MAX_DIMENSION=128,             // maximum panel dimension
+           // the default dimension when a custom panel size is chosen
+           DEFAULT_CUSTOM_DIMENSION=56,
+           // the maximum icon size to use for a panel button.  DO NOT change
+           // this to a larger value just because larger icons may be
+           // available.  The purpose of this constant is to prevent the
+           // panel from wasting tons of space.  If a panel is larger than
+           // this value, it will have rectangular buttons instead of square
+           // buttons.  See bug #42278 for details.
+           MAX_ICON_DIMENSION=KIcon::SizeLarge
+    };
+    
     static Kicker* kicker();
 
     bool isImmutable() const;
@@ -60,6 +75,11 @@ public:
 
     static QStringList configModules(bool controlCenter);
 
+    int maxButtonDim() const;
+    int maxIconDim() const; 
+    int iconMargin(int iconDim) const;
+    bool conserveSpace() const; 
+
 public slots:
     void slotLaunchConfig();
     void slotLaunchConfig(const QString& configPath);
