@@ -21,6 +21,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 ******************************************************************/
 
+#include <config.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kdebug.h>
@@ -40,6 +41,11 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 int kicker_screen_number = 0;
 
+static const char description[] =
+        I18N_NOOP("The KDE panel");
+
+static const char version[] = VERSION;
+
 static void crashHandler(int /*signal*/)
 {
     fprintf(stderr, "kicker: crashHandler called\n");
@@ -106,11 +112,9 @@ extern "C" int kdemain( int argc, char ** argv )
     else
 	appname.sprintf("kicker-screen-%d", kicker_screen_number);
 
-    KAboutData aboutData(appname.data(), I18N_NOOP("KDE Panel")
-			 , "1.1"
-			 , I18N_NOOP("The KDE desktop panel.")
-			 , KAboutData::License_BSD
-			 , I18N_NOOP("(c) 1999-2002, The KDE Team"));
+    KAboutData aboutData( appname.data(), I18N_NOOP("KDE Panel"),
+                          version, description, KAboutData::License_BSD,
+                          I18N_NOOP("(c) 1999-2004, The KDE Team") );
 
     aboutData.addAuthor("Matthias Elter",0, "elter@kde.org");
     aboutData.addAuthor("Matthias Ettrich",0, "ettrich@kde.org");
