@@ -50,12 +50,12 @@ PluginManager::PluginManager()
 
 QValueList<AppletInfo> PluginManager::applets() const
 {
-    return plugins( KGlobal::dirs()->findAllResources("applets", "*.desktop") );
+    return plugins( KGlobal::dirs()->findAllResources("applets", "*.desktop", false, true) );
 }
 
 QValueList<AppletInfo> PluginManager::extensions() const
 {
-    return plugins( KGlobal::dirs()->findAllResources("extensions", "*.desktop") );
+    return plugins( KGlobal::dirs()->findAllResources("extensions", "*.desktop", false, true) );
 }
 
 QValueList<AppletInfo> PluginManager::plugins( const QStringList& desktopFiles ) const
@@ -119,9 +119,9 @@ AppletContainer* PluginManager::createAppletContainer(
 
     // support the old (KDE 2.2) nameing scheme
     if( desktopPath.isEmpty() )
-	desktopPath = KGlobal::dirs()->findResource( "applets",
-						     desktopFile.right(
-							 desktopFile.length() - 1 ) );
+        desktopPath = KGlobal::dirs()->findResource( "applets",
+                                                     desktopFile.right(
+                                                     desktopFile.length() - 1 ) );
 
     if ( desktopPath.isEmpty() )
         return 0;
@@ -138,6 +138,12 @@ AppletContainer* PluginManager::createAppletContainer(
         container = new ExternalAppletContainer( info, opMenu, parent );
     }
 
+    if (!container->isValid())
+    {
+        delete container;
+        return 0;
+    }
+
     return container;
 }
 
