@@ -58,6 +58,7 @@ void ShowDesktop::slotWindowChanged(WId w, unsigned int dirty)
     if ( !showingDesktop )
 	return;
 
+    // SELI this needs checking for kwin_iii (_NET_SHOWING_DESKTOP)
     if ( dirty & NET::XAWMState ) {
 	NETWinInfo inf( qt_xdisplay(), w, qt_xrootwin(),
 			NET::XAWMState | NET::WMWindowType );
@@ -78,6 +79,7 @@ void ShowDesktop::showDesktop( bool b )
 
     if ( b ) {
         // this code should move to KWin after supporting NETWM1.2
+        activeWindow = kWinModule->activeWindow();
 	iconifiedList.clear();
 	const QValueList<WId> windows = kWinModule->windows();
 	QValueList<WId>::ConstIterator it;
@@ -103,6 +105,7 @@ void ShowDesktop::showDesktop( bool b )
 	for ( it=iconifiedList.begin(); it!=iconifiedList.end(); ++it ) {
 	    KWin::deIconifyWindow( *it, false  );
 	}
+        KWin::forceActiveWindow( activeWindow );
     }
 
     emit desktopShown( showingDesktop );
