@@ -1,6 +1,6 @@
 /* kasbar.h
 **
-** Copyright (C) 2001-2003 Richard Moore <rich@kde.org>
+** Copyright (C) 2001-2004 Richard Moore <rich@kde.org>
 ** Contributor: Mosfet
 **     All rights reserved.
 **
@@ -70,8 +70,6 @@ typedef QPtrList<KasItem> KasItemList;
 
 /**
  * The main view for KasBar.
- *
- * @version $Id: kasbar.h,v 1.25 2004/01/05 21:38:45 adridg Exp $
  */
 class KasBar : public QWidget
 {
@@ -151,8 +149,13 @@ public:
     */
    QColor tintColor() const { return tintColour_; }
 
+   QColor labelPenColor() const { return labelPenColor_; }
+   QColor labelBgColor() const { return labelBgColor_; }
    QColor inactivePenColor() const { return inactivePenColor_; }
+   QColor inactiveBgColor() const { return inactiveBgColor_; }
    QColor activePenColor() const { return activePenColor_; }
+   QColor activeBgColor() const { return activeBgColor_; }
+   QColor progressColor() const { return progressColor_; }
 
    //
    // Utilities
@@ -215,6 +218,14 @@ public slots:
 
    void setBackground( const QPixmap &pix );
 
+   void setLabelPenColor( const QColor &color );
+   void setLabelBgColor( const QColor &color );
+   void setInactivePenColor( const QColor &color );
+   void setInactiveBgColor( const QColor &color );
+   void setActivePenColor( const QColor &color );
+   void setActiveBgColor( const QColor &color );
+   void setProgressColor( const QColor &color );
+
 signals:
    /**
     * Emitted when kasbar wants to resize. This happens when a new window is added.
@@ -293,8 +304,13 @@ private:
    // Look and feel resources
    KPixmap *actBg;
    KPixmap *inactBg;
+   QColor labelPenColor_;
+   QColor labelBgColor_;
    QColor activePenColor_;
+   QColor activeBgColor_;
    QColor inactivePenColor_;
+   QColor inactiveBgColor_;
+   QColor progressColor_;
 };
 
 
