@@ -1,6 +1,6 @@
 /* kasitem.cpp
 **
-** Copyright (C) 2001-2003 Richard Moore <rich@kde.org>
+** Copyright (C) 2001-2004 Richard Moore <rich@kde.org>
 ** Contributor: Mosfet
 **     All rights reserved.
 **
@@ -54,8 +54,10 @@
 #include <qcursor.h>
 #include <qpainter.h>
 #include <qdrawutil.h>
+#include <qregexp.h>
 #include <qtimer.h>
 
+#include <kdebug.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
 #include <kiconloader.h>
@@ -85,7 +87,8 @@ KasItem::KasItem( KasBar *parent )
    : QObject( parent ),
      kas( parent ), pop( 0 ), popupTimer( 0 ), dragTimer( 0 ),
      title( i18n( "Kasbar" ) ),
-     mouseOver( false ), activated( false ), customPopup( false ), groupItem( false )
+     mouseOver( false ), activated( false ), customPopup( false ), groupItem( false ),
+     prog( -1 )
 {
     update();
 }
@@ -113,17 +116,23 @@ void KasItem::setText( const QString &text )
     update();
 }
 
+void KasItem::setProgress( int percent )
+{
+    if ( percent == prog )
+	return;
+
+    prog = percent;
+    update();
+}
+
 void KasItem::mouseEnter()
 {
    static const int POPUP_DELAY = 300;
-   static const int CHECK_POPUP_DELAY = 200;
 
    if ( (!customPopup) && (popupTimer == 0) ) {
       popupTimer = new QTimer( this, "popupTimer" );
       connect( popupTimer, SIGNAL( timeout() ), SLOT( showPopup() ) );
       popupTimer->start( POPUP_DELAY, true );
-      // Will check if the popup should be hidden
-      QTimer::singleShot( CHECK_POPUP_DELAY, this, SLOT( checkPopup() ) );
    }
 
    mouseOver = true;
@@ -131,22 +140,26 @@ void KasItem::mouseEnter()
 }
 
 // Check periodically if the popup can be hidden (hack)
-void KasItem::checkPopup()
+bool KasItem::checkPopup()
 {
    QPoint cursorPos = QCursor::pos();
 
-   if ( QApplication::widgetAt( cursorPos ) != kasbar()->topLevelWidget() ) {
+   if ( !QApplication::widgetAt( cursorPos ) ) {
      if ( popupTimer ) {
         delete popupTimer;
         popupTimer = 0;
      }
-     if ( (!customPopup) && pop )
+     if ( (!customPopup) && pop ) {
         hidePopup();
+	return false;
+     }
    }
    else {
       static const int CHECK_POPUP_DELAY = 200;
       QTimer::singleShot( CHECK_POPUP_DELAY, this, SLOT( checkPopup() ) );
    }
+
+   return true;
 }
 
 void KasItem::dragEnter()
@@ -189,6 +202,8 @@ void KasItem::dragLeave()
 
 void KasItem::showPopup()
 {
+   if ( !checkPopup() )
+       return;
    if ( pop )
       return;
 
@@ -201,8 +216,8 @@ void KasItem::showPopup()
 void KasItem::hidePopup()
 {
     delete pop;
-   pop = 0;
-   activated = false;
+    pop = 0;
+    activated = false;
 }
 
 void KasItem::togglePopup()
@@ -230,9 +245,21 @@ void KasItem::paintLabel( QPainter *p )
     QString text = title;
 
     if ( !groupItem ) {
-	p->fillRect( 2, 2, extent()-4, 13, QBrush( Qt::black ) );
+	p->fillRect( 2, 2, extent()-4, 13, QBrush( kasbar()->labelBgColor() ) );
+
+	if ( isProgressItem() ) {
+	    QRegExp reg( "(1?[0-9]?[0-9])%" );
+	    if ( -1 != reg.search( text ) ) {
+		prog = reg.cap(1).toInt();
+		paintProgress( p, prog );
+	    }
+	    else {
+		prog = 0;
+	    }
+	}
+
 	p->setFont( KGlobalSettings::taskbarFont() );
-	p->setPen( Qt::white );
+	p->setPen( kasbar()->labelPenColor() );
 
 	if ( fontMetrics().width( text ) > extent()-4 )
 	    p->drawText( 2, 2, extent()-4, 12, AlignLeft | AlignVCenter, text );
@@ -284,7 +311,7 @@ void KasItem::paintArrowLabel( QPainter *p, int arrowSize, bool arrowOnLeft )
     int h = 13;
     arrowSize+=2; // Add a space
 
-    p->fillRect( lx, ly, w, h, QBrush( Qt::black ) );
+    p->fillRect( lx, ly, w, h, QBrush( kasbar()->labelBgColor() ) );
 
     // Adjust for arrow
     if ( arrowOnLeft ) {
@@ -296,7 +323,7 @@ void KasItem::paintArrowLabel( QPainter *p, int arrowSize, bool arrowOnLeft )
     }
 
     p->setFont( KGlobalSettings::taskbarFont() );
-    p->setPen( Qt::white );
+    p->setPen( kasbar()->labelPenColor() );
     if ( fontMetrics().width( text ) > w )
 	p->drawText( lx, ly, w, h-1, AlignLeft | AlignVCenter, text );
     else
@@ -313,6 +340,10 @@ void KasItem::paintBackground( QPainter *p )
 
 void KasItem::paintProgress( QPainter *p, int percent )
 {
+#if 1
+    double amt = (extent()-4) * (percent / 100.0L);
+    p->fillRect( 2, 13, (int) amt, 2, QBrush( kasbar()->progressColor() ) );
+#else
     double angle = 360*16;
     angle = angle * (percent/100.0L);
 
@@ -330,6 +361,7 @@ void KasItem::paintProgress( QPainter *p, int percent )
     p->setPen( Qt::white );
     QString text = i18n("%1%");
     p->drawText( pos, AlignCenter, text.arg(percent) );
+#endif
 }
 
 void KasItem::paint( QPainter *p )
@@ -338,12 +370,12 @@ void KasItem::paint( QPainter *p )
    paintLabel( p );
    paintBackground( p );
 
-   QPixmap pixmap = KGlobal::iconLoader()->loadIcon( "wizard",
-						     KIcon::NoGroup,
-						     KIcon::SizeMedium );
+//    QPixmap pixmap = KGlobal::iconLoader()->loadIcon( "wizard",
+// 						     KIcon::NoGroup,
+// 						     KIcon::SizeMedium );
 
-   if ( !pixmap.isNull() )
-      p->drawPixmap( 4, 16, pixmap );
+//    if ( !pixmap.isNull() )
+//       p->drawPixmap( 4, 16, pixmap );
 }
 
 void KasItem::paint( QPainter *p, int x, int y )
