@@ -1,6 +1,6 @@
 /* kasitem.h
 **
-** Copyright (C) 2001-2003 Richard Moore <rich@kde.org>
+** Copyright (C) 2001-2004 Richard Moore <rich@kde.org>
 ** Contributor: Mosfet
 **     All rights reserved.
 **
@@ -66,7 +66,6 @@ class KasPopup;
 /**
  * Abstract base class for items that can be in a KasBar.
  *
- * @version $Id: kasitem.h,v 1.16 2004/01/05 21:38:45 adridg Exp $
  * @author Richard Moore, rich@kde.org
  */
 class KasItem : public QObject
@@ -89,6 +88,11 @@ public:
      */
     int extent() const { return kas->itemExtent(); }
 
+    int progress() const { return prog; }
+    bool isProgressItem() const { return prog != -1; }
+
+    void setGroupItem( bool enable = true  ) { groupItem = enable; }
+
     //
     // Popup
     //
@@ -116,8 +120,6 @@ public:
      */
     void setCustomPopup( bool enable = true ) { customPopup = enable; }
 
-    void setGroupItem( bool enable = true  ) { groupItem = enable; }
-
     //
     // Drawing Methods
     //
@@ -167,6 +169,7 @@ public slots:
 
     void setActive( bool yes );
     void setText( const QString &title );
+    void setProgress( int percent );
 
     /**
      * Shows the items popup.
@@ -179,9 +182,10 @@ public slots:
     void hidePopup();
 
     /**
-     * Check if the popup should be hidden
+     * Check if the popup should be visible. Returns true if it is ok to show
+     * it, false otherwise.
      */
-    void checkPopup();
+    bool checkPopup();
     
     /**
      * Hides or shows the popup.
@@ -248,6 +252,7 @@ private:
     bool activated;
     bool customPopup;
     bool groupItem;
+    int prog;
 };
 
 #endif // KASITEM_H
