@@ -1,6 +1,6 @@
 /* kasstartupitem.cpp
 **
-** Copyright (C) 2001-2003 Richard Moore <rich@kde.org>
+** Copyright (C) 2001-2004 Richard Moore <rich@kde.org>
 ** Contributor: Mosfet
 **     All rights reserved.
 **
@@ -151,9 +151,7 @@ void KasStartupItem::paintAnimation( QPainter *p, int x, int y )
 
 void KasStartupItem::paint( QPainter *p )
 {
-    paintFrame( p );
-    paintLabel( p );
-    paintBackground( p );
+    KasItem::paint( p );
 
     if ( kasbar()->itemSize() == KasBar::Small ) {
       //
