@@ -48,6 +48,7 @@ TaskBarExtension::TaskBarExtension(const QString& configFile, Type type,
 {
     QHBoxLayout* layout = new QHBoxLayout( this );
     container = new TaskBarContainer( false, this );
+    positionChange( position() );
     layout->addWidget( container );
     setSize(SizeSmall, customSize());
 
@@ -57,6 +58,7 @@ TaskBarExtension::TaskBarExtension(const QString& configFile, Type type,
 
 TaskBarExtension::~TaskBarExtension()
 {
+    KGlobal::locale()->removeCatalogue( "taskbarextension" );
 }
 
 void TaskBarExtension::positionChange( Position p )
