@@ -1,4 +1,4 @@
-#/*****************************************************************
+/*****************************************************************
 
 Copyright (c) 2001 Matthias Elter <elter@kde.org>
 
@@ -25,12 +25,14 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #define __taskbarextension_h__
 
 #include <kpanelextension.h>
+#include <dcopobject.h>
 
 class TaskBarContainer;
 
-class TaskBarExtension : public KPanelExtension
+class TaskBarExtension : public KPanelExtension, virtual public DCOPObject
 {
     Q_OBJECT
+    K_DCOP
 
 public:
     TaskBarExtension( const QString& configFile, Type t = Normal,
@@ -44,8 +46,16 @@ protected:
     void positionChange( Position );
     void preferences();
 
+
 private:
     TaskBarContainer*     container;
+
+k_dcop:
+    int panelSize() { return sizeInPixels(); }
+    int panelOrientation() { return static_cast<int>(orientation()); }
+    int panelPosition() { return static_cast<int>(position()); }
+    void setPanelSize(int size) { setSize(static_cast<Size>(size),true);}///slotSetSize(size); }
+
 };
 
 #endif
