@@ -177,7 +177,7 @@ TOM::TOM(QWidget *parent, const char *name)
 {
     disableAutoClear();
     m_submenus.setAutoDelete(true);
-    setCaption(i18n("Task Oriented Menu"));
+    setCaption(i18n("Task-Oriented Menu"));
 
     // KMenu legacy: support some menu config options
     KConfig* config = KGlobal::config();
@@ -340,13 +340,13 @@ int TOM::appendTaskGroup(KConfig& config, bool inSubMenu)
             }
             else
             {
-
+       
 		QIconSet iconset = BarIconSet(icon, 22);
 		if (iconset.isNull())
 		    taskGroup->insertItem(name, m_maxIndex);
 		else
 		    taskGroup->insertItem(iconset, name, m_maxIndex);
-
+	
             }
 
             m_tasks.insert(m_maxIndex, pService);
@@ -817,6 +817,7 @@ void TOM::runCommand()
     if ( kicker_screen_number )
         appname.sprintf("kdesktop-screen-%d", kicker_screen_number);
 
+    kapp->updateRemoteUserTimestamp( appname );
     kapp->dcopClient()->send( appname, "KDesktopIface",
                               "popupExecuteCommand()", data );
 }
