@@ -48,17 +48,17 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 static KCmdLineOptions options[] =
 {
-  { "+desktopfile", I18N_NOOP("The extensions desktop file."), 0 },
-  { "configfile <file>", I18N_NOOP("The config file to be used."), 0 },
-  { "callbackid <id>", I18N_NOOP("DCOP callback id of the extension container."), 0 },
+  { "+desktopfile", I18N_NOOP("The extension's desktop file"), 0 },
+  { "configfile <file>", I18N_NOOP("The config file to be used"), 0 },
+  { "callbackid <id>", I18N_NOOP("DCOP callback id of the extension container"), 0 },
   KCmdLineLastOption
 };
 
 extern "C" int kdemain( int argc, char ** argv )
 {
-    KAboutData aboutData( "extensionproxy", I18N_NOOP("Panel extension proxy.")
+    KAboutData aboutData( "extensionproxy", I18N_NOOP("Panel Extension Proxy")
                           , "v0.1.0"
-                          ,I18N_NOOP("Panel extension proxy.")
+                          ,I18N_NOOP("Panel extension proxy")
                           , KAboutData::License_BSD
                           , "(c) 2000, The KDE Developers");
     KCmdLineArgs::init(argc, argv, &aboutData );
