@@ -61,7 +61,7 @@ KPanelApplet* PluginLoader::loadApplet(
     KLibrary* lib = loader->library( QFile::encodeName(info.library()) );
 
     if( !lib ) {
-        kdWarning() << "cannot open extension: " << info.library()
+        kdWarning() << "cannot open applet: " << info.library()
                     << " because of " << loader->lastErrorMessage() << endl;
         return 0;
     }
@@ -141,6 +141,8 @@ void PluginLoader::slotPluginDestroyed( QObject* object )
 LibUnloader::LibUnloader( const QString &libName, QObject *parent )
     : QObject( parent ), _libName( libName )
 {
+    // NOTE: this doesn't work on kicker shutdown because the timer never gets
+    //       fired.
     QTimer::singleShot( 0, this, SLOT( unload() ) );
 }
 
