@@ -30,6 +30,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qtooltip.h>
 #include <qstyle.h>
 #include <qstylesheet.h>
+#include <assert.h>
 
 #include <kdebug.h>
 #include <kapplication.h>
@@ -51,6 +52,7 @@ TaskBar::Action TaskContainer::rightButtonAction = TaskBar::ShowOperationsMenu;
 
 TaskContainer::TaskContainer( Task *task, TaskManager* manager, bool show, bool sort, bool icon, bool iconifiedOnly, QWidget *parent, const char *name )
     : QToolButton( parent, name )
+    , lastActivated( 0L )
     , arrowType(Qt::LeftArrow)
     , taskManager( manager )
     , showAll( show )
@@ -68,11 +70,15 @@ TaskContainer::TaskContainer( Task *task, TaskManager* manager, bool show, bool
     sid = task->classClass();
     setAcceptDrops(true); // Always enabled to activate task during drag&drop.
 
-    connect( task, SIGNAL( changed() ), SLOT( update() ) );
+    connect( task, SIGNAL( changed() ), SLOT( taskChanged() ) );
+    connect( task, SIGNAL( activated() ), SLOT( setLastActivated() ) );
+
+    checkAttention( task );
 }
 
 TaskContainer::TaskContainer( Startup *startup, PixmapList *startupFrames, TaskManager* manager, bool show, bool sort, bool icon, bool iconifiedOnly, QWidget *parent, const char *name )
     : QToolButton( parent, name )
+    , lastActivated( 0L )
     , arrowType(Qt::LeftArrow)
     , taskManager( manager )
     , showAll( show )
@@ -89,7 +95,7 @@ TaskContainer::TaskContainer( Startup *startup, PixmapList *startupFrames, TaskM
 
     frames = startupFrames;
 
-    connect( startup, SIGNAL( changed() ), SLOT( update() ) );
+    connect( startup, SIGNAL( changed() ), SLOT( taskChanged() ) );
     animationTimer.start( 100 );
 }
 
@@ -110,8 +116,10 @@ void TaskContainer::init()
     // timers
     connect( &animationTimer, SIGNAL( timeout() ), SLOT( animationTimerFired() ) );
     connect( &dragSwitchTimer, SIGNAL( timeout() ), SLOT( dragSwitch() ) );
+    connect( &attentionTimer, SIGNAL( timeout() ), SLOT( attentionTimerFired() ) );
     currentFrame = 0;
     frames = 0;
+    attentionState = -1;
 }
 
 TaskContainer::~TaskContainer()
@@ -120,14 +128,21 @@ TaskContainer::~TaskContainer()
     dragSwitchTimer.stop();
 }
 
+void TaskContainer::taskChanged()
+{
+    if ( const Task* task = dynamic_cast< const Task* >( sender() ) )
+        checkAttention( task );
+    update();
+}
+
 void TaskContainer::update()
 {
-     QString tooltip = "<qt>" + QStyleSheet::escape(name()) + "</qt>";
-     if (currentTooltip == tooltip)
-     {
-         repaint();
-         return;
-     }
+    QString tooltip = "<qt>" + QStyleSheet::escape(name()) + "</qt>";
+    if (currentTooltip == tooltip)
+    {
+        repaint();
+        return;
+    }
 
     currentTooltip = tooltip;
     QToolTip::remove( this );
@@ -135,6 +150,17 @@ void TaskContainer::update()
     repaint();
 }
 
+void TaskContainer::setLastActivated()
+{
+    for ( Task* t = ftasks.first(); t ; t = ftasks.next() )
+        if ( t->isActive() ) {
+            lastActivated = t;
+            return;
+        }
+    lastActivated = 0L;
+}
+
+
 void TaskContainer::animationTimerFired()
 {
     if (frames && showIcon) {
@@ -161,6 +187,40 @@ void TaskContainer::animationTimerFired()
     }
 }
 
+void TaskContainer::checkAttention( const Task* t )
+{
+    bool attention = t ? t->demandsAttention() : false;
+    if( attention && attentionState == -1 ) // was activated
+    {
+        attentionTimer.start( 500 );
+        attentionState = 0;
+    }
+    else if( !attention && attentionState >= 0 )
+    { // need to check all
+        for ( Task* t = tasks.first(); t ; t = tasks.next() )
+    	    if ( t->demandsAttention())
+            {
+                attention = true;
+                break;
+            }
+        if( !attention )
+        {
+            attentionTimer.stop();
+            attentionState = -1;
+        }
+    }
+}
+
+void TaskContainer::attentionTimerFired()
+{
+    assert( attentionState != -1 );
+    if( attentionState < ATTENTION_BLINK_TIMEOUT )
+        ++attentionState;
+    else
+        attentionTimer.stop();
+    update();
+}
+
 QSizePolicy TaskContainer::sizePolicy() const
 {
     return QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );
@@ -180,8 +240,10 @@ void TaskContainer::add( Task* task )
     tasks.append( task );
     updateFilteredTaskList();
     connect( task, SIGNAL( changed() ), SLOT( update() ) );
+    connect( task, SIGNAL( activated() ), SLOT( setLastActivated() ) );
     if ( sid.isEmpty() )
 	sid = task->classClass();
+    checkAttention( task );
 
     update();
 }
@@ -207,6 +269,7 @@ void TaskContainer::remove( Task* task )
 
     tasks.removeRef( task );
     updateFilteredTaskList();
+    checkAttention();
 
     update();
 }
@@ -278,22 +341,32 @@ void TaskContainer::drawButton( QPainter *p )
 
     // draw sunken if we contain the active task
     bool active = FALSE;
+    bool demands_attention = false;
     for ( Task* t = ftasks.first(); t ; t = ftasks.next() ) {
 	task = t;
 	if ( ! task->isIconified() )
 	    iconified = false;
-	if ( t->isActive() ) {
+	if ( t->isActive() )
 	    active = TRUE;
-	    break;
-	}
+        if ( t->demandsAttention() )
+            demands_attention = true;
     }
 
-    if ( active && aboutToActivate )
-	aboutToActivate = false;
- 
     if ( active )
 	font.setBold( TRUE );
 
+    QColorGroup colors = colorGroup();
+    if ( demands_attention )
+    {   // blink until blink timeout, then display differently without blinking
+	if( attentionState == ATTENTION_BLINK_TIMEOUT
+	    || attentionState % 2 == 0 ) {
+	    colors.setColor( QColorGroup::Button,     colors.highlight() );
+	    colors.setColor( QColorGroup::Background, colors.highlight() );
+	    colors.setColor( QColorGroup::ButtonText, colors.highlightedText() );
+	    colors.setColor( QColorGroup::Text,       colors.highlightedText() );
+	}
+    }
+
     // get the task icon
     if ( task )
 	pixmap = task->pixmap();
@@ -308,9 +381,8 @@ void TaskContainer::drawButton( QPainter *p )
 
     // draw button background
     style().drawPrimitive( QStyle::PE_HeaderSection, p, QRect( 0, 0, width(), height() ),
-                           colorGroup(), sunken ? QStyle::Style_Down : QStyle::Style_Raised );
+                           colors, sunken ? QStyle::Style_Down : QStyle::Style_Raised );
 
-   
     // shift button label on sunken buttons
     if ( sunken )
 	p->translate( shift.x(), shift.y() );
@@ -328,8 +400,8 @@ void TaskContainer::drawButton( QPainter *p )
 	    }
 
 	    // fade out the icon when minimized
-			// only do this if we are not showing only iconified windows
-			// it looks pretty stupid when they are *all* faded :-)
+	    // only do this if we are not showing only iconified windows
+	    // it looks pretty stupid when they are *all* faded :-)
 	    if ( !showOnlyIconified && iconified )
 		KIconEffect::semiTransparent( pixmap );
 
@@ -377,9 +449,9 @@ void TaskContainer::drawButton( QPainter *p )
 
 	// get the color for the text label
 	if ( !showOnlyIconified && iconified )
-	    textPen = QPen( blendColors(colorGroup().button(), colorGroup().buttonText()) );
+	    textPen = QPen( blendColors(colors.button(), colors.buttonText()) );
 	else if ( ! active )
-	    textPen = QPen( colorGroup().buttonText() );
+	    textPen = QPen( colors.buttonText() );
 	else // hack for the dotNET style and others
 	    textPen = p->pen();
 
@@ -446,25 +518,28 @@ void TaskContainer::drawButton( QPainter *p )
     // draw popup arrow
     if ( ftasks.count() >= 2 )
     {
-        QStyle::PrimitiveElement e = QStyle::PE_ArrowLeft;
+	QStyle::PrimitiveElement e = QStyle::PE_ArrowLeft;
 
-        switch ( arrowType )
-        {
-            case Qt::LeftArrow: e = QStyle::PE_ArrowLeft; break;
-            case Qt::RightArrow: e = QStyle::PE_ArrowRight; break;
-            case Qt::UpArrow: e = QStyle::PE_ArrowUp; break;
-            case Qt::DownArrow: e = QStyle::PE_ArrowDown; break;
-        }
-        int flags = QStyle::Style_Enabled;
-        QRect ar = QStyle::visualRect( QRect( br.x() + br.width() - 8 - 2, br.y(), 8, br.height() ), this );
-        if ( sunken ) {
+	switch ( arrowType )
+	{
+	    case Qt::LeftArrow:  e = QStyle::PE_ArrowLeft;  break;
+	    case Qt::RightArrow: e = QStyle::PE_ArrowRight; break;
+	    case Qt::UpArrow:    e = QStyle::PE_ArrowUp;    break;
+	    case Qt::DownArrow:  e = QStyle::PE_ArrowDown;  break;
+	}
+	int flags = QStyle::Style_Enabled;
+	QRect ar = QStyle::visualRect( QRect( br.x() + br.width() - 8 - 2, br.y(), 8, br.height() ), this );
+	if ( sunken ) {
 	    flags |= QStyle::Style_Down;
 	    // Change the painter back so the arrow gets drawn in the right location
 	    p->translate( -shift.x(), -shift.y() );
 	}
 
-	style().drawPrimitive( e, p, ar, colorGroup(), flags );
+	style().drawPrimitive( e, p, ar, colors, flags );
     }
+
+    if ( aboutToActivate )
+	aboutToActivate = false;
 }
 
 QString TaskContainer::name()
@@ -477,8 +552,8 @@ QString TaskContainer::name()
 
     // single task -> use mainwindow caption
     if ( ftasks.count() == 1 ) {
-	if ( !ftasks.first()->visibleName().isEmpty() )
-	    text = ftasks.first()->visibleName();
+	if ( !ftasks.first()->visibleIconicName().isEmpty() )
+	    text = ftasks.first()->visibleIconicName();
     }
     // multiple tasks -> use the common part of all captions
     // if it is more descriptive than the class name
@@ -486,16 +561,16 @@ QString TaskContainer::name()
 	QString match;
 	int i = 1;
 	bool stop = FALSE;
-	while ( match.length() < ftasks.first()->visibleName().length() ) {
-	    match = ftasks.first()->visibleName().left( i );
+	while ( match.length() < ftasks.first()->visibleIconicName().length() ) {
+	    match = ftasks.first()->visibleIconicName().left( i );
 	    for ( Task* t = ftasks.first(); t; t = ftasks.next() )
-		if ( match.lower() !=  t->visibleName().left( i ).lower() ) {
+		if ( match.lower() !=  t->visibleIconicName().left( i ).lower() ) {
 		    stop = TRUE;
 		    break;
 		}
 
 	    if ( stop ) {
-		match = ftasks.first()->visibleName().left( --i );
+		match = ftasks.first()->visibleIconicName().left( --i );
 		break;
 	    }
 	    i++;
@@ -560,6 +635,7 @@ void TaskContainer::mouseReleaseEvent( QMouseEvent *e )
     }
 
     QToolButton::mouseReleaseEvent( e );
+    QTimer::singleShot( 75, this, SLOT(update()) );
 }
 
 void TaskContainer::slotClicked()
@@ -578,6 +654,8 @@ void TaskContainer::performAction( TaskBar::Action action )
     if ( ftasks.isEmpty() )
 	return;
 
+    bool forwards = true;
+
     switch( action ) {
     case TaskBar::ShowTaskList:
 	// If there is only one task, the correct behavior is
@@ -591,21 +669,28 @@ void TaskContainer::performAction( TaskBar::Action action )
     case TaskBar::ShowOperationsMenu:
 	popupMenu( TaskBar::ShowOperationsMenu );
 	break;
+    case TaskBar::ActivateRaiseOrIconifyReverse:
+	// cause next case to work in reverse
+	forwards = false;
     case TaskBar::ActivateRaiseOrIconify:
 	if ( ftasks.count() == 1) {
 	    ftasks.first()->activateRaiseOrIconify();
 	} else { // multiple tasks -> cycle list
-	    for ( Task* t = ftasks.first(); t ; t = ftasks.next() ) {
+	    for ( Task* t = forwards? ftasks.first() : ftasks.last();
+		  t ; t = forwards ? ftasks.next() : ftasks.prev() ) {
 		if ( t->isActive() ) {
 		    // activate next
-		    Task *t = ftasks.next();
+		    Task *t = forwards ? ftasks.next() : ftasks.prev();
 		    if ( !t )
-			t = ftasks.first();
+			t = forwards ? ftasks.first() : ftasks.last();
 		    t->activateRaiseOrIconify();
 		    return;
 	        }
 	    }
-	    ftasks.first()->activateRaiseOrIconify();
+	    if (ftasks.contains(lastActivated))
+		lastActivated->activateRaiseOrIconify();
+	    else
+		ftasks.first()->activateRaiseOrIconify();
 	}
 	break;
     case TaskBar::Activate:
@@ -630,6 +715,34 @@ void TaskContainer::performAction( TaskBar::Action action )
     }
 }
 
+// forcenext == true means the last entry in the previous
+// taskcontainer was active -> activate first
+bool TaskContainer::activateNextTask( bool forward, bool& forcenext )
+{
+    if( forcenext ) {
+        if( ( forward ? ftasks.first() : ftasks.last()) != NULL ) {
+            ( forward ? ftasks.first() : ftasks.last())->activate();
+            forcenext = false;
+            return true;
+        }
+        return false;
+    }
+    for ( Task* t = forward ? ftasks.first() : ftasks.last();
+	  t;
+          t = forward ? ftasks.next() : ftasks.prev()) {
+	if ( t->isActive() ) {
+	    t = forward ? ftasks.next() : ftasks.prev();
+            if( t != NULL ) {
+                t->activate();
+                return true;
+            }
+            forcenext = true;
+            return false;
+        }
+    }
+    return false;
+}
+
 void TaskContainer::popupMenu( TaskBar::Action action )
 {
     QPopupMenu* menu;
@@ -640,7 +753,7 @@ void TaskContainer::popupMenu( TaskBar::Action action )
         if (!kapp->authorizeKAction("kwin_rmb"))
             return;
 
-	menu = new TaskRMBMenu( &ftasks, taskManager );
+	menu = new TaskRMBMenu( &ftasks, taskManager, showAll );
     }
     else
 	return;
@@ -744,6 +857,19 @@ void TaskContainer::dragSwitch()
         popupMenu( TaskBar::ShowTaskList );
 }
 
+void TaskContainer::wheelEvent( QWheelEvent* e )
+{
+    if ( ftasks.count() > 1 ) {
+        if ( e->delta() > 0 ) {
+            // scroll away from user, previous task
+            performAction( TaskBar::ActivateRaiseOrIconifyReverse );
+        } else {
+            // scroll towards user, next task
+            performAction( TaskBar::ActivateRaiseOrIconify );
+        }
+    }
+}
+
 int TaskContainer::desktop()
 {
     if ( tasks.isEmpty() )
@@ -799,7 +925,7 @@ void TaskContainer::setShowIconifiedOnly( bool s )
 {
     if ( s == showOnlyIconified )
 	return;
-    
+
     showOnlyIconified = s;
     updateFilteredTaskList();
     update();
@@ -853,7 +979,7 @@ void TaskContainer::updateFilteredTaskList()
 		{
 		    sorted.append( t );
 		    residue.remove( t );
-		}    
+		}
 	}
 	ftasks = sorted;
 
