@@ -46,13 +46,13 @@ template class QPtrList<Task>;
 // variable without changing Task, which also uses it.
 // So, we'll leak a little memory, but it's better than crashing.
 // The real problem is that KWinModule should be a singleton.
-KWinModule* kwin_module = 0;
+KWinModule* kwin_module = NULL;
 
 TaskManager::TaskManager(QObject *parent, const char *name)
     : QObject(parent, name), _active(0), _startup_info( NULL )
 {
-    if ( !kwin_module )
-	kwin_module = new KWinModule();
+    if ( kwin_module == NULL )
+        kwin_module = new KWinModule();
 
     KGlobal::locale()->insertCatalogue("libtaskmanager");
     connect(kwin_module, SIGNAL(windowAdded(WId)), SLOT(windowAdded(WId)));
@@ -75,6 +75,7 @@ TaskManager::TaskManager(QObject *parent, const char *name)
 
 TaskManager::~TaskManager()
 {
+    KGlobal::locale()->removeCatalogue("libtaskmanager");
 }
 
 void TaskManager::configure_startup()
@@ -111,10 +112,14 @@ void TaskManager::windowAdded(WId w )
 		     NET::WMWindowType | NET::WMPid | NET::WMState );
 
     // ignore NET::Tool and other special window types
-    if (info.windowType() != NET::Normal
-        && info.windowType() != NET::Override
-        && info.windowType() != NET::Unknown
-        && info.windowType() != NET::Dialog)
+    NET::WindowType wType = info.windowType( NET::NormalMask | NET::DesktopMask | NET::DockMask
+	| NET::ToolbarMask | NET::MenuMask | NET::DialogMask | NET::OverrideMask
+	| NET::TopMenuMask | NET::UtilityMask | NET::SplashMask );
+    if ( wType != NET::Normal
+        && wType != NET::Override
+        && wType != NET::Unknown
+        && wType != NET::Dialog
+	&& wType != NET::Utility)
 	return;
 
     // ignore windows that want to be ignored by the taskbar
@@ -130,15 +135,16 @@ void TaskManager::windowAdded(WId w )
         // check if it's transient for a skiptaskbar window
         if( _skiptaskbar_windows.contains( transient_for ))
             return;
-    
+
         // lets see if this is a transient for an existing task
         if( transient_for != qt_xrootwin()
-            && transient_for != 0 ) {
+            && transient_for != 0
+            && wType != NET::Utility ) {
 
             Task* t = findTask(transient_for);
             if (t) {
 	        if (t->window() != w) {
-		    t->addTransient(w);
+		    t->addTransient(w, info);
                     // kdDebug() << "TM: Transient " << w << " added for Task: " << t->window() << endl;
                 }
 	        return;
@@ -193,7 +199,8 @@ void TaskManager::windowChanged(WId w, unsigned int dirty)
     }
 
     // check if any state we are interested in is marked dirty
-    if(!(dirty & (NET::WMVisibleName|NET::WMName|NET::WMState|NET::WMIcon|NET::XAWMState|NET::WMDesktop)) )
+    if(!(dirty & (NET::WMVisibleName|NET::WMName|NET::WMVisibleIconName|NET::WMIconName|NET::WMState
+                    |NET::WMIcon|NET::XAWMState|NET::WMDesktop)) )
         return;
 
     // find task
@@ -202,6 +209,8 @@ void TaskManager::windowChanged(WId w, unsigned int dirty)
 
     //kdDebug() << "TaskManager::windowChanged " << w << " " << dirty << endl;
 
+    if( dirty & NET::WMState )
+        t->updateDemandsAttentionState( w );
 
     // refresh icon pixmap if necessary
     if (dirty & NET::WMIcon)
@@ -313,14 +322,13 @@ bool TaskManager::isOnTop(const Task* task)
     return false;
 }
 
-
 Task::Task(WId win, TaskManager * parent, const char *name)
   : QObject(parent, name),
     _active(false), _win(win),
     _lastWidth(0), _lastHeight(0), _lastResize(false), _lastIcon(),
     _thumbSize(0.2), _thumb(), _grab()
 {
-    _info = KWin::info(_win);
+    _info = KWin::windowInfo(_win);
 
     // try to load icon via net_wm
     _pixmap = KWin::icon(_win, 16, 16, true);
@@ -342,7 +350,7 @@ Task::~Task()
 
 void Task::refresh(bool icon)
 {
-    _info = KWin::info(_win);
+    _info = KWin::windowInfo(_win);
     if (icon) {
 
         // try to load icon via net_wm
@@ -360,7 +368,7 @@ void Task::refresh(bool icon)
 	_lastIcon.resize(0,0);
 	emit iconChanged();
     }
-    emit changed();
+    emit changed(); // always changed ?  ... :(
 }
 
 void Task::setActive(bool a)
@@ -375,32 +383,37 @@ void Task::setActive(bool a)
 
 bool Task::isMaximized() const
 {
-    return(_info.state & NET::Max);
+    return(_info.state() & NET::Max);
+}
+
+bool Task::isMinimized() const
+{
+    return _info.isMinimized();
 }
 
 bool Task::isIconified() const
 {
-    return (_info.mappingState == NET::Iconic);
+    return _info.isMinimized();
 }
 
 bool Task::isAlwaysOnTop() const
 {
-    return (_info.state & NET::StaysOnTop);
+    return (_info.state() & NET::StaysOnTop);
 }
 
 bool Task::isShaded() const
 {
-    return (_info.state & NET::Shaded);
+    return (_info.state() & NET::Shaded);
 }
 
 bool Task::isOnCurrentDesktop() const
 {
-    return (_info.onAllDesktops || _info.desktop == kwin_module->currentDesktop());
+    return (_info.isOnCurrentDesktop());
 }
 
 bool Task::isOnAllDesktops() const
 {
-    return _info.onAllDesktops;
+    return _info.onAllDesktops();
 }
 
 bool Task::isActive() const
@@ -416,20 +429,45 @@ bool Task::isOnTop() const
 bool Task::isModified() const
 {
   static QString modStr = QString::fromUtf8("[") + i18n("modified") + QString::fromUtf8("]");
-  int modStrPos = _info.visibleName.find(modStr);
+  int modStrPos = _info.visibleName().find(modStr);
 
   return ( modStrPos != -1 );
 }
 
-QString Task::iconName() const
+bool Task::demandsAttention() const
 {
-    NETWinInfo ni( qt_xdisplay(),  _win, qt_xrootwin(), NET::WMIconName);
-    return QString::fromUtf8(ni.iconName());
+    return (_info.state() & NET::DemandsAttention)
+        || _transients_demanding_attention.count() > 0;
 }
-QString Task::visibleIconName() const
+
+void Task::updateDemandsAttentionState( WId w )
 {
-    NETWinInfo ni( qt_xdisplay(),  _win, qt_xrootwin(), NET::WMVisibleIconName);
-    return QString::fromUtf8(ni.visibleIconName());
+    if( window() != w ) { // 'w' is a transient for this task
+        NETWinInfo i( qt_xdisplay(), w, qt_xrootwin(), NET::WMState );
+        if( i.state() & NET::DemandsAttention ) {
+            if( !_transients_demanding_attention.contains( w )) {
+                _transients_demanding_attention.append( w );
+            }
+        } else {
+            _transients_demanding_attention.remove( w );
+        }
+    }
+}
+
+void Task::addTransient( WId w, const NETWinInfo& info )
+{
+    _transients.append( w );
+    if( info.state() & NET::DemandsAttention )
+        {
+        _transients_demanding_attention.append( w );
+        emit changed();
+        }
+}
+
+void Task::removeTransient( WId w )
+{
+    _transients.remove( w );
+    _transients_demanding_attention.remove( w );
 }
 
 QString Task::className()
@@ -569,25 +607,35 @@ bool Task::idMatch( const QString& id1, const QString& id2 )
 
 void Task::maximize()
 {
-    NETWinInfo ni( qt_xdisplay(),  _win, qt_xrootwin(), NET::WMState);
+    KWin::WindowInfo info = KWin::windowInfo( _win, NET::WMState | NET::XAWMState | NET::WMDesktop );
+    bool on_current = info.isOnCurrentDesktop();
+    if( !on_current )
+        KWin::setCurrentDesktop( info.desktop());
+    if( info.isMinimized())
+        KWin::deIconifyWindow( _win );
+    NETWinInfo ni( qt_xdisplay(),  _win, qt_xrootwin(), NET::WMState );
     ni.setState( NET::Max, NET::Max );
-
-    if (_info.mappingState == NET::Iconic)
-        activate();
+    if( !on_current )
+        KWin::forceActiveWindow( _win );
 }
 
 void Task::restore()
 {
-    NETWinInfo ni( qt_xdisplay(),  _win, qt_xrootwin(), NET::WMState);
+    KWin::WindowInfo info = KWin::windowInfo( _win, NET::WMState | NET::XAWMState | NET::WMDesktop );
+    bool on_current = info.isOnCurrentDesktop();
+    if( !on_current )
+        KWin::setCurrentDesktop( info.desktop());
+    if( info.isMinimized())
+        KWin::deIconifyWindow( _win );
+    NETWinInfo ni( qt_xdisplay(),  _win, qt_xrootwin(), NET::WMState );
     ni.setState( 0, NET::Max );
-
-    if (_info.mappingState == NET::Iconic)
-        activate();
+    if( !on_current )
+        KWin::forceActiveWindow( _win );
 }
 
 void Task::iconify()
 {
-    XIconifyWindow( qt_xdisplay(), _win, qt_xscreen() );
+    KWin::iconifyWindow( _win );
 }
 
 void Task::close()
@@ -599,20 +647,22 @@ void Task::close()
 void Task::raise()
 {
 //    kdDebug(1210) << "Task::raise(): " << name() << endl;
-    XRaiseWindow( qt_xdisplay(), _win );
+    KWin::raiseWindow( _win );
 }
 
 void Task::lower()
 {
 //    kdDebug(1210) << "Task::lower(): " << name() << endl;
-    XLowerWindow( qt_xdisplay(), _win );
+    KWin::lowerWindow( _win );
 }
 
 void Task::activate()
 {
 //    kdDebug(1210) << "Task::activate():" << name() << endl;
-    NETRootInfo ri( qt_xdisplay(), 0 );
-    ri.setActiveWindow( _win );
+    WId w = _win;
+    if( _transients_demanding_attention.count() > 0 )
+        w = _transients_demanding_attention.last();
+    KWin::forceActiveWindow( w );
 }
 
 void Task::activateRaiseOrIconify()
@@ -630,9 +680,9 @@ void Task::toDesktop(int desk)
 {
     NETWinInfo ni(qt_xdisplay(), _win, qt_xrootwin(), NET::WMDesktop);
     if (desk == 0) {
-        if (_info.onAllDesktops) {
+        if (_info.onAllDesktops()) {
             ni.setDesktop(kwin_module->currentDesktop());
-            KWin::setActiveWindow(_win);
+            KWin::forceActiveWindow(_win);
         }
         else
             ni.setDesktop(NETWinInfo::OnAllDesktops);
@@ -640,7 +690,7 @@ void Task::toDesktop(int desk)
     }
     ni.setDesktop(desk);
     if(desk == kwin_module->currentDesktop())
-        KWin::setActiveWindow(_win);
+        KWin::forceActiveWindow(_win);
 }
 
 void Task::toCurrentDesktop()
@@ -678,7 +728,7 @@ void Task::toggleShaded()
 
 void Task::publishIconGeometry(QRect rect)
 {
-    NETWinInfo ni( qt_xdisplay(),  _win, qt_xrootwin(), NET::WMIconGeometry);
+    NETWinInfo ni( qt_xdisplay(),  _win, qt_xrootwin(), 0 );
     NETRect r;
     r.pos.x = rect.x();
     r.pos.y = rect.y();
@@ -702,7 +752,7 @@ void Task::updateThumbnail()
    // on slower machines.
    //
   QWidget *rootWin = qApp->desktop();
-  QRect geom = _info.geometry;
+  QRect geom = _info.geometry();
    _grab = QPixmap::grabWindow( rootWin->winId(),
 				geom.x(), geom.y(),
 				geom.width(), geom.height() );
@@ -723,7 +773,7 @@ void Task::generateThumbnail()
    width = width * _thumbSize;
    height = height * _thumbSize;
 
-   img = img.smoothScale( (int) width, (int) height );
+   img = img.smoothScale( qRound(width), qRound(height) );
    _thumb = img;
    _grab.resize( 0, 0 ); // Makes grab a null image.
 
