@@ -24,7 +24,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef __addapplet_mnu_h__
 #define __addapplet_mnu_h__
 
-#include <qlist.h>
+#include <qvaluelist.h>
 #include <qpopupmenu.h>
 
 #include "appletinfo.h"
@@ -43,8 +43,8 @@ protected slots:
     virtual void slotAboutToShow();
 
 private:
-    QList<AppletInfo>  applets;
-    ContainerArea     *containerArea;
+    QValueList<AppletInfo>  applets;
+    ContainerArea*          containerArea;
 };
 
 #endif
