@@ -299,7 +299,7 @@ void PanelKMenu::initialize()
     else {
         xdmFifoName = dmopt.first();
 	if (kapp->authorize("start_new_session")){
-	        insertItem(SmallIconSet("fork"), i18n("Start New Session"), this, SLOT(slotNewSession()));
+	        insertItem(SmallIconSet("fork"), i18n("Start New Session..."), this, SLOT(slotNewSession()));
 	}
     }
 
@@ -312,7 +312,7 @@ void PanelKMenu::initialize()
         insertItem(SmallIconSet("filesave"), i18n("Save Session"), this, SLOT(slotSaveSession()));
 
     if (kapp->authorize("lock_screen"))
-        insertItem(SmallIconSet("lock"), i18n("Lock Screen"), this, SLOT(slotLock()));
+        insertItem(SmallIconSet("lock"), i18n("Lock Session"), this, SLOT(slotLock()));
 
     if (kapp->authorize("logout"))
       insertItem(SmallIconSet("exit"), i18n("Logout..."), this, SLOT(slotLogout()));
@@ -360,9 +360,16 @@ void PanelKMenu::slotLogout()
 
 void PanelKMenu::slotNewSession()
 {
-    if (KMessageBox::warningContinueCancel(
-	  kapp->desktop()->screen(kapp->desktop()->screenNumber(this)),
-          i18n("<p>You have chosen to open another desktop session.<br>"
+    KDialogBase *dialog= new KDialogBase("",
+                       KDialogBase::Yes | KDialogBase::No,
+                       KDialogBase::Yes, KDialogBase::No,
+                       kapp->desktop()->screen(kapp->desktop()->screenNumber(this)),
+                       "warningYesNo", true, true,
+                       KGuiItem(i18n("&Start New Session"), "fork"), KStdGuiItem::cancel() );
+    dialog->setPlainCaption(i18n("Warning - New Session"));
+
+    bool checkboxResult = kapp->authorize("lock_screen");
+    const QString text = i18n("<p>You have chosen to open another desktop session.<br>"
                "The current session will be hidden "
                "and a new login screen will be displayed.<br>"
                "An F-key is assigned to each session; "
@@ -370,8 +377,19 @@ void PanelKMenu::slotNewSession()
                "F%2 to the second session and so on. "
                "You can switch between sessions by pressing "
                "CTRL, ALT and the appropriate F-key at the same time.</p>")
-            .arg(7).arg(8)) != KMessageBox::Continue)
+                           .arg(7).arg(8);
+
+    int result = KMessageBox::createKMessageBox(dialog, QMessageBox::Warning,
+                       text, QStringList(),
+                       checkboxResult ? i18n("&Lock current session") : QString::null,
+                       &checkboxResult, 0);
+
+    if (result==KDialogBase::No)
         return;
+
+    if (checkboxResult)
+        slotLock();
+
     QFile fifo(xdmFifoName);
     if (fifo.open(IO_WriteOnly | IO_Raw)) {
         fifo.writeBlock( "reserve\n", 8 );
@@ -393,6 +411,7 @@ void PanelKMenu::slotRunCommand()
     if ( kicker_screen_number )
         appname.sprintf("kdesktop-screen-%d", kicker_screen_number);
 
+    kapp->updateRemoteUserTimestamp( appname );
     kapp->dcopClient()->send( appname, "KDesktopIface",
                               "popupExecuteCommand()", data );
 }
@@ -438,6 +457,13 @@ void PanelKMenu::resizeEvent(QResizeEvent * e)
                                       width() - sidePixmap.width(), height() ), this ) );
 }
 
+//Workaround Qt3.3.x sizing bug, by ensuring we're always wide enough.
+void PanelKMenu::resize(int width, int height)
+{
+    width = kMax(width, maximumSize().width());
+    PanelServiceMenu::resize(width, height);
+}
+
 QSize PanelKMenu::sizeHint() const
 {
     QSize s = PanelServiceMenu::sizeHint();
