@@ -27,6 +27,7 @@
 #include <kio/authinfo.h>
 #include <time.h>
 
+#define FISH_EXEC_CMD 'X'
 
 class fishProtocol : public KIO::SlaveBase
 {
@@ -36,12 +37,12 @@ public:
 
   /**
 Connects to a server and logs us in via SSH. Then starts FISH protocol.
-@ref isConnected is set to true if logging on was successfull.
+@ref isConnected is set to true if logging on was successful.
 It is set to false if the connection becomes closed.
 
  */
   void openConnection();
-  
+
   /**
    Clean up connection
   */
@@ -78,6 +79,8 @@ It is set to false if the connection becomes closed.
   void slave_status();
   /** removes a file or directory */
   void del(const KURL &u, bool isfile);
+  /** special like background execute */
+  void special( const QByteArray &data );
 
 private: // Private attributes
   /** the SSH process used to communicate with the remote end */
@@ -90,6 +93,8 @@ private: // Private attributes
   int outBufPos;
   /** length of buffer */
   int outBufLen;
+  /** use su if true else use ssh */
+  bool local;
   /**  // FIXME: just a workaround for konq deficiencies */
   bool isStat;
   /**  // FIXME: just a workaround for konq deficiencies */
@@ -103,7 +108,7 @@ protected: // Protected attributes
   /** for LIST/STAT */
   KIO::UDSAtom typeAtom;
   /** for LIST/STAT */
-  bool isFirst;
+  KIO::UDSAtom mimeAtom;
   /** for LIST/STAT */
   QString thisFn;
   /** for STAT */
@@ -144,11 +149,7 @@ protected: // Protected attributes
   /** true if a command stack is currently executing */
   bool isRunning;
   /** reason of LIST command */
-  enum { CHECK, LIST, STAT, SIZE, STATCHECK } listReason;
-  /** true if FISH server understands COPY command */
-  bool hasCopy;
-  /** true if FISH server understands RSYNC command */
-  bool hasRsync;
+  enum { CHECK, LIST } listReason;
   /** true if FISH server understands APPEND command */
   bool hasAppend;
   /** permission of created file */
@@ -159,10 +160,14 @@ protected: // Protected attributes
   int putPos;
   /** true if file already existed */
   bool checkExist;
+  /** true if this is the first login attempt (== use cached password) */
+  bool firstLogin;
   /** write buffer */
   QByteArray rawData;
   /** buffer for storing bytes used for MimeMagic */
   QByteArray mimeBuffer;
+  /** whther the mimetype has been sent already */
+  bool mimeTypeSent;
   /** number of bytes read so far */
   int dataRead;
   time_t t_last, t_start;
@@ -176,10 +181,11 @@ protected: // Protected attributes
       int lines;
   } fishInfo[];
   /** last FISH command sent to server */
-  enum fish_command_type { FISH_FISH, FISH_VER, FISH_PWD, FISH_LIST, FISH_RETR, FISH_STOR,
+  enum fish_command_type { FISH_FISH, FISH_VER, FISH_PWD, FISH_LIST, FISH_STAT,
+    FISH_RETR, FISH_STOR,
     FISH_CWD, FISH_CHMOD, FISH_DELE, FISH_MKD, FISH_RMD,
     FISH_RENAME, FISH_LINK, FISH_SYMLINK, FISH_CHOWN,
-    FISH_CHGRP, FISH_READ, FISH_WRITE, FISH_COPY, FISH_APPEND } fishCommand;
+    FISH_CHGRP, FISH_READ, FISH_WRITE, FISH_COPY, FISH_APPEND, FISH_EXEC } fishCommand;
   int fishCodeLen;
 protected: // Protected methods
   /** manages initial communication setup including password queries */
