@@ -69,8 +69,8 @@ int kdemain( int argc, char **argv )
 
 void getDriveAndPath(const QString& path, QString& drive, QString& rest)
 {
-   drive="";
-   rest="";
+   drive=QString::null;
+   rest=QString::null;
    QStringList list=QStringList::split("/",path);
    for (QStringList::Iterator it=list.begin(); it!=list.end(); it++)
    {
@@ -195,50 +195,55 @@ bool FloppyProtocol::stopAfterError(const KURL& url, const QString& drive)
    QTextIStream output(&outputString);
    QString line=output.readLine();
    kdDebug(7101)<<"line: -"<<line<<"-"<<endl;
-   if (line.contains("resource busy"))
+   if (line.find("resource busy") > -1)
    {
-      error( KIO::ERR_COULD_NOT_STAT, i18n("drive %1.\nThe drive is still busy.\nWait until it has stopped working and then try again.").arg(drive));
+      error( KIO::ERR_SLAVE_DEFINED, i18n("Could not access drive %1.\nThe drive is still busy.\nWait until it is inactive and then try again.").arg(drive));
    }
-   else if ((line.contains("Disk full")) || (line.contains("No free cluster")))
+   else if ((line.find("Disk full") > -1) || (line.find("No free cluster") > -1))
    {
-      error( KIO::ERR_COULD_NOT_WRITE, url.prettyURL()+i18n("\nThe disk in drive %1 is probably full.").arg(drive));
+      error( KIO::ERR_SLAVE_DEFINED, i18n("Could not write to file %1.\nThe disk in drive %2 is probably full.").arg(url.prettyURL(),drive));
    }
    //file not found
-   else if (line.contains("not found"))
+   else if (line.find("not found") > -1)
    {
       error( KIO::ERR_DOES_NOT_EXIST, url.prettyURL());
    }
    //no disk
-   else if (line.contains("not configured"))
+   else if (line.find("not configured") > -1)
    {
-      error( KIO::ERR_COULD_NOT_STAT, url.prettyURL()+i18n("\nThere is probably no disk in the drive %1").arg(drive));
+      error( KIO::ERR_SLAVE_DEFINED, i18n("Could not access %1.\nThere is probably no disk in the drive %2").arg(url.prettyURL(),drive));
    }
-   else if (line.contains("No such device"))
+   else if (line.find("No such device") > -1)
    {
-      error( KIO::ERR_COULD_NOT_STAT, url.prettyURL()+i18n("\nThere is probably no disk in the drive %1 or you don't have enough permissions to access the drive.").arg(drive));
+      error( KIO::ERR_SLAVE_DEFINED, i18n("Could not access %1.\nThere is probably no disk in the drive %2 or you do not have enough permissions to access the drive.").arg(url.prettyURL(),drive));
    }
-   else if (line.contains("not supported"))
+   else if (line.find("not supported") > -1)
    {
-      error( KIO::ERR_COULD_NOT_STAT, url.prettyURL()+i18n("\nThe drive %1 is not supported.").arg(drive));
+      error( KIO::ERR_SLAVE_DEFINED, i18n("Could not access %1.\nThe drive %2 is not supported.").arg(url.prettyURL(),drive));
    }
    //not supported or no such drive
-   else if (line.contains("Permission denied"))
+   else if (line.find("Permission denied") > -1)
    {
-      error( KIO::ERR_COULD_NOT_STAT, url.prettyURL()+i18n("\nMake sure the floppy in drive %1 is a DOS formatted floppy disk \nand that the permissions of the device file (e.g. /dev/fd0) are set correctly (e.g. rwxrwxrwx).").arg(drive));
+      error( KIO::ERR_SLAVE_DEFINED, i18n("Could not access %1.\nMake sure the floppy in drive %2 is a DOS-formatted floppy disk \nand that the permissions of the device file (e.g. /dev/fd0) are set correctly (e.g. rwxrwxrwx).").arg(url.prettyURL(),drive));
    }
-   else if (line.contains("non DOS media"))
+   else if (line.find("non DOS media") > -1)
    {
-      error( KIO::ERR_COULD_NOT_STAT, url.prettyURL()+i18n("\nThe disk in drive %1 is probably not a DOS formatted floppy disk.").arg(drive));
+      error( KIO::ERR_SLAVE_DEFINED, i18n("Could not access %1.\nThe disk in drive %2 is probably not a DOS-formatted floppy disk.").arg(url.prettyURL(),drive));
    }
-   else if (line.contains("Read-only"))
+   else if (line.find("Read-only") > -1)
    {
-      error( KIO::ERR_WRITE_ACCESS_DENIED, url.prettyURL()+i18n("\nThe disk in drive %1 is probably write-protected.").arg(drive));
+      error( KIO::ERR_SLAVE_DEFINED, i18n("Access denied.\nCould not write to %1.\nThe disk in drive %2 is probably write-protected.").arg(url.prettyURL(),drive));
    }
-   else if ((outputString.contains("already exists")) || (outputString.contains("Skipping ")))
+   else if ((outputString.find("already exists") > -1) || (outputString.find("Skipping ") > -1))
    {
       error( KIO::ERR_FILE_ALREADY_EXIST,url.prettyURL());
       //return false;
    }
+   else if (outputString.find("could not read boot sector") > -1)
+   {
+      error( KIO::ERR_SLAVE_DEFINED, i18n("Could not read boot sector for %1.\nThere is probably not any disk in drive %2.").arg(url.prettyURL(),drive));
+      //return false;
+   }
    else
    {
       error( KIO::ERR_UNKNOWN, outputString);
@@ -250,7 +255,7 @@ void FloppyProtocol::listDir( const KURL& _url)
 {
    kdDebug(7101)<<"Floppy::listDir() "<<_url.path()<<endl;
    KURL url(_url);
-   QString path( QFile::encodeName(url.path()));
+   QString path(url.path());
 
    if ((path.isEmpty()) || (path=="/"))
    {
@@ -276,7 +281,7 @@ void FloppyProtocol::listDir( const KURL& _url)
    {
       delete m_mtool;
       m_mtool=0;
-      error(ERR_CANNOT_LAUNCH_PROCESS,"mdir"+i18n("\nEnsure that the mtools package is installed correctly on your system."));
+      errorMissingMToolsProgram("mdir");
       return;
    }
 
@@ -358,6 +363,11 @@ void FloppyProtocol::listDir( const KURL& _url)
    //kdDebug(7101)<<"Floppy::listDir() ends"<<endl;
 }
 
+void FloppyProtocol::errorMissingMToolsProgram(const QString& name)
+{
+     error(KIO::ERR_SLAVE_DEFINED,i18n("Could not start program \"%1\".\nEnsure that the mtools package is installed correctly on your system.").arg(name));
+ }
+
 void FloppyProtocol::createUDSEntry(const StatInfo& info, UDSEntry& entry)
 {
    UDSAtom atom;
@@ -481,7 +491,7 @@ StatInfo FloppyProtocol::_stat(const KURL& url)
 {
    StatInfo info;
 
-   QString path( QFile::encodeName(url.path()));
+   QString path(url.path());
    QString drive;
    QString floppyPath;
    getDriveAndPath(path,drive,floppyPath);
@@ -513,7 +523,7 @@ StatInfo FloppyProtocol::_stat(const KURL& url)
    {
       delete m_mtool;
       m_mtool=0;
-      error(ERR_CANNOT_LAUNCH_PROCESS,"mdir"+i18n("\nEnsure that the mtools package is installed correctly on your system."));
+      errorMissingMToolsProgram("mdir");
       return info;
    }
 
@@ -560,7 +570,7 @@ StatInfo FloppyProtocol::_stat(const KURL& url)
    if (m_stdoutSize==0)
    {
       info.isValid=false;
-      error( KIO::ERR_COULD_NOT_STAT, url.prettyURL()+i18n("Reason unknown."));
+      error( KIO::ERR_COULD_NOT_STAT, url.prettyURL());
       return info;
    }
 
@@ -575,17 +585,17 @@ StatInfo FloppyProtocol::_stat(const KURL& url)
          continue;
       StatInfo info=createStatInfo(line,true,url.fileName());
       if (info.isValid==false)
-         error( KIO::ERR_COULD_NOT_STAT, url.prettyURL()+i18n("Reason unknown."));
+         error( KIO::ERR_COULD_NOT_STAT, url.prettyURL());
       return info;
    }
    if (info.isValid==false)
-      error( KIO::ERR_COULD_NOT_STAT, url.prettyURL()+i18n("Reason unknown."));
+      error( KIO::ERR_COULD_NOT_STAT, url.prettyURL());
    return info;
 }
 
 int FloppyProtocol::freeSpace(const KURL& url)
 {
-   QString path( QFile::encodeName(url.path()));
+   QString path(url.path());
    QString drive;
    QString floppyPath;
    getDriveAndPath(path,drive,floppyPath);
@@ -604,7 +614,7 @@ int FloppyProtocol::freeSpace(const KURL& url)
    {
       delete m_mtool;
       m_mtool=0;
-      error(ERR_CANNOT_LAUNCH_PROCESS,"mdir"+i18n("\nEnsure that the mtools package is installed correctly on your system."));
+      errorMissingMToolsProgram("mdir");
       return -1;
    }
 
@@ -649,7 +659,7 @@ int FloppyProtocol::freeSpace(const KURL& url)
 
    if (m_stdoutSize==0)
    {
-      error( KIO::ERR_COULD_NOT_STAT, url.prettyURL()+i18n("Reason unknown."));
+      error( KIO::ERR_COULD_NOT_STAT, url.prettyURL());
       return -1;
    }
 
@@ -681,7 +691,7 @@ void FloppyProtocol::stat( const KURL & _url)
 {
    kdDebug(7101)<<"Floppy::stat() "<<_url.path()<<endl;
    KURL url(_url);
-   QString path( QFile::encodeName(url.path()));
+   QString path(url.path());
 
    if ((path.isEmpty()) || (path=="/"))
    {
@@ -706,7 +716,7 @@ void FloppyProtocol::stat( const KURL & _url)
 void FloppyProtocol::mkdir( const KURL& url, int)
 {
    kdDebug(7101)<<"FloppyProtocol::mkdir()"<<endl;
-   QString path( QFile::encodeName(url.path()));
+   QString path(url.path());
 
    if ((path.isEmpty()) || (path=="/"))
    {
@@ -737,7 +747,7 @@ void FloppyProtocol::mkdir( const KURL& url, int)
    {
       delete m_mtool;
       m_mtool=0;
-      error(ERR_CANNOT_LAUNCH_PROCESS,"mmd"+i18n("\nEnsure that the mtools package is installed correctly on your system."));
+      errorMissingMToolsProgram("mmd");
       return;
    }
 
@@ -778,7 +788,7 @@ void FloppyProtocol::mkdir( const KURL& url, int)
 void FloppyProtocol::del( const KURL& url, bool isfile)
 {
    kdDebug(7101)<<"FloppyProtocol::del()"<<endl;
-   QString path( QFile::encodeName(url.path()));
+   QString path(url.path());
 
    if ((path.isEmpty()) || (path=="/"))
    {
@@ -801,20 +811,28 @@ void FloppyProtocol::del( const KURL& url, bool isfile)
       delete m_mtool;
    //kdDebug(7101)<<"Floppy::stat(): create args"<<endl;
    QStringList args;
+   
+   bool usingmdel;
 
    if (isfile)
+   {
       args<<"mdel"<<(drive+floppyPath);
+      usingmdel=true;
+   }
    else
+   {
       args<<"mrd"<<(drive+floppyPath);
+      usingmdel=false;
+   }
 
-   kdDebug(7101)<<"Floppy::del(): executing: mrd -"<<(drive+floppyPath)<<"-"<<endl;
+   kdDebug(7101)<<"Floppy::del(): executing: " << (usingmdel ? QString("mdel") : QString("mrd") ) << "-"<<(drive+floppyPath)<<"-"<<endl;
 
    m_mtool=new Program(args);
    if (!m_mtool->start())
    {
       delete m_mtool;
       m_mtool=0;
-      error(ERR_CANNOT_LAUNCH_PROCESS,"mrd"+i18n("\nEnsure that the mtools package is installed correctly on your system."));
+      errorMissingMToolsProgram(usingmdel ? QString("mdel") : QString("mrd"));
       return;
    }
 
@@ -854,8 +872,8 @@ void FloppyProtocol::del( const KURL& url, bool isfile)
 
 void FloppyProtocol::rename( const KURL &src, const KURL &dest, bool _overwrite )
 {
-   QString srcPath( QFile::encodeName(src.path()));
-   QString destPath( QFile::encodeName(dest.path()));
+   QString srcPath(src.path());
+   QString destPath(dest.path());
 
    kdDebug(7101)<<"Floppy::rename() -"<<srcPath<<"- to -"<<destPath<<"-"<<endl;
 
@@ -900,7 +918,7 @@ void FloppyProtocol::rename( const KURL &src, const KURL &dest, bool _overwrite
    {
       delete m_mtool;
       m_mtool=0;
-      error(ERR_CANNOT_LAUNCH_PROCESS,"mren"+i18n("\nEnsure that the mtools package is installed correctly on your system."));
+      errorMissingMToolsProgram("mren");
       return;
    }
 
@@ -940,7 +958,7 @@ void FloppyProtocol::rename( const KURL &src, const KURL &dest, bool _overwrite
 
 void FloppyProtocol::get( const KURL& url )
 {
-   QString path( QFile::encodeName(url.path()));
+   QString path(url.path());
    kdDebug(7101)<<"Floppy::get() -"<<path<<"-"<<endl;
 
    if ((path.isEmpty()) || (path=="/"))
@@ -980,7 +998,7 @@ void FloppyProtocol::get( const KURL& url )
    {
       delete m_mtool;
       m_mtool=0;
-      error(ERR_CANNOT_LAUNCH_PROCESS,"mcopy"+i18n("\nEnsure that the mtools package is installed correctly on your system."));
+      errorMissingMToolsProgram("mcopy");
       return;
    }
 
@@ -1040,7 +1058,7 @@ void FloppyProtocol::get( const KURL& url )
 
 void FloppyProtocol::put( const KURL& url, int , bool overwrite, bool )
 {
-   QString path( QFile::encodeName(url.path()));
+   QString path(url.path());
    kdDebug(7101)<<"Floppy::put() -"<<path<<"-"<<endl;
 
    if ((path.isEmpty()) || (path=="/"))
@@ -1079,7 +1097,7 @@ void FloppyProtocol::put( const KURL& url, int , bool overwrite, bool )
    {
       delete m_mtool;
       m_mtool=0;
-      error(ERR_CANNOT_LAUNCH_PROCESS,"mcopy"+i18n("\nEnsure that the mtools package is installed correctly on your system."));
+      errorMissingMToolsProgram("mcopy");
       return;
    }
 
@@ -1125,7 +1143,7 @@ void FloppyProtocol::put( const KURL& url, int , bool overwrite, bool )
             if (bytesRead>freeSpaceLeft)
             {
                result=0;
-               error( KIO::ERR_COULD_NOT_WRITE, url.prettyURL()+i18n("\nThe disk in drive %1 is probably full.").arg(drive));
+               error( KIO::ERR_SLAVE_DEFINED, i18n("Could not write to file %1.\nThe disk in drive %2 is probably full.").arg(url.prettyURL(),drive));
             }
             else
             {
