@@ -1,5 +1,5 @@
 #ifndef _IMAPLIST_H
-#define _IMAPLIST_H "$Id: imaplist.h,v 1.4 2003/03/07 22:05:30 waba Exp $"
+#define _IMAPLIST_H
 /**********************************************************************
  *
  *   imaplist.h  - IMAP4rev1 list response handler
@@ -72,6 +72,24 @@ public:
     noSelect_ = _val;
   }
 
+  bool hasChildren () const
+  {
+    return hasChildren_;
+  }
+  void setHasChildren (bool _val)
+  {
+    hasChildren_ = _val;
+  }
+
+  bool hasNoChildren () const
+  {
+    return hasNoChildren_;
+  }
+  void setHasNoChildren (bool _val)
+  {
+    hasNoChildren_ = _val;
+  }
+
   bool marked () const
   {
     return marked_;
@@ -98,6 +116,8 @@ private:
   bool noSelect_;
   bool marked_;
   bool unmarked_;
+  bool hasChildren_;
+  bool hasNoChildren_;
 };
 
 #endif
