@@ -60,6 +60,7 @@ QString rfcDecoder::fromIMAP (const QString & inSrc)
   unsigned long srcPtr = 0;
   QCString dst;
   QCString src = inSrc.ascii ();
+  uint srcLen = inSrc.length();
 
   /* initialize modified base64 decoding table */
   memset (base64, UNDEFINED, sizeof (base64));
@@ -69,7 +70,7 @@ QString rfcDecoder::fromIMAP (const QString & inSrc)
   }
 
   /* loop until end of string */
-  while (srcPtr < src.length ())
+  while (srcPtr < srcLen)
   {
     c = src[srcPtr++];
     /* deal with literal characters and &- */
@@ -156,12 +157,16 @@ QString rfcDecoder::fromIMAP (const QString & inSrc)
 /* replace " with \" and \ with \\ " and \ characters */
 QString rfcDecoder::quoteIMAP(const QString &src)
 {
+  uint len = src.length();
   QString result;
-  for (unsigned int i = 0; i < src.length(); i++)
+  result.reserve(2 * len);
+  for (unsigned int i = 0; i < len; i++)
   {
-    if (src[i] == '"' || src[i] == '\\') result += '\\';
+    if (src[i] == '"' || src[i] == '\\')
+      result += '\\';
     result += src[i];
   }
+  //result.squeeze(); - unnecessary and slow
   return result;
 }
 
@@ -331,6 +336,10 @@ const QString
 rfcDecoder::decodeRFC2047String (const QString & _str, QString & charset,
                                  QString & language)
 {
+  //do we have a rfc string
+  if (_str.find("=?") < 0)
+    return _str;
+
   QCString aStr = _str.ascii ();  // QString.length() means Unicode chars
   QCString result;
   char *pos, *beg, *end, *mid = NULL;
@@ -340,10 +349,6 @@ rfcDecoder::decodeRFC2047String (const QString & _str, QString & charset,
   const int maxLen = 200;
   int i;
 
-  //do we have a rfc string
-  if (aStr.find ("=?") < 0)
-    return aStr;
-
 //  result.truncate(aStr.length());
   for (pos = aStr.data (); *pos; pos++)
   {
@@ -365,14 +370,14 @@ rfcDecoder::decodeRFC2047String (const QString & _str, QString & charset,
     else
     {
       charset = QCString (beg, i - 1);  // -2 + 1 for the zero
-      if (charset.findRev ('*') != -1)
+      int pt = charset.findRev('*');
+      if (pt != -1)
       {
         // save language for later usage
-        language =
-          charset.right (charset.length () - charset.findRev ('*') - 1);
+        language = charset.right (charset.length () - pt - 1);
 
         // tie off language as defined in rfc2047
-        charset = charset.left (charset.findRev ('*'));
+        charset.truncate(pt);
       }
       // get encoding and check delimiting question marks
       encoding = toupper (pos[1]);
@@ -419,7 +424,8 @@ rfcDecoder::decodeRFC2047String (const QString & _str, QString & charset,
         str = KCodecs::base64Decode(str);
       }
       *pos = ch;
-      for (i = 0; i < (int) str.length (); i++)
+      int len = str.length();
+      for (i = 0; i < len; i++)
         result += (char) (QChar) str[i];
 
       pos = end - 1;
@@ -455,13 +461,14 @@ rfcDecoder::encodeRFC2047String (const QString & _str)
 {
   if (_str.isEmpty ())
     return _str;
-  signed char *latin = (signed char *) calloc (1, _str.length () + 1);
-  char *latin_un = (char *) latin;
-  strcpy (latin_un, _str.latin1 ());
-  signed char *latinStart = latin, *l, *start, *stop;
+  const signed char *latin = reinterpret_cast<const signed char *>(_str.latin1()), *l, *start, *stop;
   char hexcode;
   int numQuotes, i;
-  QCString result;
+  int rptr = 0;
+  // My stats show this number results in 12 resize() out of 73,000
+  int resultLen = 3 * _str.length() / 2;
+  QCString result(resultLen);
+  
   while (*latin)
   {
     l = latin;
@@ -500,13 +507,21 @@ rfcDecoder::encodeRFC2047String (const QString & _str)
       }
       else
         stop = l;
+      if (resultLen - rptr - 1 <= start -  latin + 1 + 16 /* =?iso-88... */) {
+        resultLen += (start - latin + 1) * 2 + 20; // more space
+	result.resize(resultLen);
+      }
       while (latin < start)
       {
-        result += *latin;
+        result[rptr++] = *latin;
         latin++;
       }
-      result += QCString ("=?iso-8859-1?q?");
-      while (latin < stop)
+      strcpy(&result[rptr], "=?iso-8859-1?q?"); rptr += 15;
+      if (resultLen - rptr - 1 <= 3*(stop - latin + 1)) {
+        resultLen += (stop - latin + 1) * 4 + 20; // more space
+	result.resize(resultLen);
+      }
+      while (latin < stop) // can add up to 3 chars/iteration
       {
         numQuotes = 0;
         for (i = 0; i < 16; i++)
@@ -516,34 +531,40 @@ rfcDecoder::encodeRFC2047String (const QString & _str)
           numQuotes = 1;
         if (numQuotes)
         {
-          result += "=";
+          result[rptr++] = '=';
           hexcode = ((*latin & 0xF0) >> 4) + 48;
           if (hexcode >= 58)
             hexcode += 7;
-          result += hexcode;
+          result[rptr++] = hexcode;
           hexcode = (*latin & 0x0F) + 48;
           if (hexcode >= 58)
             hexcode += 7;
-          result += hexcode;
+          result[rptr++] = hexcode;
         }
         else
         {
-          result += *latin;
+          result[rptr++] = *latin;
         }
         latin++;
       }
-      result += "?=";
+      result[rptr++] = '?';
+      result[rptr++] = '=';
     }
     else
     {
       while (*latin)
       {
-        result += *latin;
+        if (rptr == resultLen - 1) {
+          resultLen += 30;
+          result.resize(resultLen);
+        }
+        result[rptr++] = *latin;
         latin++;
       }
     }
   }
-  free (latinStart);
+  result[rptr] = 0;
+  //free (latinStart);
   return result;
 }
 
@@ -604,24 +625,22 @@ rfcDecoder::encodeRFC2231String (const QString & _str)
 const QString
 rfcDecoder::decodeRFC2231String (const QString & _str)
 {
-  QString charset;
-  QString language;
-
-  int p = _str.find ("'");
-  int l = _str.findRev ("'");
+  int p = _str.find ('\'');
 
   //see if it is an rfc string
   if (p < 0)
     return _str;
 
-  //first is charset or empty
-  charset = _str.left (p);
-  QString st = _str.mid (l + 1);
+  int l = _str.findRev ('\'');
 
   //second is language
   if (p >= l)
     return _str;
-  language = _str.mid (p + 1, l - p - 1);
+
+  //first is charset or empty
+  QString charset = _str.left (p);
+  QString st = _str.mid (l + 1);
+  QString language = _str.mid (p + 1, l - p - 1);
 
   //kdDebug(7116) << "Charset: " << charset << " Language: " << language << endl;
 
