@@ -2,11 +2,10 @@
 
    configdialog.h (part of Klipper - Cut & paste history for KDE)
 
-   $Id: configdialog.h,v 1.28 2002/08/30 20:55:52 pfeiffer Exp $
 
    (C) 2000 by Carsten Pfeiffer <pfeiffer@kde.org>
 
-   Licensed under the Artistic License
+   Licensed under the GNU GPL Version 2
 
  ------------------------------------------------------------- */
 
@@ -51,7 +50,7 @@ private slots:
 
 private:
     QCheckBox *cbMousePos, *cbSaveContents, *cbReplayAIH, *cbNoNull;
-    QCheckBox *cbIgnoreSelection;
+    QCheckBox *cbIgnoreSelection, *cbStripWhitespace;
     QRadioButton *cbSynchronize, *cbImplicitSelection, *cbSeparate;
     KIntNumInput *popupTimeout, *maxItems;
 
@@ -141,6 +140,9 @@ public:
     bool popupAtMousePos() const {
 	return generalWidget->cbMousePos->isChecked();
     }
+    bool stripWhiteSpace() const {
+        return generalWidget->cbStripWhitespace->isChecked();
+    }
     bool replayActionInHistory() const {
 	return generalWidget->cbReplayAIH->isChecked();
     }
@@ -182,6 +184,9 @@ public:
     void setPopupAtMousePos( bool enable ) {
 	generalWidget->cbMousePos->setChecked( enable );
     }
+    void setStripWhiteSpace( bool enable ) {
+        generalWidget->cbStripWhitespace->setChecked( enable );
+    }
     void setReplayActionInHistory( bool enable ) {
 	generalWidget->cbReplayAIH->setChecked( enable );
     }
