@@ -24,6 +24,7 @@
 #include <qfileinfo.h>
 #include <qgroupbox.h>
 #include <qhbox.h>
+#include <qwhatsthis.h>
 
 #include <klocale.h>
 #include <kstandarddirs.h>
@@ -38,6 +39,7 @@
 #include <kfiledialog.h>
 #include <kcombobox.h>
 #include <kkeydialog.h>
+#include <kprocess.h>
 #include "khotkeys.h"
 
 #include "menuinfo.h"
@@ -57,7 +59,7 @@ BasicTab::BasicTab( QWidget *parent, const char *name )
 
     // general group
     QGroupBox *general_group = new QGroupBox(this);
-    QGridLayout *grid = new QGridLayout(general_group, 4, 2,
+    QGridLayout *grid = new QGridLayout(general_group, 5, 2,
                                         KDialog::marginHint(),
                                         KDialog::spacingHint());
 
@@ -65,39 +67,65 @@ BasicTab::BasicTab( QWidget *parent, const char *name )
 
     // setup line inputs
     _nameEdit = new KLineEdit(general_group);
-	_nameEdit->setAcceptDrops(false);
+    _nameEdit->setAcceptDrops(false);
+    _descriptionEdit = new KLineEdit(general_group);
+    _descriptionEdit->setAcceptDrops(false);
     _commentEdit = new KLineEdit(general_group);
-	_commentEdit->setAcceptDrops(false);
+    _commentEdit->setAcceptDrops(false);
     _execEdit = new KURLRequester(general_group);
-	_execEdit->lineEdit()->setAcceptDrops(false);
+    _execEdit->lineEdit()->setAcceptDrops(false);
+    QWhatsThis::add(_execEdit,i18n(
+    "Following the command, you can have several place holders which will be replaced "
+    "with the actual values when the actual program is run:\n"
+    "%f - a single file name\n"
+    "%F - a list of files; use for applications that can open several local files at once\n"
+    "%u - a single URL\n"
+    "%U - a list of URLs\n"
+    "%d - the folder of the file to open\n"
+    "%D - a list of folders\n"
+    "%i - the icon\n"
+    "%m - the mini-icon\n"
+    "%c - the caption"));
+
     _launchCB = new QCheckBox(i18n("Enable &launch feedback"), general_group);
+    _systrayCB = new QCheckBox(i18n("&Place in system tray"), general_group);
 
     // setup labels
     _nameLabel = new QLabel(_nameEdit, i18n("&Name:"), general_group);
+    _descriptionLabel = new QLabel(_descriptionEdit, i18n("&Description:"), general_group);
     _commentLabel = new QLabel(_commentEdit, i18n("&Comment:"), general_group);
     _execLabel = new QLabel(_execEdit, i18n("Co&mmand:"), general_group);
     grid->addWidget(_nameLabel, 0, 0);
-    grid->addWidget(_commentLabel, 1, 0);
-    grid->addWidget(_execLabel, 2, 0);
+    grid->addWidget(_descriptionLabel, 1, 0);
+    grid->addWidget(_commentLabel, 2, 0);
+    grid->addWidget(_execLabel, 3, 0);
 
     // connect line inputs
     connect(_nameEdit, SIGNAL(textChanged(const QString&)),
             SLOT(slotChanged()));
+    connect(_descriptionEdit, SIGNAL(textChanged(const QString&)),
+	    SLOT(slotChanged()));
     connect(_commentEdit, SIGNAL(textChanged(const QString&)),
             SLOT(slotChanged()));
     connect(_execEdit, SIGNAL(textChanged(const QString&)),
             SLOT(slotChanged()));
+    connect(_execEdit, SIGNAL(urlSelected(const QString&)),
+            SLOT(slotExecSelected()));
     connect(_launchCB, SIGNAL(clicked()), SLOT(launchcb_clicked()));
+    connect(_systrayCB, SIGNAL(clicked()), SLOT(systraycb_clicked()));
 
     // add line inputs to the grid
     grid->addMultiCellWidget(_nameEdit, 0, 0, 1, 1);
-    grid->addMultiCellWidget(_commentEdit, 1, 1, 1, 1);
-    grid->addMultiCellWidget(_execEdit, 2, 2, 1, 1);
-    grid->addMultiCellWidget(_launchCB, 3, 3, 0, 1);
+    grid->addMultiCellWidget(_descriptionEdit, 1, 1, 1, 1);
+    grid->addMultiCellWidget(_commentEdit, 2, 2, 1, 2);
+    grid->addMultiCellWidget(_execEdit, 3, 3, 1, 2);
+    grid->addMultiCellWidget(_launchCB, 4, 4, 0, 2);
+    grid->addMultiCellWidget(_systrayCB, 5, 5, 0, 2);
 
     // setup icon button
     _iconButton = new KIconButton(general_group);
-    _iconButton->setFixedSize(52,52);
+    _iconButton->setFixedSize(56,56);
+    _iconButton->setIconSize(48);
     connect(_iconButton, SIGNAL(iconChanged(QString)), SLOT(slotChanged()));
     grid->addMultiCellWidget(_iconButton, 0, 1, 2, 2);
 
@@ -116,7 +144,7 @@ BasicTab::BasicTab( QWidget *parent, const char *name )
 
     _pathEdit = new KURLRequester(hbox);
     _pathEdit->setMode(KFile::Directory | KFile::LocalOnly);
-	_pathEdit->lineEdit()->setAcceptDrops(false);
+    _pathEdit->lineEdit()->setAcceptDrops(false);
 
     _pathLabel->setBuddy(_pathEdit);
 
@@ -138,7 +166,7 @@ BasicTab::BasicTab( QWidget *parent, const char *name )
     hbox->setSpacing(KDialog::spacingHint());
     _termOptLabel = new QLabel(i18n("Terminal &options:"), hbox);
     _termOptEdit = new KLineEdit(hbox);
-	_termOptEdit->setAcceptDrops(false);
+    _termOptEdit->setAcceptDrops(false);
     _termOptLabel->setBuddy(_termOptEdit);
 
     connect(_termOptEdit, SIGNAL(textChanged(const QString&)),
@@ -153,7 +181,7 @@ BasicTab::BasicTab( QWidget *parent, const char *name )
     vbox = new QVBoxLayout(_uid_group, KDialog::marginHint(),
                            KDialog::spacingHint());
 
-    _uidCB = new QCheckBox(i18n("Run as a &different user"), _uid_group);
+    _uidCB = new QCheckBox(i18n("&Run as a different user"), _uid_group);
     connect(_uidCB, SIGNAL(clicked()), SLOT(uidcb_clicked()));
     vbox->addWidget(_uidCB);
 
@@ -161,7 +189,7 @@ BasicTab::BasicTab( QWidget *parent, const char *name )
     hbox->setSpacing(KDialog::spacingHint());
     _uidLabel = new QLabel(i18n("&Username:"), hbox);
     _uidEdit = new KLineEdit(hbox);
-	_uidEdit->setAcceptDrops(false);
+    _uidEdit->setAcceptDrops(false);
     _uidLabel->setBuddy(_uidEdit);
 
     connect(_uidEdit, SIGNAL(textChanged(const QString&)),
@@ -207,10 +235,13 @@ void BasicTab::slotDisableAction()
     //disable all group at the begining.
     //because there is not file selected.
     _nameEdit->setEnabled(false);
+    _descriptionEdit->setEnabled(false);
     _commentEdit->setEnabled(false);
     _execEdit->setEnabled(false);
     _launchCB->setEnabled(false);
+    _systrayCB->setEnabled(false);
     _nameLabel->setEnabled(false);
+    _descriptionLabel->setEnabled(false);
     _commentLabel->setEnabled(false);
     _execLabel->setEnabled(false);
     _path_group->setEnabled(false);
@@ -225,11 +256,14 @@ void BasicTab::enableWidgets(bool isDF, bool isDeleted)
 {
     // set only basic attributes if it is not a .desktop file
     _nameEdit->setEnabled(!isDeleted);
+    _descriptionEdit->setEnabled(!isDeleted);
     _commentEdit->setEnabled(!isDeleted);
     _iconButton->setEnabled(!isDeleted);
     _execEdit->setEnabled(isDF && !isDeleted);
     _launchCB->setEnabled(isDF && !isDeleted);
+    _systrayCB->setEnabled(isDF && !isDeleted);
     _nameLabel->setEnabled(!isDeleted);
+    _descriptionLabel->setEnabled(!isDeleted);
     _commentLabel->setEnabled(!isDeleted);
     _execLabel->setEnabled(isDF && !isDeleted);
 
@@ -252,7 +286,10 @@ void BasicTab::setFolderInfo(MenuFolderInfo *folderInfo)
     _menuEntryInfo = 0;
 
     _nameEdit->setText(folderInfo->caption);
+    _descriptionEdit->setText(folderInfo->genericname);
+    _descriptionEdit->setCursorPosition(0);
     _commentEdit->setText(folderInfo->comment);
+    _commentEdit->setCursorPosition(0);
     _iconButton->setIcon(folderInfo->icon);
 
     // clean all disabled fields and return
@@ -261,6 +298,7 @@ void BasicTab::setFolderInfo(MenuFolderInfo *folderInfo)
     _termOptEdit->setText("");
     _uidEdit->setText("");
     _launchCB->setChecked(false);
+    _systrayCB->setChecked(false);
     _terminalCB->setChecked(false);
     _uidCB->setChecked(false);
     _keyEdit->setShortcut(0, false);
@@ -274,11 +312,38 @@ void BasicTab::setEntryInfo(MenuEntryInfo *entryInfo)
     blockSignals(true);
     _menuFolderInfo = 0;
     _menuEntryInfo = entryInfo;
+    
+    if (!entryInfo)
+    {
+       _nameEdit->setText(QString::null);
+       _descriptionEdit->setText(QString::null);
+       _commentEdit->setText(QString::null);
+       _iconButton->setIcon(QString::null);
+
+       // key binding part
+       _keyEdit->setShortcut( KShortcut(), false );
+       _execEdit->lineEdit()->setText(QString::null);
+       _systrayCB->setChecked(false);
+
+       _pathEdit->lineEdit()->setText(QString::null);
+       _termOptEdit->setText(QString::null);
+       _uidEdit->setText(QString::null);
+
+       _launchCB->setChecked(false);
+       _terminalCB->setChecked(false);
+       _uidCB->setChecked(false);
+       enableWidgets(true, true);
+       blockSignals(false);
+       return;
+    }
 
     KDesktopFile *df = entryInfo->desktopFile();
 
     _nameEdit->setText(df->readName());
+    _descriptionEdit->setText(df->readGenericName());
+    _descriptionEdit->setCursorPosition(0);
     _commentEdit->setText(df->readComment());
+    _commentEdit->setCursorPosition(0);
     _iconButton->setIcon(df->readIcon());
 
     // key binding part
@@ -287,7 +352,18 @@ void BasicTab::setEntryInfo(MenuEntryInfo *entryInfo)
         _keyEdit->setShortcut( entryInfo->shortcut(), false );
     }
 
-    _execEdit->lineEdit()->setText(df->readPathEntry("Exec"));
+    QString temp = df->readPathEntry("Exec");
+    if (temp.left(12) == "ksystraycmd ")
+    {
+      _execEdit->lineEdit()->setText(temp.right(temp.length()-12));
+      _systrayCB->setChecked(true);
+    }
+    else
+    {
+      _execEdit->lineEdit()->setText(temp);
+      _systrayCB->setChecked(false);
+    }
+
     _pathEdit->lineEdit()->setText(df->readPath());
     _termOptEdit->setText(df->readEntry("TerminalOptions"));
     _uidEdit->setText(df->readEntry("X-KDE-Username"));
@@ -314,11 +390,16 @@ void BasicTab::apply()
     {
         _menuEntryInfo->setDirty();
         _menuEntryInfo->setCaption(_nameEdit->text());
+        _menuEntryInfo->setDescription(_descriptionEdit->text());
         _menuEntryInfo->setIcon(_iconButton->icon());
 
         KDesktopFile *df = _menuEntryInfo->desktopFile();
         df->writeEntry("Comment", _commentEdit->text());
-        df->writePathEntry("Exec", _execEdit->lineEdit()->text());
+        if (_systrayCB->isChecked())
+          df->writePathEntry("Exec", _execEdit->lineEdit()->text().prepend("ksystraycmd "));
+        else
+          df->writePathEntry("Exec", _execEdit->lineEdit()->text());
+
         df->writePathEntry("Path", _pathEdit->lineEdit()->text());
 
         if (_terminalCB->isChecked())
@@ -334,6 +415,7 @@ void BasicTab::apply()
     else
     {
         _menuFolderInfo->setCaption(_nameEdit->text());
+        _menuFolderInfo->setGenericName(_descriptionEdit->text());
         _menuFolderInfo->setComment(_commentEdit->text());
         _menuFolderInfo->setIcon(_iconButton->icon());
     }
@@ -355,6 +437,11 @@ void BasicTab::launchcb_clicked()
     slotChanged();
 }
 
+void BasicTab::systraycb_clicked()
+{
+    slotChanged();
+}
+
 void BasicTab::termcb_clicked()
 {
     _termOptEdit->setEnabled(_terminalCB->isChecked());
@@ -369,6 +456,13 @@ void BasicTab::uidcb_clicked()
     slotChanged();
 }
 
+void BasicTab::slotExecSelected()
+{
+    QString path = _execEdit->lineEdit()->text();
+    if (!path.startsWith("'"))
+        _execEdit->lineEdit()->setText(KProcess::quote(path));
+}
+
 void BasicTab::slotCapturedShortcut(const KShortcut& cut)
 {
     if (signalsBlocked())
