@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -22,6 +22,7 @@
 #define __khotkeys_public_h__
 
 #include <qstring.h>
+#include <kservice.h>
 
 // see kdebase/khotkeys/kcontrol for info on these
 
@@ -35,6 +36,8 @@ public:
                                             const QString shortcut_P );
     static bool menuEntryMoved( const QString& new_P, const QString& old_P );
     static void menuEntryDeleted( const QString& entry_P );
+    static QStringList allShortCuts( );
+    static KService::Ptr findMenuEntry( const QString &shortcut_P );
 };
 
 #endif
