@@ -24,8 +24,8 @@
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kdebug.h>
+#include <kedittoolbar.h>
 #include <kglobal.h>
-#include <kkeydialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kservice.h>
@@ -37,11 +37,9 @@
 #include "kmenuedit.h"
 #include "kmenuedit.moc"
 
-KMenuEdit::KMenuEdit (QWidget *, const char *name)
-  : KMainWindow (0, name), m_tree(0), m_basicTab(0), m_splitter(0)
+KMenuEdit::KMenuEdit (bool controlCenter, QWidget *, const char *name)
+  : KMainWindow (0, name), m_tree(0), m_basicTab(0), m_splitter(0), m_controlCenter(controlCenter)
 {
-    setCaption(i18n("Edit K Menu"));
-
     // restore size
     KConfig *config = KGlobal::config();
     config->setGroup("General");
@@ -57,7 +55,7 @@ KMenuEdit::KMenuEdit (QWidget *, const char *name)
     // setup GUI
     setupActions();
     slotChangeView();
-
+    setAutoSaveSettings();
 }
 
 KMenuEdit::~KMenuEdit()
@@ -76,6 +74,8 @@ void KMenuEdit::setupActions()
 {
     (void)new KAction(i18n("&New Submenu..."), "menu_new", 0, actionCollection(), "newsubmenu");
     (void)new KAction(i18n("New &Item..."), "filenew", KStdAccel::openNew(), actionCollection(), "newitem");
+    if (!m_controlCenter)
+       (void)new KAction(i18n("New &Separator"), "menu_new_sep", 0, actionCollection(), "newsep");
 
     m_actionDelete = 0;
 
@@ -84,18 +84,14 @@ void KMenuEdit::setupActions()
     KStdAction::cut(0, 0, actionCollection());
     KStdAction::copy(0, 0, actionCollection());
     KStdAction::paste(0, 0, actionCollection());
-    KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
-}
-
-void KMenuEdit::slotConfigureKeys()
-{
-  KKeyDialog::configure( actionCollection(), this );
+    KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
+    KStdAction::configureToolbars(this, SLOT(slotConfigureToolbars()), actionCollection());
 }
 
 void KMenuEdit::setupView()
 {
     m_splitter = new QSplitter(Horizontal, this);
-    m_tree = new TreeView(actionCollection(), m_splitter);
+    m_tree = new TreeView(m_controlCenter, actionCollection(), m_splitter);
     m_basicTab = new BasicTab(m_splitter);
 
     connect(m_tree, SIGNAL(entrySelected(MenuFolderInfo *)),
@@ -144,7 +140,10 @@ void KMenuEdit::slotChangeView()
 
     if (!m_splitter)
        setupView();
-    createGUI("kmenueditui.rc");
+    if (m_controlCenter)
+       createGUI("kcontroleditui.rc");
+    else
+       createGUI("kmenueditui.rc");
 
     m_tree->setViewMode(m_showHidden);
 }
@@ -158,17 +157,29 @@ bool KMenuEdit::queryClose()
 {
     if (!m_tree->dirty()) return true;
 
-    int result = KMessageBox::warningYesNoCancel(this,
+
+    int result;
+    if (m_controlCenter)
+    {
+       result = KMessageBox::warningYesNoCancel(this,
+                    i18n("You have made changes to the Control Center.\n"
+                         "Do you want to save the changes or discard them?"),
+                    i18n("Save Control Center Changes?"),
+                    KStdGuiItem::save(), KStdGuiItem::discard() );
+    }
+    else
+    {
+       result = KMessageBox::warningYesNoCancel(this,
                     i18n("You have made changes to the menu.\n"
                          "Do you want to save the changes or discard them?"),
                     i18n("Save Menu Changes?"),
                     KStdGuiItem::save(), KStdGuiItem::discard() );
+    }
 
     switch(result)
     {
       case KMessageBox::Yes:
-         m_tree->save();
-         return true;
+         return m_tree->save();
 
       case KMessageBox::No:
          return true;
@@ -179,3 +190,9 @@ bool KMenuEdit::queryClose()
     return false;
 }
 
+void KMenuEdit::slotConfigureToolbars()
+{
+    KEditToolbar dlg( factory() );
+      
+    dlg.exec();
+}
