@@ -98,3 +98,38 @@ void KonqViewIface::enablePopupMenu( bool b )
 {
   m_pView->enablePopupMenu( b );
 }
+
+uint KonqViewIface::historyLength()const
+{
+    return m_pView->historyLength();
+}
+
+bool KonqViewIface::allowHTML() const
+{
+    return m_pView->allowHTML();
+}
+
+void KonqViewIface::goForward()
+{
+    m_pView->go(-1);
+}
+
+void KonqViewIface::goBack()
+{
+    m_pView->go(+1);
+}
+
+bool KonqViewIface::isPopupMenuEnabled() const
+{
+    return m_pView->isPopupMenuEnabled();
+}
+
+bool KonqViewIface::canGoBack()const
+{
+    return m_pView->canGoBack();
+}
+
+bool KonqViewIface::canGoForward()const
+{
+    return m_pView->canGoForward();
+}
