@@ -27,12 +27,11 @@ class clientApp : public KApplication
 {
   Q_OBJECT
 public:
-
   /** Parse command-line arguments and "do it" */
   static bool doIt();
 
   /** Make konqueror open a window for @p url */
-  static bool createNewWindow(const KURL & url, const QString & mimetype = QString::null);
+  static bool createNewWindow(const KURL & url, bool newTab, const QString & mimetype = QString::null);
 
   /** Make konqueror open a window for @p profile, @p url and @p mimetype */
   static bool openProfile(const QString & profile, const QString & url, const QString & mimetype = QString::null);
@@ -44,6 +43,7 @@ protected slots:
 private:
   static bool m_ok;
   static QCString startup_id_str;
+  
 };
 
 #endif
