@@ -25,6 +25,7 @@
 #include <konq_dirpart.h>
 #include <kmimetyperesolver.h>
 #include <qptrdict.h>
+#include <qptrlist.h>
 #include <kfileivi.h>
 
 class KonqPropsView;
@@ -100,6 +101,12 @@ protected slots:
   void slotOnViewport();
   void slotSelectionChanged();
 
+  // Slot used for spring loading folders
+  void slotDragHeld( QIconViewItem *item );
+  void slotDragEntered();
+  void slotDragLeft();
+  void slotDragFinished();
+
   // slots connected to the directory lister - or to the kfind interface
   // They are reimplemented from KonqDirPart.
   virtual void slotStarted();
@@ -119,6 +126,8 @@ protected slots:
    * after everything was done.
    */
   void slotRenderingFinished();
+  // (Re)Draws m_pIconView's contents. Connected to m_pTimeoutRefreshTimer.
+  void slotRefreshViewport();
 
   // Connected to KonqDirPart
   void slotKFindOpened();
@@ -167,6 +176,21 @@ protected:
 
   bool m_bUpdateContentsPosAfterListing:1;
 
+  bool m_bDirPropertiesChanged:1;
+  
+  /**
+   * Set in doCloseURL and used in setViewMode to restart a preview
+   * job interrupted when switching to IconView or MultiColumnView.
+   * Hacks like this must be removed in KDE4!
+   */
+  bool m_bPreviewRunningBeforeCloseURL:1;
+
+  bool m_bNeedSetCurrentItem:1;
+  
+  KFileIVI * m_pEnsureVisible;
+  
+  QStringList m_itemsToSelect;
+  
   SortCriterion m_eSortCriterion;
 
   KToggleAction *m_paDotFiles;
@@ -191,6 +215,8 @@ protected:
 
   KonqIconViewWidget *m_pIconView;
 
+  QTimer *m_pTimeoutRefreshTimer;
+
   QPtrDict<KFileIVI> m_itemDict; // maps KFileItem * -> KFileIVI *
 
   KMimeTypeResolver<KFileIVI,KonqKfmIconView> * m_mimeTypeResolver;
@@ -241,4 +267,34 @@ private:
   bool m_bSaveViewPropertiesLocally;
 };
 
+class SpringLoadingManager : public QObject
+{
+    Q_OBJECT
+private:
+    SpringLoadingManager();
+    static SpringLoadingManager *s_self;
+public:
+    static SpringLoadingManager &self();
+    static bool exists();
+
+    void springLoadTrigger(KonqKfmIconView *view, KFileItem *file,
+                           QIconViewItem *item);
+
+    void dragLeft(KonqKfmIconView *view);
+    void dragEntered(KonqKfmIconView *view);
+    void dragFinished(KonqKfmIconView *view);
+
+private slots:
+    void finished();
+
+private:
+    KURL m_startURL;
+    KParts::ReadOnlyPart *m_startPart;
+
+    // Timer allowing to know the user wants to abort the spring loading
+    // and go back to his start url (closing the opened window if needed)
+    QTimer m_endTimer;
+};
+
+
 #endif
