@@ -17,6 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <qstyle.h>
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kcompletionbox.h>
@@ -34,8 +35,8 @@ KConfig * KonqCombo::s_config = 0L;
 const int KonqCombo::temporary = 0;
 
 KonqCombo::KonqCombo( QWidget *parent, const char *name )
-    : KHistoryCombo( parent, name ),
-      m_returnPressed( false ),
+          : KHistoryCombo( parent, name ),
+            m_returnPressed( false ), 
             m_permanent( false ),
             m_modifier( NoButton )
 {
@@ -53,17 +54,17 @@ KonqCombo::KonqCombo( QWidget *parent, const char *name )
     // handling of signals later.
     setHandleSignals( true );
     completionBox()->setTabHandling( true );
-
+    
     // Make the lineedit consume the Key_Enter event...
     setTrapReturnKey( true );
     
-    connect( this, SIGNAL( cleared() ), SLOT( slotCleared() ));
-    connect( this, SIGNAL( highlighted( int )), SLOT( slotSetIcon( int )));
-    connect( this, SIGNAL( activated( const QString& )),
-             SLOT( slotActivated( const QString& )) );
+    connect( this, SIGNAL(cleared() ), SLOT(slotCleared()) );
+    connect( this, SIGNAL(highlighted( int )), SLOT(slotSetIcon( int )) );
+    connect( this, SIGNAL(activated( const QString& )),
+             SLOT(slotActivated( const QString& )) );
 
     if ( !kapp->dcopClient()->isAttached() )
-	kapp->dcopClient()->attach();
+        kapp->dcopClient()->attach();
 }
 
 KonqCombo::~KonqCombo()
@@ -84,38 +85,38 @@ void KonqCombo::setURL( const QString& url )
     kdDebug(1202) << "*** KonqCombo::setURL: " << url 
                   << ", returnPressed ? " << m_returnPressed << endl;
     setTemporary( url );
-
+    
     if ( m_returnPressed ) { // Really insert...
-	m_returnPressed = false;
-	QByteArray data;
-	QDataStream s( data, IO_WriteOnly );
-	s << url << kapp->dcopClient()->defaultObject();
-	kapp->dcopClient()->send( "konqueror*", "KonquerorIface",
-				  "addToCombo(QString,QCString)", data);
+        m_returnPressed = false;      
+        QByteArray data;
+        QDataStream s( data, IO_WriteOnly );
+        s << url << kapp->dcopClient()->defaultObject();
+        kapp->dcopClient()->send( "konqueror*", "KonquerorIface",
+                                  "addToCombo(QString,QCString)", data);
     }
 }
 
 void KonqCombo::setTemporary( const QString& text )
 {
-    setTemporary( text, KonqPixmapProvider::self()->pixmapFor( text ) );
+    setTemporary( text, KonqPixmapProvider::self()->pixmapFor(text) );
 }
 
 void KonqCombo::setTemporary( const QString& url, const QPixmap& pix )
 {
     kdDebug(1202) << "*** KonqCombo::setTemporary: " << url << ", temporary = " 
                   << temporary << endl;
-
+    
     // Insert a temporary item when we don't have one yet
     if ( count() == 0 )
-	insertItem( pix, url, temporary );
+      insertItem( pix, url, temporary );
     else
     {
-	if ( url != temporaryItem() )
-	    applyPermanent();
-	
-	updateItem( pix, url, temporary );
+        if (url != temporaryItem())
+          applyPermanent();
+        
+        updateItem( pix, url, temporary );
     }
-	
+        
     setCurrentItem( temporary );
 }
 
@@ -153,21 +154,21 @@ void KonqCombo::insertPermanent( const QString& url )
 // called right before a new (different!) temporary item will be set. So we
 // insert an item that was marked permanent properly at position 1.
 void KonqCombo::applyPermanent()
-{
+{    
     if ( m_permanent && !temporaryItem().isEmpty() ) {
-
+        
         // Remove as many items as needed to honour maxCount()
         int index = count();
-	while ( count() >= maxCount() )
+        while ( count() >= maxCount() )
             removeItem( --index );
-
+        
         QString url (temporaryItem());
-	insertItem( KonqPixmapProvider::self()->pixmapFor( url ), url, 1 );
+        insertItem( KonqPixmapProvider::self()->pixmapFor( url ), url, 1 );
         kdDebug(1202) << "*** KonqCombo::applyPermanent: " << url << endl;
-
+        
         // Remove all duplicates starting from index = 2
         removeDuplicates( 2 );       
-	m_permanent = false;
+        m_permanent = false;
     }
 }
 
@@ -176,11 +177,11 @@ void KonqCombo::updateItem(const QPixmap& pix, const QString& t, int index)
 {
     // No need to flicker
     if (text( index ) == t &&
-	(pixmap(index) && pixmap(index)->serialNumber() == pix.serialNumber()))
-	return;
-
-    kdDebug(1202) << "*** KonqCombo::updateItem: item='" << t << "', index='"
-                  << index << "'" << endl;        
+        (pixmap(index) && pixmap(index)->serialNumber() == pix.serialNumber()))
+        return;
+        
+    // kdDebug(1202) << "*** KonqCombo::updateItem: item='" << t << "', index='"
+    //               << index << "'" << endl;
     
     // QComboBox::changeItem() doesn't honour the pixmap when
     // using an editable combobox, so we just remove and insert    
@@ -222,7 +223,7 @@ void KonqCombo::updatePixmaps()
     setUpdatesEnabled( false );
     KonqPixmapProvider *prov = KonqPixmapProvider::self();
     for ( int i = 1; i < count(); i++ ) {
-	updateItem( prov->pixmapFor( text( i ) ), text( i ), i );
+        updateItem( prov->pixmapFor( text( i ) ), text( i ), i );
     }
     setUpdatesEnabled( true );
     repaint();
@@ -251,14 +252,14 @@ void KonqCombo::loadItems()
                     KIcon::SizeSmall), item, i++ );
             else
                 // icons will be loaded on-demand
-        	insertItem( item, i++ );
+                insertItem( item, i++ );
             first = false;
         }
         ++it;
     }
 
     if ( count() > 0 )
-	m_permanent = true; // we want the first loaded item to stay
+        m_permanent = true; // we want the first loaded item to stay
 }
 
 void KonqCombo::slotSetIcon( int index )
@@ -290,7 +291,7 @@ void KonqCombo::saveItems()
     int i = m_permanent ? 0 : 1;
 
     for ( ; i < count(); i++ )
-	items.append( text( i ) );
+        items.append( text( i ) );
 
     s_config->setGroup( "Location Bar" );
     s_config->writeEntry( "ComboContents", items );
@@ -304,7 +305,7 @@ void KonqCombo::clearTemporary( bool makeCurrent )
     applyPermanent();
     changeItem( QString::null, temporary ); // ### default pixmap?
     if ( makeCurrent )
-	setCurrentItem( temporary );
+      setCurrentItem( temporary );
 }
 
 bool KonqCombo::eventFilter( QObject *o, QEvent *ev )
@@ -347,7 +348,7 @@ void KonqCombo::keyPressEvent( QKeyEvent *e )
     // pixmap. Yes, QComboBox still sucks.
     if ( KKey( e ) == KKey( int( KStdAccel::rotateUp() ) ) ||
          KKey( e ) == KKey( int( KStdAccel::rotateDown() ) ) )
-	setTemporary( currentText() );
+         setTemporary( currentText() );
 }
 
 /* 
@@ -358,11 +359,11 @@ void KonqCombo::keyPressEvent( QKeyEvent *e )
 */
 void KonqCombo::selectWord(QKeyEvent *e)
 {
-    QLineEdit *edit = lineEdit();
+    QLineEdit* edit = lineEdit();    
     QString text = edit->text();
     int pos = edit->cursorPosition();
     int pos_old = pos;
-    int count = 0;
+    int count = 0;  
     
     // TODO: make these a parameter when in kdelibs/kdeui...
     QValueList<QChar> chars;
@@ -370,15 +371,15 @@ void KonqCombo::selectWord(QKeyEvent *e)
     bool allow_space_break = true;
     
     if( e->key() == Key_Left || e->key() == Key_Backspace ) {
-	do {
-	    pos--;
-	    count++;
+        do {
+            pos--;
+            count++;
             if( allow_space_break && text[pos].isSpace() && count > 1 )
                 break;
-	} while( pos >= 0 && (chars.findIndex(text[pos]) == -1 || count <= 1) );
+        } while( pos >= 0 && (chars.findIndex(text[pos]) == -1 || count <= 1) );
         
-	if( e->state() & ShiftButton ) {
-            edit->cursorForward(true, 1-count);
+        if( e->state() & ShiftButton ) {
+                  edit->cursorForward(true, 1-count);
         } 
         else if(  e->key() == Key_Backspace ) {
             edit->cursorForward(false, 1-count);
@@ -393,22 +394,22 @@ void KonqCombo::selectWord(QKeyEvent *e)
         }
      } 
      else if( e->key() == Key_Right || e->key() == Key_Delete ){
-	do {
-	    pos++;
-	    count++;
-            if( allow_space_break && text[pos].isSpace() )
-                break;
-	} while( pos < (int) text.length() && chars.findIndex(text[pos]) == -1 );
+        do {
+            pos++;
+            count++;
+                  if( allow_space_break && text[pos].isSpace() )
+                      break;
+        } while( pos < (int) text.length() && chars.findIndex(text[pos]) == -1 );
         
-	if( e->state() & ShiftButton ) {
+        if( e->state() & ShiftButton ) {
             edit->cursorForward(true, count+1);
         } 
         else if(  e->key() == Key_Delete ) {
             edit->cursorForward(false, -count-1);
             QString text = edit->text();
             int pos_to_right = text.length() - pos - 1;
-	    QString cut = text.left(pos_old) +
-               (pos_to_right > 0 ? text.right(pos_to_right) : "" );
+            QString cut = text.left(pos_old) +
+               (pos_to_right > 0 ? text.right(pos_to_right) : QString::null );
             edit->setText(cut);
             edit->setCursorPosition(pos_old);
         } 
@@ -447,7 +448,9 @@ void KonqCombo::mousePressEvent( QMouseEvent *e )
     if ( e->button() == LeftButton && pixmap( currentItem()) ) {
         // check if the pixmap was clicked
         int x = e->pos().x();
-        if ( x > 2 && x < lineEdit()->x() ) {
+        int x0 = QStyle::visualRect( style().querySubControlMetrics( QStyle::CC_ComboBox, this, QStyle::SC_ComboBoxEditField ), this ).x();
+	
+        if ( x > x0 + 2 && x < lineEdit()->x() ) {
             m_dragStart = e->pos();
             return; // don't call KComboBox::mousePressEvent!
         }
@@ -466,7 +469,7 @@ void KonqCombo::mouseMoveEvent( QMouseEvent *e )
          (e->pos() - m_dragStart).manhattanLength() >
          KGlobalSettings::dndEventDelay() )
     {
-        KURL url = currentText();
+        KURL url ( currentText() );
         if ( url.isValid() )
         {
             KURL::List list;
