@@ -53,10 +53,10 @@ void KonqCheckBox::drawButton( QPainter *p )
     //static QPixmap indicator_anchor( UserIcon( "indicator_anchor" ) );
     static QPixmap indicator_connect( UserIcon( "indicator_connect" ) );
     static QPixmap indicator_noconnect( UserIcon( "indicator_noconnect" ) );
-    
+
    if (isOn() || isDown())
       p->drawPixmap(0,0,indicator_connect);
-   else 
+   else
       p->drawPixmap(0,0,indicator_noconnect);
 }
 
@@ -145,7 +145,7 @@ void KonqFrameStatusBar::splitFrameMenu()
 
    // We have to ship the remove view action ourselves,
    // since this may not be the active view (passive view)
-   KAction actRemoveView(i18n("Remove View"), 0, m_pParentKonqFrame, SLOT(slotRemoveView()), (QObject*)0, "removethisview");
+   KAction actRemoveView(i18n("Close View"), 0, m_pParentKonqFrame, SLOT(slotRemoveView()), (QObject*)0, "removethisview");
    //KonqView * nextView = mw->viewManager()->chooseNextView( m_pParentKonqFrame->childView() );
    actRemoveView.setEnabled( mw->mainViewsCount() > 1 || m_pParentKonqFrame->childView()->isToggleView() || m_pParentKonqFrame->childView()->isPassiveMode() );
 
@@ -273,7 +273,7 @@ void KonqFrameStatusBar::updateActiveStatus()
 
     static QPixmap indicator_viewactive( UserIcon( "indicator_viewactive" ) );
     static QPixmap indicator_empty( UserIcon( "indicator_empty" ) );
-        m_led->setPixmap( hasFocus ? indicator_viewactive : indicator_empty );
+    m_led->setPixmap( hasFocus ? indicator_viewactive : indicator_empty );
 }
 
 //###################################################################
@@ -445,20 +445,9 @@ void KonqFrame::slotStatusBarClicked()
 
 void KonqFrame::slotLinkedViewClicked( bool mode )
 {
-  if (m_pView->mainWindow()->linkableViewsCount() == 2)
-  {
-    // Exactly two linkable views : link both
-    KonqMainWindow::MapViews mapViews = m_pView->mainWindow()->viewMap();
-    KonqMainWindow::MapViews::Iterator it = mapViews.begin();
-    if( (*it)->isFollowActive() ) // skip sidebar
-        ++it;
-    (*it)->setLinkedView( mode );
-    ++it;
-    if( (*it)->isFollowActive() ) // skip sidebar
-        ++it;
-    (*it)->setLinkedView( mode );
-  }
-  else // Normal case : just this view
+  if ( m_pView->mainWindow()->linkableViewsCount() == 2 )
+    m_pView->mainWindow()->slotLinkView();
+  else
     m_pView->setLinkedView( mode );
 }
 
@@ -670,4 +659,10 @@ void KonqFrameContainer::childEvent( QChildEvent *c )
       QSplitter::childEvent(c);
 }
 
+void KonqFrameContainer::setRubberband( int pos  )
+{
+    emit setRubberbandCalled();
+    QSplitter::setRubberband( pos );
+}
+
 #include "konq_frame.moc"
