@@ -30,11 +30,32 @@ class KActionCollection;
 class KonqMainWindow;
 class KonqView;
 
+/**
+ * This XML-GUI-Client is passed to KonqPopupMenu to add extra actions into it,
+ * using the XMLGUI merging. It offers embedding actions and tabbed-browsing actions.
+ * Its XML looks like this:
+ * @code
+
+ <kpartgui name="konqueror" >
+ <Menu name="popupmenu" >
+  <menu group="preview" name="preview submenu" >
+   <text>Preview In</text>
+   <action group="preview" name="0" />
+   <action group="preview" name="1" />
+  </menu>
+  <action group="tabhandling" name="newview" />
+  <action group="tabhandling" name="openintab" />
+  <separator group="tabhandling" />
+ </Menu>
+ </kpartgui>
+
+ * @endcode
+ */
 class PopupMenuGUIClient : public KXMLGUIClient
 {
 public:
   PopupMenuGUIClient( KonqMainWindow *mainWindow, const KTrader::OfferList &embeddingServices,
-                      bool dirsSelected );
+                      bool dirsSelected, bool isIntoTrash );
   virtual ~PopupMenuGUIClient();
 
   virtual KAction *action( const QDomElement &element ) const;
