@@ -55,8 +55,11 @@ void KonqListViewItem::updateContents()
    // Set the text of each column
    setText(0,m_fileitem->text());
 
-   if (S_ISDIR(m_fileitem->mode()))
-       sortChar='0';
+   // The order is: .dir (0), dir (1), .file (2), file (3)
+   sortChar = S_ISDIR( m_fileitem->mode() ) ? 1 : 3;
+   if ( m_fileitem->text()[0] == '.' )
+       --sortChar;
+
    //now we have the first column, so let's do the rest
 
    int numExtra = 1;
@@ -169,7 +172,7 @@ void KonqListViewItem::setPixmap( int column, const QPixmap& pm )
    int oldWidth = current ? current->width() : 0;
    int oldHeight = current ? current->height() : 0;
 
-   if ( m_pixmaps.size() <= column )
+   if ( (int)m_pixmaps.size() <= column )
       m_pixmaps.resize( column+1 );
 
    delete current;
@@ -206,7 +209,7 @@ void KonqListViewItem::setPixmap( int column, const QPixmap& pm )
 const QPixmap* KonqListViewItem::pixmap( int column ) const
 {
    bool ok;
-   if (m_pixmaps.count() <= column)
+   if ((int)m_pixmaps.count() <= column)
       return 0;
 
    QPixmap *pm = m_pixmaps.at( column, &ok );
@@ -218,8 +221,9 @@ const QPixmap* KonqListViewItem::pixmap( int column ) const
 int KonqBaseListViewItem::compare( QListViewItem* item, int col, bool ascending ) const
 {
    KonqListViewItem* k = static_cast<KonqListViewItem*>( item );
-   if ( sortChar != k->sortChar ) // KDE 4: make sortChar a bool
-	return !ascending ? k->sortChar - sortChar : sortChar - k->sortChar;
+   if ( sortChar != k->sortChar )
+      // Dirs are always first, even when sorting in descending order
+      return !ascending ? k->sortChar - sortChar : sortChar - k->sortChar;
 
    for ( unsigned int i=0; i<m_pListViewWidget->NumberOfAtoms; i++ )
    {
@@ -319,7 +323,7 @@ const char* KonqBaseListViewItem::makeAccessString( const mode_t mode)
 
 KonqBaseListViewItem::KonqBaseListViewItem(KonqBaseListViewWidget *_listViewWidget, KFileItem* _fileitem)
 :KListViewItem(_listViewWidget)
-,sortChar('1')
+,sortChar(0)
 ,m_bDisabled(false)
 ,m_bActive(false)
 ,m_fileitem(_fileitem)
@@ -328,7 +332,7 @@ KonqBaseListViewItem::KonqBaseListViewItem(KonqBaseListViewWidget *_listViewWidg
 
 KonqBaseListViewItem::KonqBaseListViewItem(KonqBaseListViewWidget *_listViewWidget, KonqBaseListViewItem *_parent, KFileItem* _fileitem)
 :KListViewItem(_parent)
-,sortChar('1')
+,sortChar(0)
 ,m_bDisabled(false)
 ,m_bActive(false)
 ,m_fileitem(_fileitem)
