@@ -53,16 +53,17 @@ ColumnInfo::ColumnInfo()
 {}
 
 
-ColumnInfo::ColumnInfo(const QString& n, const QString& desktopName, int kioUds,int count,bool enabled,KToggleAction* someAction)
+ColumnInfo::ColumnInfo(const QString& n, const QString& desktopName, int kioUds,int count,bool enabled,KToggleAction* someAction, int theWidth)
    :displayInColumn(count)
    ,name(n)
    ,desktopFileName(desktopName)
    ,udsId(kioUds)
    ,displayThisOne(enabled)
    ,toggleThisOne(someAction)
+   ,width(theWidth)
 {}
 
-void ColumnInfo::setData(const QString& n, const QString& desktopName, int kioUds,int count,bool enabled,KToggleAction* someAction)
+void ColumnInfo::setData(const QString& n, const QString& desktopName, int kioUds,int count,bool enabled,KToggleAction* someAction, int theWidth)
 {
    displayInColumn=count;
    name=n;
@@ -70,6 +71,7 @@ void ColumnInfo::setData(const QString& n, const QString& desktopName, int kioUd
    udsId=kioUds;
    displayThisOne=enabled;
    toggleThisOne=someAction;
+   width=theWidth;
 }
 
 
@@ -189,8 +191,13 @@ void KonqBaseListViewWidget::readProtocolConfig( const QString & protocol )
    sortedByColumn=config->readEntry("SortBy","FileName");
    m_bAscending=config->readBoolEntry("SortOrder",TRUE);
 
+   // width of filename column
+   m_filenameColumnWidth=config->readNumEntry("FileNameColumnWidth",
+      25*fontMetrics().width( "m" ) );
+
    bool defaultColumns = false;
    QStringList lstColumns = config->readListEntry( "Columns" );
+   QValueList<int> lstColumnWidths = config->readIntListEntry( "ColumnWidths" );
    if (lstColumns.isEmpty())
    {
       // Default column selection
@@ -203,6 +210,7 @@ void KonqBaseListViewWidget::readProtocolConfig( const QString & protocol )
       lstColumns.append( "Group" );
       lstColumns.append( "Link" );
    }
+
    // Default number of columns
    NumberOfAtoms = 11;
    int extraIndex = NumberOfAtoms;
@@ -227,7 +235,6 @@ void KonqBaseListViewWidget::readProtocolConfig( const QString & protocol )
        }
    }
 
-
    //disable everything
    for (unsigned int i=0; i<NumberOfAtoms; i++)
    {
@@ -253,6 +260,43 @@ void KonqBaseListViewWidget::readProtocolConfig( const QString & protocol )
             if ( confColumns[j].toggleThisOne )
                 confColumns[j].toggleThisOne->setChecked(TRUE);
             currentColumn++;
+
+            if (i < lstColumnWidths.count())
+                confColumns[j].width = *lstColumnWidths.at(i);
+            else {
+                // Default Column widths
+                ColumnInfo *tmpColumn = &confColumns[j];
+                QString str;
+
+                if (tmpColumn->udsId==KIO::UDS_SIZE)
+                    str = KGlobal::locale()->formatNumber(888888888, 0) + "  ";
+                else if (tmpColumn->udsId==KIO::UDS_ACCESS)
+                    str = "--Permissions--";
+                else if (tmpColumn->udsId==KIO::UDS_USER)
+                    str = "a_long_username";
+                else if (tmpColumn->udsId==KIO::UDS_GROUP)
+                    str = "a_groupname";
+                else if (tmpColumn->udsId==KIO::UDS_LINK_DEST)
+                    str = "a_quite_long_filename_for_link_dest";
+                else if (tmpColumn->udsId==KIO::UDS_FILE_TYPE)
+                    str = "a_long_comment_for_mimetype";
+                else if (tmpColumn->udsId==KIO::UDS_MIME_TYPE)
+                    str = "_a_long_/_mimetype_";
+                else if (tmpColumn->udsId==KIO::UDS_URL)
+                    str = "a_long_lonq_long_very_long_url";
+                else if ((tmpColumn->udsId==KIO::UDS_MODIFICATION_TIME)
+                         || (tmpColumn->udsId==KIO::UDS_ACCESS_TIME)
+                         || (tmpColumn->udsId==KIO::UDS_CREATION_TIME))
+                {
+                    QDateTime dt(QDate(2000,10,10),QTime(20,20,20));
+                    str = KGlobal::locale()->formatDate(dt.date(),TRUE) +
+                          KGlobal::locale()->formatTime(dt.time()) + "----";
+                }
+                else
+                    str = "it_is_the_default_width";
+
+                confColumns[j].width = fontMetrics().width(str);
+            }
             break;
          }
       }
@@ -288,19 +332,21 @@ void KonqBaseListViewWidget::readProtocolConfig( const QString & protocol )
 void KonqBaseListViewWidget::createColumns()
 {
    //this column is always required, so add it
-   if (columns()<1) addColumn(i18n("Name"));
+   if (columns()<1)
+       addColumn( i18n("Name"), m_filenameColumnWidth );
    setSorting(0,TRUE);
 
-   //remove all but the first column
-   for (int i=columns()-1; i>0; i--)
-      removeColumn(i);
+   //remove all columns that will be re-added
+   for ( int i=columns()-1; i>m_filenameColumn; i--)
+        removeColumn(i);
+
    //now add the checked columns
-   int currentColumn(1);
-   for (int i=0; i<NumberOfAtoms; i++)
+   int currentColumn = m_filenameColumn+1;
+   for (int i=0; i<(int)NumberOfAtoms; i++)
    {
       if ((confColumns[i].displayThisOne) && (confColumns[i].displayInColumn==currentColumn))
       {
-         addColumn(i18n(confColumns[i].name.utf8() ));
+         addColumn(i18n(confColumns[i].name.utf8() ), confColumns[i].width);
          if (sortedByColumn == confColumns[i].desktopFileName)
             setSorting(currentColumn,m_bAscending);
          if (confColumns[i].udsId==KIO::UDS_SIZE)
@@ -311,8 +357,6 @@ void KonqBaseListViewWidget::createColumns()
    }
    if (sortedByColumn=="FileName")
       setSorting(0,m_bAscending);
-   //for (unsigned int i=0; i<NumberOfAtoms; i++)
-   //  kdDebug(1202)<<"i: "<<i<<" name: "<<confColumns[i].name<<" disp: "<<confColumns[i].displayInColumn<<" on: "<<confColumns[i].displayThisOne<<endl;
 }
 
 void KonqBaseListViewWidget::stop()
@@ -372,7 +416,6 @@ void KonqBaseListViewWidget::contentsMousePressEvent( QMouseEvent *e )
          if ( ! ( e->state() & ControlButton ) )
             setSelected( itemAt( vp ), false );
       }
-
       if ( e->button() != RightButton )
          QListView::contentsMousePressEvent( e );
    }
@@ -476,8 +519,7 @@ void KonqBaseListViewWidget::slotAutoScroll()
    const int oldBottom = m_rubber->normalize().bottom();
 
    drawRubber();
-   m_rubber->setRight( vc.x() );
-   m_rubber->setBottom( vc.y() );
+   m_rubber->setBottomRight( vc );
 
    QListViewItem *cur = itemAt( QPoint(0,0) );
 
@@ -490,23 +532,15 @@ void KonqBaseListViewWidget::slotAutoScroll()
       rect = QRect( viewportToContents( rect.topLeft() ),
                     viewportToContents( rect.bottomRight() ) );
 
-      int offset = 0;
       if ( !allColumnsShowFocus() )
       {
-         int hpos = header()->mapToIndex( 0 );
-         for ( int index = 0; index < hpos; index++ )
-            offset += columnWidth( header()->mapToSection( index ) );
-
-         rect.setLeft( offset );
-         rect.setRight( offset + columnWidth( 0 ) );
+         rect.setLeft( header()->sectionPos( 0 ) );
+         rect.setWidth( header()->sectionSize( 0 ) );
       }
       else
       {
-         for ( int index = 0; index < columns(); index++ )
-            offset += columnWidth( header()->mapToSection( index ) );
-
          rect.setLeft( 0 );
-         rect.setRight( offset );
+         rect.setWidth( header()->headerWidth() );
       }
 
       QRect r = rect;
@@ -600,6 +634,7 @@ void KonqBaseListViewWidget::viewportDragMoveEvent( QDragMoveEvent *_ev )
    if ( !item )
    {
       _ev->acceptAction();
+      m_dragOverItem = 0L;
       return;
    }
 
@@ -794,10 +829,10 @@ void KonqBaseListViewWidget::slotReturnPressed( QListViewItem *_item )
     }
 }
 
-void KonqBaseListViewWidget::slotPopupMenu(QListViewItem*, const QPoint &point, int )
+void KonqBaseListViewWidget::slotPopupMenu(QListViewItem*, const QPoint &point, int c )
 {
    kdDebug() << "KonqBaseListViewWidget::slotPopupMenu" << endl;
-   popupMenu( point,false );
+   popupMenu( point, c == -1 ); // c == -1 when activated by keyboard
 }
 
 void KonqBaseListViewWidget::popupMenu( const QPoint& _global, bool alwaysForSelectedFiles )
@@ -877,17 +912,27 @@ bool KonqBaseListViewWidget::openURL( const KURL &url )
    m_dirLister->setMimeFilter( m_pBrowserView->mimeFilter() );
    m_dirLister->setShowingDotFiles( m_pBrowserView->m_pProps->isShowingDotFiles() );
 
-   if ( m_pBrowserView->extension()->urlArgs().reload )
+   KParts::URLArgs args = m_pBrowserView->extension()->urlArgs();
+   if ( args.reload )
    {
-      KParts::URLArgs args = m_pBrowserView->extension()->urlArgs();
       args.xOffset = contentsX();
       args.yOffset = contentsY();
       m_pBrowserView->extension()->setURLArgs( args );
 
       if ( currentItem() && itemRect( currentItem() ).isValid() )
          m_itemToGoTo = currentItem()->text(0);
+
+      m_pBrowserView->m_filesToSelect.clear();
+      iterator it = begin();
+      for( ; it != end(); it++ )
+         if ( it->isSelected() )
+            m_pBrowserView->m_filesToSelect += it->text(0);
    }
 
+   m_itemsToSelect = m_pBrowserView->m_filesToSelect;
+   if ( !m_itemsToSelect.isEmpty() && m_itemToGoTo.isEmpty() )
+      m_itemToGoTo = m_itemsToSelect[0];
+
    if ( columnWidthMode(0) == Maximum )
       setColumnWidth(0,50);
 
@@ -895,7 +940,7 @@ bool KonqBaseListViewWidget::openURL( const KURL &url )
    m_bUpdateContentsPosAfterListing = true;
 
    // Start the directory lister !
-   m_dirLister->openURL( url, false /* new url */, m_pBrowserView->extension()->urlArgs().reload );
+   m_dirLister->openURL( url, false /* new url */, args.reload );
 
    // Apply properties and reflect them on the actions
    // do it after starting the dir lister to avoid changing the properties
@@ -1014,7 +1059,13 @@ void KonqBaseListViewWidget::slotNewItems( const KFileItemList & entries )
          setCurrentItem( tmp );
          m_itemFound = true;
       }
-
+      if ( !m_itemsToSelect.isEmpty() ) {
+         QStringList::Iterator tsit = m_itemsToSelect.find( (*kit)->name() );
+         if ( tsit != m_itemsToSelect.end() ) {
+            m_itemsToSelect.remove( tsit );
+            setSelected( tmp, true );
+         }
+      }
       if ( !(*kit)->isMimeTypeKnown() )
           m_pBrowserView->lstPendingMimeIconItems().append( tmp );
    }
@@ -1031,13 +1082,13 @@ void KonqBaseListViewWidget::slotNewItems( const KFileItemList & entries )
 
 void KonqBaseListViewWidget::slotDeleteItem( KFileItem * _fileitem )
 {
-  kdDebug(1202) << k_funcinfo << "removing " << _fileitem->url().url() << " from tree!" << endl;
-
-  m_pBrowserView->deleteItem( _fileitem );
   iterator it = begin();
   for( ; it != end(); ++it )
     if ( (*it).item() == _fileitem )
     {
+      kdDebug(1202) << k_funcinfo << "removing " << _fileitem->url().url() << " from tree!" << endl;
+
+      m_pBrowserView->deleteItem( _fileitem );
       m_pBrowserView->lstPendingMimeIconItems().remove( &(*it) );
 
       delete &(*it);
@@ -1048,6 +1099,10 @@ void KonqBaseListViewWidget::slotDeleteItem( KFileItem * _fileitem )
       return;
     }
 
+  // This is needed for the case the root of the current view is deleted.
+  // I supposed slotUpdateBackground has to be called as well after an item
+  // was removed from a listview and was just forgotten previously (Brade).
+  // OK, but this code also gets activated when deleting a hidden file... (dfaure)
   if ( !viewport()->isUpdatesEnabled() )
   {
     viewport()->setUpdatesEnabled( true );
@@ -1082,6 +1137,7 @@ void KonqBaseListViewWidget::slotRedirection( const KURL & url )
       createColumns();
    }
    emit m_pBrowserView->extension()->setLocationBarURL( url.prettyURL() );
+   emit m_pBrowserView->setWindowCaption( url.prettyURL() );
    m_pBrowserView->m_url=url;
    m_url = url;
 }
