@@ -53,7 +53,12 @@ class KonqSidebarPlugin : public QObject
 		void requestURL(KURL&);
 		void started(KIO::Job *);
 		void completed();
+		void setIcon(const QString& icon);
+		void setCaption(const QString& caption);
 
+
+	protected:
+		bool universalMode();
 	public slots:
 	  void openURL(const KURL& url);
 
