@@ -95,7 +95,7 @@ void KonqSidebarDirTreeModule::addTopLevelItem( KonqSidebarTreeTopLevelItem * it
     else
         return;
 
-    bool bListable = KProtocolInfo::supportsListing( targetURL.protocol() );
+    bool bListable = KProtocolInfo::supportsListing( targetURL );
     //kdDebug(1201) << targetURL.prettyURL() << " listable : " << bListable << endl;
 
     if ( !bListable )
@@ -377,7 +377,7 @@ void KonqSidebarDirTreeModule::slotNewItems( const KFileItemList& entries )
     KFileItem * firstItem = const_cast<KFileItemList&>(entries).first(); // qlist sucks for constness
 
     // Find parent item - it's the same for all the items
-    KURL dir( firstItem->url() );
+    KURL dir( firstItem->url().url(-1) );
     dir.setFileName( "" );
     dir.setPass( QString::null );
     kdDebug(1201) << this << " KonqSidebarDirTreeModule::slotNewItems dir=" << dir.url(-1) << endl;
@@ -388,7 +388,7 @@ void KonqSidebarDirTreeModule::slotNewItems( const KFileItemList& entries )
 
     if( !parentItem )
     {
-        KMessageBox::error( tree(), i18n("Can't find parent item %1 in the tree. Internal error.").arg( dir.url(-1) ) );
+        KMessageBox::error( tree(), i18n("Cannot find parent item %1 in the tree. Internal error.").arg( dir.url(-1) ) );
        	return;
     }
 
