@@ -17,13 +17,9 @@
 #define TE_PTY_H
 
 #include <config.h>
-#include <sys/types.h>
-#include <sys/ioctl.h>
 
 #include <kprocess.h>
-#include <termios.h>
 #include <qsocketnotifier.h>
-#include <qtimer.h>
 #include <qstrlist.h>
 #include <qvaluelist.h>
 #include <qmemarray.h>
@@ -44,26 +40,23 @@ Q_OBJECT
      * the necessary connections to the signals and slots of the
      * instance before starting the execution of the client.
      */
-    int run( const char* pgm, QStrList & args, const char* term, bool _addutmp,
+    int run( const char* pgm, QStrList & args, const char* term, ulong winid, bool _addutmp,
              const char* konsole_dcop = "", const char* konsole_dcop_session = "" );
     void setWriteable(bool writeable);
-    void setXonXoff(bool _xonxoff) { m_bXonXoff = _xonxoff; }
-    int makePty(bool _addutmp);
-    int masterFd() { return m_MasterFd; }
     QString error() { return m_strError; }
+    void setXonXoff(bool on);
+    void setSize(int lines, int cols);
 
   public slots:
     void lockPty(bool lock);
     void send_bytes(const char* s, int len);
-    void setSize(int lines, int columns);
 
   signals:
 
     /*!
         emitted when the client program terminates.
-        \param status the wait(2) status code of the terminated client program.
     */
-    void done(int status);
+    void done(int returnCode);
 
     /*!
         emitted when a new block of data comes in.
@@ -71,66 +64,45 @@ Q_OBJECT
         \param len - the length of the block
     */
     void block_in(const char* s, int len);
+    
+    /*!
+        emitted when buffer_full becomes false
+    */
+    void buffer_empty();
 
   public:
 
     void send_byte(char s);
     void send_string(const char* s);
+    bool buffer_full() { return m_bufferFull; }
 
-    const char* deviceName();
-
-    virtual void commClose();
-    
-  protected:
-      virtual int commSetupDoneC();
-      virtual int setupCommunication(Communication comm);
-  
   protected slots:
-      void DataReceived(int, int& len);
+      void dataReceived(KProcess *, char *buf, int len);
   public slots:
       void donePty();
       
   private:
-    void startPgm(const char* pgm, QValueList<QCString> & args, const char* term);
-    void openPty();
     void appendSendJob(const char* s, int len);
 
   private slots:
     void doSendJobs();
+    void writeReady();
 
   private:
 
-    struct winsize m_WSize;
-    int m_MasterFd;
-    int m_SlaveFd;
-    bool             m_bNeedGrantPty;
-    bool             m_bXonXoff;
-    bool             m_bAddUtmp;
-    char ptynam[50]; // "/dev/ptyxx" | "/dev/ptmx"
-    char ttynam[50]; // "/dev/ttyxx" | "/dev/pts/########..."
-    const char *pgm;
     QString m_strError;
 
-    // environment variables
-    const char *term;
-    const char *konsole_dcop;
-    const char *konsole_dcop_session;
-
     struct SendJob {
       SendJob() {}
       SendJob(const char* b, int len) {
         buffer.duplicate(b,len);
-        start = 0;
         length = len;
       }
       QMemArray<char> buffer;
-      int start;
       int length;
     };
     QValueList<SendJob> pendingSendJobs;
-    QTimer* pSendJobTimer;
-
-  friend int chownpty(int, bool);
+    bool m_bufferFull;
 };
 
 #endif
