@@ -20,8 +20,6 @@
 #include <kmainwindow.h>
 #include <kdialogbase.h>
 #include <ksimpleconfig.h>
-#include <kaction.h>
-#include <kpopupmenu.h>
 #include <keditcl.h>
 
 #include <kwinmodule.h>
@@ -44,11 +42,19 @@
 #undef PACKAGE
 #undef VERSION
 #define PACKAGE "konsole"
-#define VERSION "1.2.3"
+#define VERSION "1.4.2"
 
 class KRootPixmap;
+class QLabel;
 class QCheckBox;
 class KonsoleFind;
+class KPopupMenu;
+class KAction;
+class KToggleAction;
+class KSelectAction;
+class KRadioAction;
+class KTabWidget;
+class QToolButton;
 
 // Defined in main.C
 const char *konsole_shell(QStrList &args);
@@ -61,25 +67,25 @@ class Konsole : public KMainWindow, virtual public KonsoleIface
 public:
 
   Konsole(const char * name, const QString &_program, QStrList & _args, int histon,
-    bool menubaron, bool toolbaron, bool frameon, bool scrollbaron, const QString &icon, const QString &_title, 
-    QCString type = 0, const QString &_term=QString::null, bool b_inRestore = false, const QString &workdir=QString::null);
+    bool menubaron, bool tabbaron, bool frameon, bool scrollbaron, const QString &icon, const QString &_title,
+    QCString type = 0, const QString &_term=QString::null, bool b_inRestore = false, const int wanted_tabbar = 0,
+    const QString &workdir=QString::null);
   ~Konsole();
   void setColLin(int columns, int lines);
-  void setFullScreen(bool on);
   void setAutoClose(bool on);
   void initFullScreen();
   void initSessionFont(int fontNo);
-  void initSessionTitle(const QString &_title);
+  void initSessionTitle(const QString &_title, TESession* _se=0);
   void initSessionKeyTab(const QString &keyTab);
   void initMonitorActivity(bool on);
   void initMonitorSilence(bool on);
   void initMasterMode(bool on);
   void newSession(const QString &program, const QStrList &args, const QString &term, const QString &icon, const QString &cwd);
   void setSchema(const QString & path);
-  
-  void enableFullScripting(bool b);
 
-  void run();
+  void enableFullScripting(bool b);
+  void enableFixedSize(bool b);
+
   void setDefaultSession(const QString &filename);
   void showTipOnStart();
 
@@ -101,8 +107,14 @@ public:
 
   void callReadPropertiesInternal(KConfig *config, int number) { readPropertiesInternal(config,number); }
 
+  enum TabPosition { TabNone, TabTop, TabBottom };
+  enum TabViewModes { ShowIconAndText = 0, ShowTextOnly = 1, ShowIconOnly = 2 };
+
+  enum { BELLSYSTEM=0, BELLNOTIFY=1, BELLVISUAL=2 };  // From TEWidget.h
+
 public slots:
-  void activateSession(const int position);
+  void activateSession(int position);
+  void activateSession(QWidget*);
 
   void makeGUI();
   QString newSession();
@@ -113,30 +125,29 @@ protected:
  void saveProperties(KConfig* config);
  void readProperties(KConfig* config);
 
- 
-
 private slots:
-  void currentDesktopChanged(int desk);
-  void slotBackgroundChanged(int desk);
   void configureRequest(TEWidget*,int,int,int);
   void activateSession();
   void activateSession(TESession*);
   void closeCurrentSession();
+  void confirmCloseCurrentSession();
   void doneChild(KonsoleChild*, TESession*);
   void doneSession(TESession*);
   void slotCouldNotClose();
-  void slotToggleFullscreen();
+  void toggleFullScreen();
+  void setFullScreen(bool on);
   void schema_menu_activated(int item);
-  void pixmap_menu_activated(int item);
+  void pixmap_menu_activated(int item, TEWidget* tewidget=0);
   void keytab_menu_activated(int item);
   void schema_menu_check();
   void attachSession(TESession*);
-  void detachSession();
+  void slotDetachSession();
   void bookmarks_menu_check();
   void newSession(int kind);
-  void newSessionToolbar(int kind);
+  void newSessionTabbar(int kind);
   void updateSchemaMenu();
   void updateKeytabMenu();
+  void updateRMBMenu();
 
   void changeColumns(int);
   void notifySessionState(TESession* session,int state);
@@ -145,17 +156,17 @@ private slots:
   void prevSession();
   void nextSession();
   void activateMenu();
+  void slotMovedTab(int,int);
   void moveSessionLeft();
   void moveSessionRight();
   void allowPrevNext();
-  void setSchema(int n);
+  void setSchema(int n, TEWidget* tewidget=0);   // no slot necessary?
   void sendSignal(int n);
   void slotClearTerminal();
   void slotResetClearTerminal();
-  void slotToggleToolbar();
+  void slotSelectTabbar();
   void slotToggleMenubar();
   void slotRenameSession();
-  void slotRenameSession(int);
   void slotRenameSession(TESession* ses, const QString &name);
   void slotToggleMonitor();
   void slotToggleMasterMode();
@@ -169,15 +180,17 @@ private slots:
   void slotSelectFont();
   void slotSelectScrollbar();
   void loadScreenSessions();
+  void updateFullScreen(bool on);
 
   void slotSaveSettings();
   void slotSaveSessionsProfile();
+  void slotConfigureNotifications();
   void slotConfigureKeys();
   void slotConfigure();
   void reparseConfiguration();
 
-  void clearAllListenToKeyPress();
-  void restoreAllListenToKeyPress();
+  void disableMasterModeConnections();
+  void enableMasterModeConnections();
   void enterURL( const QString&, const QString& );
   void newSession( const QString&, const QString& );
 
@@ -189,48 +202,72 @@ private slots:
   void fontNotFound();
   void showTip();
 
+  void slotSetSelectionEnd() { te->setSelectionEnd(); }
+  void slotCopyClipboard() { te->copyClipboard(); }
+  void slotPasteClipboard() { te->pasteClipboard(); }
+  void slotPasteSelection() { te->pasteSelection(); }
+
   void listSessions();
-  void switchToSession1() { activateSession(1); }
-  void switchToSession2() { activateSession(2); }
-  void switchToSession3() { activateSession(3); }
-  void switchToSession4() { activateSession(4); }
-  void switchToSession5() { activateSession(5); }
-  void switchToSession6() { activateSession(6); }
-  void switchToSession7() { activateSession(7); }
-  void switchToSession8() { activateSession(8); }
-  void switchToSession9() { activateSession(9); }
-  void switchToSession10() { activateSession(10); }
-  void switchToSession11() { activateSession(11); }
-  void switchToSession12() { activateSession(12); }
+  void switchToSession();
 
   void biggerFont();
   void smallerFont();
 
+  void slotZModemDetected(TESession *session);
+  void slotZModemUpload();
+
   void slotPrint();
 
+  void toggleBidi();
+
+  void slotTabContextMenu(QWidget*, const QPoint &);
+  void slotTabDetachSession();
+  void slotTabRenameSession();
+  void slotTabCloseSession();
+  void slotTabToggleMonitor();
+  void slotTabToggleMasterMode();
+  void slotTabbarContextMenu(const QPoint &);
+  void slotTabSetViewOptions(int);
+  void slotTabbarToggleDynamicHide();
+
 private:
   KSimpleConfig *defaultSession();
-  QString newSession(KSimpleConfig *co, QString pgm = QString::null, const QStrList &args = QStrList(), const QString &_term = QString::null, const QString &_icon = QString::null, const QString &_title = QString::null, const QString &_cwd = QString::null);
+  QString newSession(KSimpleConfig *co, QString pgm = QString::null, const QStrList &args = QStrList(),
+                     const QString &_term = QString::null, const QString &_icon = QString::null,
+                     const QString &_title = QString::null, const QString &_cwd = QString::null);
   void readProperties(KConfig *config, const QString &schema, bool globalConfigOnly);
   void applySettingsToGUI();
+  void makeTabWidget();
   void makeBasicGUI();
   void runSession(TESession* s);
   void addSession(TESession* s);
+  void detachSession(TESession* _se=0);
   void setColorPixmaps();
 
-  void setSchema(ColorSchema* s);
-  void setFont(int fontno);
+  void setSchema(ColorSchema* s, TEWidget* tewidget=0);
+  void setFont(int fontno=-1);
+  void setMasterMode(bool _state, TESession* _se=0);
 
-  void clearSessionHistory(TESession & session);
   void buildSessionMenus();
   void addSessionCommand(const QString & path);
   void loadSessionCommands();
   void addScreenSession(const QString & path, const QString & socket);
   void resetScreenSessions();
 
+  void initTEWidget(TEWidget* new_te, TEWidget* default_te);
+  void switchToTabWidget();
+  void switchToFlat();
+
+  void createSessionTab(TEWidget *widget, const QIconSet& iconSet,
+                        const QString &text, int index = -1);
+  QIconSet iconSetForSession(TESession *session) const;
+
+  bool eventFilter( QObject *o, QEvent *e );
+
+  QPtrList<TEWidget> activeTEs();
+
   QPtrDict<TESession> action2session;
   QPtrDict<KRadioAction> session2action;
-  QPtrDict<KToolBarButton> session2button;
   QPtrList<TESession> sessions;
   QPtrList<KonsoleChild> detached;
   QIntDict<KSimpleConfig> no2command;
@@ -239,13 +276,14 @@ private:
   KSimpleConfig* m_defaultSession;
   QString m_defaultSessionFilename;
 
-  TEWidget*      te;
+  KTabWidget* tabwidget; // if null then there is only one TEWidget in system
+  TEWidget*      te;     // the visible TEWidget, either sole one or one of many
   TESession*     se;
   TESession*     se_previous;
   TESession*     m_initialSession;
   ColorSchemaList* colors;
 
-  KRootPixmap*   rootxpm;
+  QPtrDict<KRootPixmap> rootxpms;
   KWinModule*    kWinModule;
 
   KMenuBar*   menubar;
@@ -259,22 +297,26 @@ private:
   KPopupMenu* m_options;
   KPopupMenu* m_schema;
   KPopupMenu* m_keytab;
-  KPopupMenu* m_toolbarSessionsCommands;
+  KPopupMenu* m_tabbarSessionsCommands;
   KPopupMenu* m_signals;
   KPopupMenu* m_help;
   KPopupMenu* m_rightButton;
+  KPopupMenu* m_sessionList;
+  KPopupMenu* m_tabPopupMenu;
+  KPopupMenu* m_tabPopupTabsMenu;
+  KPopupMenu* m_tabbarPopupMenu;
 
-  KToggleAction *monitorActivity;
-  KToggleAction *monitorSilence;
-  KToggleAction *masterMode;
-  KToggleAction *showToolbar;
+  KAction *m_zmodemUpload;
+  KToggleAction *monitorActivity, *m_tabMonitorActivity;
+  KToggleAction *monitorSilence, *m_tabMonitorSilence;
+  KToggleAction *masterMode, *m_tabMasterMode;
   KToggleAction *showMenubar;
-  KToggleAction *showScrollbar;
   KToggleAction *m_fullscreen;
 
   KSelectAction *selectSize;
   KSelectAction *selectFont;
   KSelectAction *selectScrollbar;
+  KSelectAction *selectTabbar;
   KSelectAction *selectBell;
 
   KAction       *m_clearHistory;
@@ -288,6 +330,7 @@ private:
 
   KAction       *m_copyClipboard;
   KAction       *m_pasteClipboard;
+  KAction       *m_pasteSelection;
   KAction       *m_clearTerminal;
   KAction       *m_resetClearTerminal;
   KAction       *m_clearAllSessionHistories;
@@ -296,6 +339,7 @@ private:
   KAction       *m_closeSession;
   KAction       *m_print;
   KAction       *m_quit;
+  KAction       *m_tabDetachSession;
 
   KActionCollection *m_shortcuts;
 
@@ -314,6 +358,7 @@ private:
   int         n_font;
   int         n_defaultFont; // font as set in config to use as default for new sessions
   int         n_scroll;
+  int         n_tabbar;
   int         n_bell;
   int         n_render;
   int         curr_schema; // current schema no
@@ -334,19 +379,33 @@ private:
 
   QTimer      m_closeTimeout;
 
+  TabViewModes m_tabViewMode;
+  bool        b_dynamicTabHide;
+
   bool        b_framevis:1;
   bool        b_fullscreen:1;
   bool        m_menuCreated:1;
   bool        skip_exit_query:1;
   bool        b_warnQuit:1;
   bool        isRestored:1;
-  bool        b_allowResize:1;
+  bool        b_allowResize:1; // Whether application may resize
+  bool        b_fixedSize:1; // Whether user may resize
   bool        b_addToUtmp:1;
   bool        b_xonXoff:1;
+  bool        b_bidiEnabled:1;
 
   bool        b_histEnabled:1;
   bool        b_fullScripting:1;
+  bool        b_showstartuptip:1;
+
   unsigned int m_histSize;
+  int m_separator_id;
+
+  TESession*  m_contextMenuSession;
+
+  QToolButton* m_newSessionButton;
+  QToolButton* m_removeSessionButton;
+  QPoint      m_newSessionButtonMousePressPos;
 };
 
 class QSpinBox;
@@ -369,6 +428,7 @@ public slots:
   bool isOn() const;
 
 protected:
+  QLabel*        m_label;
   QSpinBox*      m_size;
   QCheckBox*     m_btnEnable;
   QPushButton*   m_setUnlimited;
