@@ -35,11 +35,23 @@
 #include <kfontdialog.h>
 #include <kglobalsettings.h>
 #include <kiconloader.h>
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <krun.h>
 #include <kstdaction.h>
+#include <qlabel.h>
+
+#include <qcheckbox.h>
+#include <qspinbox.h>
+#include <qpushbutton.h>
+#include <kpopupmenu.h>
+#include <krootpixmap.h>
+#include <kconfig.h>
+#include <kaction.h>
+
+// We can't use the ARGB32 visual when embedded in another application
+bool argb_visual = false;
 
 extern "C"
 {
@@ -124,14 +136,14 @@ void KonsoleFontSelectAction::slotActivated(int index) {
 
 //////////////////////////////////////////////////////////////////////
 
-const char *fonts[] = {
+static const char * const fonts[] = {
  "13",
  "7",   // tiny font, never used
  "10",  // small font
  "13",  // medium
  "15",  // large
  "20", // huge
- "-misc-console-medium-r-normal--16-160-72-72-c-160-iso10646-1", // "Linux"
+ "-misc-console-medium-r-normal--16-160-72-72-c-80-iso10646-1", // "Linux"
  "-misc-fixed-medium-r-normal--15-140-75-75-c-90-iso10646-1",    // "Unicode"
  };
 
@@ -158,6 +170,7 @@ konsolePart::konsolePart(QWidget *_parentWidget, const char *widgetName, QObject
 ,m_options(0)
 ,m_popupMenu(0)
 ,m_histSize(DEFAULT_HISTORY_SIZE)
+,m_runningShell( false )
 {
   parentWidget=_parentWidget;
   setInstance(konsoleFactory::instance());
@@ -172,6 +185,7 @@ konsolePart::konsolePart(QWidget *_parentWidget, const char *widgetName, QObject
 
   QStrList eargs;
 
+
   const char* shell = getenv("SHELL");
   if (shell == NULL || *shell == '\0') shell = "/bin/sh";
   eargs.append(shell);
@@ -179,35 +193,15 @@ konsolePart::konsolePart(QWidget *_parentWidget, const char *widgetName, QObject
   te->setMinimumSize(150,70);    // allow resizing, cause resize in TEWidget
 
   setWidget(te);
-  se = new TESession(te,shell,eargs,"xterm");
-  connect( se,SIGNAL(done(TESession*)),
-           this,SLOT(doneSession(TESession*)) );
-  connect( se,SIGNAL(openURLRequest(const QString &)),
-           this,SLOT(emitOpenURLRequest(const QString &)) );
+  te->setFocus();
   connect( te,SIGNAL(configureRequest(TEWidget*,int,int,int)),
            this,SLOT(configureRequest(TEWidget*,int,int,int)) );
-  connect( se, SIGNAL( updateTitle() ),
-           this, SLOT( updateTitle() ) );
-  connect( se, SIGNAL(restoreAllListenToKeyPress()),
-           this, SLOT(restoreAllListenToKeyPress()) );
-  // We ignore the following signals
-  //connect( se, SIGNAL(renameSession(TESession*,const QString&)),
-  //         this, SLOT(slotRenameSession(TESession*, const QString&)) );
-  //connect( se->getEmulation(), SIGNAL(changeColumns(int)),
-  //         this, SLOT(changeColumns(int)) );
-  //connect( se, SIGNAL(clearAllListenToKeyPress()),
-  //        this, SLOT(clearAllListenToKeyPress()) );
-  connect( se->getEmulation(),SIGNAL(ImageSizeChanged(int,int)), 
-           this,SLOT(notifySize(int,int)));
-
-  rootxpm = new KRootPixmap(te);
 
   colors = new ColorSchemaList();
   colors->checkSchemas();
   colors->sort();
 
   readProperties();
-  se->setConnect(true);
 
   makeGUI();
 
@@ -220,34 +214,30 @@ konsolePart::konsolePart(QWidget *_parentWidget, const char *widgetName, QObject
         curr_schema=sch->numb();
      else
         curr_schema = 0;
+
      for (uint i=0; i<m_schema->count(); i++)
         m_schema->setItemChecked(i,false);
 
      m_schema->setItemChecked(curr_schema,true);
-     se->setSchemaNo(curr_schema);
   }
 
   // insert keymaps into menu
   if (m_keytab)
   {
-     for (int i = 0; i < KeyTrans::count(); i++) 
+     for (int i = 0; i < KeyTrans::count(); i++)
      {
         KeyTrans* ktr = KeyTrans::find(i);
         QString title=ktr->hdr();
-#if QT_VERSION >= 0x030200
         m_keytab->insertItem(title.replace('&',"&&"),ktr->numb());
-#else
-        m_keytab->insertItem(title.replace(QRegExp("^&|([^&])&"),"\\1&&"),ktr->numb());
-#endif
      }
   }
 
   applySettingsToGUI();
 
   // kDebugInfo("Loading successful");
-  se->run();
 
-  connect( se, SIGNAL( destroyed() ), this, SLOT( sessionDestroyed() ) );
+  QTimer::singleShot( 0, this, SLOT( showShell() ) );
+
 }
 
 void konsolePart::doneSession(TESession*)
@@ -255,28 +245,28 @@ void konsolePart::doneSession(TESession*)
   // see doneSession in konsole.cpp
   if (se)
   {
-    kdDebug(1211) << "doneSession - disconnecting done" << endl;;
+    kdDebug(1211) << "doneSession - disconnecting done" << endl;
     disconnect( se,SIGNAL(done(TESession*)),
                 this,SLOT(doneSession(TESession*)) );
     se->setConnect(false);
     //QTimer::singleShot(100,se,SLOT(terminate()));
-    kdDebug(1211) << "se->terminate()" << endl;;
+    kdDebug(1211) << "se->terminate()" << endl;
     se->terminate();
   }
 }
 
 void konsolePart::sessionDestroyed()
 {
-  kdDebug(1211) << "sessionDestroyed()" << endl;;
+  kdDebug(1211) << "sessionDestroyed()" << endl;
   disconnect( se, SIGNAL( destroyed() ), this, SLOT( sessionDestroyed() ) );
   se = 0;
   delete this;
 }
 
-void konsolePart::configureRequest(TEWidget*te,int,int x,int y)
+void konsolePart::configureRequest(TEWidget*_te,int,int x,int y)
 {
   if (m_popupMenu)
-     m_popupMenu->popup(te->mapToGlobal(QPoint(x,y)));
+     m_popupMenu->popup(_te->mapToGlobal(QPoint(x,y)));
 }
 
 konsolePart::~konsolePart()
@@ -313,9 +303,7 @@ bool konsolePart::openURL( const KURL & url )
       struct stat buff;
       stat( QFile::encodeName( url.path() ), &buff );
       QString text = ( S_ISDIR( buff.st_mode ) ? url.path() : url.directory() );
-      KRun::shellQuote(text);
-      text = QString::fromLatin1("cd ") + text + '\n';
-      te->emitText( text );
+      showShellInDir( text );
   }
 
   emit completed();
@@ -327,7 +315,7 @@ void konsolePart::emitOpenURLRequest(const QString &cwd)
   KURL url;
   url.setPath(cwd);
   if (url==currentURL)
-    return; 
+    return;
   currentURL=url;
   m_extension->emitOpenURLRequest(url);
 }
@@ -418,8 +406,9 @@ void konsolePart::makeGUI()
         m_options->insertItem( SmallIconSet( "colorize" ), i18n( "Sch&ema" ), m_schema);
      }
 
+
      KAction *historyType = new KAction(i18n("&History..."), "history", 0, this,
-                                     SLOT(slotHistoryType()), actions, "history");
+                                        SLOT(slotHistoryType()), actions, "history");
      historyType->plug(m_options);
      m_options->insertSeparator();
 
@@ -459,6 +448,7 @@ void konsolePart::makeGUI()
      // Frame on/off
      showFrame = new KToggleAction(i18n("Show Fr&ame"), 0,
                                 this, SLOT(slotToggleFrame()), actions);
+     showFrame->setCheckedState(i18n("Hide Fr&ame"));
      showFrame->plug(m_options);
 
      // Word Connectors
@@ -476,10 +466,14 @@ void konsolePart::makeGUI()
 
   // Popup Menu -------------------------------------------------------------------
   m_popupMenu = new KPopupMenu((KMainWindow*)parentWidget);
+  KAction* selectionEnd = new KAction(i18n("Set Selection End"), 0, te,
+                               SLOT(setSelectionEnd()), actions, "selection_end");
+  selectionEnd->plug(m_popupMenu);
+
   KAction *copyClipboard = new KAction(i18n("&Copy"), "editcopy", 0,
                                         te, SLOT(copyClipboard()), actions, "edit_copy");
   copyClipboard->plug(m_popupMenu);
-  
+
   KAction *pasteClipboard = new KAction(i18n("&Paste"), "editpaste", 0,
                                         te, SLOT(pasteClipboard()), actions, "edit_paste");
   pasteClipboard->plug(m_popupMenu);
@@ -544,7 +538,7 @@ void konsolePart::readProperties()
 
   QString schema = config->readEntry("Schema");
 
-  s_kconfigSchema=config->readEntry("schema", "");
+  s_kconfigSchema=config->readEntry("schema");
   ColorSchema* sch = colors->find(schema.isEmpty() ? s_kconfigSchema : schema);
   if (!sch) {
     sch=(ColorSchema*)colors->at(0);  //the default one
@@ -557,22 +551,21 @@ void konsolePart::readProperties()
 
   if (sch->useTransparency()) {
     //KONSOLEDEBUG << "Setting up transparency" << endl;
+    if (!rootxpm)
+      rootxpm = new KRootPixmap(te);
     rootxpm->setFadeEffect(sch->tr_x(), QColor(sch->tr_r(), sch->tr_g(), sch->tr_b()));
     rootxpm->start();
+    rootxpm->repaint(true);
   }
   else {
-    rootxpm->stop();
+    if (rootxpm) {
+      rootxpm->stop();
+      delete rootxpm;
+      rootxpm=0;
+    }
     pixmap_menu_activated(sch->alignment());
   }
 
-  if (b_histEnabled && m_histSize)
-    se->setHistory(HistoryTypeBuffer(m_histSize));
-  else if (b_histEnabled && !m_histSize)
-    se->setHistory(HistoryTypeFile());
-  else
-    se->setHistory(HistoryTypeNone());
-
-  se->setKeymapNo(n_keytab);
   te->setBellMode(n_bell);
   te->setBlinkingCursor(config->readBoolEntry("BlinkingCursor",false));
   te->setFrameStyle( b_framevis?(QFrame::WinPanel|QFrame::Sunken):QFrame::NoFrame );
@@ -585,8 +578,6 @@ void konsolePart::readProperties()
   config = new KConfig("konsolerc",true);
   config->setDesktopGroup();
   te->setTerminalSizeHint( config->readBoolEntry("TerminalSizeHint",true) );
-  config->setGroup("UTMP");
-  se->setAddToUtmp( config->readBoolEntry("AddToUtmp",true));
   delete config;
 }
 
@@ -619,7 +610,7 @@ void konsolePart::sendSignal(int sn)
 
 void konsolePart::closeCurrentSession()
 {
-  se->closeSession();
+  if ( se ) se->closeSession();
 }
 
 void konsolePart::slotToggleFrame()
@@ -630,12 +621,17 @@ void konsolePart::slotToggleFrame()
 
 void konsolePart::slotSelectScrollbar()
 {
+  if ( ! se ) return;
   n_scroll = selectScrollbar->currentItem();
   te->setScrollbarLocation(n_scroll);
 }
 
 void konsolePart::slotSelectFont() {
   int item = selectFont->currentItem();
+  if( item > 9 ) // compensate for the two separators
+      --item;
+  if( item > 6 )
+      --item;
   // KONSOLEDEBUG << "slotSelectFont " << item << endl;
   if (item == DEFAULTFONT) {
     if ( KFontDialog::getFont(defaultFont, true) == QDialog::Rejected ) {
@@ -648,30 +644,31 @@ void konsolePart::slotSelectFont() {
 
 void konsolePart::setFont(int fontno)
 {
+  if ( ! se ) return;
   QFont f;
   if (fontno == DEFAULTFONT)
     f = defaultFont;
   else
-  if (fonts[fontno][0] == '-')
-  {
-    f.setRawName( fonts[fontno] );
-    f.setFixedPitch(true);
-    f.setStyleHint( QFont::TypeWriter );
-    if ( !f.exactMatch() && fontno != DEFAULTFONT)
+    if (fonts[fontno][0] == '-')
     {
-      // Ugly hack to prevent bug #20487
-      fontNotFound_par=fonts[fontno];
-      QTimer::singleShot(1,this,SLOT(fontNotFound()));
-      return;
+      f.setRawName( fonts[fontno] );
+      f.setFixedPitch(true);
+      f.setStyleHint( QFont::TypeWriter );
+      if ( !f.exactMatch() && fontno != DEFAULTFONT)
+      {
+        // Ugly hack to prevent bug #20487
+        fontNotFound_par=fonts[fontno];
+        QTimer::singleShot(1,this,SLOT(fontNotFound()));
+        return;
+      }
+    }
+    else
+    {
+      f.setFamily("fixed");
+      f.setFixedPitch(true);
+      f.setStyleHint(QFont::TypeWriter);
+      f.setPixelSize(QString(fonts[fontno]).toInt());
     }
-  }
-  else
-  {
-    f.setFamily("fixed");
-    f.setFixedPitch(true);
-    f.setStyleHint(QFont::TypeWriter);
-    f.setPixelSize(QString(fonts[fontno]).toInt());
-  }
 
 
   se->setFontNo(fontno);
@@ -682,7 +679,7 @@ void konsolePart::setFont(int fontno)
 void konsolePart::fontNotFound()
 {
   QString msg = i18n("Font `%1' not found.\nCheck README.linux.console for help.").arg(fontNotFound_par);
-  KMessageBox::error(parentWidget,  msg);
+  KMessageBox::information(parentWidget,  msg, i18n("Font Not Found"), QString("font_not_found_%1").arg(fontNotFound_par));
 }
 
 void konsolePart::updateKeytabMenu()
@@ -695,6 +692,7 @@ void konsolePart::updateKeytabMenu()
 
 void konsolePart::keytab_menu_activated(int item)
 {
+  if ( ! se ) return;
   se->setKeymapNo(item);
   updateKeytabMenu();
 }
@@ -716,16 +714,12 @@ void konsolePart::schema_menu_check()
 void konsolePart::updateSchemaMenu()
 {
   if (!m_schema) return;
-  
+
   m_schema->clear();
   for (int i = 0; i < (int) colors->count(); i++)  {
     ColorSchema* s = (ColorSchema*)colors->at(i);
     QString title=s->title();
-#if QT_VERSION >= 0x030200
     m_schema->insertItem(title.replace('&',"&&"),s->numb(),0);
-#else
-    m_schema->insertItem(title.replace(QRegExp("^&|([^&])&"),"\\1&&"),s->numb(),0);
-#endif
   }
 
   if (te && se) {
@@ -752,6 +746,7 @@ void konsolePart::setSchema(int numb)
 
 void konsolePart::setSchema(ColorSchema* s)
 {
+  if (!se) return;
   if (!s) return;
 
   if (m_schema) {
@@ -765,11 +760,18 @@ void konsolePart::setSchema(ColorSchema* s)
   te->setColorTable(s->table()); //FIXME: set twice here to work around a bug
 
   if (s->useTransparency()) {
+    if (!rootxpm)
+      rootxpm = new KRootPixmap(te);
     rootxpm->setFadeEffect(s->tr_x(), QColor(s->tr_r(), s->tr_g(), s->tr_b()));
     rootxpm->start();
+    rootxpm->repaint(true);
   }
   else {
-    rootxpm->stop();
+    if (rootxpm) {
+      rootxpm->stop();
+      delete rootxpm;
+      rootxpm=0;
+    }
     pixmap_menu_activated(s->alignment());
   }
 
@@ -777,7 +779,7 @@ void konsolePart::setSchema(ColorSchema* s)
   se->setSchemaNo(s->numb());
 }
 
-void konsolePart::notifySize(int lines, int columns)
+void konsolePart::notifySize(int /* lines */, int /* columns */)
 {
   ColorSchema *sch=colors->find(s_schema);
 
@@ -830,6 +832,7 @@ void konsolePart::pixmap_menu_activated(int item)
 
 void konsolePart::slotHistoryType()
 {
+  if ( ! se ) return;
   HistoryTypeDialog dlg(se->history(), m_histSize, (KMainWindow*)parentWidget);
   if (dlg.exec()) {
     if (dlg.isOn()) {
@@ -868,22 +871,25 @@ void konsolePart::slotBlinkingCursor()
 }
 
 void konsolePart::slotWordSeps() {
-  KLineEditDlg dlg(i18n("Characters other than alphanumerics considered part of a word when double clicking:"),s_word_seps, (KMainWindow*)parentWidget);
-  dlg.setCaption(i18n("Word Connectors"));
-  if (dlg.exec()) {
-    s_word_seps = dlg.text();
+  bool ok;
+
+  QString seps = KInputDialog::getText( i18n( "Word Connectors" ),
+      i18n( "Characters other than alphanumerics considered part of a word when double clicking:" ), s_word_seps, &ok, parentWidget );
+  if ( ok )
+  {
+    s_word_seps = seps;
     te->setWordCharacters(s_word_seps);
   }
 }
 
-void konsolePart::restoreAllListenToKeyPress()
+void konsolePart::enableMasterModeConnections()
 {
-    se->setListenToKeyPress(true);
+  if ( se ) se->setListenToKeyPress(true);
 }
 
 void konsolePart::updateTitle()
 {
-    emit setWindowCaption( se->fullTitle() );
+  if ( se ) emit setWindowCaption( se->fullTitle() );
 }
 
 void konsolePart::guiActivateEvent( KParts::GUIActivateEvent * )
@@ -998,4 +1004,97 @@ void konsoleBrowserExtension::emitOpenURLRequest(const KURL &url)
   emit openURLRequest(url);
 }
 
+const char* sensibleShell()
+{
+  const char* shell = getenv("SHELL");
+  if (shell == NULL || *shell == '\0') shell = "/bin/sh";
+  return shell;
+}
+
+void konsolePart::startProgram( const QString& program,
+                                const QStrList& args )
+{
+  if ( se ) delete se;
+  se = new TESession(te, program, args, "xterm", parentWidget->winId());
+  connect( se,SIGNAL(done(TESession*)),
+           this,SLOT(doneSession(TESession*)) );
+  connect( se,SIGNAL(openURLRequest(const QString &)),
+           this,SLOT(emitOpenURLRequest(const QString &)) );
+  connect( se, SIGNAL( updateTitle() ),
+           this, SLOT( updateTitle() ) );
+  connect( se, SIGNAL(enableMasterModeConnections()),
+           this, SLOT(enableMasterModeConnections()) );
+  connect( se, SIGNAL( processExited() ),
+           this, SLOT( slotProcessExited() ) );
+  connect( se, SIGNAL( receivedData( const QString& ) ),
+           this, SLOT( slotReceivedData( const QString& ) ) );
+
+  // We ignore the following signals
+  //connect( se, SIGNAL(renameSession(TESession*,const QString&)),
+  //         this, SLOT(slotRenameSession(TESession*, const QString&)) );
+  //connect( se->getEmulation(), SIGNAL(changeColumns(int)),
+  //         this, SLOT(changeColumns(int)) );
+  //connect( se, SIGNAL(disableMasterModeConnections()),
+  //        this, SLOT(disableMasterModeConnections()) );
+
+  if (b_histEnabled && m_histSize)
+    se->setHistory(HistoryTypeBuffer(m_histSize));
+  else if (b_histEnabled && !m_histSize)
+    se->setHistory(HistoryTypeFile());
+  else
+    se->setHistory(HistoryTypeNone());
+  se->setKeymapNo(n_keytab);
+  KConfig* config = new KConfig("konsolerc",true);
+  config->setGroup("UTMP");
+  se->setAddToUtmp( config->readBoolEntry("AddToUtmp",true));
+  delete config;
+
+  se->setConnect(true);
+  se->setSchemaNo(curr_schema);
+  se->run();
+  connect( se, SIGNAL( destroyed() ), this, SLOT( sessionDestroyed() ) );
+  setFont( n_font ); // we do this here, to make TEWidget recalculate
+                     // its geometry..
+  te->emitText( QString::fromLatin1( "\014" ) );
+}
+
+void konsolePart::showShellInDir( const QString& dir )
+{
+  if ( ! m_runningShell )
+  {
+    const char* s = sensibleShell();
+    QStrList args;
+    args.append( s );
+    startProgram( s, args );
+    m_runningShell = true;
+  };
+
+  if ( ! dir.isNull() )
+  {
+      QString text = dir;
+      KRun::shellQuote(text);
+      text = QString::fromLatin1("cd ") + text + '\n';
+      te->emitText( text );
+  };
+}
+
+void konsolePart::showShell()
+{
+    if ( ! se ) showShellInDir( QString::null );
+}
+
+void konsolePart::sendInput( const QString& text )
+{
+    te->emitText( text );
+}
+
+void konsolePart::slotProcessExited()
+{
+    emit processExited();
+}
+void konsolePart::slotReceivedData( const QString& s )
+{
+    emit receivedData( s );
+}
+
 #include "konsole_part.moc"
