@@ -192,6 +192,11 @@ private:
   bool           zmodemBusy;
   KProcIO*       zmodemProc;
   ZModemDialog*  zmodemProgress;
+
+  // Color/Font Changes by ESC Sequences
+
+  QColor         modifiedBackground; // as set by: echo -en '\033]11;Color\007
+
 };
 
 #endif
