@@ -29,11 +29,12 @@
 #include <krun.h>
 #include <kkeynative.h>
 #include <kdebug.h>
+#include <kiconloader.h>
 
 #include "kospage.h"
 
 KOSPage::KOSPage(QWidget *parent, const char *name ) : KOSPageDlg(parent,name) {
-	px_osSidebar->setPixmap(locate("data", "kpersonalizer/pics/step2.png"));
+	px_osSidebar->setPixmap(UserIcon("step2.png"));
 	// initialize the textview with the default description - KDE of course
 	slotKDEDescription();
 	// Set the configfiles
@@ -88,9 +89,6 @@ void KOSPage::save(bool currSettings){
 	/// restart kwin  for window effects
 	kapp->dcopClient()->send("kwin*", "", "reconfigure()", "");
 	///////////////////////////////////////////
-	/// restart klipper
-	kapp->dcopClient()->send("klipper", "klipper", "quitProcess()", "");
-	KRun::runCommand("klipper", "klipper", "klipper.png");
 }
 
 
@@ -102,19 +100,19 @@ void KOSPage::saveCheckState(bool currSettings){
 		// write the settings to the configfiles, depending on wich radiobutton is checked
 		if(rb_kde->isChecked()){
 			writeKDE();
-			emit selectedOS("KDE");	// send a signal to be catched by the KStylePage to set the according style by default depending on the OS selection
+			emit selectedOS("KDE");	// send a signal to be caught by the KStylePage to set the according style by default depending on the OS selection
 		}
 		else if(rb_unix->isChecked()){
 			writeUNIX();
-			emit selectedOS("CDE");	// send a signal to be catched by the KStylePage to set the according style by default depending on the OS selection
+			emit selectedOS("CDE");	// send a signal to be caught by the KStylePage to set the according style by default depending on the OS selection
 		}
 		else if(rb_windows->isChecked()){
 			writeWindows();
-			emit selectedOS("win");	// send a signal to be catched by the KStylePage to set the according style by default depending on the OS selection
+			emit selectedOS("win");	// send a signal to be caught by the KStylePage to set the according style by default depending on the OS selection
 		}
 		else if(rb_mac->isChecked()){
 			writeMacOS();
-			emit selectedOS("mac");	// send a signal to be catched by the KStylePage to set the according style by default depending on the OS selection
+			emit selectedOS("mac");	// send a signal to be caught by the KStylePage to set the according style by default depending on the OS selection
 		}
 	}
 	else {  // User has pressed "cancel & dismiss", so his old settings are written back
@@ -302,9 +300,9 @@ void KOSPage::writeKeyEntrys(QString keyfile){
 	// load the default .kksrc - file
 	KSimpleConfig* defScheme = new KSimpleConfig(locate("keys", "kde3.kksrc"), true);
 
-	// we need the entrys from the default - file, so we can compare with them
+	// we need the entries from the default - file, so we can compare with them
 	QMap<QString, QString> defMap = defScheme->entryMap("Global Shortcuts");
-	// first delete the group in kdeglobals, then write the non-default entrys from the global .kksrc - file
+	// first delete the group in kdeglobals, then write the non-default entries from the global .kksrc - file
 	cglobal->deleteGroup("Global Shortcuts", true, true);
 	// get the Global - Shortcuts and write them to kdeglobals
 	cglobal->setGroup("Global Shortcuts");
@@ -317,9 +315,9 @@ void KOSPage::writeKeyEntrys(QString keyfile){
 		}
 	}
 
-	// we need the entrys from the default - file, so we can compare with them
+	// we need the entries from the default - file, so we can compare with them
 	defMap = defScheme->entryMap("Shortcuts");
-	// first delete the group in kdeglobals, then write the non-default entrys from the global .kksrc - file
+	// first delete the group in kdeglobals, then write the non-default entries from the global .kksrc - file
 	cglobal->deleteGroup("Shortcuts", true, true);
 	cglobal->setGroup("Shortcuts");
 	givenMap = scheme->entryMap("Shortcuts");
