@@ -56,9 +56,13 @@ KStylePage::KStylePage(QWidget *parent, const char *name ) : KStylePageDlg(paren
 	kde->setText( 1, i18n( "KDE default style" ) );
 
 	classic = new QListViewItem( klv_styles);
-	classic->setText( 0, i18n( "KDE classic" ) );
+	classic->setText( 0, i18n( "KDE Classic" ) );
 	classic->setText( 1, i18n( "Classic KDE style" ) );
 
+	plastik = new QListViewItem( klv_styles );
+	plastik->setText( 0, i18n( "Plastik" ) );
+	plastik->setText( 1, i18n( "A modern, yet simple style" ) );
+
 	cde = new QListViewItem( klv_styles);
 	cde->setText( 0, i18n( "Sunshine" ) );
 	cde->setText( 1, i18n( "A very common desktop" ) );
@@ -121,6 +125,8 @@ void KStylePage::saveKWin(bool curSettings){
 			kdf = new KDesktopFile(kstd->findResource("data", "kwin/redmond.desktop"));
 		else if (platinum->isSelected() && kwin_system_exist)
 			kdf = new KDesktopFile(kstd->findResource("data", "kwin/system.desktop"));
+		else if (plastik->isSelected() && kwin_plastik_exist)
+			kdf = new KDesktopFile(kstd->findResource("data", "kwin/plastik.desktop"));
 		else if (kde->isSelected()) {
 			if (kwin_keramik_exist && (QColor::numBitPlanes() > 8))
 				kdf = new KDesktopFile(kstd->findResource("data", "kwin/keramik.desktop"));
@@ -213,7 +219,7 @@ void KStylePage::saveColors(bool curSettings){
 void KStylePage::saveIcons(bool curSettings) {
 	QString theme = origIcons;
 	if (curSettings) {
-		if ( (kde->isSelected() || platinum->isSelected())
+		if ( (kde->isSelected() || platinum->isSelected() || plastik->isSelected())
 			&& icon_crystalsvg_exist)
 				theme = "crystalsvg";
 		else if ( (classic->isSelected() || cde->isSelected() || win->isSelected())
@@ -258,6 +264,9 @@ void KStylePage::changeCurrentStyle() {
 	else if (platinum->isSelected() && platinum_exist) {
 		currentStyle="Platinum";
 	}
+	else if (plastik->isSelected() && kde_plastik_exist) {
+		currentStyle="Plastik";
+	}
 	else if (classic->isSelected()) {
 		// Use the highcolor style if the display supports it
 		if ( (QColor::numBitPlanes() > 8) && kde_hc_exist ) {
@@ -328,6 +337,12 @@ void KStylePage::getColors(colorSet *set, bool colorfile ){
 			set->usrCol2.setNamedColor ("#C0C0C0");
 			set->colorFile=locate("colors", "KDETwo.kcsrc");
 		}
+		else if(plastik->isSelected()){
+			set->bgMode="VerticalGradient";
+			set->usrCol1.setNamedColor("#2A569D");
+			set->usrCol2.setNamedColor("#6C8BB9");
+			set->colorFile=locate("colors","Plastik.kcsrc");
+		}
 		else if(cde->isSelected()){
 			set->bgMode="Flat";
 			set->usrCol1.setNamedColor("#718BA5");
@@ -398,12 +413,13 @@ void KStylePage::getColors(colorSet *set, bool colorfile ){
 void KStylePage::getAvailability() {
 	// test, wich styles are available
 	kde_keramik_exist = kde_hc_exist = kde_def_exist = cde_exist
-					  = win_exist = platinum_exist = false;
+		= kde_plastik_exist = win_exist = platinum_exist = false;
 	QStringList styles = QStyleFactory::keys();
 	for (QStringList::iterator it = styles.begin(); it != styles.end(); it++) {
 		if (*it == "Keramik") kde_keramik_exist = true;
 		else if (*it == "HighColor") kde_hc_exist = true;
 		else if (*it == "Default") kde_def_exist = true;
+		else if (*it == "Plastik") kde_plastik_exist = true;
 		else if (*it == "Motif") cde_exist = true;
 		else if (*it == "Windows") win_exist = true;
 		else if (*it == "Platinum") platinum_exist = true;
@@ -412,17 +428,20 @@ void KStylePage::getAvailability() {
 	// and disable the ListItems, if they are not.
 	if ( !(kde_keramik_exist || kde_light_exist) ) kde->setVisible(false);
 	if ( !(kde_hc_exist || kde_def_exist) ) classic->setVisible(false);
+	if (!kde_plastik_exist || QPixmap::defaultDepth() <= 8) plastik->setVisible(false);
 	if (!cde_exist) cde->setVisible(false);
 	if (!win_exist) win->setVisible(false);
 	if (!platinum_exist) platinum->setVisible(false);
 
 	// test, wich KWin-styles are available
-	kwin_keramik_exist = kwin_system_exist
+	kwin_keramik_exist = kwin_system_exist = kwin_plastik_exist
 			= kwin_default_exist = kwin_win_exist
 			= kwin_cde_exist = kwin_quartz_exist = false;
 	KStandardDirs* kstd = KGlobal::dirs();
 	if (!kstd->findResource("data", "kwin/keramik.desktop").isNull())
 		kwin_keramik_exist = true;
+	if (!kstd->findResource("data", "kwin/plastik.desktop").isNull())
+		kwin_plastik_exist = true;
 	if (!kstd->findResource("data", "kwin/system.desktop").isNull())
 		kwin_system_exist = true;
 	if (!kstd->findResource("data", "kwin/redmond.desktop").isNull())
@@ -493,13 +512,6 @@ void KStylePage::liveUpdate() {
 	}
 	// tell all apps about the changed style
 	KIPC::sendMessageAll(KIPC::StyleChanged);
-	// color-stuff
-	QApplication::setOverrideCursor( waitCursor );
-	QStringList args;
-	args.append("style");
-	kapp->kdeinitExecWait("kcminit", args);
-	QApplication::restoreOverrideCursor();
-	QApplication::flushX();
 	// color palette changes
 	KIPC::sendMessageAll(KIPC::PaletteChanged);
 	// kwin-style
