@@ -43,18 +43,18 @@ void usage(char *name)
 				"Any arguments (except -setup) are passed on to the screen saver.").arg( name ).local8Bit().data());
 }
 
-static const char *appName = "random";
+static const char appName[] = "random";
 
-static const char *description = I18N_NOOP("Start a random KDE screen saver");
+static const char description[] = I18N_NOOP("Start a random KDE screen saver");
 
-static const char *version = "2.0.0";
+static const char version[] = "2.0.0";
 
 static const KCmdLineOptions options[] =
 {
-	{ "setup", I18N_NOOP("Setup screen saver."), 0 },
-	{ "window-id wid", I18N_NOOP("Run in the specified XWindow."), 0 },
-	{ "root", I18N_NOOP("Run in the root XWindow."), 0 },
-	//  { "+-- [options]", I18N_NOOP("Options to pass to the screen saver."), 0 }
+	{ "setup", I18N_NOOP("Setup screen saver"), 0 },
+	{ "window-id wid", I18N_NOOP("Run in the specified XWindow"), 0 },
+	{ "root", I18N_NOOP("Run in the root XWindow"), 0 },
+	//  { "+-- [options]", I18N_NOOP("Options to pass to the screen saver"), 0 }
 	KCmdLineLastOption
 };
 
@@ -104,44 +104,49 @@ int main(int argc, char *argv[])
 	KConfig type("krandom.kssrc");
 	type.setGroup("Settings");
 	bool opengl = type.readBoolEntry("OpenGL");
-	bool manipulatescreen = type.readBoolEntry("ManipulateScreen"); 
+	bool manipulatescreen = type.readBoolEntry("ManipulateScreen");
+        bool fortune = !KStandardDirs::findExe("fortune").isEmpty();
 
 	for (uint i = 0; i < tempSaverFileList.count(); i++)
 	{
 		kdDebug() << "Looking at " << tempSaverFileList[i] << endl;
 		KDesktopFile saver(tempSaverFileList[i], true);
-		if (saver.readEntry("X-KDE-Type").utf8())
+		kdDebug() << "read X-KDE-Type" << endl;
+		QString saverType = saver.readEntry("X-KDE-Type");
+		if (saverType.isEmpty()) // no X-KDE-Type defined so must be OK
 		{
-			kdDebug() << "read X-KDE-Type" << endl;
-			QString saverType = saver.readEntry("X-KDE-Type").utf8();
-			if (saverType.isEmpty()) // no X-KDE-Type defined so must be OK
+			saverFileList.append(tempSaverFileList[i]);
+		}
+		else
+		{
+			QStringList saverTypes = QStringList::split(";", saverType);
+			for (QStringList::ConstIterator it =  saverTypes.begin(); it != saverTypes.end(); ++it )
 			{
-				saverFileList.append(tempSaverFileList[i]);
-			}
-			else
-			{
-				QStringList saverTypes = QStringList::split(";", saverType);
-				for (uint i = 0; i < saverTypes.count(); i++)
+				kdDebug() << "saverTypes is "<< *it << endl;
+				if (*it == "ManipulateScreen")
 				{
-					kdDebug() << "saverTypes is "<< saverTypes[i] << endl;
-					if (saverTypes[i] == "ManipulateScreen")
+					if (manipulatescreen)
 					{
-						if (manipulatescreen)
-						{
-							saverFileList.append(tempSaverFileList[i]);
-						}
+						saverFileList.append(tempSaverFileList[i]);
 					}
-					else
-					if (saverTypes[i] == "OpenGL")
+				}
+				else
+				if (*it == "OpenGL")
+				{
+					if (opengl)
 					{
-						if (opengl)
-						{
-							saverFileList.append(tempSaverFileList[i]);
-						}
+						saverFileList.append(tempSaverFileList[i]);
+					}
+				}
+				if (*it == "Fortune")
+				{
+					if (fortune)
+					{
+						saverFileList.append(tempSaverFileList[i]);
 					}
 				}
-			}
 
+			}
 		}
 	}
 
