@@ -130,21 +130,39 @@ void KSMClient::resetState()
  * client ID, so we fake one.
  */
 static KStaticDeleter<QString> smy_addr;
-char * safeSmsGenerateClientID( SmsConn c )
+char * safeSmsGenerateClientID( SmsConn /*c*/ )
 {
-    char *ret = SmsGenerateClientID(c);
+//  Causes delays with misconfigured network :-/.
+//    char *ret = SmsGenerateClientID(c);
+    char* ret = NULL;
     if (!ret) {
         static QString *my_addr = 0;
        if (!my_addr) {
-           qWarning("Can't get own host name. Your system is severely misconfigured\n");
+//           qWarning("Can't get own host name. Your system is severely misconfigured\n");
            smy_addr.setObject(my_addr,new QString);
 
            /* Faking our IP address, the 0 below is "unknown" address format
               (1 would be IP, 2 would be DEC-NET format) */
-           my_addr->sprintf("0%.8x", KApplication::random());
+           char hostname[ 256 ];
+           if( gethostname( hostname, 255 ) != 0 )
+               my_addr->sprintf("0%.8x", KApplication::random());
+           else {
+               // create some kind of hash for the hostname
+               int addr[ 4 ] = { 0, 0, 0, 0 };
+               int pos = 0;
+               for( unsigned int i = 0;
+                    i < strlen( hostname );
+                    ++i, ++pos )
+                  addr[ pos % 4 ] += hostname[ i ];
+               *my_addr = "0";
+               for( int i = 0;
+                    i < 4;
+                    ++i )
+                  *my_addr += QString::number( addr[ i ], 16 );
+           }
        }
        /* Needs to be malloc(), to look the same as libSM */
-       ret = (char *)malloc(1+9+13+10+4+1 + /*safeness*/ 10);
+       ret = (char *)malloc(1+my_addr->length()+13+10+4+1 + /*safeness*/ 10);
        static int sequence = 0;
 
        if (ret == NULL)
@@ -896,7 +914,7 @@ void KSMServer::deleteClient( KSMClient* client )
     delete client;
     if ( state == Shutdown || state == Checkpoint )
         completeShutdownOrCheckpoint();
-    if ( state == Killing )
+    if ( state == Killing || state == Killing2 )
         completeKilling();
 }
 
@@ -956,6 +974,8 @@ void KSMServer::shutdown( KApplication::ShutdownConfirm confirm,
         (confirm == KApplication::ShutdownConfirmYes) ? false :
        (confirm == KApplication::ShutdownConfirmNo) ? true :
                   !config->readBoolEntry( "confirmLogout", true );
+    if (!config->readBoolEntry( "offerShutdown", true ))
+        maysd = false;
     if (sdtype == KApplication::ShutdownTypeDefault)
         sdtype = (KApplication::ShutdownType)
                  config->readNumEntry( "shutdownType", (int)KApplication::ShutdownTypeNone );
@@ -1238,7 +1258,7 @@ void KSMServer::completeShutdownOrCheckpoint()
         kdDebug( 1218 ) << " We killed all clients. We have now clients.count()=" <<
            clients.count() << endl;
         completeKilling();
-        QTimer::singleShot( 4000, kapp, SLOT( quit() ) );
+        QTimer::singleShot( 4000, this, SLOT( timeoutQuit() ) );
     } else if ( state == Checkpoint ) {
         state = Idle;
     }
@@ -1248,7 +1268,7 @@ void KSMServer::completeKilling()
 {
     kdDebug( 1218 ) << "KSMServer::completeKilling clients.count()=" <<
         clients.count() << endl;
-    if ( state != Killing ) {
+    if ( state != Killing && state != Killing2 ) {
         //      kdWarning() << "Not Killing !!! state=" << state << endl;
         return;
     }
@@ -1256,17 +1276,44 @@ void KSMServer::completeKilling()
     if ( clients.isEmpty() ) {
         kapp->quit();
     } else {
-        for (KSMClient *c = clients.first(); c; c = clients.next()) {
-            if (! c->wasPhase2)
-                return;
+        if( state == Killing ) {
+            for (KSMClient *c = clients.first(); c; c = clients.next()) {
+                if (! c->wasPhase2)
+                    return;
+            }
+            // the wm was not killed yet, do it
+            for (KSMClient *c = clients.first(); c; c = clients.next()) {
+                SmsDie( c->connection() );
+            }
         }
-        // the wm was not killed yet, do it
-        for (KSMClient *c = clients.first(); c; c = clients.next()) {
-            SmsDie( c->connection() );
+        else {
+            for (KSMClient *c = clients.first(); c; c = clients.next()) {
+                if (c->wasPhase2)
+                    return;
+            }
+            // only clients from first phase of killing remain, don't time out
+            // second time just because of them
         }
     }
 }
 
+void KSMServer::timeoutQuit()
+{
+    state = Killing2;
+    bool kill_phase2 = false;
+    for (KSMClient *c = clients.first(); c; c = clients.next()) {
+        if (c->wasPhase2) {
+            kill_phase2 = true;
+            SmsDie( c->connection() );
+        } else {
+            kdWarning( 1218 ) << "SmsDie timeout, client " << c->program() << "(" << c->clientId() << ")" << endl;
+        }
+    }
+    if( !kill_phase2 )
+        kapp->quit();
+    QTimer::singleShot( 4000, kapp, SLOT( quit() ) );
+}
+
 void KSMServer::discardSession()
 {
     KConfig* config = KGlobal::config();
@@ -1829,9 +1876,11 @@ QString KSMServer::windowWmClientMachine(WId w)
             hostnamebuf[sizeof(hostnamebuf)-1] = 0;
             if (result == hostnamebuf)
                 result = "localhost";
-            char *dot = strchr(hostnamebuf, '.');
-            if (dot && !(*dot = 0) && result == hostnamebuf)
-                result = "localhost";
+            if(char *dot = strchr(hostnamebuf, '.')) {
+                *dot = '\0';
+                if(result == hostnamebuf)
+                    result = "localhost";
+            }
         }
     }
     return QString::fromLatin1(result);
