@@ -9,8 +9,7 @@ Copyright (C) 2000 Matthias Ettrich <ettrich@kde.org>
 
 #include <qpixmap.h>
 #include <qdialog.h>
-#include <qradiobutton.h>
-class QCheckBox;
+class QPushButton;
 class QVButtonGroup;
 
 #include <kapplication.h>
@@ -25,29 +24,16 @@ public:
     static void stop() { delete s_pSelf; s_pSelf = 0L; }
     static KSMShutdownFeedback * self() { return s_pSelf; }
 
-
 protected:
     ~KSMShutdownFeedback() {}
 
+private slots:
+    void slotPaintEffect();
+
 private:
-    void paintEvent( QPaintEvent* );
     static KSMShutdownFeedback * s_pSelf;
     KSMShutdownFeedback();
-};
-
-// A radiobutton with a dblclk signal
-class KSMRadioButton : public QRadioButton
-{
-	Q_OBJECT
-
-public:
-	KSMRadioButton (const QString &text, QWidget *parent, const char *name = 0L);
-
-private:
-	virtual void mouseDoubleClickEvent (QMouseEvent *pe);
-	
-signals:
-	void doubleClicked();
+    int m_currentY;
 };
 
 // The confirmation dialog
@@ -59,14 +45,16 @@ public:
     static bool confirmShutdown( bool maysd, bool maynuke, KApplication::ShutdownType& sdtype, KApplication::ShutdownMode& sdmode );
 
 public slots:
-    void slotSdMode(int);
+    void slotLogout();
+    void slotHalt();
+    void slotReboot();
 
 protected:
     ~KSMShutdownDlg() {};
 
 private:
     KSMShutdownDlg( QWidget* parent, bool maysd, bool maynuke, KApplication::ShutdownType sdtype, KApplication::ShutdownMode sdmode );
-    QRadioButton *rLogout, *rHalt, *rReboot;
+    KApplication::ShutdownType m_shutdownType;
 #if 0
     , *rSched, *rTry, *rForce;
     QVButtonGroup *mgrp;
