@@ -1,8 +1,8 @@
 /*
     KSysGuard, the KDE System Guard
-   
+
 	Copyright (c) 2001 Tobias Koenig <tokoe@kde.org>
-    
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of version 2 of the GNU General Public
     License as published by the Free Software Foundation.
@@ -14,9 +14,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-	$Id: LogFile.cc,v 1.3 2002/10/13 22:52:03 tokoe Exp $
 */
 
 #include <stdio.h>
@@ -25,6 +24,9 @@
 #include <qpushbutton.h>
 #include <qregexp.h>
 
+#include <qfile.h>
+#include <qlistbox.h>
+
 #include <kfontdialog.h>
 #include <kdebug.h>
 #include <klocale.h>
@@ -39,17 +41,17 @@ LogFile::LogFile(QWidget *parent, const char *name, const QString& title)
 {
 	monitor = new QListBox(this);
 	Q_CHECK_PTR(monitor);
-	
+
 	setMinimumSize(50, 25);
 
-	registerPlotterWidget(monitor);
+	setPlotterWidget(monitor);
 
 	setModified(false);
 }
 
 LogFile::~LogFile(void)
 {
-	sendRequest(sensors.at(0)->hostName, QString("logfile_unregister %1" ).arg(logFileID), 43);
+	sendRequest(sensors().at(0)->hostName(), QString("logfile_unregister %1" ).arg(logFileID), 43);
 }
 
 bool
@@ -62,10 +64,10 @@ LogFile::addSensor(const QString& hostName, const QString& sensorName, const QSt
 
 	QString sensorID = sensorName.right(sensorName.length() - (sensorName.findRev("/") + 1));
 
-	sendRequest(sensors.at(0)->hostName, QString("logfile_register %1" ).arg(sensorID), 42);
+	sendRequest(sensors().at(0)->hostName(), QString("logfile_register %1" ).arg(sensorID), 42);
 
 	if (title.isEmpty())
-		setTitle(sensors.at(0)->hostName + ":" + sensorID);
+		setTitle(sensors().at(0)->hostName() + ":" + sensorID);
 	else
 		setTitle(title);
 
@@ -75,21 +77,21 @@ LogFile::addSensor(const QString& hostName, const QString& sensorName, const QSt
 }
 
 
-void LogFile::settings(void)
+void LogFile::configureSettings(void)
 {
 	QColorGroup cgroup = monitor->colorGroup();
 
 	lfs = new LogFileSettings(this);
 	Q_CHECK_PTR(lfs);
-	
+
 	lfs->fgColor->setColor(cgroup.text());
 	lfs->fgColor->setText(i18n("Foreground color:"));
 	lfs->bgColor->setColor(cgroup.base());
 	lfs->bgColor->setText(i18n("Background color:"));
 	lfs->fontButton->setFont(monitor->font());
 	lfs->ruleList->insertStringList(filterRules);
-	lfs->title->setText(getTitle());
-	
+	lfs->title->setText(title());
+
 	connect(lfs->okButton, SIGNAL(clicked()), lfs, SLOT(accept()));
 	connect(lfs->applyButton, SIGNAL(clicked()), this, SLOT(applySettings()));
 	connect(lfs->cancelButton, SIGNAL(clicked()), lfs, SLOT(reject()));
@@ -147,13 +149,13 @@ void LogFile::applySettings(void)
 {
 	QColorGroup cgroup = monitor->colorGroup();
 
-	cgroup.setColor(QColorGroup::Text, lfs->fgColor->getColor());
-	cgroup.setColor(QColorGroup::Base, lfs->bgColor->getColor());
+	cgroup.setColor(QColorGroup::Text, lfs->fgColor->color());
+	cgroup.setColor(QColorGroup::Base, lfs->bgColor->color());
 	monitor->setPalette(QPalette(cgroup, cgroup, cgroup));
 	monitor->setFont(lfs->fontButton->font());
 
 	filterRules.clear();
-	for (int i = 0; i < lfs->ruleList->count(); i++)
+	for (uint i = 0; i < lfs->ruleList->count(); i++)
 		filterRules.append(lfs->ruleList->text(i));
 
 	setTitle(lfs->title->text());
@@ -166,26 +168,26 @@ LogFile::applyStyle()
 {
 	QColorGroup cgroup = monitor->colorGroup();
 
-	cgroup.setColor(QColorGroup::Text, KSGRD::Style->getFgColor1());
-	cgroup.setColor(QColorGroup::Base, KSGRD::Style->getBackgroundColor());
+	cgroup.setColor(QColorGroup::Text, KSGRD::Style->firstForegroundColor());
+	cgroup.setColor(QColorGroup::Base, KSGRD::Style->backgroundColor());
 	monitor->setPalette(QPalette(cgroup, cgroup, cgroup));
 
 	setModified(true);
 }
 
 bool
-LogFile::createFromDOM(QDomElement& element)
+LogFile::restoreSettings(QDomElement& element)
 {
 	QFont font;
 	QColorGroup cgroup = monitor->colorGroup();
 
-	cgroup.setColor(QColorGroup::Text, restoreColorFromDOM(element, "textColor", Qt::green));
-	cgroup.setColor(QColorGroup::Base, restoreColorFromDOM(element, "backgroundColor", Qt::black));
+	cgroup.setColor(QColorGroup::Text, restoreColor(element, "textColor", Qt::green));
+	cgroup.setColor(QColorGroup::Base, restoreColor(element, "backgroundColor", Qt::black));
 	monitor->setPalette(QPalette(cgroup, cgroup, cgroup));
 
 	addSensor(element.attribute("hostName"), element.attribute("sensorName"), (element.attribute("sensorType").isEmpty() ? "logfile" : element.attribute("sensorType")), element.attribute("title"));
 
-	font.setRawName(element.attribute("font"));
+	font.fromString( element.attribute( "font" ) );
 	monitor->setFont(font);
 
 	QDomNodeList dnList = element.elementsByTagName("filter");
@@ -194,7 +196,7 @@ LogFile::createFromDOM(QDomElement& element)
 		filterRules.append(element.attribute("rule"));
 	}
 
-	internCreateFromDOM(element);
+	SensorDisplay::restoreSettings(element);
 
 	setModified(false);
 
@@ -202,16 +204,16 @@ LogFile::createFromDOM(QDomElement& element)
 }
 
 bool
-LogFile::addToDOM(QDomDocument& doc, QDomElement& element, bool save)
+LogFile::saveSettings(QDomDocument& doc, QDomElement& element, bool save)
 {
-	element.setAttribute("hostName", sensors.at(0)->hostName);
-	element.setAttribute("sensorName", sensors.at(0)->name);
-	element.setAttribute("sensorType", sensors.at(0)->type);
+	element.setAttribute("hostName", sensors().at(0)->hostName());
+	element.setAttribute("sensorName", sensors().at(0)->name());
+	element.setAttribute("sensorType", sensors().at(0)->type());
 
-	element.setAttribute("font", monitor->font().rawName());
+	element.setAttribute("font", monitor->font().toString());
 
-	addColorToDOM(element, "textColor", monitor->colorGroup().text());
-	addColorToDOM(element, "backgroundColor", monitor->colorGroup().base());
+	saveColor(element, "textColor", monitor->colorGroup().text());
+	saveColor(element, "backgroundColor", monitor->colorGroup().base());
 
 	for (QStringList::Iterator it = filterRules.begin();
 		 it != filterRules.end(); it++)
@@ -221,7 +223,7 @@ LogFile::addToDOM(QDomDocument& doc, QDomElement& element, bool save)
 		element.appendChild(filter);
 	}
 
-	internAddToDOM(doc, element);
+	SensorDisplay::saveSettings(doc, element);
 
 	if (save)
 		setModified(false);
@@ -232,8 +234,8 @@ LogFile::addToDOM(QDomDocument& doc, QDomElement& element, bool save)
 void
 LogFile::updateMonitor()
 {
-	sendRequest(sensors.at(0)->hostName,
-				QString("%1 %2" ).arg(sensors.at(0)->name).arg(logFileID), 19);
+	sendRequest(sensors().at(0)->hostName(),
+				QString("%1 %2" ).arg(sensors().at(0)->name()).arg(logFileID), 19);
 }
 
 void
@@ -247,7 +249,7 @@ LogFile::answerReceived(int id, const QString& answer)
 		case 19: {
 			KSGRD::SensorTokenizer lines(answer, '\n');
 
-			for (uint i = 0; i < lines.numberOfTokens(); i++) {
+			for (uint i = 0; i < lines.count(); i++) {
 				if (monitor->count() == MAXLINES)
 					monitor->removeItem(0);
 
@@ -256,7 +258,7 @@ LogFile::answerReceived(int id, const QString& answer)
 				for (QStringList::Iterator it = filterRules.begin(); it != filterRules.end(); it++) {
 					QRegExp *expr = new QRegExp((*it).latin1());
 					if (expr->search(lines[i].latin1()) != -1) {
-						KNotifyClient::event("pattern_match", QString("rule '%1' matched").arg((*it).latin1()));
+						KNotifyClient::event(winId(), "pattern_match", QString("rule '%1' matched").arg((*it).latin1()));
 					}
 					delete expr;
 				}
@@ -274,6 +276,6 @@ LogFile::answerReceived(int id, const QString& answer)
 void
 LogFile::resizeEvent(QResizeEvent*)
 {
-	frame->setGeometry(0, 0, this->width(), this->height());
+	frame()->setGeometry(0, 0, this->width(), this->height());
 	monitor->setGeometry(10, 20, this->width() - 20, this->height() - 30);
 }
