@@ -19,7 +19,6 @@
     KSysGuard is currently maintained by Chris Schlaeger <cs@kde.org>.
     Please do not commit any changes without consulting me first. Thanks!
 
-    $Id: SignalPlotter.h,v 1.5 2004/01/04 13:43:48 waba Exp $
 */
 
 #ifndef KSG_SIGNALPLOTTER_H
@@ -67,7 +66,7 @@ class SignalPlotter : public QWidget
     void setGraphStyle( uint style );
     uint graphStyle() const;
 
-    void setHorizontalScale( int scale );
+    void setHorizontalScale( uint scale );
     int horizontalScale() const;
 
     void setShowVerticalLines( bool value );
