@@ -19,7 +19,6 @@
     KSysGuard is currently maintained by Chris Schlaeger <cs@kde.org>.
     Please do not commit any changes without consulting me first. Thanks!
 
-    $Id: SensorManager.cc,v 1.8 2003/03/07 22:08:24 waba Exp $
 */
 
 #include <qcombobox.h>
@@ -277,7 +276,7 @@ void SensorManager::hostLost( const SensorAgent *agent )
 
   if ( mBroadcaster ) {
     QCustomEvent *event = new QCustomEvent( QEvent::User );
-    event->setData( new QString( i18n( "Connection to %1 has been lost!" )
+    event->setData( new QString( i18n( "Connection to %1 has been lost." )
                     .arg( agent->hostName() ) ) );
     kapp->postEvent( mBroadcaster, event );
   }
