@@ -25,7 +25,6 @@
     Johannes Wuebben <wuebben@math.cornell.edu> and Nicolas Leclercq
     <nicknet@planete.net>.
 
-    $Id: ksysguard.cc,v 1.73.2.2 2004/03/09 14:38:59 waba Exp $
 */
 
 #include <assert.h>
@@ -52,7 +51,6 @@
 #include <kstdaction.h>
 #include <kwin.h>
 #include <kwinmodule.h>
-#include <kkeydialog.h>
 
 #include "../version.h"
 #include "SensorBrowser.h"
@@ -60,7 +58,7 @@
 
 #include "ksysguard.h"
 
-static const char* Description = I18N_NOOP( "KDE System Guard" );
+static const char Description[] = I18N_NOOP( "KDE system guard" );
 TopLevel* topLevel;
 
 /**
@@ -118,34 +116,19 @@ TopLevel::TopLevel( const char *name )
   KStdAction::cut( mWorkSpace, SLOT( cut() ), actionCollection() );
   KStdAction::copy( mWorkSpace, SLOT( copy() ), actionCollection() );
   KStdAction::paste( mWorkSpace, SLOT( paste() ), actionCollection() );
-  new KAction( i18n( "&Work Sheet Properties..." ), "configure", 0, mWorkSpace,
+  new KAction( i18n( "&Worksheet Properties" ), "configure", 0, mWorkSpace,
                SLOT( configure() ), actionCollection(), "configure_sheet" );
 
   KStdAction::revert( this, SLOT( resetWorkSheets() ), actionCollection() );
-  KStdAction::showToolbar( "mainToolBar", actionCollection() );
-  mActionStatusBar = KStdAction::showStatusbar( this, SLOT( showStatusBar() ),
-                                                actionCollection() );
-  mActionStatusBar->setChecked( false );
-
-  KStdAction::configureToolbars( this, SLOT( editToolbars() ), actionCollection() );
-  KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
 
   new KAction( i18n( "Configure &Style..." ), "colorize", 0, this,
                SLOT( editStyle() ), actionCollection(), "configure_style" );
 
-  createGUI();
-
-  resize( 600, 440 );
+  // TODO remove resize and fix so sizeHints() determines default size.
+  resize( 640, 480 );
+  setupGUI();
 }
 
-TopLevel::~TopLevel()
-{
-}
-
-void TopLevel::slotConfigureKeys()
-{
-  KKeyDialog::configure( actionCollection(), this );
-}
 
 /*
  * DCOP Interface functions
@@ -294,6 +277,21 @@ void TopLevel::initStatusBar()
    * answerReceived(). */
   KSGRD::SensorMgr->sendRequest( "localhost", "mem/swap/used?",
                                  (KSGRD::SensorClient*)this, 5 );
+
+  updateStatusBar();
+  
+  KToggleAction *sb = dynamic_cast<KToggleAction*>(action("options_show_statusbar"));
+  if (sb)
+     connect(sb, SIGNAL(toggled(bool)), this, SLOT(updateStatusBar()));
+}
+
+void TopLevel::updateStatusBar()
+{
+  if ( mTimerId == -1 )
+    mTimerId = startTimer( 2000 );
+
+  // call timerEvent to fill the status bar with real values
+  timerEvent( 0 );
 }
 
 void TopLevel::connectHost()
@@ -306,24 +304,6 @@ void TopLevel::disconnectHost()
   mSensorBrowser->disconnect();
 }
 
-void TopLevel::showStatusBar()
-{
-  if ( mActionStatusBar->isChecked() ) {
-    statusBar()->show();
-    if ( mTimerId == -1 )
-      mTimerId = startTimer( 2000 );
-
-    // call timerEvent to fill the status bar with real values
-    timerEvent( 0 );
-  } else {
-    statusBar()->hide();
-    if ( mTimerId != -1 ) {
-      killTimer( mTimerId );
-      mTimerId = -1;
-    }
-  }
-}
-
 void TopLevel::editToolbars()
 {
   saveMainWindowSettings( kapp->config() );
@@ -391,13 +371,6 @@ void TopLevel::readProperties( KConfig *cfg )
      maximized, so we save the coordinates instead */
   if ( cfg->readBoolEntry( "isMinimized" ) == true )
     showMinimized();
-  else {
-    int wx = cfg->readNumEntry( "PosX", 100 );
-    int wy = cfg->readNumEntry( "PosY", 100 );
-    int ww = cfg->readNumEntry( "SizeX", 600 );
-    int wh = cfg->readNumEntry( "SizeY", 375 );
-    setGeometry( wx, wy, ww, wh );
-  }
 
   QValueList<int> sizes = cfg->readIntListEntry( "SplitterSizeList" );
   if ( sizes.isEmpty() ) {
@@ -415,26 +388,15 @@ void TopLevel::readProperties( KConfig *cfg )
   mActionOpenRecent->loadEntries( cfg );
 
   applyMainWindowSettings( cfg );
-
-  if ( !statusBar()->isHidden() ) {
-    mActionStatusBar->setChecked( true );
-    showStatusBar();
-  }
 }
 
 void TopLevel::saveProperties( KConfig *cfg )
 {
   mActionOpenRecent->saveEntries( cfg );
 
-  cfg->writeEntry( "PosX", x() );
-  cfg->writeEntry( "PosY", y() );
-  cfg->writeEntry( "SizeX", width() );
-  cfg->writeEntry( "SizeY", height() );
   cfg->writeEntry( "isMinimized", isMinimized() );
   cfg->writeEntry( "SplitterSizeList", mSplitter->sizes() );
 
-  saveMainWindowSettings( cfg );
-
   KSGRD::Style->saveProperties( cfg );
   KSGRD::SensorMgr->saveProperties( cfg );
 
@@ -571,7 +533,7 @@ int main( int argc, char** argv )
   aboutData.addAuthor( "Alex Sanda", 0, "alex@darkstart.ping.at" );
   aboutData.addAuthor( "Bernd Johannes Wuebben", 0, "wuebben@math.cornell.edu" );
   aboutData.addAuthor( "Ralf Mueller", 0, "rlaf@bj-ig.de" );
-  aboutData.addAuthor( "Hamish Rodda", 0, "meddie@yoyo.cc.monash.edu.au" );
+  aboutData.addAuthor( "Hamish Rodda", 0, "rodda@kde.org" );
   aboutData.addAuthor( "Torsten Kasch", I18N_NOOP( "Solaris Support\n"
                        "Parts derived (by permission) from the sunos5\n"
                        "module of William LeFebvre's \"top\" utility." ),
