@@ -19,7 +19,6 @@
     KSysGuard is currently maintained by Chris Schlaeger <cs@kde.org>. Please do
     not commit any changes without consulting me first. Thanks!
 
-    $Id: ksysguard.h,v 1.23 2003/05/24 14:19:33 mlaurent Exp $
 */
 
 #ifndef KSG_KSYSGUARD_H
@@ -48,7 +47,6 @@ class TopLevel : public KMainWindow, public KSGRD::SensorClient, public DCOPObje
 
   public:
     TopLevel( const char *name = 0 );
-    ~TopLevel();
 
   virtual void saveProperties( KConfig* );
   virtual void readProperties( KConfig* );
@@ -82,18 +80,16 @@ class TopLevel : public KMainWindow, public KSGRD::SensorClient, public DCOPObje
   protected slots:
     void connectHost();
     void disconnectHost();
-    void showStatusBar();
+    void updateStatusBar();
     void editToolbars();
     void editStyle();
     void slotNewToolbarConfig();
-    void slotConfigureKeys();
 
   private:
     QPtrList<DCOPClientTransaction> mDCopFIFO;
 
     QSplitter* mSplitter;
     KRecentFilesAction* mActionOpenRecent;
-    KToggleAction* mActionStatusBar;
 
     SensorBrowser* mSensorBrowser;
     Workspace* mWorkSpace;
