@@ -19,6 +19,7 @@ License. See the file "COPYING" for the exact licensing terms.
 #include "client.h"
 #include "workspace.h"
 
+#include <fixx11h.h>
 #include <qpopupmenu.h>
 #include <kxerrorhandler.h>
 #include <kstartupinfo.h>
@@ -26,6 +27,7 @@ License. See the file "COPYING" for the exact licensing terms.
 #include "notifications.h"
 #include "atoms.h"
 #include "group.h"
+#include "rules.h"
 
 extern Time qt_x_time;
 
@@ -235,6 +237,7 @@ void Workspace::setActiveClient( Client* c, allowed_t )
             focus_chain.append( c );
         active_client->demandAttention( false );
         }
+    pending_take_activity = NULL;
 
     updateCurrentTopMenu();
     updateToolWindows( false );
@@ -297,45 +300,75 @@ void Workspace::activateClient( Client* c, bool force )
   \sa Workspace::activateClient()
  */
 void Workspace::requestFocus( Client* c, bool force )
-    { // the 'if( c == active_client ) return;' optimization mustn't be done here
+    {
+    takeActivity( c, ActivityFocus | ( force ? ActivityFocusForce : 0 ), false);
+    }
+    
+void Workspace::takeActivity( Client* c, int flags, bool handled )
+    {
+     // the 'if( c == active_client ) return;' optimization mustn't be done here
     if (!focusChangeEnabled() && ( c != active_client) )
-        return;
+        flags &= ~ActivityFocus;
 
-    //TODO will be different for non-root clients. (subclassing?)
     if ( !c ) 
         {
         focusToNull();
         return;
         }
 
-    if( !c->isOnCurrentDesktop()) // shouldn't happen, call activateClient() if needed
+    if( flags & ActivityFocus )
         {
-        kdWarning( 1212 ) << "requestFocus: not on current desktop" << endl;
-        return;
+        Client* modal = c->findModal();
+        if( modal != NULL && modal != c )	
+            { 
+            if( !modal->isOnDesktop( c->desktop()))
+                {
+                modal->setDesktop( c->desktop());
+                if( modal->desktop() != c->desktop()) // forced desktop
+                    activateClient( modal );
+                }
+            // if the click was inside the window (i.e. handled is set),
+            // but it has a modal, there's no need to use handled mode, because
+            // the modal doesn't get the click anyway
+            // raising of the original window needs to be still done
+            if( flags & ActivityRaise )
+                raiseClient( c );
+            flags &= ~ActivityRaise;
+            c = modal;
+            handled = false;
+            }
+        cancelDelayFocus();
         }
-
-    Client* modal = c->findModal();
-    if( modal != NULL && modal != c )	
-        { 
-        if( !modal->isOnDesktop( c->desktop())) // move the modal to client's desktop
-            modal->setDesktop( c->isOnAllDesktops() ? currentDesktop() : c->desktop());
-        requestFocus( modal, force );
-        return;
-        }
-    if ( c->isShown( false ) ) 
-        {
-        c->takeFocus( force, Allowed );
-        should_get_focus.append( c );
-        focus_chain.remove( c );
-        if ( c->wantsTabFocus() )
-            focus_chain.append( c );
-        }
-    else if ( c->isShade() && c->wantsInput()) 
+    if ( !( flags & ActivityFocusForce ) && ( c->isTopMenu() || c->isDock() || c->isSplash()) )
+        flags &= ~ActivityFocus; // toplevel menus and dock windows don't take focus if not forced
+    if( c->isShade())
         {
+        if( c->wantsInput() && ( flags & ActivityFocus ))
+            {
         // client cannot accept focus, but at least the window should be active (window menu, et. al. )
-        c->setActive( true );
-        focusToNull();
+            c->setActive( true );
+            focusToNull();
+            }
+        flags &= ~ActivityFocus;
+        handled = false; // no point, can't get clicks
         }
+    if( !c->isShown( true )) // shouldn't happen, call activateClient() if needed
+        {
+        kdWarning( 1212 ) << "takeActivity: not shown" << endl;
+        return;
+        }
+    c->takeActivity( flags, handled, Allowed );
+    }
+
+void Workspace::handleTakeActivity( Client* c, Time /*timestamp*/, int flags )
+    {
+    if( pending_take_activity != c ) // pending_take_activity is reset when doing restack or activation
+        return;
+    if(( flags & ActivityRaise ) != 0 )
+        raiseClient( c );
+    if(( flags & ActivityFocus ) != 0 && c->isShown( false ))
+        c->takeFocus( Allowed );
+    pending_take_activity = NULL;
     }
 
 /*!
@@ -415,10 +448,15 @@ void Workspace::gotFocusIn( const Client* c )
         }
     }
 
+void Workspace::setShouldGetFocus( Client* c )
+    {
+    should_get_focus.append( c );
+    updateStackingOrder(); // e.g. fullscreens have different layer when active/not-active
+    }
 
 // focus_in -> the window got FocusIn event
 // session_active -> the window was active when saving session
-bool Workspace::allowClientActivation( const Client* c, Time time, bool focus_in, bool session_active )
+bool Workspace::allowClientActivation( const Client* c, Time time, bool focus_in )
     {
     // options->focusStealingPreventionLevel :
     // 0 - none    - old KWin behaviour, new windows always get focus
@@ -430,8 +468,8 @@ bool Workspace::allowClientActivation( const Client* c, Time time, bool focus_in
     // 4 - extreme - no window gets focus without user intervention
     if( time == -1U )
         time = c->userTime();
-    if( session_saving
-        && options->focusStealingPreventionLevel <= 2 ) // <= normal
+    int level = c->rules()->checkFSP( options->focusStealingPreventionLevel );
+    if( session_saving && level <= 2 ) // <= normal
         {
         return true;
         }
@@ -446,10 +484,12 @@ bool Workspace::allowClientActivation( const Client* c, Time time, bool focus_in
         }
     if( time == 0 ) // explicitly asked not to get focus
         return false;
-    if( options->focusStealingPreventionLevel == 0 ) // none
+    if( level == 0 ) // none
         return true;
-    if( options->focusStealingPreventionLevel == 4 ) // extreme
+    if( level == 4 ) // extreme
         return false;
+    if( !c->isOnCurrentDesktop())
+        return false; // allow only with level == 0
     if( c->ignoreFocusStealing())
         return true;
     if( ac == NULL || ac->isDesktop())
@@ -463,22 +503,19 @@ bool Workspace::allowClientActivation( const Client* c, Time time, bool focus_in
         kdDebug( 1212 ) << "Activation: Belongs to active application" << endl;
         return true;
         }
-    if( options->focusStealingPreventionLevel == 3 ) // high
+    if( level == 3 ) // high
         return false;
     if( time == -1U )  // no time known
-        if( session_active )
-            return !was_user_interaction; // see Client::readUserTimeMapTimestamp()
-        else
         {
-        kdDebug() << "Activation: No timestamp at all" << endl;
-        if( options->focusStealingPreventionLevel == 1 ) // low
+        kdDebug( 1212 ) << "Activation: No timestamp at all" << endl;
+        if( level == 1 ) // low
             return true;
         // no timestamp at all, don't activate - because there's also creation timestamp
         // done on CreateNotify, this case should happen only in case application
         // maps again already used window, i.e. this won't happen after app startup
         return false; 
         }
-    // options->focusStealingPreventionLevel == 2 // normal
+    // level == 2 // normal
     Time user_time = ac->userTime();
     kdDebug( 1212 ) << "Activation, compared:" << c << ":" << time << ":" << user_time
         << ":" << ( timestampCompare( time, user_time ) >= 0 ) << endl;
@@ -489,17 +526,17 @@ bool Workspace::allowClientActivation( const Client* c, Time time, bool focus_in
 // a window to be fully raised upon its own request (XRaiseWindow),
 // if refused, it will be raised only on top of windows belonging
 // to the same application
-bool Workspace::allowFullClientRaising( const Client* c )
+bool Workspace::allowFullClientRaising( const Client* c, Time time )
     {
-    if( session_saving
-        && options->focusStealingPreventionLevel <= 2 ) // <= normal
+    int level = c->rules()->checkFSP( options->focusStealingPreventionLevel );
+    if( session_saving && level <= 2 ) // <= normal
         {
         return true;
         }
     Client* ac = mostRecentlyActivatedClient();
-    if( options->focusStealingPreventionLevel == 0 ) // none
+    if( level == 0 ) // none
         return true;
-    if( options->focusStealingPreventionLevel == 4 ) // extreme
+    if( level == 4 ) // extreme
         return false;
     if( ac == NULL || ac->isDesktop())
         {
@@ -514,17 +551,12 @@ bool Workspace::allowFullClientRaising( const Client* c )
         kdDebug( 1212 ) << "Raising: Belongs to active application" << endl;
         return true;
         }
-    if( options->focusStealingPreventionLevel == 3 ) // high
+    if( level == 3 ) // high
         return false;
-    if( !c->hasUserTimeSupport())
-        {
-        kdDebug() << "Raising: No support" << endl;
-        if( options->focusStealingPreventionLevel == 1 ) // low
-            return true;
-        }
-    // options->focusStealingPreventionLevel == 2 // normal
-    kdDebug() << "Raising: Refusing" << endl;
-    return false;
+    Time user_time = ac->userTime();
+    kdDebug( 1212 ) << "Raising, compared:" << time << ":" << user_time
+        << ":" << ( timestampCompare( time, user_time ) >= 0 ) << endl;
+    return timestampCompare( time, user_time ) >= 0; // time >= user_time
     }
 
 // called from Client after FocusIn that wasn't initiated by KWin and the client
@@ -636,18 +668,27 @@ KWIN_COMPARE_PREDICATE( SameApplicationActiveHackPredicate, const Client*,
     !cl->isSplash() && !cl->isToolbar() && !cl->isTopMenu() && !cl->isUtility() && !cl->isMenu()
     && Client::belongToSameApplication( cl, value, true ) && cl != value);
 
-Time Client::readUserTimeMapTimestamp( const KStartupInfoData* asn_data,
-    const SessionInfo* session ) const
+Time Client::readUserTimeMapTimestamp( const KStartupInfoId* asn_id, const KStartupInfoData* asn_data,
+    bool session ) const
     {
     Time time = info->userTime();
     kdDebug( 1212 ) << "User timestamp, initial:" << time << endl;
     // newer ASN timestamp always replaces user timestamp, unless user timestamp is 0
     // helps e.g. with konqy reusing
-    if( asn_data != NULL && time != 0
-        && ( time == -1U
-            || ( asn_data->timestamp() != -1U
-                && timestampCompare( asn_data->timestamp(), time ) > 0 )))
-        time = asn_data->timestamp();
+    if( asn_data != NULL && time != 0 )
+        {
+        // prefer timestamp from ASN id (timestamp from data is obsolete way)
+        if( asn_id->timestamp() != 0
+            && ( time == -1U || timestampCompare( asn_id->timestamp(), time ) > 0 ))
+            {
+            time = asn_id->timestamp();
+            }
+        else if( asn_data->timestamp() != -1U
+            && ( time == -1U || timestampCompare( asn_data->timestamp(), time ) > 0 ))
+            {
+            time = asn_data->timestamp();
+            }
+        }
     kdDebug( 1212 ) << "User timestamp, ASN:" << time << endl;
     if( time == -1U )
         { // The window doesn't have any timestamp.
@@ -656,7 +697,7 @@ Time Client::readUserTimeMapTimestamp( const KStartupInfoData* asn_data,
       // use the _KDE_NET_WM_USER_CREATION_TIME trick.
       // Otherwise, refuse activation of a window
       // from already running application if this application
-      // is not the active one.
+      // is not the active one (unless focus stealing prevention is turned off).
         Client* act = workspace()->mostRecentlyActivatedClient();
         if( act != NULL && !belongToSameApplication( act, this, true ))
             {
@@ -677,7 +718,8 @@ Time Client::readUserTimeMapTimestamp( const KStartupInfoData* asn_data,
                 if( workspace()->findClient( SameApplicationActiveHackPredicate( this )))
                     first_window = false;
                 }
-            if( !first_window )
+            // don't refuse if focus stealing prevention is turned off
+            if( !first_window && rules()->checkFSP( options->focusStealingPreventionLevel ) > 0 )
                 {
                 kdDebug( 1212 ) << "User timestamp, already exists:" << 0 << endl;
                 return 0; // refuse activation
@@ -691,8 +733,8 @@ Time Client::readUserTimeMapTimestamp( const KStartupInfoData* asn_data,
         // it's better not to activate the new one.
         // Unless it was the active window at the time
         // of session saving and there was no user interaction yet,
-        // this check will be done in Workspace::allowClientActiovationTimestamp().
-        if( session && !session->fake )
+        // this check will be done in manage().
+        if( session )
             return -1U;
         if( ignoreFocusStealing() && act != NULL )
             time = act->userTime();
@@ -760,15 +802,19 @@ void Client::setActive( bool act)
 
 void Client::startupIdChanged()
     {
+    KStartupInfoId asn_id;
     KStartupInfoData asn_data;
-    bool asn_valid = workspace()->checkStartupNotification( window(), asn_data );
+    bool asn_valid = workspace()->checkStartupNotification( window(), asn_id, asn_data );
     if( !asn_valid )
         return;
     if( asn_data.desktop() != 0 )
         workspace()->sendClientToDesktop( this, asn_data.desktop(), true );
-    if( asn_data.timestamp() != -1U )
+    Time timestamp = asn_id.timestamp();
+    if( timestamp == 0 && asn_data.timestamp() != -1U )
+        timestamp = asn_data.timestamp();
+    if( timestamp != 0 )
         {
-        bool activate = workspace()->allowClientActivation( this, asn_data.timestamp());
+        bool activate = workspace()->allowClientActivation( this, timestamp );
         if( asn_data.desktop() != 0 && !isOnCurrentDesktop())
             activate = false; // it was started on different desktop than current one
         if( activate )
@@ -790,13 +836,21 @@ void Client::updateUrgency()
     
 void Group::startupIdChanged()
     {
+    KStartupInfoId asn_id;
     KStartupInfoData asn_data;
-    bool asn_valid = workspace()->checkStartupNotification( leader_wid, asn_data );
+    bool asn_valid = workspace()->checkStartupNotification( leader_wid, asn_id, asn_data );
     if( !asn_valid )
         return;
-    if( asn_data.timestamp() != -1U && user_time != -1U
-        &&timestampCompare( asn_data.timestamp(), user_time ) > 0 )
+    if( asn_id.timestamp() != 0 && user_time != -1U
+        && timestampCompare( asn_id.timestamp(), user_time ) > 0 )
+        {
+        user_time = asn_id.timestamp();
+        }
+    else if( asn_data.timestamp() != -1U && user_time != -1U
+        && timestampCompare( asn_data.timestamp(), user_time ) > 0 )
+        {
         user_time = asn_data.timestamp();
+        }
     }
 
 void Group::updateUserTime( Time time )
