@@ -27,6 +27,7 @@ License. See the file "COPYING" for the exact licensing terms.
 #include "workspace.h"
 #include "atoms.h"
 #include "notifications.h"
+#include "rules.h"
 
 #include <X11/extensions/shape.h>
 
@@ -111,6 +112,7 @@ Client::Client( Workspace *ws )
     keep_above = FALSE;
     keep_below = FALSE;
     is_shape = FALSE;
+    motif_noborder = false;
     motif_may_move = TRUE;
     motif_may_resize = TRUE;
     motif_may_close = TRUE;
@@ -129,13 +131,12 @@ Client::Client( Workspace *ws )
 
     Pdeletewindow = 0;
     Ptakefocus = 0;
+    Ptakeactivity = 0;
     Pcontexthelp = 0;
     Pping = 0;
     input = FALSE;
-    store_settings = FALSE;
     skip_pager = FALSE;
 
-
     max_mode = MaximizeRestore;
 
     cmap = None;
@@ -156,7 +157,7 @@ Client::~Client()
     assert( frame == None && wrapper == None );
     assert( decoration == NULL );
     assert( block_geometry == 0 );
-//    assert( !check_active_modal );
+    assert( !check_active_modal );
     delete info;
     delete bridge;
     }
@@ -172,8 +173,10 @@ void Client::deleteClient( Client* c, allowed_t )
  */
 void Client::releaseWindow( bool on_shutdown )
     {
+    StackingUpdatesBlocker blocker( workspace());
     if (moveResizeMode)
        leaveMoveResize();
+    finishWindowRules();
     setModal( false ); // otherwise its mainwindow wouldn't get focus
     hidden = true; // so that it's not considered visible anymore (can't use hideClient(), it would set flags)
     if( !on_shutdown )
@@ -219,8 +222,10 @@ void Client::releaseWindow( bool on_shutdown )
 // (e.g. the application closed it)
 void Client::destroyClient()
     {
+    StackingUpdatesBlocker blocker( workspace());
     if (moveResizeMode)
        leaveMoveResize();
+    finishWindowRules();
     ++block_geometry;
     setModal( false );
     hidden = true; // so that it's not considered visible anymore
@@ -289,9 +294,9 @@ void Client::destroyDecoration()
         int save_workarea_diff_x = workarea_diff_x;
         int save_workarea_diff_y = workarea_diff_y;
         if( !isShade())
-            plainResize( clientSize(), ForceGeometrySet );
+            plainResize( sizeForClientSize( clientSize()), ForceGeometrySet );
         else
-            plainResize( QSize( clientSize().width(), 0 ), ForceGeometrySet );
+            plainResize( sizeForClientSize( QSize( clientSize().width(), 0 ), SizemodeShaded ), ForceGeometrySet );
         move( grav );
         workarea_diff_x = save_workarea_diff_x;
         workarea_diff_y = save_workarea_diff_y;
@@ -322,9 +327,9 @@ void Client::checkBorderSizes()
 
 void Client::detectNoBorder()
     {
-    if( Shape::hasShape( window()) || Motif::noBorder( window()))
+    if( Shape::hasShape( window()))
         {
-        noborder = true; // TODO for all window types?
+        noborder = true;
         return;
         }
     switch( windowType())
@@ -380,7 +385,7 @@ void Client::resizeDecoration( const QSize& s )
 
 bool Client::noBorder() const
     {
-    return noborder || isFullScreen() || user_noborder;
+    return noborder || isFullScreen() || user_noborder || motif_noborder;
     }
 
 bool Client::userCanSetNoBorder() const
@@ -397,10 +402,12 @@ void Client::setUserNoBorder( bool set )
     {
     if( !userCanSetNoBorder())
         return;
+    set = rules()->checkNoBorder( set );
     if( user_noborder == set )
         return;
     user_noborder = set;
     updateDecoration( true, false );
+    updateWindowRules();
     }
 
 void Client::updateShape()
@@ -486,7 +493,7 @@ bool Client::isMinimizable() const
     {
     if( isSpecialWindow() && !isOverride())
         return false;
-    if( isTransient() && !wantsTabFocus())
+    if( isTransient())
         { // #66868 - let other xmms windows be minimized when the mainwindow is minimized
         bool shown_mainwindow = false;
         ClientList mainclients = mainClients();
@@ -513,7 +520,7 @@ bool Client::isMinimizable() const
 /*!
   Minimizes this client plus its transients
  */
-void Client::minimize()
+void Client::minimize( bool avoid_animation )
     {
     if ( !isMinimizable() || isMinimized())
         return;
@@ -523,7 +530,7 @@ void Client::minimize()
     Notify::raise( Notify::Minimize );
 
     // SELI mainClients().isEmpty() ??? - and in unminimize() too
-    if ( mainClients().isEmpty() && isOnCurrentDesktop())
+    if ( mainClients().isEmpty() && isOnCurrentDesktop() && !avoid_animation )
         animateMinimizeOrUnminimize( true ); // was visible or shaded
 
     setMappingState( IconicState );
@@ -531,9 +538,10 @@ void Client::minimize()
     rawHide();
     updateAllowedActions();
     workspace()->updateMinimizedOfTransients( this );
+    updateWindowRules();
     }
 
-void Client::unminimize()
+void Client::unminimize( bool avoid_animation )
     {
     if( !isMinimized())
         return;
@@ -543,7 +551,7 @@ void Client::unminimize()
     info->setState( 0, NET::Hidden );
     if( isOnCurrentDesktop())
         {
-        if( mainClients().isEmpty())
+        if( mainClients().isEmpty() && !avoid_animation )
             animateMinimizeOrUnminimize( FALSE );
         if( isShown( false ))
             setMappingState( NormalState );
@@ -551,6 +559,7 @@ void Client::unminimize()
         }
     updateAllowedActions();
     workspace()->updateMinimizedOfTransients( this );
+    updateWindowRules();
     }
 
 extern bool         blockAnimation;
@@ -684,13 +693,18 @@ void Client::setShade( ShadeMode mode )
     {
     if( !isShadeable())
         return;
+    mode = rules()->checkShade( mode );
     if( shade_mode == mode )
         return;
     bool was_shade = isShade();
     ShadeMode was_shade_mode = shade_mode;
     shade_mode = mode;
     if( was_shade == isShade())
+        {
+        if( decoration != NULL ) // decoration may want to update after e.g. hover-shade changes
+            decoration->shadeChange();
         return; // no real change in shaded state
+        }
 
     if( shade_mode == ShadeNormal )
         {
@@ -779,6 +793,7 @@ void Client::setShade( ShadeMode mode )
     updateAllowedActions();
     workspace()->updateMinimizedOfTransients( this );
     decoration->shadeChange();
+    updateWindowRules();
     }
 
 void Client::shadeHover()
@@ -884,7 +899,7 @@ void Client::rawHide()
     workspace()->clientHidden( this );
     }
 
-static void sendClientMessage(Window w, Atom a, long x)
+void Client::sendClientMessage(Window w, Atom a, Atom protocol, long data1, long data2, long data3)
     {
     XEvent ev;
     long mask;
@@ -894,8 +909,11 @@ static void sendClientMessage(Window w, Atom a, long x)
     ev.xclient.window = w;
     ev.xclient.message_type = a;
     ev.xclient.format = 32;
-    ev.xclient.data.l[0] = x;
+    ev.xclient.data.l[0] = protocol;
     ev.xclient.data.l[1] = qt_x_time;
+    ev.xclient.data.l[2] = data1;
+    ev.xclient.data.l[3] = data2;
+    ev.xclient.data.l[4] = data3;
     mask = 0L;
     if (w == qt_xrootwin())
       mask = SubstructureRedirectMask;        /* magic! */
@@ -907,7 +925,7 @@ static void sendClientMessage(Window w, Atom a, long x)
  */
 bool Client::isCloseable() const
     {
-    return motif_may_close && ( !isSpecialWindow() || isOverride()); // TODO is NET::Override special?
+    return rules()->checkCloseable( motif_may_close && ( !isSpecialWindow() || isOverride())); // TODO is NET::Override special?
     }
 
 /*!
@@ -965,11 +983,13 @@ void Client::pingWindow()
     {
     if( !Pping )
         return; // can't ping :(
+    if( options->killPingTimeout == 0 )
+        return; // turned off
     if( ping_timer != NULL )
         return; // pinging already
     ping_timer = new QTimer( this );
     connect( ping_timer, SIGNAL( timeout()), SLOT( pingTimeout()));
-    ping_timer->start( 5000, true ); // give it 5 seconds
+    ping_timer->start( options->killPingTimeout, true );
     ping_timestamp = qt_x_time;
     workspace()->sendPingToWindow( window(), ping_timestamp );
     }
@@ -1001,7 +1021,7 @@ void Client::killProcess( bool ask, Time timestamp )
     if( process_killer != NULL )
         return;
     Q_ASSERT( !ask || timestamp != CurrentTime );
-    QCString machine = wmClientMachine();
+    QCString machine = wmClientMachine( true );
     pid_t pid = info->pid();
     if( pid <= 0 || machine.isEmpty()) // needed properties missing
         return;
@@ -1047,19 +1067,25 @@ void Client::processKillerExited()
 void Client::setSkipTaskbar( bool b, bool from_outside )
     {
     if( from_outside )
+        {
+        b = rules()->checkSkipTaskbar( b );
         original_skip_taskbar = b;
+        }
     if ( b == skipTaskbar() )
         return;
     skip_taskbar = b;
     info->setState( b?NET::SkipTaskbar:0, NET::SkipTaskbar );
+    updateWindowRules();
     }
 
 void Client::setSkipPager( bool b )
     {
+    b = rules()->checkSkipPager( b );
     if ( b == skipPager() )
         return;
     skip_pager = b;
     info->setState( b?NET::SkipPager:0, NET::SkipPager );
+    updateWindowRules();
     }
 
 void Client::setModal( bool m )
@@ -1073,15 +1099,11 @@ void Client::setModal( bool m )
     // _NET_WM_STATE_MODAL should possibly rather be _NET_WM_WINDOW_TYPE_MODAL_DIALOG
     }
 
-void Client::toggleOnAllDesktops()
-    {
-    setOnAllDesktops( !isOnAllDesktops());
-    }
-
 void Client::setDesktop( int desktop )
     {
     if( desktop != NET::OnAllDesktops ) // do range check
         desktop = KMAX( 1, KMIN( workspace()->numberOfDesktops(), desktop ));
+    desktop = rules()->checkDesktop( desktop );
     if( desk == desktop )
         return;
     int was_desk = desk;
@@ -1096,6 +1118,7 @@ void Client::setDesktop( int desktop )
     if( decoration != NULL )
         decoration->desktopChange();
     virtualDesktopChange(); // hide/show if needed
+    updateWindowRules();
     }
 
 void Client::setOnAllDesktops( bool b )
@@ -1114,15 +1137,35 @@ bool Client::isOnCurrentDesktop() const
     return isOnDesktop( workspace()->currentDesktop());
     }
 
-/*!
-  Puts the focus on this window. Clients should never calls this
-  themselves, instead they should use Workspace::requestFocus().
- */
-void Client::takeFocus( bool force, allowed_t )
+// performs activation and/or raising of the window
+void Client::takeActivity( int flags, bool handled, allowed_t )
     {
-    if ( !force && ( isTopMenu() || isDock() || isSplash()) )
-        return; // toplevel menus and dock windows don't take focus if not forced
+    if( !handled || !Ptakeactivity )
+        {
+        if( flags & ActivityFocus )
+            takeFocus( Allowed );
+        if( flags & ActivityRaise )
+            workspace()->raiseClient( this );
+        return;
+        }
 
+#ifndef NDEBUG
+    static Time previous_activity_timestamp;
+    static Client* previous_client;
+    if( previous_activity_timestamp == qt_x_time && previous_client != this )
+        {
+        kdWarning( 1212 ) << "Repeated use of the same X timestamp for activity" << endl;
+        kdDebug( 1212 ) << kdBacktrace() << endl;
+        }
+    previous_activity_timestamp = qt_x_time;
+    previous_client = this;
+#endif
+    workspace()->sendTakeActivity( this, qt_x_time, flags );
+    }
+
+// performs the actual focusing of the window using XSetInputFocus and WM_TAKE_FOCUS
+void Client::takeFocus( allowed_t )
+    {
 #ifndef NDEBUG
     static Time previous_focus_timestamp;
     static Client* previous_client;
@@ -1134,12 +1177,13 @@ void Client::takeFocus( bool force, allowed_t )
     previous_focus_timestamp = qt_x_time;
     previous_client = this;
 #endif
-    if ( input ) 
+    if ( rules()->checkAcceptFocus( input ))
         {
         XSetInputFocus( qt_xdisplay(), window(), RevertToPointerRoot, qt_x_time );
         }
     if ( Ptakefocus )
         sendClientMessage(window(), atoms->wm_protocols, atoms->wm_take_focus);
+    workspace()->setShouldGetFocus( this );
     }
 
 /*!
@@ -1175,19 +1219,26 @@ void Client::showContextHelp()
   Fetches the window's caption (WM_NAME property). It will be
   stored in the client's caption().
  */
-KWIN_COMPARE_PREDICATE( FetchNameInternalPredicate, const Client*, (!cl->isSpecialWindow() || cl->isToolbar()) && cl != value && cl->caption() == value->caption());
-
 void Client::fetchName()
     {
-    QString s;
+    setCaption( readName());
+    }
 
+QString Client::readName() const
+    {
     if ( info->name() && info->name()[ 0 ] != '\0' ) 
-        s = QString::fromUtf8( info->name() );
+        return QString::fromUtf8( info->name() );
     else 
-        s = KWin::readNameProperty( window(), XA_WM_NAME );
-    if ( s != cap_normal ) 
+        return KWin::readNameProperty( window(), XA_WM_NAME );
+    }
+    
+KWIN_COMPARE_PREDICATE( FetchNameInternalPredicate, const Client*, (!cl->isSpecialWindow() || cl->isToolbar()) && cl != value && cl->caption() == value->caption());
+
+void Client::setCaption( const QString& s, bool force )
+    {
+    if ( s != cap_normal || force ) 
         {
-        bool reset_name = cap_normal.isEmpty();
+        bool reset_name = force;
         for( unsigned int i = 0;
              i < s.length();
              ++i )
@@ -1224,24 +1275,29 @@ void Client::fetchName()
 void Client::fetchIconicName()
     {
     QString s;
-
     if ( info->iconName() && info->iconName()[ 0 ] != '\0' ) 
         s = QString::fromUtf8( info->iconName() );
     else 
         s = KWin::readNameProperty( window(), XA_WM_ICON_NAME );
     if ( s != cap_iconic ) 
         {
+	bool was_set = !cap_iconic.isEmpty();
         cap_iconic = s;
-        if( !cap_suffix.isEmpty() && !cap_iconic.isEmpty()) // keep the same suffix in iconic name if it's set
-            info->setVisibleIconName( ( s + cap_suffix ).utf8() );
+        if( !cap_suffix.isEmpty())
+	    {
+	    if( !cap_iconic.isEmpty()) // keep the same suffix in iconic name if it's set
+        	info->setVisibleIconName( ( s + cap_suffix ).utf8() );
+	    else if( was_set )
+		info->setVisibleIconName( "" ); //remove
+	    }
         }
     }
 
 /*!\reimp
  */
-QString Client::caption() const
+QString Client::caption( bool full ) const
     {
-    return cap_normal + cap_suffix;
+    return full ? cap_normal + cap_suffix : cap_normal;
     }
 
 void Client::getWMHints()
@@ -1264,6 +1320,23 @@ void Client::getWMHints()
     updateAllowedActions(); // group affects isMinimizable()
     }
 
+void Client::getMotifHints()
+    {
+    bool mnoborder, mresize, mmove, mminimize, mmaximize, mclose;
+    Motif::readFlags( client, mnoborder, mresize, mmove, mminimize, mmaximize, mclose );
+    motif_noborder = mnoborder;
+    if( !hasNETSupport()) // NETWM apps should set type and size constraints
+        {
+        motif_may_resize = mresize; // this should be set using minsize==maxsize, but oh well
+        motif_may_move = mmove;
+        }
+    // mminimize; - ignore, bogus - e.g. shading or sending to another desktop is "minimizing" too
+    // mmaximize; - ignore, bogus - maximizing is basically just resizing
+    motif_may_close = mclose; // motif apps like to crash when they set this hint and WM closes them anyway
+    if( isManaged())
+        updateDecoration( true ); // check if noborder state has changed
+    }
+
 void Client::readIcons( Window win, QPixmap* icon, QPixmap* miniicon )
     {    
     // get the icons, allow scaling
@@ -1312,6 +1385,7 @@ void Client::getWindowProtocols()
 
     Pdeletewindow = 0;
     Ptakefocus = 0;
+    Ptakeactivity = 0;
     Pcontexthelp = 0;
     Pping = 0;
 
@@ -1322,6 +1396,8 @@ void Client::getWindowProtocols()
                 Pdeletewindow = 1;
             else if (p[i] == atoms->wm_take_focus)
                 Ptakefocus = 1;
+            else if (p[i] == atoms->net_wm_take_activity)
+                Ptakeactivity = 1;
             else if (p[i] == atoms->net_wm_context_help)
                 Pcontexthelp = 1;
             else if (p[i] == atoms->net_wm_ping)
@@ -1341,7 +1417,7 @@ static int nullErrorHandler(Display *, XErrorEvent *)
  */
 QCString Client::staticWindowRole(WId w)
     {
-    return getStringProperty(w, qt_window_role);
+    return getStringProperty(w, qt_window_role).lower();
     }
 
 /*!
@@ -1362,29 +1438,12 @@ QCString Client::staticWmCommand(WId w)
 
 /*!
   Returns WM_CLIENT_MACHINE property for a given window.
-  Local machine is always returned as "localhost".
  */
 QCString Client::staticWmClientMachine(WId w)
     {
     QCString result = getStringProperty(w, XA_WM_CLIENT_MACHINE);
     if (result.isEmpty()) 
-        {
         result = "localhost";
-        }
-    else 
-        {
-        // special name for the local machine (localhost)
-        char hostnamebuf[80];
-        if (gethostname (hostnamebuf, sizeof hostnamebuf) >= 0) 
-            {
-            hostnamebuf[sizeof(hostnamebuf)-1] = 0;
-            if (result == hostnamebuf)
-                result = "localhost";
-            char *dot = strchr(hostnamebuf, '.');
-            if (dot && !(*dot = 0) && result == hostnamebuf)
-                result = "localhost";
-            }
-        }
     return result;
     }
 
@@ -1447,11 +1506,16 @@ QCString Client::wmCommand()
   Returns client machine for this client,
   taken either from its window or from the leader window.
 */
-QCString Client::wmClientMachine() const
+QCString Client::wmClientMachine( bool use_localhost ) const
     {
     QCString result = staticWmClientMachine(window());
     if (result.isEmpty() && wmClientLeaderWin && wmClientLeaderWin!=window())
         result = staticWmClientMachine(wmClientLeaderWin);
+    if( use_localhost )
+        { // special name for the local machine (localhost)
+        if( result != "localhost" && isLocalMachine( result ))
+            result = "localhost";
+        }
     return result;
     }
 
@@ -1469,24 +1533,13 @@ Window Client::wmClientLeader() const
 bool Client::wantsTabFocus() const
     {
     return ( isNormalWindow() || isDialog() || isOverride())
-                          && ( input || Ptakefocus ) && !skip_taskbar;
+        && wantsInput() && !skip_taskbar;
     }
 
 
 bool Client::wantsInput() const
     {
-    return input;
-    }
-
-/*!
-  Returns whether the window is moveable or has a fixed
-  position. !isMovable implies !isResizable.
- */
-bool Client::isMovable() const
-    {
-    return motif_may_move && !isFullScreen() &&
-        ( !isSpecialWindow() || isOverride() || isSplash() || isToolbar()) && // allow moving of splashscreens :)
-        ( maximizeMode() != MaximizeFull || options->moveResizeMaximizedWindows() );
+    return rules()->checkAcceptFocus( input || Ptakefocus );
     }
 
 bool Client::isDesktop() const
@@ -1547,28 +1600,34 @@ bool Client::isSpecialWindow() const
         || isToolbar(); // TODO
     }
 
-NET::WindowType Client::windowType( bool strict, int supported_types ) const
+NET::WindowType Client::windowType( bool direct, int supported_types ) const
     {
     NET::WindowType wt = info->windowType( supported_types );
-    // TODO is this 'strict' really needed (and used?)
-    if( !strict )
-        { // hacks here
-        if( wt == NET::Menu )
-            {
-            // ugly hack to support the times when NET::Menu meant NET::TopMenu
-            // if it's as wide as the screen, not very high and has its upper-left
-            // corner a bit above the screen's upper-left cornet, it's a topmenu
-            if( x() == 0 && y() < 0 && y() > -10 && height() < 100
-                && abs( width() - workspace()->clientArea( FullArea, this ).width()) < 10 )
-                wt = NET::TopMenu;
-            }
-        const char* const oo_prefix = "openoffice.org"; // QCString has no startsWith()
-        // oo_prefix is lowercase, because resourceClass() is forced to be lowercase
-        if( qstrncmp( resourceClass(), oo_prefix, strlen( oo_prefix )) == 0 && wt == NET::Dialog )
-            wt = NET::Normal; // see bug #66065
-        if( wt == NET::Unknown ) // this is more or less suggested in NETWM spec
-            wt = isTransient() ? NET::Dialog : NET::Normal;
+    if( direct )
+        return wt;
+    NET::WindowType wt2 = rules()->checkType( wt );
+    if( wt != wt2 )
+        {
+        wt = wt2;
+        info->setWindowType( wt ); // force hint change
         }
+    // hacks here
+    if( wt == NET::Menu )
+        {
+        // ugly hack to support the times when NET::Menu meant NET::TopMenu
+        // if it's as wide as the screen, not very high and has its upper-left
+        // corner a bit above the screen's upper-left cornet, it's a topmenu
+        if( x() == 0 && y() < 0 && y() > -10 && height() < 100
+            && abs( width() - workspace()->clientArea( FullArea, this ).width()) < 10 )
+            wt = NET::TopMenu;
+        }
+    // TODO change this to rule
+    const char* const oo_prefix = "openoffice.org"; // QCString has no startsWith()
+    // oo_prefix is lowercase, because resourceClass() is forced to be lowercase
+    if( qstrncmp( resourceClass(), oo_prefix, strlen( oo_prefix )) == 0 && wt == NET::Dialog )
+        wt = NET::Normal; // see bug #66065
+    if( wt == NET::Unknown ) // this is more or less suggested in NETWM spec
+        wt = isTransient() ? NET::Dialog : NET::Normal;
     return wt;
     }
 
@@ -1578,10 +1637,9 @@ NET::WindowType Client::windowType( bool strict, int supported_types ) const
  */
 void Client::setCursor( Position m )
     {
-    if ( !isResizable() || isShade() || noBorder())
+    if( !isResizable() || isShade())
         {
-        setCursor( arrowCursor );
-        return;
+        m = PositionCenter;
         }
     switch ( m ) 
         {
@@ -1602,7 +1660,7 @@ void Client::setCursor( Position m )
             setCursor( sizeHorCursor );
             break;
         default:
-            if( buttonDown )
+            if( buttonDown && isMovable())
                 setCursor( sizeAllCursor );
             else
                 setCursor( arrowCursor );
@@ -1660,21 +1718,16 @@ void Client::updateAllowedActions( bool force )
 void Client::autoRaise()
     {
     workspace()->raiseClient( this );
-    delete autoRaiseTimer;
-    autoRaiseTimer = 0;
+    cancelAutoRaise();
     }
-
+    
 void Client::cancelAutoRaise()
     {
     delete autoRaiseTimer;
     autoRaiseTimer = 0;
     }
 
-#ifdef NDEBUG
-kndbgstream& operator<<( kndbgstream& stream, const Client* ) { return stream; }
-kndbgstream& operator<<( kndbgstream& stream, const ClientList&  ) { return stream; }
-kndbgstream& operator<<( kndbgstream& stream, const ConstClientList& ) { return stream; }
-#else
+#ifndef NDEBUG
 kdbgstream& operator<<( kdbgstream& stream, const Client* cl )
     {
     if( cl == NULL )
