@@ -12,10 +12,6 @@ License. See the file "COPYING" for the exact licensing terms.
 #ifndef KWIN_CLIENT_H
 #define KWIN_CLIENT_H
 
-#include "utils.h"
-#include "options.h"
-#include "workspace.h"
-#include "kdecoration.h"
 #include <qframe.h>
 #include <qvbox.h>
 #include <qpixmap.h>
@@ -27,6 +23,12 @@ License. See the file "COPYING" for the exact licensing terms.
 #include <X11/Xutil.h>
 #include <fixx11h.h>
 
+#include "utils.h"
+#include "options.h"
+#include "workspace.h"
+#include "kdecoration.h"
+#include "rules.h"
+
 class QTimer;
 class KProcess;
 class KStartupInfoData;
@@ -65,11 +67,13 @@ class Client : public QObject, public KDecorationDefines
         Group* group();
         void checkGroup( Group* gr = NULL, bool force = false );
     // prefer isXXX() instead
-        NET::WindowType windowType( bool strict = false, int supported_types = SUPPORTED_WINDOW_TYPES_MASK ) const;
+        NET::WindowType windowType( bool direct = false, int supported_types = SUPPORTED_WINDOW_TYPES_MASK ) const;
+        const WindowRules* rules() const;
 
         QRect geometry() const;
         QSize size() const;
         QSize minSize() const;
+        QSize maxSize() const;
         QPoint pos() const;
         QRect rect() const;
         int x() const;
@@ -112,13 +116,6 @@ class Client : public QObject, public KDecorationDefines
     // !isMinimized() && not hidden, i.e. normally visible on some virtual desktop
         bool isShown( bool shaded_is_shown ) const;
 
-        enum ShadeMode
-            {
-            ShadeNone, // not shaded
-            ShadeNormal, // normally shaded - isShade() is true only here
-            ShadeHover, // "shaded", but visible due to hover unshade
-            ShadeActivated // "shaded", but visible due to alt+tab to the window
-            };
         bool isShade() const; // true only for ShadeNormal
         ShadeMode shadeMode() const; // prefer isShade()
         void setShade( ShadeMode mode );
@@ -160,9 +157,6 @@ class Client : public QObject, public KDecorationDefines
         void setModal( bool modal );
         bool isModal() const;
 
-        bool storeSettings() const;
-        void setStoreSettings( bool );
-
     // auxiliary functions, depend on the windowType
         bool wantsTabFocus() const;
         bool wantsInput() const;
@@ -187,7 +181,8 @@ class Client : public QObject, public KDecorationDefines
         bool isResizable() const;
         bool isCloseable() const; // may be closed by the user (may have a close button)
 
-        void takeFocus( bool force, allowed_t );
+        void takeActivity( int flags, bool handled, allowed_t ); // takes ActivityFlags as arg (in utils.h)
+        void takeFocus( allowed_t );
         void demandAttention( bool set = true );
 
         void setMask( const QRegion& r, int mode = X::Unsorted );
@@ -216,18 +211,18 @@ class Client : public QObject, public KDecorationDefines
 
         bool providesContextHelp() const;
 
-        bool performMouseCommand( Options::MouseCommand, QPoint globalPos );
+        bool performMouseCommand( Options::MouseCommand, QPoint globalPos, bool handled = false );
 
         QCString windowRole() const;
         QCString sessionId();
         QCString resourceName() const;
         QCString resourceClass() const;
         QCString wmCommand();
-        QCString wmClientMachine() const;
+        QCString wmClientMachine( bool use_localhost ) const;
         Window   wmClientLeader() const;
         pid_t pid() const;
 
-        QRect adjustedClientArea( const QRect& area ) const;
+        QRect adjustedClientArea( const QRect& desktop, const QRect& area ) const;
 
         Colormap colormap() const;
 
@@ -236,17 +231,17 @@ class Client : public QObject, public KDecorationDefines
     // updates visibility depending on whether it's on the current desktop
         void virtualDesktopChange();
 
-        QString caption() const;
+        QString caption( bool full = true ) const;
 
         void keyPressEvent( uint key_code ); // FRAME ??
-
+        void updateMouseGrab();
         Window moveResizeGrabWindow() const;
 
         const QPoint calculateGravitation( bool invert, int gravity = 0 ) const; // FRAME public?
 
         void NETMoveResize( int x_root, int y_root, NET::Direction direction );
         void NETMoveResizeWindow( int flags, int x, int y, int width, int height );
-        void restackWindow( Window above, int detail, NET::RequestSource source, bool send_event = false );
+        void restackWindow( Window above, int detail, NET::RequestSource source, Time timestamp, bool send_event = false );
         
         void gotPing( Time timestamp );
 
@@ -269,20 +264,20 @@ class Client : public QObject, public KDecorationDefines
         static bool belongToSameApplication( const Client* c1, const Client* c2, bool active_hack = false );
         static void readIcons( Window win, QPixmap* icon, QPixmap* miniicon );
 
-    public slots: // FRAME these probably don't need to be slots anymore
-        void minimize();
-        void unminimize();
+        void minimize( bool avoid_animation = false );
+        void unminimize( bool avoid_animation = false );
         void closeWindow();
         void killWindow();
         void maximize( MaximizeMode );
-        void toggleOnAllDesktops();
         void toggleShade();
         void showContextHelp();
-        void autoRaise();
         void cancelAutoRaise();
-        void shadeHover();
         void destroyClient();
 
+    private slots:
+        void autoRaise();
+        void shadeHover();
+
     private:
         friend class Bridge; // FRAME
         virtual void processMousePressEvent( QMouseEvent* e );
@@ -335,20 +330,30 @@ class Client : public QObject, public KDecorationDefines
         void updateAllowedActions( bool force = false );
         QSize sizeForClientSize( const QSize&, Sizemode mode = SizemodeAny ) const;
         void changeMaximize( bool horizontal, bool vertical, bool adjust );
+        bool checkFullScreenHack( const QRect& geom ) const;
+        void updateFullScreenHack( const QRect& geom );
         void getWmNormalHints();
+        void getMotifHints();
         void getIcons();
         void getWmClientLeader();
         void fetchName();
         void fetchIconicName();
+        QString readName() const;
+        void setCaption( const QString& s, bool force = false );
         bool hasTransientInternal( const Client* c, bool indirect, ConstClientList& set ) const;
+        void setupWindowRules( bool ignore_temporary );
+        void updateWindowRules();
+        void finishWindowRules();
 
         void updateWorkareaDiffs();
         void checkDirection( int new_diff, int old_diff, QRect& rect, const QRect& area );
         static int computeWorkareaDiff( int left, int right, int a_left, int a_right );
-        void configureRequest( int value_mask, int rx, int ry, int rw, int rh, int gravity = 0 );
+        void configureRequest( int value_mask, int rx, int ry, int rw, int rh, int gravity, bool from_tool );
         // resizeWithChecks() resizes according to gravity, and checks workarea position
         void resizeWithChecks( int w, int h, ForceGeometry_t force = NormalGeometrySet );
         void resizeWithChecks( const QSize& s, ForceGeometry_t force = NormalGeometrySet );
+        NETExtendedStrut strut() const;
+        bool hasStrut() const;
 
         bool startMoveResize();
         void finishMoveResize( bool cancel );
@@ -356,7 +361,6 @@ class Client : public QObject, public KDecorationDefines
         void checkUnrestrictedMoveResize();
         void handleMoveResize( int x, int y, int x_root, int y_root );
         void positionGeometryTip();
-        void updateMouseGrab();
         void grabButton( int mod );
         void ungrabButton( int mod );
         void resetMaximize();
@@ -365,6 +369,8 @@ class Client : public QObject, public KDecorationDefines
         void pingWindow();
         void killProcess( bool ask, Time timestamp = CurrentTime );
         void updateUrgency();
+        static void sendClientMessage( Window w, Atom a, Atom protocol,
+            long data1 = 0, long data2 = 0, long data3 = 0 );
 
         void embedClient( Window w, const XWindowAttributes &attr );    
         void detectNoBorder();
@@ -374,8 +380,8 @@ class Client : public QObject, public KDecorationDefines
         void rawShow(); // just shows it
         void rawHide(); // just hides it
 
-        Time readUserTimeMapTimestamp( const KStartupInfoData* asn_data,
-            const SessionInfo* session ) const;
+        Time readUserTimeMapTimestamp( const KStartupInfoId* asn_id, const KStartupInfoData* asn_data,
+            bool session ) const;
         Time readUserCreationTime() const;
         static bool sameAppWindowRoleMatch( const Client* c1, const Client* c2, bool active_hack );
         void startupIdChanged();
@@ -417,6 +423,7 @@ class Client : public QObject, public KDecorationDefines
         void cleanGrouping();
         void checkGroupTransients();
         void setTransient( Window new_transient_for_id );
+        void checkActiveModal();
         Client* transient_for;
         Window transient_for_id;
         Window original_transient_for_id;
@@ -429,11 +436,12 @@ class Client : public QObject, public KDecorationDefines
         uint original_skip_taskbar :1; // unaffected by KWin
         uint Pdeletewindow :1; // does the window understand the DeleteWindow protocol?
         uint Ptakefocus :1;// does the window understand the TakeFocus protocol?
+        uint Ptakeactivity : 1; // does it support _NET_WM_TAKE_ACTIVITY
         uint Pcontexthelp : 1; // does the window understand the ContextHelp protocol?
         uint Pping : 1; // does it support _NET_WM_PING?
         uint input :1; // does the window want input in its wm_hints
-        uint store_settings : 1;
         uint skip_pager : 1;
+        uint motif_noborder : 1;
         uint motif_may_resize : 1;
         uint motif_may_move :1;
         uint motif_may_close : 1;
@@ -446,7 +454,7 @@ class Client : public QObject, public KDecorationDefines
         uint not_obscured : 1;
         uint urgency : 1; // XWMHints, UrgencyHint
         uint ignore_focus_stealing : 1; // don't apply focus stealing prevention to this client
-        uint check_active_modal : 1; // see Client::addTransient()
+        WindowRules client_rules;
         void getWMHints();
         void readIcons();
         void getWindowProtocols();
@@ -484,8 +492,10 @@ class Client : public QObject, public KDecorationDefines
         bool shade_geometry_change;
         int border_left, border_right, border_top, border_bottom;
         QRegion _mask;
+        static bool check_active_modal; // see Client::checkActiveModal()
         friend struct FetchNameInternalPredicate;
         friend struct CheckIgnoreFocusStealingProcedure;
+        friend struct ResetupRulesProcedure;
         void show() { assert( false ); } // SELI remove after Client is no longer QWidget
         void hide() { assert( false ); }
     };
@@ -634,7 +644,7 @@ bool Client::isShade() const
     }
 
 inline
-Client::ShadeMode Client::shadeMode() const
+ShadeMode Client::shadeMode() const
     {
     return shade_mode;
     }
@@ -679,17 +689,6 @@ inline bool Client::keepBelow() const
     return keep_below;
     }
 
-inline bool Client::storeSettings() const
-    {
-    return store_settings;
-    }
-
-inline void Client::setStoreSettings( bool b )
-    {
-    store_settings = b;
-    }
-
-
 inline bool Client::shape() const
     {
     return is_shape;
@@ -756,11 +755,6 @@ inline QSize Client::size() const
     return frame_geometry.size();
     }
 
-inline QSize Client::minSize() const
-    {
-    return QSize( xSizeHint.min_width, xSizeHint.min_height );
-    }
-
 inline QPoint Client::pos() const
     {
     return frame_geometry.topLeft();
@@ -831,6 +825,11 @@ inline bool Client::ignoreFocusStealing() const
     return ignore_focus_stealing;
     }
 
+inline const WindowRules* Client::rules() const
+    {
+    return &client_rules;
+    }
+
 KWIN_PROCEDURE( CheckIgnoreFocusStealingProcedure, cl->ignore_focus_stealing = options->checkIgnoreFocusStealing( cl ));
 
 inline Window Client::moveResizeGrabWindow() const
@@ -839,9 +838,12 @@ inline Window Client::moveResizeGrabWindow() const
     }
 
 #ifdef NDEBUG
-kndbgstream& operator<<( kndbgstream& stream, const Client* );
-kndbgstream& operator<<( kndbgstream& stream, const ClientList& );
-kndbgstream& operator<<( kndbgstream& stream, const ConstClientList& );
+inline
+kndbgstream& operator<<( kndbgstream& stream, const Client* ) { return stream; }
+inline
+kndbgstream& operator<<( kndbgstream& stream, const ClientList& ) { return stream; }
+inline
+kndbgstream& operator<<( kndbgstream& stream, const ConstClientList& ) { return stream; }
 #else
 kdbgstream& operator<<( kdbgstream& stream, const Client* );
 kdbgstream& operator<<( kdbgstream& stream, const ClientList& );
