@@ -4,15 +4,20 @@
  * Changes:
  *   Customizable button positions by Karol Szwed <gallium@kde.org>
  *
- *   Thin frame in fixed size windows, titlebar gradient support and
- *   accessibility improvements are
- *   Copyright (c) 2003 Luciano Montanaro <mikelima@virgilio.it>
+ *   Thin frame in fixed size windows, titlebar gradient support, accessibility
+ *   improvements, customizable menu double click action and button hover
+ *   effects are
+ *   Copyright (c) 2003,2004 Luciano Montanaro <mikelima@cirulla.net>
  */
 
 #include "b2client.h"
+#include <qapplication.h>
 #include <qlayout.h>
 #include <qdrawutil.h>
 #include <kpixmapeffect.h>
+#include <kimageeffect.h>
+#include <kicontheme.h>
+#include <kiconeffect.h>
 #include <kdrawutil.h>
 #include <klocale.h>
 #include <kconfig.h>
@@ -26,33 +31,53 @@ namespace B2 {
 
 #include "bitmaps.h"
 
-#define P_CLOSE 0
-#define P_MAX 1
-#define P_NORMALIZE 2
-#define P_ICONIFY 3
-#define P_PINUP 4
-#define P_MENU 5
-#define P_HELP 6
-#define NUM_PIXMAPS ((P_HELP + 1) * 4)
+enum { 
+    Norm = 0, 
+    Hover, Down, INorm, IHover, IDown, 
+    NumStates 
+};
+
+enum {
+    P_CLOSE = 0, 
+    P_MAX, P_NORMALIZE, P_ICONIFY, P_PINUP, P_MENU, P_HELP, P_SHADE, P_RESIZE,
+    P_NUM_BUTTON_TYPES
+};
+
+#define NUM_PIXMAPS (P_NUM_BUTTON_TYPES * NumStates)
 
 static KPixmap *pixmap[NUM_PIXMAPS];
 
-//active
-#define PIXMAP_A(i)  (pixmap[(i)*4])
-//active, down
-#define PIXMAP_AD(i) (pixmap[(i)*4 +1])
-//inactive
-#define PIXMAP_I(i)  (pixmap[(i)*4 +2])
-//inactive, down
-#define PIXMAP_ID(i) (pixmap[(i)*4 +3])
+// active
+#define PIXMAP_A(i)  (pixmap[(i) * NumStates + Norm])
+// active, hover
+#define PIXMAP_AH(i) (pixmap[(i) * NumStates + Hover])
+// active, down
+#define PIXMAP_AD(i) (pixmap[(i) * NumStates + Down])
+// inactive
+#define PIXMAP_I(i)  (pixmap[(i) * NumStates + INorm])
+// inactive, hover
+#define PIXMAP_IH(i) (pixmap[(i) * NumStates + IHover])
+// inactive, down
+#define PIXMAP_ID(i) (pixmap[(i) * NumStates + IDown])
 
 static KPixmap* titleGradient[2] = {0, 0};
 
 static int thickness = 4; // Frame thickness
 static int buttonSize = 16;
 
+enum DblClickOperation {
+	NoOp = 0,
+	MinimizeOp,
+	ShadeOp,
+	CloseOp
+};
+
+static DblClickOperation menu_dbl_click_op = NoOp;
+
 static bool pixmaps_created = false;
 static bool colored_frame = false;
+static bool do_draw_handle = true;
+static bool drawSmallBorders = false;
 
 // =====================================
 
@@ -79,7 +104,20 @@ static void read_config(B2ClientFactory *f)
 
     KConfig conf("kwinb2rc");
     conf.setGroup("General");
-    colored_frame = conf.readBoolEntry( "UseTitleBarBorderColors", false );
+    colored_frame = conf.readBoolEntry("UseTitleBarBorderColors", false);
+    do_draw_handle = conf.readBoolEntry("DrawGrabHandle", true);
+    drawSmallBorders = !options()->moveResizeMaximizedWindows();
+
+    QString opString = conf.readEntry("MenuButtonDoubleClickOperation", "NoOp");
+    if (opString == "Close") {
+        menu_dbl_click_op = B2::CloseOp;
+    } else if (opString == "Minimize") {
+        menu_dbl_click_op = B2::MinimizeOp;
+    } else if (opString == "Shade") {
+        menu_dbl_click_op = B2::ShadeOp;
+    } else {
+        menu_dbl_click_op = B2::NoOp;
+    }
 
     switch (options()->preferredBorderSize(f)) {
     case KDecoration::BorderTiny:
@@ -108,8 +146,8 @@ static void drawB2Rect(KPixmap *pix, const QColor &primary, bool down)
     QColor hColor = primary.light(150);
     QColor lColor = primary.dark(150);
 
-    if(QPixmap::defaultDepth() > 8){
-        if(down)
+    if (QPixmap::defaultDepth() > 8) {
+        if (down)
             KPixmapEffect::gradient(*pix, lColor, hColor,
                                     KPixmapEffect::DiagonalGradient);
         else
@@ -118,13 +156,13 @@ static void drawB2Rect(KPixmap *pix, const QColor &primary, bool down)
     }
     else
         pix->fill(primary);
-    int x2 = pix->width()-1;
-    int y2 = pix->height()-1;
+    int x2 = pix->width() - 1;
+    int y2 = pix->height() - 1;
     p.setPen(down ? hColor : lColor);
     p.drawLine(0, 0, x2, 0);
     p.drawLine(0, 0, 0, y2);
-    p.drawLine(1, x2-1, x2-1, y2-1);
-    p.drawLine(x2-1, 1, x2-1, y2-1);
+    p.drawLine(1, x2 - 1, x2 - 1, y2 - 1);
+    p.drawLine(x2 - 1, 1, x2 - 1, y2 - 1);
     p.setPen(down ? lColor : hColor);
     p.drawRect(1, 1, x2, y2);
 
@@ -138,7 +176,7 @@ QPixmap* kwin_get_menu_pix_hack()
 
 static void create_pixmaps()
 {
-    if ( pixmaps_created )
+    if (pixmaps_created)
         return;
     pixmaps_created = true;
 
@@ -148,11 +186,13 @@ static void create_pixmaps()
 
     for (i = 0; i < NUM_PIXMAPS; i++) {
         pixmap[i] = new KPixmap;
-	switch (i / 4) {
+	switch (i / NumStates) {
 	case P_MAX: // will be initialized by copying P_CLOSE
+	case P_RESIZE: 
 	    break;
 	case P_ICONIFY:
 	    pixmap[i]->resize(10, 10); break;
+	case P_SHADE:
 	case P_CLOSE:
 	    pixmap[i]->resize(bsize, bsize); break;
 	default:
@@ -170,21 +210,33 @@ static void create_pixmaps()
     PIXMAP_ID(P_PINUP)->setMask(pindownMask);
 
     QBitmap menuMask(16, 16, menu_mask_bits, true);
-    for (i = 0; i < 4; i++) pixmap[P_MENU * 4 + i]->setMask(menuMask);
+    for (i = 0; i < NumStates; i++) 
+	pixmap[P_MENU * NumStates + i]->setMask(menuMask);
 
     QBitmap helpMask(16, 16, help_mask_bits, true);
-    for (i = 0; i < 4; i++) pixmap[P_HELP * 4 + i]->setMask(helpMask);
+    for (i = 0; i < NumStates; i++) 
+	pixmap[P_HELP * NumStates + i]->setMask(helpMask);
 
     QBitmap normalizeMask(16, 16, true);
     // draw normalize icon mask
-    QPainter mask(&normalizeMask);
+    QPainter mask;
+    mask.begin(&normalizeMask);
 
     QBrush one(Qt::color1);
     mask.fillRect(normalizeMask.width() - 12, normalizeMask.height() - 12, 
 		  12, 12, one);
     mask.fillRect(0, 0, 10, 10, one);
+    mask.end();
 
-    for (i = 0; i < 4; i++) pixmap[P_NORMALIZE * 4 + i]->setMask(normalizeMask);
+    for (i = 0; i < NumStates; i++) 
+	pixmap[P_NORMALIZE * NumStates + i]->setMask(normalizeMask);
+    
+    QBitmap shadeMask(bsize, bsize, true);
+    mask.begin(&shadeMask);
+    mask.fillRect(0, 0, bsize, 6, one);
+    mask.end();
+    for (i = 0; i < NumStates; i++) 
+	pixmap[P_SHADE * NumStates + i]->setMask(shadeMask);
 
     titleGradient[0] = 0;
     titleGradient[1] = 0;
@@ -248,20 +300,19 @@ QValueList< B2ClientFactory::BorderSize > B2ClientFactory::borderSizes() const
 
 // =====================================
 
-void B2Client::maxButtonClicked( )
+void B2Client::maxButtonClicked()
 {
-    switch ( button[BtnMax]->last_button ) {
-    case MidButton:
-	maximize(maximizeMode() ^ MaximizeVertical);
-	break;
-    case RightButton:
-	maximize(maximizeMode() ^ MaximizeHorizontal);
-	break;
-    case LeftButton:
-    default:
-	maximize(maximizeMode() == MaximizeFull ? MaximizeRestore : MaximizeFull);
-	break;
-    }
+    maximize(button[BtnMax]->last_button);
+}
+
+void B2Client::shadeButtonClicked()
+{
+    setShade(!isSetShade());
+}
+
+void B2Client::resizeButtonPressed()
+{
+    performWindowOperation(ResizeOp);
 }
 
 B2Client::B2Client(KDecorationBridge *b, KDecorationFactory *f)
@@ -271,9 +322,15 @@ B2Client::B2Client(KDecorationBridge *b, KDecorationFactory *f)
 
 void B2Client::init()
 {
-    const QString tips[]= {i18n("Menu"), isOnAllDesktops()?i18n("Not On All Desktops"):i18n("On All desktops"),
-                           i18n("Minimize"), i18n("Maximize"),
-                           i18n("Close"), i18n("Help") };
+    const QString tips[] = {
+	i18n("Menu"), 
+	isOnAllDesktops() ? 
+	    i18n("Not on all desktops") : i18n("On all desktops"), 
+	i18n("Minimize"), i18n("Maximize"), 
+	i18n("Close"), i18n("Help"),
+	isSetShade() ? i18n("Unshade") : i18n("Shade"),
+	i18n("Resize") 
+    };
 
     createMainWidget(WResizeNoErase | WRepaintNoErase);
     widget()->installEventFilter(this);
@@ -287,11 +344,11 @@ void B2Client::init()
     g = new QGridLayout(widget(), 0, 0);
     if (isPreview()) {
         g->addMultiCellWidget(
-		new QLabel(i18n( "<b><center>B II preview</center></b>"),
+		new QLabel(i18n("<b><center>B II preview</center></b>"),
 		    widget()),
 		1, 1, 1, 2);
     } else {
-	g->addMultiCell( new QSpacerItem( 0, 0 ), 1, 1, 1, 2);
+	g->addMultiCell(new QSpacerItem(0, 0), 1, 1, 1, 2);
     }
 
     // Left and right border width
@@ -307,7 +364,7 @@ void B2Client::init()
     g->addItem(rightSpacer, 1, 3);
 
     // Bottom border height
-    spacer = new QSpacerItem(10, thickness + (isResizable() ? 4 : 0),
+    spacer = new QSpacerItem(10, thickness + (mustDrawHandle() ? 4 : 0),
 	    QSizePolicy::Expanding, QSizePolicy::Minimum);
     g->addItem(spacer, 3, 1);
 
@@ -315,21 +372,21 @@ void B2Client::init()
     g->addRowSpacing(0, buttonSize + 4);
 
     titlebar = new B2Titlebar(this);
-    titlebar->setMinimumWidth(16);
+    titlebar->setMinimumWidth(buttonSize + 4);
     titlebar->setFixedHeight(buttonSize + 4);
 
-    QBoxLayout *titleLayout = new QBoxLayout(titlebar, QBoxLayout::LeftToRight, 0, 1, 0);
+    QBoxLayout *titleLayout = new QBoxLayout(titlebar, 
+	    QBoxLayout::LeftToRight, 0, 1, 0);
     titleLayout->addSpacing(3);
 
-    if (options()->customButtonPositions())
-    {
-        addButtons( options()->titleButtonsLeft(), tips, titlebar, titleLayout );
+    if (options()->customButtonPositions()) {
+        addButtons(options()->titleButtonsLeft(), tips, titlebar, titleLayout);
         titleLayout->addItem(titlebar->captionSpacer);
-        addButtons( options()->titleButtonsRight(), tips, titlebar, titleLayout );
+        addButtons(options()->titleButtonsRight(), tips, titlebar, titleLayout);
     } else {
-        addButtons( "MSH", tips, titlebar, titleLayout );
+        addButtons("MSH", tips, titlebar, titleLayout);
         titleLayout->addItem(titlebar->captionSpacer);
-        addButtons( "IAX", tips, titlebar, titleLayout );
+        addButtons("IAX", tips, titlebar, titleLayout);
     }
 
     titleLayout->addSpacing(3);
@@ -337,13 +394,15 @@ void B2Client::init()
     QColor c = options()->colorGroup(KDecoration::ColorTitleBar, isActive()).
         color(QColorGroup::Button);
 
-    for (int i = 0; i < BtnCount; i++)
+    for (int i = 0; i < BtnCount; i++) {
         if (button[i])
             button[i]->setBg(c);
+    }
 
+    titlebar->updateGeometry();
+    positionButtons();
     titlebar->recalcBuffer();
     titlebar->installEventFilter(this);
-    positionButtons();
 }
 
 void B2Client::addButtons(const QString& s, const QString tips[],
@@ -354,87 +413,116 @@ void B2Client::addButtons(const QString& s, const QString tips[],
 
     for (unsigned int i = 0; i < s.length(); i++) {
         switch (s[i].latin1()) {
-            case 'M':  // Menu button
-                if (!button[BtnMenu]) {
-                    button[BtnMenu] = new B2Button(this, tb, tips[BtnMenu], LeftButton|RightButton);
-                    button[BtnMenu]->setPixmaps(P_MENU);
-                    button[BtnMenu]->setUseMiniIcon();
-                    connect(button[BtnMenu], SIGNAL(clicked()),
-                            this, SLOT(menuButtonPressed()));
-                    titleLayout->addWidget(button[BtnMenu]);
-                }
-                break;
-            case 'S':  // Sticky button
-                if (!button[BtnSticky]) {
-                    button[BtnSticky] = new B2Button(this, tb, tips[BtnSticky]);
-                    button[BtnSticky]->setPixmaps(P_PINUP);
-                    button[BtnSticky]->setToggle();
-                    button[BtnSticky]->setDown(isOnAllDesktops());
-                    connect(button[BtnSticky], SIGNAL(clicked()),
-                            this, SLOT(toggleOnAllDesktops()));
-                    titleLayout->addWidget(button[BtnSticky]);
-                }
-                break;
-            case 'H':  // Help button
-                if (providesContextHelp() && (!button[BtnHelp])) {
-                    button[BtnHelp] = new B2Button(this, tb, tips[BtnHelp]);
-                    button[BtnHelp]->setPixmaps(P_HELP);
-                    connect(button[BtnHelp], SIGNAL(clicked()),
-                            this, SLOT(showContextHelp()));
-                    titleLayout->addWidget(button[BtnHelp]);
-                }
-                break;
-            case 'I':  // Minimize button
-                if (isMinimizable() && (!button[BtnIconify])) {
-                    button[BtnIconify]= new B2Button(this, tb,tips[BtnIconify]);
-                    button[BtnIconify]->setPixmaps(P_ICONIFY);
-                    connect(button[BtnIconify], SIGNAL(clicked()),
-                            this, SLOT(minimize()));
-                    titleLayout->addWidget(button[BtnIconify]);
-                }
-                break;
-            case 'A':  // Maximize button
-                if (isMaximizable() && (!button[BtnMax])) {
-                    button[BtnMax]= new B2Button(this, tb, tips[BtnMax], LeftButton|MidButton|RightButton);
-                    button[BtnMax]->setPixmaps(maximizeMode() == MaximizeFull ?
-			    P_NORMALIZE : P_MAX);
-                    connect(button[BtnMax], SIGNAL(clicked()),
-                            this, SLOT(maxButtonClicked()));
-                    titleLayout->addWidget(button[BtnMax]);
-                }
-                break;
-            case 'X':  // Close button
-                if (isCloseable() && !button[BtnClose]) {
-                    button[BtnClose]= new B2Button(this, tb, tips[BtnClose]);
-                    button[BtnClose]->setPixmaps(P_CLOSE);
-                    connect(button[BtnClose], SIGNAL(clicked()),
-                            this, SLOT(closeWindow()));
-                    titleLayout->addWidget(button[BtnClose]);
-                }
-		break;
-	    case '_': // Additional spacing
-		titleLayout->addSpacing(4);
-		break;
+	case 'M':  // Menu button
+	    if (!button[BtnMenu]) {
+		button[BtnMenu] = new B2Button(this, tb, tips[BtnMenu], 
+			LeftButton | RightButton);
+		button[BtnMenu]->setPixmaps(P_MENU);
+		button[BtnMenu]->setUseMiniIcon();
+		connect(button[BtnMenu], SIGNAL(pressed()),
+			this, SLOT(menuButtonPressed()));
+		titleLayout->addWidget(button[BtnMenu]);
+	    }
+	    break;
+	case 'S':  // Sticky button
+	    if (!button[BtnSticky]) {
+		button[BtnSticky] = new B2Button(this, tb, tips[BtnSticky]);
+		button[BtnSticky]->setPixmaps(P_PINUP);
+		button[BtnSticky]->setToggle();
+		button[BtnSticky]->setDown(isOnAllDesktops());
+		connect(button[BtnSticky], SIGNAL(clicked()),
+			this, SLOT(toggleOnAllDesktops()));
+		titleLayout->addWidget(button[BtnSticky]);
+	    }
+	    break;
+	case 'H':  // Help button
+	    if (providesContextHelp() && (!button[BtnHelp])) {
+		button[BtnHelp] = new B2Button(this, tb, tips[BtnHelp]);
+		button[BtnHelp]->setPixmaps(P_HELP);
+		connect(button[BtnHelp], SIGNAL(clicked()),
+			this, SLOT(showContextHelp()));
+		titleLayout->addWidget(button[BtnHelp]);
+	    }
+	    break;
+	case 'I':  // Minimize button
+	    if (isMinimizable() && (!button[BtnIconify])) {
+		button[BtnIconify] = new B2Button(this, tb,tips[BtnIconify]);
+		button[BtnIconify]->setPixmaps(P_ICONIFY);
+		connect(button[BtnIconify], SIGNAL(clicked()),
+			this, SLOT(minimize()));
+		titleLayout->addWidget(button[BtnIconify]);
+	    }
+	    break;
+	case 'A':  // Maximize button
+	    if (isMaximizable() && (!button[BtnMax])) {
+		button[BtnMax] = new B2Button(this, tb, tips[BtnMax], 
+			LeftButton | MidButton | RightButton);
+		button[BtnMax]->setPixmaps(maximizeMode() == MaximizeFull ?
+			P_NORMALIZE : P_MAX);
+		connect(button[BtnMax], SIGNAL(clicked()),
+			this, SLOT(maxButtonClicked()));
+		titleLayout->addWidget(button[BtnMax]);
+	    }
+	    break;
+	case 'X':  // Close button
+	    if (isCloseable() && !button[BtnClose]) {
+		button[BtnClose] = new B2Button(this, tb, tips[BtnClose]);
+		button[BtnClose]->setPixmaps(P_CLOSE);
+		connect(button[BtnClose], SIGNAL(clicked()),
+			this, SLOT(closeWindow()));
+		titleLayout->addWidget(button[BtnClose]);
+	    }
+	    break;
+	case 'L': // Shade button
+	    if (isShadeable() && !button[BtnShade]) {
+		button[BtnShade] = new B2Button(this, tb, tips[BtnShade]);
+		button[BtnShade]->setPixmaps(P_SHADE);
+		connect(button[BtnShade], SIGNAL(clicked()),
+			this, SLOT(shadeButtonClicked()));
+		titleLayout->addWidget(button[BtnShade]);
+	    }
+	    break;
+	case 'R': // Resize button
+	    if (isResizable() && !button[BtnResize]) {
+		button[BtnResize] = new B2Button(this, tb, tips[BtnResize]);
+		button[BtnResize]->setPixmaps(P_RESIZE);
+		connect(button[BtnResize], SIGNAL(pressed()),
+			this, SLOT(resizeButtonPressed()));
+		titleLayout->addWidget(button[BtnResize]);
+	    }
+	    break;
+	case '_': // Additional spacing
+	    titleLayout->addSpacing(4);
+	    break;
 	}
     }
 }
 
+bool B2Client::mustDrawHandle() const 
+{ 
+    if (drawSmallBorders && (maximizeMode() & MaximizeVertical)) {
+	return false;
+    } else {
+	return do_draw_handle && isResizable();
+    }
+}
+
 void B2Client::iconChange()
 {
     if (button[BtnMenu])
         button[BtnMenu]->repaint(false);
 }
 
-
 // Gallium: New button show/hide magic for customizable
 //          button positions.
 void B2Client::calcHiddenButtons()
 {
     // Hide buttons in this order:
-    // Sticky, Help, Maximize, Minimize, Close, Menu
-    B2Button* btnArray[] = { button[BtnSticky], button[BtnHelp],
-                             button[BtnMax], button[BtnIconify],
-                             button[BtnClose], button[BtnMenu] };
+    // Shade, Sticky, Help, Resize, Maximize, Minimize, Close, Menu
+    B2Button* btnArray[] = { 
+	button[BtnShade], button[BtnSticky], button[BtnHelp], button[BtnResize],
+	button[BtnMax], button[BtnIconify], button[BtnClose], button[BtnMenu] 
+    };
     int minWidth = 120;
     int currentWidth = width();
     int count = 0;
@@ -483,7 +571,7 @@ void B2Client::captionChange()
     titlebar->repaint(false);
 }
 
-void B2Client::paintEvent( QPaintEvent* e)
+void B2Client::paintEvent(QPaintEvent* e)
 {
     QPainter p(widget());
 
@@ -496,19 +584,20 @@ void B2Client::paintEvent( QPaintEvent* e)
     int fHeight = height() - t.height();
 
     // distance from the bottom border - it is different if window is resizable
-    int bb = isResizable() ? 4 : 0;
+    int bb = mustDrawHandle() ? 4 : 0;
     int bDepth = thickness + bb;
 
     QColorGroup fillColor = options()->colorGroup(frameColorGroup, isActive());
     QBrush fillBrush(options()->color(frameColorGroup, isActive()));
 
     // outer frame rect
-    p.drawRect(0, t.bottom() - thickness + 1, width(), fHeight - bb + thickness);
+    p.drawRect(0, t.bottom() - thickness + 1, 
+	    width(), fHeight - bb + thickness);
 
     if (thickness >= 2) {
 	// inner window rect
-	p.drawRect(thickness - 1, t.bottom(), width() - 2 * (thickness - 1),
-		fHeight - bDepth + 2);
+	p.drawRect(thickness - 1, t.bottom(), 
+		width() - 2 * (thickness - 1), fHeight - bDepth + 2);
 
 	if (thickness >= 3) {
 	    // frame shade panel
@@ -538,7 +627,7 @@ void B2Client::paintEvent( QPaintEvent* e)
     }
 
     // bottom handle rect
-    if (isResizable()) {
+    if (mustDrawHandle()) {
         p.setPen(Qt::black);
 	int hx = width() - 40;
 	int hw = 40;
@@ -581,7 +670,7 @@ void B2Client::paintEvent( QPaintEvent* e)
     }
 }
 
-#define QCOORDARRLEN(x) sizeof(x)/(sizeof(QCOORD)*2)
+#define QCOORDARRLEN(x) sizeof(x) / (sizeof(QCOORD) * 2)
 
 void B2Client::doShape()
 {
@@ -599,13 +688,14 @@ void B2Client::doShape()
 		width() - t.right() - 1, t.height() - thickness);
     }
     mask -= QRect(width() - 1, height() - 1, 1, 1); //bottom right point
-    if (isResizable()) {
+    if (mustDrawHandle()) {
 	mask -= QRect(0, height() - 5, 1, 1); //bottom left point
 	mask -= QRect(width() - 1, height() - 1, 1, 1); //bottom right point
 	mask -= QRect(width() - 40, height() - 1, 1, 1); //handle left point
 	mask -= QRect(0, height() - 4, width() - 40, 4); //bottom left
     } else {
 	mask -= QRect(0, height() - 1, 1, 1); // bottom left point
+	mask -= QRect(width() - 1, height() - 1, 1, 1); //bottom right point
     }
 
     setMask(mask);
@@ -614,42 +704,43 @@ void B2Client::doShape()
 void B2Client::showEvent(QShowEvent *)
 {
     calcHiddenButtons();
+    positionButtons();
     doShape();
     widget()->repaint();
     titlebar->repaint(false);
 }
 
-KDecoration::Position B2Client::mousePosition( const QPoint& p ) const
+KDecoration::Position B2Client::mousePosition(const QPoint& p) const
 {
     const int range = 16;
     QRect t = titlebar->geometry();
     t.setHeight(buttonSize + 4 - thickness);
     int ly = t.bottom();
     int lx = t.right();
-    int bb = isResizable() ? 0 : 5;
+    int bb = mustDrawHandle() ? 0 : 5;
 
-    if ( p.x() > t.right() ) {
-        if ( p.y() <= ly + range && p.x() >= width()-range)
+    if (p.x() > t.right()) {
+        if (p.y() <= ly + range && p.x() >= width() - range)
             return PositionTopRight;
-        else if ( p.y() <= ly + thickness )
+        else if (p.y() <= ly + thickness)
             return PositionTop;
-    } else if ( p.x() < bar_x_ofs ) {
-        if ( p.y() <= ly + range && p.x() <= range )
+    } else if (p.x() < bar_x_ofs) {
+        if (p.y() <= ly + range && p.x() <= range)
             return PositionTopLeft;
-        else if ( p.y() <= ly + thickness )
+        else if (p.y() <= ly + thickness)
             return PositionTop;
-    } else if ( p.y() < ly ) {
+    } else if (p.y() < ly) {
         if (p.x() > bar_x_ofs + thickness &&
 		p.x() < lx - thickness && p.y() > thickness)
             return KDecoration::mousePosition(p);
         if (p.x() > bar_x_ofs + range && p.x() < lx - range)
             return PositionTop;
-        if ( p.y() <= range ) {
-            if ( p.x() <= bar_x_ofs + range )
+        if (p.y() <= range) {
+            if (p.x() <= bar_x_ofs + range)
                 return PositionTopLeft;
             else return PositionTopRight;
         } else {
-            if ( p.x() <= bar_x_ofs + range )
+            if (p.x() <= bar_x_ofs + range)
                 return PositionLeft;
             else return PositionRight;
         }
@@ -665,7 +756,6 @@ KDecoration::Position B2Client::mousePosition( const QPoint& p ) const
     return KDecoration::mousePosition(p);
 }
 
-
 void B2Client::titleMoveAbs(int new_ofs)
 {
     if (new_ofs < 0) new_ofs = 0;
@@ -676,7 +766,7 @@ void B2Client::titleMoveAbs(int new_ofs)
         bar_x_ofs = new_ofs;
 	positionButtons();
 	doShape();
-	widget()->repaint( 0, 0, width(), buttonSize + 4, false );
+	widget()->repaint(0, 0, width(), buttonSize + 4, false);
 	titlebar->repaint(false);
     }
 }
@@ -692,7 +782,8 @@ void B2Client::desktopChange()
     if (B2Button *b = button[BtnSticky]) {
         b->setDown(on);
 	QToolTip::remove(b);
-	QToolTip::add(b, on ? i18n("Not On All Desktops") : i18n("On All Desktops"));
+	QToolTip::add(b, 
+		on ? i18n("Not on all desktops") : i18n("On all desktops"));
     }
 }
 
@@ -700,13 +791,13 @@ void B2Client::maximizeChange()
 {
     bool m = maximizeMode() == MaximizeFull;
     if (button[BtnMax]) {
-        button[BtnMax]->setPixmaps( m ? P_NORMALIZE : P_MAX );
+        button[BtnMax]->setPixmaps(m ? P_NORMALIZE : P_MAX);
         button[BtnMax]->repaint();
 	QToolTip::remove(button[BtnMax]);
 	QToolTip::add(button[BtnMax],
 		m ? i18n("Restore") : i18n("Maximize"));
     }
-    spacer->changeSize(10, thickness + (isResizable() ? 4 : 0),
+    spacer->changeSize(10, thickness + (mustDrawHandle() ? 4 : 0),
 	    QSizePolicy::Expanding, QSizePolicy::Minimum);
 
     g->activate();
@@ -731,10 +822,14 @@ void B2Client::activeChange()
 
 void B2Client::shadeChange()
 {
-    spacer->changeSize(10, thickness + (isResizable() ? 4 : 0),
+    spacer->changeSize(10, thickness + (mustDrawHandle() ? 4 : 0),
 	    QSizePolicy::Expanding, QSizePolicy::Minimum);
     g->activate();
     doShape();
+    if (B2Button *b = button[BtnShade]) {
+	QToolTip::remove(b);
+	QToolTip::add(b, isSetShade() ? i18n("Unshade") : i18n("Shade"));
+    }
 }
 
 QSize B2Client::minimumSize() const
@@ -753,39 +848,44 @@ void B2Client::borders(int &left, int &right, int &top, int &bottom) const
 {
     left = right = thickness;
     top = buttonSize + 4;
-    bottom = thickness + (isResizable() ? 4 : 0);
+    bottom = thickness + (mustDrawHandle() ? 4 : 0);
 }
 
 void B2Client::menuButtonPressed()
 {
-    QPoint menupoint = button[BtnMenu]->mapToGlobal(
-	    button[BtnMenu]->rect().bottomLeft());
-    KDecorationFactory* f = factory();
-    showWindowMenu(menupoint);
-    if( !f->exists( this )) // 'this' was destroyed
-        return;
-    button[BtnMenu]->setDown(false);
+    static B2Client *lastClient = NULL;
+    
+    bool dbl = (lastClient == this && 
+	        time.elapsed() <= QApplication::doubleClickInterval());
+    lastClient = this;
+    time.start();
+    if (!dbl) {
+	KDecorationFactory* f = factory();
+	QRect menuRect = button[BtnMenu]->rect();
+	QPoint menuTop = button[BtnMenu]->mapToGlobal(menuRect.topLeft());
+	QPoint menuBottom = button[BtnMenu]->mapToGlobal(menuRect.bottomRight());
+	showWindowMenu(QRect(menuTop, menuBottom));
+	if (!f->exists(this)) // 'this' was destroyed
+	    return;
+	button[BtnMenu]->setDown(false);
+    } else {
+	switch (menu_dbl_click_op) {
+	case B2::MinimizeOp:
+	    minimize();
+	    break;
+	case B2::ShadeOp:
+	    setShade(!isSetShade());
+	    break;
+	case B2::CloseOp:
+	    closeWindow();
+	    break;
+	case B2::NoOp:
+	default:
+	    break;
+	}
+    }
 }
 
-#if 0
-void B2Client::slotReset()
-{
-    redraw_pixmaps();
-    QColor c = options()->colorGroup(KDecoration::ColorTitleBar, isActive()).
-        color(QColorGroup::Button);
-
-    for (int i = 0; i < BtnCount; i++)
-        if (button[i]) {
-            button[i]->setBg(c);
-            button[i]->repaint(false);
-        }
-
-    widget()->repaint();
-    titlebar->recalcBuffer();
-    titlebar->repaint(false);
-}
-#endif
-
 void B2Client::unobscureTitlebar()
 {
     /* we just noticed, that we got obscured by other windows
@@ -797,7 +897,7 @@ void B2Client::unobscureTitlebar()
     }
     in_unobs = 1;
     QRegion reg(QRect(0,0,width(), buttonSize + 4));
-    reg = unobscuredRegion( reg );
+    reg = unobscuredRegion(reg);
     if (!reg.isEmpty()) {
         // there is at least _one_ pixel from our title area, which is not
 	// obscured, we use the first rect we find
@@ -810,33 +910,49 @@ void B2Client::unobscureTitlebar()
 
 static void redraw_pixmaps()
 {
+    int i;
     QColorGroup aGrp = options()->colorGroup(KDecoration::ColorButtonBg, true);
     QColorGroup iGrp = options()->colorGroup(KDecoration::ColorButtonBg, false);
 
     // close
     drawB2Rect(PIXMAP_A(P_CLOSE), aGrp.button(), false);
+    drawB2Rect(PIXMAP_AH(P_CLOSE), aGrp.button(), true);
     drawB2Rect(PIXMAP_AD(P_CLOSE), aGrp.button(), true);
 
     drawB2Rect(PIXMAP_I(P_CLOSE), iGrp.button(), false);
+    drawB2Rect(PIXMAP_IH(P_CLOSE), iGrp.button(), true);
     drawB2Rect(PIXMAP_ID(P_CLOSE), iGrp.button(), true);
 
-    // maximize
-    int i;
-    for (i = 0; i < 4; i++) {
-	*pixmap[P_MAX*4 + i] = *pixmap[P_CLOSE*4 + i];
-	pixmap[P_MAX*4 + i]->detach();
+    // shade
+    KPixmap thinBox;
+    thinBox.resize(buttonSize - 2, 6);
+    for (i = 0; i < NumStates; i++) {
+	bool is_act = (i < 2);
+	bool is_down = ((i & 1) == 1);
+	KPixmap *pix = pixmap[P_SHADE * NumStates + i];
+	QColor color = is_act ? aGrp.button() : iGrp.button();
+	drawB2Rect(&thinBox, color, is_down);
+	pix->fill(Qt::black);
+	bitBlt(pix, 0, 0, &thinBox, 
+		0, 0, thinBox.width(), thinBox.height(), Qt::CopyROP, true);
     }
 
+    // maximize
+    for (i = 0; i < NumStates; i++) {
+	*pixmap[P_MAX * NumStates + i] = *pixmap[P_CLOSE * NumStates + i];
+	pixmap[P_MAX * NumStates + i]->detach();
+    }
+    
     // normalize + iconify
     KPixmap smallBox;
     smallBox.resize(10, 10);
     KPixmap largeBox;
     largeBox.resize(12, 12);
 
-    for (i = 0; i < 4; i++) {
-	bool is_act = (i < 2);
-	bool is_down = ((i & 1) == 1);
-	KPixmap *pix = pixmap[P_NORMALIZE*4 + i];
+    for (i = 0; i < NumStates; i++) {
+	bool is_act = (i < 3);
+	bool is_down = (i == Down || i == IDown);
+	KPixmap *pix = pixmap[P_NORMALIZE * NumStates + i];
 	drawB2Rect(&smallBox, is_act ? aGrp.button() : iGrp.button(), is_down);
 	drawB2Rect(&largeBox, is_act ? aGrp.button() : iGrp.button(), is_down);
 	pix->fill(options()->color(KDecoration::ColorTitleBar, is_act));
@@ -844,51 +960,74 @@ static void redraw_pixmaps()
 	       0, 0, 12, 12, Qt::CopyROP, true);
 	bitBlt(pix, 0, 0, &smallBox, 0, 0, 10, 10, Qt::CopyROP, true);
 
-	bitBlt(pixmap[P_ICONIFY * 4 + i], 0, 0,
+	bitBlt(pixmap[P_ICONIFY * NumStates + i], 0, 0,
 	       &smallBox, 0, 0, 10, 10, Qt::CopyROP, true);
     }
+    
+    // resize
+    for (i = 0; i < NumStates; i++) {
+	bool is_act = (i < 3);
+	bool is_down = (i == Down || i == IDown);
+	*pixmap[P_RESIZE * NumStates + i] = *pixmap[P_CLOSE * NumStates + i];
+	pixmap[P_RESIZE * NumStates + i]->detach();
+	drawB2Rect(&smallBox, is_act ? aGrp.button() : iGrp.button(), is_down);
+	bitBlt(pixmap[P_RESIZE * NumStates + i], 
+		0, 0, &smallBox, 0, 0, 10, 10, Qt::CopyROP, true);
+    }
+
 
     QPainter p;
     // x for close + menu + help
-    int pix = P_CLOSE;
-    const unsigned char *light = close_white_bits;
-    const unsigned char *dark = close_dgray_bits;
-    int off = (pixmap[pix * 4]->width() - 16) / 2;
-    for (i = 0; i < 4; i++) {
-	p.begin(pixmap[pix * 4 + i]);
-	kColorBitmaps(&p, (i < 2) ? aGrp : iGrp, off, off, 16, 16, true,
-		      light, NULL, NULL, dark, NULL, NULL);
-	p.end();
-    }
-    // x for close + menu + help
-    for (int j = 0; j < 2; j++) {
+    for (int j = 0; j < 3; j++) {
+        int pix;
+        unsigned const char *light, *dark;
         switch (j) {
-	case 1:
-	    pix = P_MENU; light = menu_white_bits; dark = menu_dgray_bits;
-	    break;
+        case 0:
+            pix = P_CLOSE; light = close_white_bits; dark = close_dgray_bits;
+            break;
+        case 1:
+            pix = P_MENU; light = menu_white_bits; dark = menu_dgray_bits;
+            break;
         default:
-	    pix = P_HELP; light = help_light_bits; dark = help_dark_bits;
-	    break;
+            pix = P_HELP; light = help_light_bits; dark = help_dark_bits;
+            break;
         }
-        for (i = 0; i < 4; i++) {
-            p.begin(pixmap[pix * 4 + i]);
-            kColorBitmaps(&p, (i < 2) ? aGrp : iGrp, 0, 0, 16, 16, true,
+	int off = (pixmap[pix * NumStates]->width() - 16) / 2;
+        for (i = 0; i < NumStates; i++) {
+            p.begin(pixmap[pix * NumStates + i]);
+            kColorBitmaps(&p, (i < 3) ? aGrp : iGrp, off, off, 16, 16, true,
                           light, NULL, NULL, dark, NULL, NULL);
             p.end();
         }
     }
 
     // pin
-    for (i = 0; i < 4; i++) {
-        const unsigned char *white = (i&1) ? pindown_white_bits : pinup_white_bits;
-        const unsigned char *gray = (i&1) ? pindown_gray_bits : pinup_gray_bits;
-        const unsigned char *dgray = (i&1) ? pindown_dgray_bits : pinup_dgray_bits;
-        p.begin(pixmap[P_PINUP*4 + i]);
-        kColorBitmaps(&p, (i<2)?aGrp:iGrp, 0, 0, 16, 16, true, white,
+    for (i = 0; i < NumStates; i++) {
+	bool isDown = (i == Down || i == IDown);
+        unsigned const char *white = isDown ? pindown_white_bits : pinup_white_bits;
+        unsigned const char *gray = isDown ? pindown_gray_bits : pinup_gray_bits;
+        unsigned const char *dgray =isDown ? pindown_dgray_bits : pinup_dgray_bits;
+        p.begin(pixmap[P_PINUP * NumStates + i]);
+        kColorBitmaps(&p, (i < 3) ? aGrp : iGrp, 0, 0, 16, 16, true, white,
                       gray, NULL, dgray, NULL, NULL);
         p.end();
     }
 
+    // Apply the hilight effect to the 'Hover' icons
+    KIconEffect ie;
+    QPixmap hilighted;
+    for (i = 0; i < P_NUM_BUTTON_TYPES; i++) {
+	int offset = i * NumStates;
+	hilighted = ie.apply(*pixmap[offset + Norm], 
+		KIcon::Small, KIcon::ActiveState);
+	*pixmap[offset + Hover] = hilighted;    
+
+	hilighted = ie.apply(*pixmap[offset + INorm], 
+		KIcon::Small, KIcon::ActiveState);
+	*pixmap[offset + IHover] = hilighted;    
+    }
+
+    
     // Create the titlebar gradients
     if (QPixmap::defaultDepth() > 8) {
 	QColor titleColor[4] = {
@@ -927,11 +1066,11 @@ void B2Client::positionButtons()
     QString cap = caption();
     if (cap.length() < 5) // make sure the titlebar has sufficiently wide
         cap = "XXXXX";    // area for dragging the window
-    int textLen = fm.width( cap );
+    int textLen = fm.width(cap);
 
     QRect t = titlebar->captionSpacer->geometry();
-    int titleWidth = titlebar->width() - t.width() + textLen+2;
-    if (titleWidth > width()) titleWidth=width();
+    int titleWidth = titlebar->width() - t.width() + textLen + 2;
+    if (titleWidth > width()) titleWidth = width();
 
     titlebar->resize(titleWidth, buttonSize + 4);
     titlebar->move(bar_x_ofs, 0);
@@ -955,16 +1094,25 @@ bool B2Client::drawbound(const QRect& geom, bool clear)
 	int barLeft = geom.left() + bar_x_ofs;
 	int barRight = barLeft + t.width() - 1;
 	if (barRight > geom.right()) barRight = geom.right();
+        // line width is 5 pixels, so compensate for the 2 outer pixels (#88657)
+        QRect g = geom;
+        g.setLeft( g.left() + 2 );
+        g.setTop( g.top() + 2 );
+        g.setRight( g.right() - 2 );
+        g.setBottom( g.bottom() - 2 );
+        frameTop += 2;
+        barLeft += 2;
+        barRight -= 2;
 
 	bound_shape.putPoints(0, 8,
-		geom.left(), frameTop,
+		g.left(), frameTop,
 		barLeft, frameTop,
-		barLeft, geom.top(),
-		barRight, geom.top(),
+		barLeft, g.top(),
+		barRight, g.top(),
 		barRight, frameTop,
-		geom.right(), frameTop,
-		geom.right(), geom.bottom(),
-		geom.left(), geom.bottom());
+		g.right(), frameTop,
+		g.right(), g.bottom(),
+		g.left(), g.bottom());
     } else {
 	*visible_bound = geom;
     }
@@ -1008,10 +1156,12 @@ bool B2Client::eventFilter(QObject *o, QEvent *e)
 
 // =====================================
 
-B2Button::B2Button(B2Client *_client, QWidget *parent, const QString& tip, const int realizeBtns)
-   : QButton(parent, 0)
+B2Button::B2Button(B2Client *_client, QWidget *parent, 
+	const QString& tip, const int realizeBtns)
+   : QButton(parent, 0), hover(false)
 {
     setBackgroundMode(NoBackground);
+    setCursor(arrowCursor);
     realizeButtons = realizeBtns;
     client = _client;
     useMiniIcon = false;
@@ -1041,62 +1191,71 @@ void B2Button::drawButton(QPainter *p)
     if (useMiniIcon) {
         QPixmap miniIcon = client->icon().pixmap(QIconSet::Small,
 		client->isActive() ? QIconSet::Normal : QIconSet::Disabled);
-        p->drawPixmap((width()-miniIcon.width())/2,
-                      (height()-miniIcon.height())/2, miniIcon);
-    }
-    else{
-        if(client->isActive()){
-            if (isDown())
-                p->drawPixmap((width()-pDown->width())/2,
-                              (height()-pDown->height())/2, *pDown);
+        p->drawPixmap((width() - miniIcon.width()) / 2,
+                      (height() - miniIcon.height()) / 2, miniIcon);
+    } else {
+	int type;
+        if (client->isActive()) {
+            if (isOn() || isDown())
+		type = Down;
+            else if (hover)
+		type = Hover;
+	    else
+		type = Norm;
+        } else {
+            if (isOn() || isDown())
+		type = IDown;
+	    else if (hover)
+		type = IHover;
             else
-                p->drawPixmap((width()-pNorm->width())/2,
-                              (height()-pNorm->height())/2, *pNorm);
-        }
-        else{
-            if (isDown())
-                p->drawPixmap((width()-pDown->width())/2,
-                              (height()-pDown->height())/2, *iDown);
-            else
-                p->drawPixmap((width()-pNorm->width())/2,
-                              (height()-pNorm->height())/2, *iNorm);
+		type = INorm;
         }
+	p->drawPixmap((width() - icon[type]->width()) / 2, 
+		(height() - icon[type]->height()) / 2, *icon[type]);
     }
 }
 
-void B2Button::setPixmaps(KPixmap *pix, KPixmap *pixDown, KPixmap *iPix,
-                          KPixmap *iPixDown)
-{
-    pNorm = pix;
-    pDown = pixDown;
-    iNorm = iPix;
-    iDown = iPixDown;
-    repaint(false);
-}
-
 void B2Button::setPixmaps(int button_id)
 {
-  button_id *= 4;
-  setPixmaps(B2::pixmap[button_id], B2::pixmap[button_id+1],
-	     B2::pixmap[button_id+2], B2::pixmap[button_id+3]);
+    button_id *= NumStates;
+    for (int i = 0; i < NumStates; i++) {
+	icon[i] = B2::pixmap[button_id + i];
+    }
+    repaint(false);
 }
 
-void B2Button::mousePressEvent( QMouseEvent* e )
+void B2Button::mousePressEvent(QMouseEvent * e)
 {
     last_button = e->button();
-    QMouseEvent me(e->type(), e->pos(), e->globalPos(),
-                    (e->button()&realizeButtons)?LeftButton:NoButton, e->state());
+    QMouseEvent me(e->type(), e->pos(), e->globalPos(), 
+	    (e->button() & realizeButtons) ? LeftButton : NoButton, 
+	    e->state());
     QButton::mousePressEvent(&me);
 }
 
-void B2Button::mouseReleaseEvent( QMouseEvent* e )
+void B2Button::mouseReleaseEvent(QMouseEvent * e)
 {
     last_button = e->button();
-    QMouseEvent me(e->type(), e->pos(), e->globalPos(),
-                   (e->button()&realizeButtons)?LeftButton:NoButton, e->state());
+    QMouseEvent me(e->type(), e->pos(), e->globalPos(), 
+	    (e->button() & realizeButtons) ? LeftButton : NoButton, 
+	    e->state());
     QButton::mouseReleaseEvent(&me);
 }
 
+void B2Button::enterEvent(QEvent *e)
+{
+    hover = true;
+    repaint(false);
+    QButton::enterEvent(e);
+}
+
+void B2Button::leaveEvent(QEvent *e)
+{
+    hover = false;
+    repaint(false);
+    QButton::leaveEvent(e);
+}
+
 // =====================================
 
 B2Titlebar::B2Titlebar(B2Client *parent)
@@ -1105,7 +1264,7 @@ B2Titlebar::B2Titlebar(B2Client *parent)
       set_x11mask(false), isfullyobscured(false), shift_move(false)
 {
     setBackgroundMode(NoBackground);
-    captionSpacer = new QSpacerItem(10, buttonSize + 4,
+    captionSpacer = new QSpacerItem(buttonSize, buttonSize + 4,
 	    QSizePolicy::Expanding, QSizePolicy::Fixed);
 }
 
@@ -1125,7 +1284,7 @@ bool B2Titlebar::x11Event(XEvent *e)
 	    StructureNotifyMask | SubstructureRedirectMask |
 	    VisibilityChangeMask);
     }
-    switch ( e->type ) {
+    switch (e->type) {
     case VisibilityNotify:
 	isfullyobscured = false;
 	if (e->xvisibility.state == VisibilityFullyObscured) {
@@ -1167,7 +1326,6 @@ void B2Titlebar::drawTitlebar(QPainter &p, bool state)
 
 void B2Titlebar::recalcBuffer()
 {
-    QFontMetrics fm(options()->font(true));
     titleBuffer.resize(width(), height());
 
     QPainter p(&titleBuffer);
@@ -1200,7 +1358,7 @@ void B2Titlebar::mouseDoubleClickEvent(QMouseEvent *e)
     }
 }
 
-void B2Titlebar::mousePressEvent( QMouseEvent * e )
+void B2Titlebar::mousePressEvent(QMouseEvent * e)
 {
     shift_move = e->state() & ShiftButton;
     if (shift_move) {
@@ -1210,13 +1368,13 @@ void B2Titlebar::mousePressEvent( QMouseEvent * e )
     }
 }
 
-void B2Titlebar::mouseReleaseEvent( QMouseEvent * e )
+void B2Titlebar::mouseReleaseEvent(QMouseEvent * e)
 {
     if (shift_move) shift_move = false;
     else e->ignore();
 }
 
-void B2Titlebar::mouseMoveEvent( QMouseEvent * e )
+void B2Titlebar::mouseMoveEvent(QMouseEvent * e)
 {
     if (shift_move) {
 	int oldx = mapFromGlobal(moveOffset).x();
