@@ -1,6 +1,4 @@
 /* 	
- * $Id: config.h,v 1.2 2003/06/30 08:16:14 aseigo Exp $
- *
  *	This file contains the B2 configuration widget
  *
  *	Copyright (c) 2001
@@ -13,6 +11,9 @@
 
 #include <qcheckbox.h>
 #include <qgroupbox.h>
+#include <qhgroupbox.h>
+#include <qlabel.h>
+#include <qcombobox.h>
 #include <kconfig.h>
 
 class B2Config: public QObject
@@ -38,6 +39,9 @@ class B2Config: public QObject
 	private:
 		KConfig*   b2Config;
 		QCheckBox* cbColorBorder;
+		QCheckBox*  showGrabHandleCb;
+		QHGroupBox* actionsGB;
+		QComboBox*  menuDblClickOp;
 		QWidget* gb;
 };
 
