@@ -1,6 +1,4 @@
 /*
- * $Id: quartz.h,v 1.13 2003/12/15 15:10:17 lunakl Exp $
- *
  * Gallium-Quartz KWin client
  *
  * Copyright 2001
@@ -59,7 +57,7 @@ class QuartzButton : public QButton
 		void setBitmap(const unsigned char *bitmap);
 		void setTipText(const QString &tip);
 		QSize sizeHint() const;
-		int   last_button;
+		ButtonState last_button;
 		void turnOn( bool isOn );
 
 	protected:
@@ -98,7 +96,7 @@ class QuartzClient : public KDecoration
 		void mouseDoubleClickEvent( QMouseEvent * );
 		virtual void captionChange();
 		void maximizeChange();
-		virtual void shadeChange() {};
+		virtual void shadeChange();
 		virtual void activeChange();
 		virtual void iconChange();
 		virtual void desktopChange();
@@ -108,7 +106,12 @@ class QuartzClient : public KDecoration
 
 	protected slots:
 		void slotMaximize();
+		void slotAbove();
+		void slotBelow();
+		void slotShade();
 		void menuButtonPressed();
+		void keepAboveChange( bool );
+		void keepBelowChange( bool );
 
 	private:
 		bool isTool();
@@ -116,7 +119,8 @@ class QuartzClient : public KDecoration
 		void addClientButtons( const QString& s, bool isLeft=true );
 
 		enum Buttons{ BtnHelp=0, BtnMax, BtnIconify, BtnClose,
-					  BtnMenu, BtnOnAllDesktops, BtnCount };
+					  BtnMenu, BtnOnAllDesktops, BtnAbove, BtnBelow,
+					  BtnShade, BtnCount };
 		QuartzButton* button[ QuartzClient::BtnCount ];
 		int           lastButtonWidth;
 		int 		  titleHeight, borderSize;
