@@ -1,5 +1,4 @@
 /*
- * $Id: redmond.cpp,v 1.23.2.1 2004/01/21 19:16:12 giessl Exp $
  *
  * Redmond KWin client
  *
@@ -237,7 +236,8 @@ void delete_pixmaps()
 
 RedmondButton::RedmondButton(RedmondDeco *parent, const char *name,
       const unsigned char *bitmap, bool menuButton, bool isMini, int size, const QString& tip, const int realizeBtns)
-    : QButton(parent->widget(), name)
+    : QButton(parent->widget(), name),
+      last_button( NoButton ) 
 {
 	// Eliminate background flicker
 	setBackgroundMode( NoBackground );
@@ -485,12 +485,9 @@ void RedmondDeco::iconChange()
 
 void RedmondDeco::slotMaximize()
 {
-    if ( button[BtnMax]->last_button == MidButton )
-       maximize( maximizeMode() ^ MaximizeVertical );
-    else if ( button[BtnMax]->last_button == RightButton )
-       maximize( maximizeMode() ^ MaximizeHorizontal );
-    else
-       maximize( maximizeMode() == MaximizeFull ? MaximizeRestore : MaximizeFull );
+    if (button[BtnMax]) {
+        maximize(button[BtnMax]->last_button);
+    }
 }
 
 
@@ -817,10 +814,14 @@ void RedmondDeco::menuButtonPressed()
     lastClient = this;
     t->start();
     if (!dbl) {
-		QPoint menupoint(button[BtnMenu]->rect().bottomLeft().x()-3,
-		                 button[BtnMenu]->rect().bottomLeft().y()+4);
+		QRect menuRect = button[BtnMenu]->rect();
+		QPoint menuTop = QPoint(menuRect.topLeft().x()-3,
+		                 menuRect.topLeft().y());
+		QPoint menuBottom = QPoint(menuRect.bottomRight().x()+3,
+		                 menuRect.bottomRight().y()+4);
                 KDecorationFactory* f = factory();
-		showWindowMenu(button[BtnMenu]->mapToGlobal(menupoint));
+		showWindowMenu(QRect(button[BtnMenu]->mapToGlobal(menuTop), 
+					button[BtnMenu]->mapToGlobal(menuBottom)));
                 if( !f->exists( this )) // 'this' was destroyed
                     return;
 		button[BtnMenu]->setDown(false);
