@@ -1,5 +1,4 @@
 /*
- * $Id: redmond.h,v 1.10 2003/12/15 15:10:17 lunakl Exp $
  *
  * Redmond KWin client
  *
@@ -47,7 +46,7 @@ public:
 	void reset();
 
 	QSize sizeHint() const;
-	int   last_button;
+	ButtonState last_button;
 
 protected:
 	void mousePressEvent(QMouseEvent* e);
