@@ -26,15 +26,14 @@
 
 namespace Web
 {
- using namespace KWinInternal;
-    
+
  class WebButtonClose : public WebButton
   {
     Q_OBJECT
 
     public:
 
-      WebButtonClose(QWidget * parent);
+      WebButtonClose(QWidget * parent, WebClient* deco);
 
     protected:
 
