@@ -26,7 +26,6 @@
 
 namespace Web
 {
-  using namespace KWinInternal;
 
   class WebButtonMaximize : public WebButton
   {
@@ -34,7 +33,7 @@ namespace Web
 
     public:
 
-      WebButtonMaximize(bool maximised, QWidget * parent);
+      WebButtonMaximize(bool maximised, QWidget * parent, WebClient* deco);
 
     protected:
 
