@@ -192,7 +192,7 @@ void Workspace::updateMinimizedOfTransients( Client* c )
             if( !(*it)->isMinimized()
                  && !(*it)->isTopMenu() ) // topmenus are not minimized, they're hidden
                 {
-                (*it)->minimize();
+                (*it)->minimize( true ); // avoid animation
                 updateMinimizedOfTransients( (*it) );
                 }
             }
@@ -206,7 +206,7 @@ void Workspace::updateMinimizedOfTransients( Client* c )
             if( (*it)->isMinimized()
                 && !(*it)->isTopMenu())
                 {
-                (*it)->unminimize();
+                (*it)->unminimize( true ); // avoid animation
                 updateMinimizedOfTransients( (*it) );
                 }
             }
@@ -266,7 +266,7 @@ bool Client::belongToSameApplication( const Client* c1, const Client* c2, bool a
     else if( c2->isTransient() && c1->hasTransient( c2, true ))
         same_app = true; // c2 has c1 as mainwindow
     else if( c1->pid() != c2->pid()
-        || c1->wmClientMachine() != c2->wmClientMachine())
+        || c1->wmClientMachine( false ) != c2->wmClientMachine( false ))
         ; // different processes
     else if( c1->wmClientLeader() != c2->wmClientLeader()
         && c1->wmClientLeader() != c1->window() // if WM_CLIENT_LEADER is not set, it returns window(),
@@ -419,6 +419,8 @@ void Client::setTransient( Window new_transient_for_id )
             transient_for->addTransient( this );
             } // checkGroup() will check 'check_active_modal'
         checkGroup( NULL, true ); // force, because transiency has changed
+        if( isTopMenu())
+            workspace()->updateCurrentTopMenu();
         workspace()->updateClientLayer( this );
         }
     }
@@ -859,7 +861,15 @@ void Client::checkGroup( Group* set_group, bool force )
 	    }
         }
     checkGroupTransients();
-    // if the active window got new modal transient, activate it
+    checkActiveModal();
+    workspace()->updateClientLayer( this );
+    }
+
+bool Client::check_active_modal = false;
+
+void Client::checkActiveModal()
+    {
+    // if the active window got new modal transient, activate it.
     // cannot be done in AddTransient(), because there may temporarily
     // exist loops, breaking findModal
     Client* check_modal = workspace()->mostRecentlyActivatedClient();
@@ -867,11 +877,13 @@ void Client::checkGroup( Group* set_group, bool force )
         {
         Client* new_modal = check_modal->findModal();
         if( new_modal != NULL && new_modal != check_modal )
+            {
+            if( !new_modal->isManaged())
+                return; // postpone check until end of manage()
             workspace()->activateClient( new_modal );
+            }
         check_modal->check_active_modal = false;
         }
-    workspace()->updateClientLayer( this );
     }
 
-
 } // namespace
