@@ -1,6 +1,4 @@
 /*
-	$Id: kwindecoration.cpp,v 1.52.2.1 2004/05/15 00:48:09 tibirna Exp $
-
 	This is the new kwindecoration kcontrol module
 
 	Copyright (c) 2001
@@ -137,8 +135,8 @@ KWinDecorationModule::KWinDecorationModule(QWidget* parent, const char* name, co
 	cbUseCustomButtonPositions = new QCheckBox(
 			i18n("Use custom titlebar button &positions"), buttonPage );
 	QWhatsThis::add( cbUseCustomButtonPositions,
-			i18n(  "The appropriate settings can be found in the \"Buttons\" Tab. "
-				   "Please note that this option is not available on all styles yet!" ) );
+			i18n(  "The appropriate settings can be found in the \"Buttons\" Tab; "
+				   "please note that this option is not available on all styles yet." ) );
 
 	buttonBox = new QGroupBox( 1, Qt::Horizontal,
 			i18n("Titlebar Button Positions"), buttonPage );
@@ -178,6 +176,14 @@ KWinDecorationModule::KWinDecorationModule(QWidget* parent, const char* name, co
 
 	// Allow kwin dcop signal to update our selection list
 	connectDCOPSignal("kwin", 0, "dcopResetAllClients()", "dcopUpdateClientList()", false);
+	
+	KAboutData *about =
+		new KAboutData(I18N_NOOP("kcmkwindecoration"),
+				I18N_NOOP("Window Decoration Control Module"),
+				0, 0, KAboutData::License_GPL,
+				I18N_NOOP("(c) 2001 Karol Szwed"));
+	about->addAuthor("Karol Szwed", 0, "gallium@kde.org");
+	setAboutData(about);
 }
 
 
@@ -595,18 +601,6 @@ QString KWinDecorationModule::quickHelp() const
 }
 
 
-const KAboutData* KWinDecorationModule::aboutData() const
-{
-	KAboutData* about =
-		new KAboutData(I18N_NOOP("kcmkwindecoration"),
-				I18N_NOOP("Window Decoration Control Module"),
-				0, 0, KAboutData::License_GPL,
-				I18N_NOOP("(c) 2001 Karol Szwed"));
-	about->addAuthor("Karol Szwed", 0, "gallium@kde.org");
-	return about;
-}
-
-
 void KWinDecorationModule::resetKWin()
 {
 	bool ok = kapp->dcopClient()->send("kwin", "KWinInterface",
