@@ -1,6 +1,4 @@
 /* 
-	$Id: pixmaps.h,v 1.4 2003/09/19 11:14:41 lunakl Exp $
-
 	This is the new kwindecoration kcontrol module
 
 	Copyright (c) 2001
@@ -351,4 +349,164 @@ const char * titlebarspacer_xpm[] = {
 ".+@#$%",
 ".+@#$%"};
 
+/* XPM */
+const char * button_above_others_xpm[] = {
+"20 20 16 1",
+" 	c None",
+".	c #F3F3F3",
+"+	c #F2F2F2",
+"@	c #F1F1F1",
+"#	c #FFFFFF",
+"$	c #F0F0F0",
+"%	c #6E6E6E",
+"&	c #EFEFEF",
+"*	c #EEEEEE",
+"=	c #EDEDED",
+"-	c #ECECEC",
+";	c #EBEBEB",
+">	c #EAEAEA",
+",	c #E9E9E9",
+"'	c #E8E8E8",
+")	c #E7E7E7",
+"....................",
+"....................",
+"++++++++++++++++++++",
+"@@@@@@@@@@@@@@@@@@@@",
+"@@@@###########@@@@@",
+"$$$$#%%%%%%%%%%$$$$$",
+"&&&&#%&&&&&&&#%&&&&&",
+"&&&&#%&&#%%&&#%&&&&&",
+"****#%*#%%%%*#%*****",
+"====#%#%%%%%%#%=====",
+"====#%==#%%==#%=====",
+"----#%--#%%--#%-----",
+";;;;#%;;#%%;;#%;;;;;",
+";;;;#%########%;;;;;",
+">>>>#%%%%%%%%%%>>>>>",
+",,,,,,,,,,,,,,,,,,,,",
+",,,,,,,,,,,,,,,,,,,,",
+"''''''''''''''''''''",
+"))))))))))))))))))))",
+"))))))))))))))))))))"};
+
+/* XPM */
+const char * button_below_others_xpm[] = {
+"20 20 16 1",
+" 	c None",
+".	c #F3F3F3",
+"+	c #F2F2F2",
+"@	c #F1F1F1",
+"#	c #FFFFFF",
+"$	c #F0F0F0",
+"%	c #6E6E6E",
+"&	c #EFEFEF",
+"*	c #EEEEEE",
+"=	c #EDEDED",
+"-	c #ECECEC",
+";	c #EBEBEB",
+">	c #EAEAEA",
+",	c #E9E9E9",
+"'	c #E8E8E8",
+")	c #E7E7E7",
+"....................",
+"....................",
+"++++++++++++++++++++",
+"@@@@@@@@@@@@@@@@@@@@",
+"@@@@###########@@@@@",
+"$$$$#%%%%%%%%%%$$$$$",
+"&&&&#%&&##&&&#%&&&&&",
+"&&&&#%&&#%%&&#%&&&&&",
+"****#%**#%%**#%*****",
+"====#%###%%==#%=====",
+"====#%#%%%%%%#%=====",
+"----#%-#%%%%-#%-----",
+";;;;#%;;#%%;;#%;;;;;",
+";;;;#%########%;;;;;",
+">>>>#%%%%%%%%%%>>>>>",
+",,,,,,,,,,,,,,,,,,,,",
+",,,,,,,,,,,,,,,,,,,,",
+"''''''''''''''''''''",
+"))))))))))))))))))))",
+"))))))))))))))))))))"};
+
+/* XPM */
+const char * button_shade_xpm[] = {
+"20 20 16 1",
+" 	c None",
+".	c #F3F3F3",
+"+	c #F2F2F2",
+"@	c #F1F1F1",
+"#	c #FFFFFF",
+"$	c #F0F0F0",
+"%	c #6E6E6E",
+"&	c #EFEFEF",
+"*	c #EEEEEE",
+"=	c #EDEDED",
+"-	c #ECECEC",
+";	c #EBEBEB",
+">	c #EAEAEA",
+",	c #E9E9E9",
+"'	c #E8E8E8",
+")	c #E7E7E7",
+"....................",
+"....................",
+"++++++++++++++++++++",
+"@@@@@@@@@@@@@@@@@@@@",
+"@@@@###########@@@@@",
+"$$$$#%%%%%%%%%%$$$$$",
+"&&&&#%########%&&&&&",
+"&&&&#%%%%%%%%%%&&&&&",
+"*********#**********",
+"========#%%=========",
+"=======#%%%%========",
+"------#%%%%%%-------",
+";;;;;;;;#%%;;;;;;;;;",
+";;;;;#;#;#;#;#;;;;;;",
+">>>>>%>%>%>%>%>>>>>>",
+",,,,,,,,,,,,,,,,,,,,",
+",,,,,,,,,,,,,,,,,,,,",
+"''''''''''''''''''''",
+"))))))))))))))))))))",
+"))))))))))))))))))))"};
+
+/* XPM */
+const char * button_resize_xpm[] = {
+"20 20 16 1",
+" 	c None",
+".	c #F3F3F3",
+"+	c #F2F2F2",
+"@	c #F1F1F1",
+"#	c #FFFFFF",
+"$	c #F0F0F0",
+"%	c #6E6E6E",
+"&	c #EFEFEF",
+"*	c #EEEEEE",
+"=	c #EDEDED",
+"-	c #ECECEC",
+";	c #EBEBEB",
+">	c #EAEAEA",
+",	c #E9E9E9",
+"'	c #E8E8E8",
+")	c #E7E7E7",
+"....................",
+"....................",
+"++++++++++++++++++++",
+"@@@@@@@@@@@@@@@@@@@@",
+"@@@@###########@@@@@",
+"$$$$#%%%%%%%%%%$$$$$",
+"&&&&#%...#%..#%&&&&&",
+"&&&&#%...#%..#%&&&&&",
+"****#%...#%..#%*****",
+"====#%####%..#%=====",
+"====#%%%%%%..#%=====",
+"----#%.......#%-----",
+";;;;#%.......#%;;;;;",
+";;;;#%########%;;;;;",
+">>>>#%%%%%%%%%%>>>>>",
+",,,,,,,,,,,,,,,,,,,,",
+",,,,,,,,,,,,,,,,,,,,",
+"''''''''''''''''''''",
+"))))))))))))))))))))",
+"))))))))))))))))))))"};
+
 // vim: ts=4
