@@ -32,7 +32,6 @@ class KConfig;
 class KFocusConfig;
 class KActionsConfig;
 class KAdvancedConfig;
-class KAboutData;
 
 class KWinOptions : public KCModule
 {
@@ -47,7 +46,6 @@ public:
   void save();
   void defaults();
   QString quickHelp() const;
-  const KAboutData* aboutData() const;
 
 
 protected slots:
