@@ -54,9 +54,11 @@
 #define KWIN_MINIMIZE_ANIM         "AnimateMinimize"
 #define KWIN_MINIMIZE_ANIM_SPEED   "AnimateMinimizeSpeed"
 #define KWIN_RESIZE_OPAQUE         "ResizeMode"
-#define KWIN_GEOMETRY		   "GeometryTip"
+#define KWIN_GEOMETRY              "GeometryTip"
 #define KWIN_AUTORAISE_INTERVAL    "AutoRaiseInterval"
 #define KWIN_AUTORAISE             "AutoRaise"
+#define KWIN_DELAYFOCUS_INTERVAL   "DelayFocusInterval"
+#define KWIN_DELAYFOCUS            "DelayFocus"
 #define KWIN_CLICKRAISE            "ClickRaise"
 #define KWIN_ANIMSHADE             "AnimateShade"
 #define KWIN_MOVE_RESIZE_MAXIMIZED "MoveResizeMaximizedWindows"
@@ -130,20 +132,22 @@ KFocusConfig::KFocusConfig (bool _standAlone, KConfig *_config, QWidget * parent
     // FIXME, when more policies have been added to KWin
     wtstr = i18n("The focus policy is used to determine the active window, i.e."
                                       " the window you can work in. <ul>"
-                                      " <li><em>Click to focus:</em> A window becomes active when you click into it. This is the behavior"
-                                      " you might know from other operating systems.</li>"
+                                      " <li><em>Click to focus:</em> A window becomes active when you click into it."
+                                      " This is the behavior you might know from other operating systems.</li>"
                                       " <li><em>Focus follows mouse:</em> Moving the mouse pointer actively on to a"
-                                      " normal window activates it. Very practical if you are using the mouse a lot.</li>"
+                                      " normal window activates it. New windows will receive the focus,"
+                                      " without you having to point the mouse at them explicitly."
+                                      " Very practical if you are using the mouse a lot.</li>"
                                       " <li><em>Focus under mouse:</em> The window that happens to be under the"
-                                      " mouse pointer becomes active. If the mouse points nowhere, the last window"
-                                      " that was under the mouse has focus. </li>"
-                                      " <li><em>Focus strictly under mouse:</em> This is even worse than"
-                                      " 'Focus under mouse'. Only the window under the mouse pointer is"
+                                      " mouse pointer is active. If the mouse points nowhere, the last window"
+                                      " that was under the mouse has focus."
+                                      " New windows will not automatically receive the focus.</li>"
+                                      " <li><em>Focus strictly under mouse:</em> Only the window under the mouse pointer is"
                                       " active. If the mouse points nowhere, nothing has focus."
                                       " </ul>"
-                                      " Note that 'Focus under mouse' and 'Focus strictly under mouse' are not"
-                                      " particularly useful. They are only provided for old-fashioned"
-                                      " die-hard UNIX people ;-)"
+                                      "Note that 'Focus under mouse' and 'Focus strictly under mouse' prevent certain"
+                                      " features such as the Alt+Tab walk through windows dialog in the KDE mode"
+                                      " from working properly."
                          );
     QWhatsThis::add( focusCombo, wtstr);
     QWhatsThis::add(fLabel, wtstr);
@@ -162,6 +166,19 @@ KFocusConfig::KFocusConfig (bool _standAlone, KConfig *_config, QWidget * parent
     autoRaise->setSuffix(i18n(" msec"));
     fLay->addWidget(autoRaise);
 
+    connect(focusCombo, SIGNAL(activated(int)), this, SLOT(setDelayFocusEnabled()) );
+    
+    delayFocusOn = new QCheckBox(i18n("Delay focus"), fcsBox);
+    fLay->addWidget(delayFocusOn);
+    connect(delayFocusOn,SIGNAL(toggled(bool)), this, SLOT(delayFocusOnTog(bool)));
+
+    delayFocus = new KIntNumInput(500, fcsBox);
+    delayFocus->setLabel(i18n("Dela&y:"), Qt::AlignVCenter|Qt::AlignLeft);
+    delayFocus->setRange(0, 3000, 100, true);
+    delayFocus->setSteps(100,100);
+    delayFocus->setSuffix(i18n(" msec"));
+    fLay->addWidget(delayFocus);
+    
     clickRaiseOn = new QCheckBox(i18n("C&lick raise active window"), fcsBox);
     connect(clickRaiseOn,SIGNAL(toggled(bool)), this, SLOT(clickRaiseOnTog(bool)));
     fLay->addWidget(clickRaiseOn);
@@ -180,46 +197,47 @@ KFocusConfig::KFocusConfig (bool _standAlone, KConfig *_config, QWidget * parent
                                         " it for inactive windows, you need to change the settings"
                                         " in the Actions tab.") );
 
+    QWhatsThis::add( delayFocusOn, i18n("When this option is enabled, there will be a delay after which the"
+                                        " window the mouse pointer is over will become active (receive focus).") );
+    QWhatsThis::add( delayFocus, i18n("This is the delay after which the window the mouse pointer is over"
+                                       " will automatically receive focus.") );
+
     lay->addWidget(fcsBox);
 
     kbdBox = new QButtonGroup(i18n("Navigation"), this);
     kbdBox->setColumnLayout( 0, Qt::Horizontal );
-    QGridLayout *kLay = new QGridLayout(kbdBox->layout(), 4, 4,
-                                        KDialog::spacingHint());
-    QLabel *altTabLabel = new QLabel( i18n("Walk through windows mode:"), kbdBox);
-    kLay->addWidget(altTabLabel, 1, 0);
-    kdeMode = new QRadioButton(i18n("&KDE"), kbdBox);
-    kLay->addWidget(kdeMode, 1, 1);
-    cdeMode = new QRadioButton(i18n("CD&E"), kbdBox);
-    kLay->addWidget(cdeMode, 1, 2);
+    QVBoxLayout *kLay = new QVBoxLayout(kbdBox->layout(), KDialog::spacingHint());
+
+    altTabPopup = new QCheckBox( i18n("Show window list while switching windows"), kbdBox );
+    kLay->addWidget( altTabPopup );
 
     wtstr = i18n("Hold down the Alt key and press the Tab key repeatedly to walk"
                  " through the windows on the current desktop (the Alt+Tab"
-                 " combination can be reconfigured). The two different modes mean:<ul>"
-                 "<li><b>KDE</b>: a nice widget is shown, displaying the icons of all windows to"
-                 " walk through and the title of the currently selected one;"
-                 "<li><b>CDE</b>: the focus is passed to a new window each time Tab is pressed."
-                 " No fancy widget.</li></ul>");
-    QWhatsThis::add( altTabLabel, wtstr );
-    QWhatsThis::add( kdeMode, wtstr );
-    QWhatsThis::add( cdeMode, wtstr );
+                 " combination can be reconfigured).\n\n"
+                 "If this checkbox is checked"
+                 " a popup widget is shown, displaying the icons of all windows to"
+                 " walk through and the title of the currently selected one.\n\n"
+                 "Otherwise, the focus is passed to a new window each time Tab"
+                 " is pressed, with no popup widget.  In addition, the previously"
+                 " activated window will be sent to the back in this mode.");
+    QWhatsThis::add( altTabPopup, wtstr );
 
     traverseAll = new QCheckBox( i18n( "&Traverse windows on all desktops" ), kbdBox );
-    kLay->addMultiCellWidget( traverseAll, 2, 2, 0, 2 );
+    kLay->addWidget( traverseAll );
 
     wtstr = i18n( "Leave this option disabled if you want to limit walking through"
                   " windows to the current desktop." );
     QWhatsThis::add( traverseAll, wtstr );
 
     rollOverDesktops = new QCheckBox( i18n("Desktop navi&gation wraps around"), kbdBox );
-    kLay->addMultiCellWidget(rollOverDesktops, 3, 3, 0, 2);
+    kLay->addWidget(rollOverDesktops);
 
     wtstr = i18n( "Enable this option if you want keyboard or active desktop border navigation beyond"
                   " the edge of a desktop to take you to the opposite edge of the new desktop." );
     QWhatsThis::add( rollOverDesktops, wtstr );
 
     showPopupinfo = new QCheckBox( i18n("Popup desktop name on desktop &switch"), kbdBox );
-    kLay->addMultiCellWidget(showPopupinfo, 4, 4, 0, 2);
+    kLay->addWidget(showPopupinfo);
 
     wtstr = i18n( "Enable this option if you wish to see the current desktop"
                   " name popup whenever the current desktop is changed." );
@@ -233,8 +251,8 @@ KFocusConfig::KFocusConfig (bool _standAlone, KConfig *_config, QWidget * parent
     connect(focusCombo, SIGNAL(activated(int)), SLOT(changed()));
     connect(fcsBox, SIGNAL(clicked(int)), SLOT(changed()));
     connect(autoRaise, SIGNAL(valueChanged(int)), SLOT(changed()));
-    connect(kdeMode, SIGNAL(clicked()), SLOT(changed()));
-    connect(cdeMode, SIGNAL(clicked()), SLOT(changed()));
+    connect(delayFocus, SIGNAL(valueChanged(int)), SLOT(changed()));
+    connect(altTabPopup, SIGNAL(clicked()), SLOT(changed()));
     connect(traverseAll, SIGNAL(clicked()), SLOT(changed()));
     connect(rollOverDesktops, SIGNAL(clicked()), SLOT(changed()));
     connect(showPopupinfo, SIGNAL(clicked()), SLOT(changed()));
@@ -261,16 +279,31 @@ void KFocusConfig::setAutoRaiseInterval(int tb)
     autoRaise->setValue(tb);
 }
 
+void KFocusConfig::setDelayFocusInterval(int tb)
+{
+    delayFocus->setValue(tb);
+}
+
 int KFocusConfig::getAutoRaiseInterval()
 {
     return autoRaise->value();
 }
 
+int KFocusConfig::getDelayFocusInterval()
+{
+    return delayFocus->value();
+}
+
 void KFocusConfig::setAutoRaise(bool on)
 {
     autoRaiseOn->setChecked(on);
 }
 
+void KFocusConfig::setDelayFocus(bool on)
+{
+    delayFocusOn->setChecked(on);
+}
+
 void KFocusConfig::setClickRaise(bool on)
 {
     clickRaiseOn->setChecked(on);
@@ -291,18 +324,35 @@ void KFocusConfig::setAutoRaiseEnabled()
     }
 }
 
+void KFocusConfig::setDelayFocusEnabled()
+{
+    // the delayed focus related widgets are: delayFocus
+    if ( focusCombo->currentItem() != CLICK_TO_FOCUS )
+    {
+        delayFocusOn->setEnabled(true);
+        delayFocusOnTog(delayFocusOn->isChecked());
+    }
+    else
+    {
+        delayFocusOn->setEnabled(false);
+        delayFocusOnTog(false);
+    }
+}
 
 void KFocusConfig::autoRaiseOnTog(bool a) {
     autoRaise->setEnabled(a);
     clickRaiseOn->setEnabled( !a );
 }
 
+void KFocusConfig::delayFocusOnTog(bool a) {
+    delayFocus->setEnabled(a);
+}
+
 void KFocusConfig::clickRaiseOnTog(bool ) {
 }
 
 void KFocusConfig::setAltTabMode(bool a) {
-    kdeMode->setChecked(a);
-    cdeMode->setChecked(!a);
+    altTabPopup->setChecked(a);
 }
 
 void KFocusConfig::setTraverseAll(bool a) {
@@ -336,11 +386,17 @@ void KFocusConfig::load( void )
     int k = config->readNumEntry(KWIN_AUTORAISE_INTERVAL,750);
     setAutoRaiseInterval(k);
 
+    k = config->readNumEntry(KWIN_DELAYFOCUS_INTERVAL,750);
+    setDelayFocusInterval(k);
+    
     key = config->readEntry(KWIN_AUTORAISE);
     setAutoRaise(key == "on");
+    key = config->readEntry(KWIN_DELAYFOCUS);
+    setDelayFocus(key == "on");
     key = config->readEntry(KWIN_CLICKRAISE);
     setClickRaise(key != "off");
     setAutoRaiseEnabled();      // this will disable/hide the auto raise delay widget if focus==click
+    setDelayFocusEnabled();
 
     key = config->readEntry(KWIN_ALTTABMODE, "KDE");
     setAltTabMode(key == "KDE");
@@ -377,17 +433,26 @@ void KFocusConfig::save( void )
     if (v <0) v = 0;
     config->writeEntry(KWIN_AUTORAISE_INTERVAL,v);
 
+    v = getDelayFocusInterval();
+    if (v <0) v = 0;
+    config->writeEntry(KWIN_DELAYFOCUS_INTERVAL,v);
+    
     if (autoRaiseOn->isChecked())
         config->writeEntry(KWIN_AUTORAISE, "on");
     else
         config->writeEntry(KWIN_AUTORAISE, "off");
 
+    if (delayFocusOn->isChecked())
+        config->writeEntry(KWIN_DELAYFOCUS, "on");
+    else
+        config->writeEntry(KWIN_DELAYFOCUS, "off");
+
     if (clickRaiseOn->isChecked())
         config->writeEntry(KWIN_CLICKRAISE, "on");
     else
         config->writeEntry(KWIN_CLICKRAISE, "off");
 
-    if (kdeMode->isChecked())
+    if (altTabPopup->isChecked())
         config->writeEntry(KWIN_ALTTABMODE, "KDE");
     else
         config->writeEntry(KWIN_ALTTABMODE, "CDE");
@@ -415,8 +480,10 @@ void KFocusConfig::save( void )
 void KFocusConfig::defaults()
 {
     setAutoRaiseInterval(0);
+    setDelayFocusInterval(0);
     setFocus(CLICK_TO_FOCUS);
     setAutoRaise(false);
+    setDelayFocus(false);
     setClickRaise(true);
     setAltTabMode(true);
     setTraverseAll( false );
@@ -506,7 +573,7 @@ KAdvancedConfig::KAdvancedConfig (bool _standAlone, KConfig *_config, QWidget *p
 
     lay->addWidget(electricBox);
 
-    QHBoxLayout* focusStealingLayout = new QHBoxLayout( this, KDialog::marginHint(), KDialog::spacingHint());
+    QHBoxLayout* focusStealingLayout = new QHBoxLayout( lay,KDialog::spacingHint());
     QLabel* focusStealingLabel = new QLabel( i18n( "Focus stealing prevention level:" ), this );
     focusStealing = new QComboBox( this );
     focusStealing->insertItem( i18n( "Focus Stealing Prevention Level", "None" ));
@@ -518,14 +585,16 @@ KAdvancedConfig::KAdvancedConfig (bool _standAlone, KConfig *_config, QWidget *p
     focusStealingLayout->addWidget( focusStealingLabel );
     focusStealingLayout->addWidget( focusStealing, AlignLeft );
     wtstr = i18n( "This option specifies how much KWin will try to prevent unwanted focus stealing "
-                  "caused by unexpected activation of new windows.<ul>"
-                  "<li><em>None:</em> The standard old behavior - prevention is turned off "
+                  "caused by unexpected activation of new windows. (Note: This feature does not "
+                  "work with the Focus Under Mouse or Focus Strictly Under Mouse focus policies.)"
+                  "<ul>"
+                  "<li><em>None:</em> Prevention is turned off "
                   "and new windows always become activated.</li>"
-                  "<li><em>Low:</em> Prevention is enabled; when some window doesn't have support "
+                  "<li><em>Low:</em> Prevention is enabled; when some window does not have support "
                   "for the underlying mechanism and KWin cannot reliably decide whether to "
                   "activate the window or not, it will be activated. This setting may have both "
                   "worse and better results than normal level, depending on the applications.</li>"
-                  "<li><em>Normal:</em> Prevention is enabled; the default setting.</li>"
+                  "<li><em>Normal:</em> Prevention is enabled.</li>"
                   "<li><em>High:</em> New windows get activated only if no window is currently active "
                   "or if they belong to the currently active application. This setting is probably "
                   "not really usable when not using mouse focus policy.</li>"
@@ -536,8 +605,6 @@ KAdvancedConfig::KAdvancedConfig (bool _standAlone, KConfig *_config, QWidget *p
 
     connect(focusStealing, SIGNAL(activated(int)), SLOT(changed()));
 
-    lay->addLayout( focusStealingLayout );
-
     lay->addStretch();
     load();
 
@@ -701,9 +768,9 @@ KMovingConfig::KMovingConfig (bool _standAlone, KConfig *_config, QWidget *paren
     geometryTipOn = new QCheckBox(i18n("Display window &geometry when moving or resizing"), windowsBox);
     bLay->addWidget(geometryTipOn);
     QWhatsThis::add(geometryTipOn, i18n("Enable this option if you want a window's geometry to be displayed"
-			    		" while it is being moved or resized. The window position relative"
-					" to the top-left corner of the screen is displayed together with"
-					" its size."));
+                                        " while it is being moved or resized. The window position relative"
+                                        " to the top-left corner of the screen is displayed together with"
+                                        " its size."));
 
     QGridLayout *rLay = new QGridLayout(2,3);
     bLay->addLayout(rLay);
@@ -819,7 +886,7 @@ KMovingConfig::KMovingConfig (bool _standAlone, KConfig *_config, QWidget *paren
 
     OverlapSnap=new QCheckBox(i18n("Snap windows onl&y when overlapping"),MagicBox);
     QWhatsThis::add( OverlapSnap, i18n("Here you can set that windows will be only"
-                                       " snapped if you try to overlap them, i.e. they won't be snapped if the windows"
+                                       " snapped if you try to overlap them, i.e. they will not be snapped if the windows"
                                        " comes only near another window or border.") );
 
     lay->addWidget(MagicBox);
