@@ -30,6 +30,7 @@ DEALINGS IN THE SOFTWARE.
 #include <qobject.h>
 #include <qiconset.h>
 #include <netwm_def.h>
+#include <kdeversion.h>
 
 class KDecorationOptionsPrivate;
 class KDecorationBridge;
@@ -39,6 +40,7 @@ class KDecorationFactory;
 /**
  * This class provides a namespace for all decoration related classes.
  * All shared types are defined here.
+ * @since 3.2
  */
 class KDecorationDefines
 {
@@ -86,7 +88,8 @@ public:
         KeepAboveOp,
         KeepBelowOp,
         OperationsOp,
-        ToggleStoreSettingsOp,
+        WindowRulesOp,
+        ToggleStoreSettingsOp = WindowRulesOp, ///< @obsolete
         HMaximizeOp,
         VMaximizeOp,
         LowerOp,
@@ -156,6 +159,7 @@ class KDecorationProvides
  * This class holds various configuration settings for the decoration.
  * It is accessible from the decorations either as KDecoration::options()
  * or KDecorationFactory::options().
+ * @since 3.2
  */
 class KDecorationOptions : public KDecorationDefines
     {
@@ -204,6 +208,9 @@ public:
     * @li 'I' minimize ( iconify ) button
     * @li 'A' maximize button
     * @li 'X' close button
+    * @li 'F' keep_above_others button
+    * @li 'B' keep_below_others button
+    * @li 'L' shade button
     * @li '_' spacer
     *
     * The default ( which is also returned if customButtonPositions returns false )
@@ -268,6 +275,7 @@ protected:
  * that give various information about the decorated window, and also
  * provides pure virtual functions for controlling the decoration that
  * every decoration should implement.
+ * @since 3.2
  */
 class KDecoration
     : public QObject, public KDecorationDefines
@@ -341,6 +349,8 @@ class KDecoration
 	/**
 	 * Returns @a true if the decorated window is currently shaded.
          * If the window is e.g. hover unshaded, it's not considered to be shaded.
+         * This function should not be used for the shade titlebar button, use
+         * @ref isSetShade() instead.
          *
          * @see isSetShade
 	 */
@@ -402,12 +412,22 @@ class KDecoration
 	 */
 	QString caption() const;
 	/**
-	 * This function invokes the window operations menu. IMPORTANT: As a result
-         * of this function, the decoration object that called it may be destroyed
-         * after the function returns. This means that the decoration object must
-         * either return immediately after calling showWindowMenu(), or it must
-         * use KDecorationFactory::exists() to check it's still valid. For example,
-         * the code handling clicks on the menu button should look similarly like this:
+	 * This function invokes the window operations menu. 
+	 * \param pos specifies the place on the screen where the menu should
+	 * show up. The menu pops up at the bottom-left corner of the specified
+	 * rectangle, unless there is no space, in which case the menu is
+	 * displayed above the rectangle.
+	 * 
+	 * \note Decorations that enable a double-click operation for the menu
+	 * button must ensure to call \a showWindowMenu() with the \a pos
+	 * rectangle set to the menu button geometry.
+	 * IMPORTANT: As a result of this function, the decoration object that
+	 * called it may be destroyed after the function returns. This means
+	 * that the decoration object must either return immediately after
+	 * calling showWindowMenu(), or it must use
+	 * KDecorationFactory::exists() to check it's still valid. For example,
+	 * the code handling clicks on the menu button should look similarly
+	 * like this:
          *
          * \code
          * KDecorationFactory* f = factory(); // needs to be saved before
@@ -417,6 +437,11 @@ class KDecoration
 	 * button[MenuButton]->setDown(false);
          * \endcode
 	 */
+	void showWindowMenu( const QRect &pos );
+
+	/**
+	 * Overloaded version of the above. 
+	 */
 	void showWindowMenu( QPoint pos );
         /**
          * This function performs the given window operation. This function may destroy
@@ -456,7 +481,7 @@ class KDecoration
          * Returns the intersection of the given region with the region left
          * unobscured by the windows stacked above the current one. You can use
          * this function to, for example, try to keep the titlebar visible if
-         * there is an hole available. The region returned is in the coordinate
+         * there is a hole available. The region returned is in the coordinate
          * space of the decoration.
          * @param r The region you want to check for holes
          */
@@ -554,10 +579,28 @@ class KDecoration
 	 * isShade() to get the current state.
 	 */
         virtual void shadeChange() = 0;
+#if KDE_IS_VERSION( 3, 90, 0 )
+#warning Redo all the XYZChange() virtuals as signals.
+#endif
+    signals:
+        /**
+         * This signal is emitted whenever the window's keep-above state changes.
+         * @since 3.3
+         */
+        void keepAboveChanged( bool );
+        /**
+         * This signal is emitted whenever the window's keep-below state changes.
+         * @since 3.3
+         */
+        void keepBelowChanged( bool );
+    public:
 	/**
 	 * This function may be reimplemented to provide custom bound drawing
 	 * for transparent moving or resizing of the window.
 	 * @a False should be returned if the default implementation should be used.
+         * Note that if you e.g. paint the outline using a 5 pixels wide line,
+         * you should compensate for the 2 pixels that would make the window
+         * look larger.
 	 *
 	 * @param geom  The geometry at this the bound should be drawn
 	 * @param clear @a true if the bound should be cleared
@@ -657,6 +700,31 @@ class KDecoration
          * just like showWindowMenu().
 	 */
 	void closeWindow();
+        /*
+         * Changes the maximize mode of the decorated window. This function should
+         * be preferred to the other maximize() overload for reacting on clicks
+         * on the maximize titlebar button.
+         * NOTE: This function is new in KDE3.3. In order to support also KDE3.2,
+         * it is recommended to use code like this:
+         * \code
+         * ButtonState button = ... ;
+         * #if KDE_IS_VERSION( 3, 3, 0 )
+         * maximize( button );
+         * #else
+         * if( button == MidButton )
+	 *     maximize( maximizeMode() ^ MaximizeVertical );
+         * else if( button == RightButton )
+         *     maximize( maximizeMode() ^ MaximizeHorizontal );
+         * else
+         *     maximize( maximizeMode() == MaximizeFull ? MaximizeRestore : MaximizeFull );
+         * #endif
+         * \endcode
+         * @since 3.3
+         */
+#if KDE_IS_VERSION( 3, 90, 0 )
+#warning Update the docs.
+#endif
+        void maximize( ButtonState button );
 	/**
 	 * Set the maximize mode of the decorated window.
 	 * @param mode The maximization mode to be set.
@@ -671,6 +739,10 @@ class KDecoration
 	 * the what's this mode).
 	 */
         void showContextHelp();
+        /**
+         * Moves the window to the given desktop. Use NET::OnAllDesktops for making
+         * the window appear on all desktops.
+         */
         void setDesktop( int desktop );
 	/**
 	 * This function toggles the on-all-desktops state of the decorated window.
@@ -696,6 +768,14 @@ class KDecoration
 	 * @param set Whether to keep the window below others
 	 */
         void setKeepBelow( bool set );
+        /**
+         * @internal
+         */
+        void emitKeepAboveChanged( bool above ) { emit keepAboveChanged( above ); }
+        /**
+         * @internal
+         */
+        void emitKeepBelowChanged( bool below ) { emit keepBelowChanged( below ); }
     private:
 	KDecorationBridge* bridge_;
 	QWidget* w_;
