@@ -22,9 +22,9 @@ License. See the file "COPYING" for the exact licensing terms.
 #include <X11/extensions/shape.h>
 
 #include "notifications.h"
+#include "rules.h"
 
 extern Time qt_x_time;
-extern Atom qt_window_role;
 
 namespace KWinInternal
 {
@@ -73,25 +73,13 @@ bool Client::manage( Window w, bool isMapped )
     properties[ WinInfo::PROTOCOLS2 ] =
         NET::WM2UserTime |
         NET::WM2StartupId |
+        NET::WM2ExtendedStrut |
         0;
 
     info = new WinInfo( this, qt_xdisplay(), client, qt_xrootwin(), properties, 2 );
 
     cmap = attr.colormap;
 
-    bool mresize, mmove, mminimize, mmaximize, mclose;
-    if( Motif::funcFlags( client, mresize, mmove, mminimize, mmaximize, mclose )) 
-        {
-        if( !hasNETSupport()) // NETWM apps should set type and size constraints
-            {
-            motif_may_resize = mresize; // this should be set using minsize==maxsize, but oh well
-            motif_may_move = mmove;
-            }
-        // mminimize; - ignore, bogus - e.g. shading or sending to another desktop is "minimizing" too
-        // mmaximize; - ignore, bogus - maximizing is basically just resizing
-        motif_may_close = mclose; // motif apps like to crash when they set this hint and WM closes them anyway
-        }
-
     XClassHint classHint;
     if ( XGetClassHint( qt_xdisplay(), client, &classHint ) ) 
         {
@@ -102,38 +90,40 @@ bool Client::manage( Window w, bool isMapped )
         XFree( classHint.res_name );
         XFree( classHint.res_class );
         }
-    ignore_focus_stealing = options->checkIgnoreFocusStealing( this );
+    ignore_focus_stealing = options->checkIgnoreFocusStealing( this ); // TODO change to rules
+
+    window_role = staticWindowRole( w );
+    // first only read the caption text, so that setupWindowRules() can use it for matching,
+    // and only then really set the caption using setCaption(), which checks for duplicates etc.
+    // and also relies on rules already existing
+    cap_normal = readName();
+    setupWindowRules( false );
+    setCaption( cap_normal, true );
 
     detectNoBorder();
-    fetchName();
     fetchIconicName();
     getWMHints(); // needs to be done before readTransient() because of reading the group
     getWmClientLeader(); // needs to be done before readTransient() because of same app comparing
+    modal = ( info->state() & NET::Modal ) != 0; // needs to be valid before handling groups
     readTransient();
     getIcons();
     getWindowProtocols();
     getWmNormalHints(); // get xSizeHint
-    window_role = getStringProperty( w, qt_window_role );
+    getMotifHints();
 
     // TODO try to obey all state information from info->state()
 
     original_skip_taskbar = skip_taskbar = ( info->state() & NET::SkipTaskbar) != 0;
     skip_pager = ( info->state() & NET::SkipPager) != 0;
-    modal = ( info->state() & NET::Modal ) != 0;
-
-    // window wants to stay on top?
-    keep_above = ( info->state() & NET::KeepAbove ) != 0;
-    // window wants to stay on bottom?
-    keep_below = ( info->state() & NET::KeepBelow ) != 0;
-    if( keep_above && keep_below )
-        keep_above = keep_below = false;
 
+    KStartupInfoId asn_id;
     KStartupInfoData asn_data;
-    bool asn_valid = workspace()->checkStartupNotification( window(), asn_data );
+    bool asn_valid = workspace()->checkStartupNotification( window(), asn_id, asn_data );
 
     workspace()->updateClientLayer( this );
 
     SessionInfo* session = workspace()->takeSessionInfo( this );
+    
     if ( session )
         {
         if ( session->minimized )
@@ -142,6 +132,10 @@ bool Client::manage( Window w, bool isMapped )
             setUserNoBorder( true );
         }
 
+    init_minimize = rules()->checkMinimize( init_minimize, !isMapped );
+    if( rules()->checkNoBorder( false, !isMapped ))
+        setUserNoBorder( true );
+
     // initial desktop placement
     if ( info->desktop() )
         desk = info->desktop(); // window had the initial desktop property!
@@ -182,6 +176,7 @@ bool Client::manage( Window w, bool isMapped )
         }
     if ( desk == 0 ) // assume window wants to be visible on the current desktop
         desk = workspace()->currentDesktop();
+    desk = rules()->checkDesktop( desk, !isMapped );
     if( desk != NET::OnAllDesktops ) // do range check
         desk = KMAX( 1, KMIN( workspace()->numberOfDesktops(), desk ));
     info->setDesktop( desk );
@@ -196,19 +191,16 @@ bool Client::manage( Window w, bool isMapped )
 
     QRect area;
     if( isMapped || session )
-        area = workspace()->clientArea( WorkArea, geom.center(), desktop());
+        area = workspace()->clientArea( FullArea, geom.center(), desktop());
     else if( options->xineramaPlacementEnabled )
         area = workspace()->clientArea( PlacementArea, QCursor::pos(), desktop());
     else
         area = workspace()->clientArea( PlacementArea, geom.center(), desktop());
 
-    // if it's noborder window, and has size of one screen or the whole desktop geometry, it's fullscreen hack
-    if( ( geom.size() == workspace()->clientArea( FullArea, geom.center(), desktop()).size()
-            || geom.size() == workspace()->clientArea( ScreenArea, geom.center(), desktop()).size())
-        && noBorder() && !isUserNoBorder() && isFullScreenable( true )) 
+    if( checkFullScreenHack( geom ))
         {
         fullscreen_mode = FullScreenHack;
-        geom = workspace()->clientArea( MaximizeFullArea, geom.center(), desktop());
+        geom = workspace()->clientArea( FullScreenArea, geom.center(), desktop());
         placementDone = true;
         }
 
@@ -219,34 +211,30 @@ bool Client::manage( Window w, bool isMapped )
         placementDone = true;
         }
 
-    if ( isMapped || session || placementDone
-         || ( isTransient() && !isUtility() && !isDialog() && !isSplash())) 
-        {  // TODO
-        placementDone = TRUE;
-        }
+    bool usePosition = false;
+    if ( isMapped || session || placementDone )
+        placementDone = true; // use geometry
+    else if( isTransient() && !isUtility() && !isDialog() && !isSplash())
+        usePosition = true;
     else if( isTransient() && !hasNETSupport())
-        placementDone = true;
-    else if( isDialog() && hasNETSupport()) // see Placement::placeDialog()
-        ; // force using placement policy
+        usePosition = true;
+    else if( isDialog() && hasNETSupport())
+    // if the dialog is actually non-NETWM transient window, don't try to apply placement to it,
+    // it breaks with too many things (xmms, display)
+        {
+        if( mainClients().count() >= 1 )
+            ; // force using placement policy
+        else
+            usePosition = true;
+        }
     else if( isSplash())
         ; // force using placement policy
     else
+        usePosition = true;
+    if( !rules()->checkIgnorePosition( !usePosition ))
         {
         bool ignorePPosition = ( options->ignorePositionClasses.contains(QString::fromLatin1(resourceClass())));
 
-        if ((xSizeHint.flags & PPosition) && ! ignorePPosition) 
-            {
-            int tx = geom.x();
-            int ty = geom.y();
-
-// TODO tyhle testy nepocitaji s dekoraci, ani s gravity
-            if (tx < 0)
-                tx = area.right() + tx;
-            if (ty < 0)
-                ty = area.bottom() + ty;
-            geom.moveTopLeft(QPoint(tx, ty));
-            }
-
         if ( ( (xSizeHint.flags & PPosition) && !ignorePPosition ) ||
              (xSizeHint.flags & USPosition) ) 
             {
@@ -254,16 +242,19 @@ bool Client::manage( Window w, bool isMapped )
             // disobey xinerama placement option for now (#70943)
             area = workspace()->clientArea( PlacementArea, geom.center(), desktop());
             }
+        }
+    if( true ) // size is always obeyed for now, only with constraints applied
         if ( (xSizeHint.flags & USSize) || (xSizeHint.flags & PSize) ) 
             {
             // keep in mind that we now actually have a size :-)
             }
-        }
 
     if (xSizeHint.flags & PMaxSize)
-        geom.setSize( geom.size().boundedTo( QSize(xSizeHint.max_width, xSizeHint.max_height ) ) );
+        geom.setSize( geom.size().boundedTo(
+            rules()->checkMaxSize( QSize(xSizeHint.max_width, xSizeHint.max_height ) ) ) );
     if (xSizeHint.flags & PMinSize)
-        geom.setSize( geom.size().expandedTo( QSize(xSizeHint.min_width, xSizeHint.min_height ) ) );
+        geom.setSize( geom.size().expandedTo(
+            rules()->checkMinSize( QSize(xSizeHint.min_width, xSizeHint.min_height ) ) ) );
 
     if( isMovable())
         {
@@ -276,8 +267,14 @@ bool Client::manage( Window w, bool isMapped )
 
     updateDecoration( false ); // also gravitates
     // TODO is CentralGravity right here, when resizing is done after gravitating?
-    plainResize( sizeForClientSize( geom.size()));
+    plainResize( rules()->checkSize( sizeForClientSize( geom.size()), !isMapped ));
 
+    QPoint forced_pos = rules()->checkPosition( invalidPoint, !isMapped );
+    if( forced_pos != invalidPoint )
+        {
+        move( forced_pos );
+        placementDone = true;
+        }
     if( !placementDone ) 
         { // placement needs to be after setting size
         workspace()->place( this, area );
@@ -308,7 +305,7 @@ bool Client::manage( Window w, bool isMapped )
         }
 
     if( init_minimize )
-        minimize();
+        minimize( true ); // no animation
 
     // SELI this seems to be mainly for kstart and ksystraycmd
     // probably should be replaced by something better
@@ -319,6 +316,8 @@ bool Client::manage( Window w, bool isMapped )
     // other settings from the previous session
     if ( session ) 
         {
+        // session restored windows are not considered to be new windows WRT rules,
+        // i.e. obey only forcing rules
         setKeepAbove( session->keepAbove );
         setKeepBelow( session->keepBelow );
         setSkipTaskbar( session->skipTaskbar, true );
@@ -369,33 +368,27 @@ bool Client::manage( Window w, bool isMapped )
         // done after checking that the window isn't larger than the workarea, so that
         // the restore geometry from the checks above takes precedence, and window
         // isn't restored larger than the workarea
-        if ( (info->state() & NET::Max) == NET::Max )
-            maximize( Client::MaximizeFull );
-        else if ( info->state() & NET::MaxVert )
-            maximize( Client::MaximizeVertical );
-        else if ( info->state() & NET::MaxHoriz )
-            maximize( Client::MaximizeHorizontal );
+        MaximizeMode maxmode = static_cast< MaximizeMode >
+            ((( info->state() & NET::MaxVert ) ? MaximizeVertical : 0 )
+            | (( info->state() & NET::MaxHoriz ) ? MaximizeHorizontal : 0 ));
+        MaximizeMode forced_maxmode = rules()->checkMaximize( maxmode, !isMapped );
+        // either hints were set to maximize, or is forced to maximize,
+        // or is forced to non-maximize and hints were set to maximize
+        if( forced_maxmode != MaximizeRestore || maxmode != MaximizeRestore )
+            maximize( forced_maxmode );
 
         // read other initial states
-        if( info->state() & NET::Shaded )
-            setShade( ShadeNormal );
-        if( info->state() & NET::KeepAbove )
-            setKeepAbove( true );
-        if( info->state() & NET::KeepBelow )
-            setKeepBelow( true );
-        if( info->state() & NET::SkipTaskbar )
-            setSkipTaskbar( true, true );
-        if( info->state() & NET::SkipPager )
-            setSkipPager( true );
+        setShade( rules()->checkShade( info->state() & NET::Shaded ? ShadeNormal : ShadeNone, !isMapped ));
+        setKeepAbove( rules()->checkKeepAbove( info->state() & NET::KeepAbove, !isMapped ));
+        setKeepBelow( rules()->checkKeepBelow( info->state() & NET::KeepBelow, !isMapped ));
+        setSkipTaskbar( rules()->checkSkipTaskbar( info->state() & NET::SkipTaskbar, !isMapped ), true );
+        setSkipPager( rules()->checkSkipPager( info->state() & NET::SkipPager, !isMapped ));
         if( info->state() & NET::DemandsAttention )
             demandAttention();
         if( info->state() & NET::Modal )
             setModal( true );
-        if( fullscreen_mode != FullScreenHack )
-            {
-            if(( info->state() & NET::FullScreen ) != 0 && isFullScreenable())
-                setFullScreen( true, false );
-            }
+        if( fullscreen_mode != FullScreenHack && isFullScreenable())
+            setFullScreen( rules()->checkFullScreen( info->state() & NET::FullScreen, !isMapped ), false );
         }
 
     updateAllowedActions( true );
@@ -405,7 +398,7 @@ bool Client::manage( Window w, bool isMapped )
     // - keep it?
     XLowerWindow( qt_xdisplay(), frameId());
 
-    user_time = readUserTimeMapTimestamp( asn_valid ? &asn_data : NULL, session );
+    user_time = readUserTimeMapTimestamp( asn_valid ? &asn_id : NULL, asn_valid ? &asn_data : NULL, session );
 
     if( isTopMenu()) // they're shown in Workspace::addClient() if their mainwindow
         hideClient( true ); // is the active one
@@ -417,8 +410,15 @@ bool Client::manage( Window w, bool isMapped )
         if( isNormalWindow())
             Notify::raise( Notify::New );
 
+        bool allow;
+        if( session )
+            allow = session->active && !workspace()->wasUserInteraction();
+        else
+            allow = workspace()->allowClientActivation( this, userTime(), false );
+
         // if session saving, force showing new windows (i.e. "save file?" dialogs etc.)
-        if( workspace()->sessionSaving() && !isOnCurrentDesktop())
+        // also force if activation is allowed
+        if( !isOnCurrentDesktop() && !isMapped && !session && ( allow || workspace()->sessionSaving()))
             workspace()->setCurrentDesktop( desktop());
 
         if( isOnCurrentDesktop())
@@ -432,7 +432,7 @@ bool Client::manage( Window w, bool isMapped )
                 }
             else
                 {
-                if( workspace()->allowClientActivation( this, userTime(), false, session && session->active ))
+                if( allow )
                     {
                     workspace()->raiseClient( this );
                     rawShow();
@@ -444,7 +444,7 @@ bool Client::manage( Window w, bool isMapped )
                     {
                     workspace()->restackClientUnderActive( this );
                     rawShow();
-                    if( ( !session || session->fake ) && ( !isSpecialWindow() || isOverride()))
+                    if( !session && ( !isSpecialWindow() || isOverride()))
                         demandAttention();
                     }
                 }
@@ -453,7 +453,7 @@ bool Client::manage( Window w, bool isMapped )
             {
             virtualDesktopChange();
             workspace()->raiseClient( this );
-            if( ( !session || session->fake ) && !isMapped )
+            if( !session && !isMapped )
                 demandAttention();
             }
         }
@@ -482,7 +482,12 @@ bool Client::manage( Window w, bool isMapped )
 
     delete session;
 
+    checkActiveModal();
+
     ungrabXServer();
+    
+    client_rules.discardTemporary();
+    updateWindowRules(); // was blocked while !isManaged()
 
     return true;
     }
