@@ -11,6 +11,8 @@ License. See the file "COPYING" for the exact licensing terms.
 
 #include "options.h"
 
+#ifndef KCMRULES
+
 #include <qpalette.h>
 #include <qpixmap.h>
 #include <kapplication.h>
@@ -21,9 +23,13 @@ License. See the file "COPYING" for the exact licensing terms.
 
 #include "client.h"
 
+#endif
+
 namespace KWinInternal
 {
 
+#ifndef KCMRULES
+
 Options::Options()
     :   electric_borders( 0 ),
         electric_border_delay(0)
@@ -45,8 +51,8 @@ unsigned long Options::updateSettings()
     changed |= d->updateKWinSettings( config ); // read decoration settings
 
     config->setGroup( "Windows" );
-    moveMode = config->readEntry("MoveMode", "Opaque" ) == "Opaque"?Opaque:Transparent;
-    resizeMode = config->readEntry("ResizeMode", "Opaque" ) == "Opaque"?Opaque:Transparent;
+    moveMode = stringToMoveResizeMode( config->readEntry("MoveMode", "Opaque" ));
+    resizeMode = stringToMoveResizeMode( config->readEntry("ResizeMode", "Opaque" ));
     show_geometry_tip = config->readBoolEntry("GeometryTip", false);
 
     QString val;
@@ -84,19 +90,15 @@ unsigned long Options::updateSettings()
         xineramaPlacementEnabled = gc->readBoolEntry ("XineramaPlacementEnabled", true);
         xineramaMovementEnabled = gc->readBoolEntry ("XineramaMovementEnabled", true);
         xineramaMaximizeEnabled = gc->readBoolEntry ("XineramaMaximizeEnabled", true);
+        xineramaFullscreenEnabled = gc->readBoolEntry ("XineramaFullscreenEnabled", true);
         }
     else 
         {
-        xineramaPlacementEnabled = xineramaMovementEnabled = xineramaMaximizeEnabled = false;
+        xineramaPlacementEnabled = xineramaMovementEnabled = xineramaMaximizeEnabled = xineramaFullscreenEnabled = false;
         }
     delete gc;
 
-    val = config->readEntry("Placement","Smart");
-    if (val == "Random")               placement = Random;
-    else if (val == "Cascade")              placement = Cascade;
-    else if (val == "Centered")     placement = Centered;
-    else if (val == "ZeroCornered") placement = ZeroCornered;
-    else                            placement = Smart;
+    placement = Placement::policyFromString( config->readEntry("Placement"), true );
 
     animateShade = config->readBoolEntry("AnimateShade", TRUE );
 
@@ -107,11 +109,15 @@ unsigned long Options::updateSettings()
         {
         autoRaise = false;
         autoRaiseInterval = 0;
+        delayFocus = false;
+        delayFocusInterval = 0;
         }
     else 
         {
         autoRaise = config->readBoolEntry("AutoRaise", FALSE );
         autoRaiseInterval = config->readNumEntry("AutoRaiseInterval", 0 );
+        delayFocus = config->readBoolEntry("DelayFocus", FALSE );
+        delayFocusInterval = config->readNumEntry("DelayFocusInterval", 0 );
         }
 
     shadeHover = config->readBoolEntry("ShadeHover", FALSE );
@@ -141,6 +147,8 @@ unsigned long Options::updateSettings()
          ++it )
         (*it) = (*it).lower();
 
+    killPingTimeout = config->readNumEntry( "KillPingTimeout", 5000 );
+
     // Mouse bindings
     config->setGroup( "MouseBindings");
     CmdActiveTitlebar1 = mouseCommand(config->readEntry("CommandActiveTitlebar1","Raise"), true );
@@ -249,5 +257,16 @@ bool Options::checkIgnoreFocusStealing( const Client* c )
     {
     return ignoreFocusStealingClasses.contains(QString::fromLatin1(c->resourceClass()));
     }
+#endif
+
+Options::MoveResizeMode Options::stringToMoveResizeMode( const QString& s )
+    {
+    return s == "Opaque" ? Opaque : Transparent;
+    }
+
+const char* Options::moveResizeModeToString( MoveResizeMode mode )
+    {
+    return mode == Opaque ? "Opaque" : "Transparent";
+    }
 
 } // namespace
