@@ -16,6 +16,7 @@ License. See the file "COPYING" for the exact licensing terms.
 #include <kshortcut.h>
 #include <qcursor.h>
 #include <netwm.h>
+#include <kxmessages.h>
 
 #include "KWinInterface.h"
 #include "utils.h"
@@ -28,6 +29,7 @@ class QPopupMenu;
 class KConfig;
 class KGlobalAccel;
 class KStartupInfo;
+class KStartupInfoId;
 class KStartupInfoData;
 
 namespace KWinInternal
@@ -39,6 +41,8 @@ class PopupInfo;
 class RootInfo;
 class PluginMgr;
 class Placement;
+class Rules;
+class WindowRules;
 
 class SystemTrayWindow
     {
@@ -80,11 +84,6 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
         template< typename T1, typename T2 > void forEachClient( T1 procedure, T2 predicate );
         template< typename T > void forEachClient( T procedure );
 
-        Group* findGroup( Window leader ) const;
-        void addGroup( Group* group, allowed_t );
-        void removeGroup( Group* group, allowed_t );
-        Group* findClientLeaderGroup( const Client* c ) const;
-
         QRect clientArea( clientAreaOption, const QPoint& p, int desktop ) const;
         QRect clientArea( clientAreaOption, const Client* c ) const;
 
@@ -109,13 +108,14 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
         // stealing prevention code.
         Client* mostRecentlyActivatedClient() const;
 
-        void setActiveClient( Client*, allowed_t );
         void activateClient( Client*, bool force = FALSE  );
         void requestFocus( Client* c, bool force = FALSE );
-        bool allowClientActivation( const Client* c, Time time = -1U, bool focus_in = false,
-            bool session_active = false );
+        void takeActivity( Client* c, int flags, bool handled ); // flags are ActivityFlags
+        void handleTakeActivity( Client* c, Time timestamp, int flags ); // flags are ActivityFlags
+        bool allowClientActivation( const Client* c, Time time = -1U, bool focus_in = false );
         void restoreFocus();
         void gotFocusIn( const Client* );
+        void setShouldGetFocus( Client* );
         bool fakeRequestedActivity( Client* c );
         void unfakeActivity( Client* c );
         void activateNextClient( Client* c );
@@ -132,10 +132,11 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
         void placeSmart( Client* c, const QRect& area );
 
         QPoint adjustClientPosition( Client* c, QPoint pos );
+        QRect adjustClientSize( Client* c, QRect moveResizeGeom, int mode );
         void raiseClient( Client* c );
         void lowerClient( Client* c );
-        void raiseClientRequest( Client* c );
-        void lowerClientRequest( Client* c );
+        void raiseClientRequest( Client* c, NET::RequestSource src, Time timestamp );
+        void lowerClientRequest( Client* c, NET::RequestSource src, Time timestamp );
         void restackClientUnderActive( Client* );
         void updateClientLayer( Client* c );
         void raiseOrLowerClient( Client * );
@@ -165,6 +166,7 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
         Client* previousStaticClient(Client*) const;
         int nextDesktopFocusChain( int iDesktop ) const;
         int previousDesktopFocusChain( int iDesktop ) const;
+        void closeTabBox();
 
          /**
          * Returns the list of clients sorted in stacking order, with topmost client
@@ -182,9 +184,13 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
         void showWindowMenuAt( unsigned long id, int x, int y );
 
         /**
-         * Shows the menu operations menu for the client
-         * and makes it active if it's not already.
+	 * Shows the menu operations menu for the client and makes it active if
+	 * it's not already.
          */
+        void showWindowMenu( const QRect &pos, Client* cl );
+	/**
+	 * Backwards compatibility.
+	 */
         void showWindowMenu( int x, int y, Client* cl );
         void showWindowMenu( QPoint pos, Client* cl );
 
@@ -197,7 +203,8 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
         void storeSession( KConfig* config, SMSavePhase phase );
 
         SessionInfo* takeSessionInfo( Client* );
-
+        WindowRules findWindowRules( const Client*, bool );
+        void rulesUpdated();
 
     // dcop interface
         void cascadeDesktop();
@@ -214,21 +221,31 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
         bool isNotManaged( const QString& title );  // ### setter or getter ?
 
         void sendPingToWindow( Window w, Time timestamp ); // called from Client::pingWindow()
+        void sendTakeActivity( Client* c, Time timestamp, long flags ); // called from Client::takeActivity()
 
     // only called from Client::destroyClient() or Client::releaseWindow()
         void removeClient( Client*, allowed_t );
+        void setActiveClient( Client*, allowed_t );
+        Group* findGroup( Window leader ) const;
+        void addGroup( Group* group, allowed_t );
+        void removeGroup( Group* group, allowed_t );
+        Group* findClientLeaderGroup( const Client* c ) const;
 
-        bool checkStartupNotification( Window w, KStartupInfoData& data );
+        bool checkStartupNotification( Window w, KStartupInfoId& id, KStartupInfoData& data );
 
         void focusToNull(); // SELI public?
+        
+        bool forcedGlobalMouseGrab() const;
 
         void sessionSaveStarted();
         void sessionSaveDone();
         void setWasUserInteraction();
+        bool wasUserInteraction() const;
         bool sessionSaving() const;
 
         bool managingTopMenus() const;
         int topMenuHeight() const;
+        void updateCurrentTopMenu();
 
         int packPositionLeft( const Client* cl, int oldx, bool left_edge ) const;
         int packPositionRight( const Client* cl, int oldx, bool right_edge ) const;
@@ -237,6 +254,9 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
 
         static QStringList configModules(bool controlCenter);
 
+        void cancelDelayFocus();
+        void requestDelayFocus( Client* );
+
     public slots:
         void refresh();
     // keybindings
@@ -306,13 +326,17 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
     private slots:
         void desktopPopupAboutToShow();
         void clientPopupAboutToShow();
-        void sendToDesktop( int );
+        void slotSendToDesktop( int );
         void clientPopupActivated( int );
         void configureWM();
         void desktopResized();
         void slotUpdateToolWindows();
         void lostTopMenuSelection();
         void lostTopMenuOwner();
+        void delayFocus();
+        void gotTemporaryRulesMessage( const QString& );
+        void cleanupTemporaryRules();
+        void writeWindowRules();
 
     protected:
         bool keyPressMouseEmulation( XKeyEvent& ev );
@@ -335,16 +359,17 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
         void oneStepThroughDesktops( bool forward, int mode ); // TabBox::Mode::DesktopMode | DesktopListMode
         void oneStepThroughDesktops( bool forward );
         void oneStepThroughDesktopList( bool forward );
+        bool establishTabBoxGrab();
+        void removeTabBoxGrab();
 
         void updateStackingOrder( bool propagate_new_clients = false );
         void propagateClients( bool propagate_new_clients ); // called only from updateStackingOrder
         ClientList constrainedStackingOrder();
         void raiseClientWithinApplication( Client* c );
         void lowerClientWithinApplication( Client* c );
-        bool allowFullClientRaising( const Client* c );
+        bool allowFullClientRaising( const Client* c, Time timestamp );
         bool keepTransientAbove( const Client* mainwindow, const Client* transient );
         void blockStackingUpdates( bool block );
-        void updateCurrentTopMenu();
         void addTopMenu( Client* c );
         void removeTopMenu( Client* c );
         void setupTopMenuHandling();
@@ -379,7 +404,7 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
         void tabBoxKeyRelease( const XKeyEvent& ev );
 
     // electric borders
-        void checkElectricBorders();
+        void checkElectricBorders( bool force = false );
         void createBorderWindows();
         void destroyBorderWindows();
         void electricBorder(XEvent * e);
@@ -403,15 +428,16 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
 
         Client* popup_client;
 
-        void loadSessionInfo();
-
         QWidget* desktop_widget;
 
+        void loadSessionInfo();
+        void loadWindowRules();
+        void editWindowRules( Client* );
+
         QPtrList<SessionInfo> session;
-        QPtrList<SessionInfo> fakeSession;
-        void loadFakeSessionInfo();
-        void storeFakeSessionInfo( Client* c );
-        void writeFakeSessionInfo();
+        QValueList<Rules*> rules;
+        KXMessages temporaryRulesMessages;
+        QTimer rulesUpdatedTimer;
         static const char* windowTypeToTxt( NET::WindowType type );
         static NET::WindowType txtToWindowType( const char* txt );
         static bool sessionInfoWindowTypeMatch( Client* c, SessionInfo* info );
@@ -420,6 +446,11 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
         Client* last_active_client;
         Client* most_recently_raised; // used _only_ by raiseOrLowerClient()
         Client* movingClient;
+        Client* pending_take_activity;
+
+    // delay(ed) window focus timer and client
+        QTimer* delayFocusTimer;
+        Client* delayfocus_client;
 
         ClientList clients;
         ClientList desktops;
@@ -505,6 +536,7 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
         Placement *initPositioning;
 
         QRect* workarea; //  array of workareas for virtual desktops
+        QRect** screenarea; // array of workareas per xinerama screen for all virtual desktops
 
         bool managing_topmenus;
         KSelectionOwner* topmenu_selection;
@@ -516,6 +548,8 @@ class Workspace : public QObject, public KWinInterface, public KDecorationDefine
         int set_active_client_recursion;
         int block_stacking_updates; // when >0, stacking updates are temporarily disabled
         bool blocked_propagating_new_clients; // propagate also new clients after enabling stacking updates?
+        Window null_focus_window;
+        bool forced_global_mouse_grab;
         friend class StackingUpdatesBlocker;
     };
 
@@ -532,7 +566,7 @@ class StackingUpdatesBlocker
     };
 
 // NET WM Protocol handler class
-class RootInfo : public NETRootInfo2
+class RootInfo : public NETRootInfo3
     {
     private:
         typedef KWinInternal::Client Client;  // because of NET::Client
@@ -547,7 +581,8 @@ class RootInfo : public NETRootInfo2
         virtual void moveResize(Window w, int x_root, int y_root, unsigned long direction);
         virtual void moveResizeWindow(Window w, int flags, int x, int y, int width, int height );
         virtual void gotPing(Window w, Time timestamp);
-        virtual void restackWindow(Window w, Window above, int detail);
+        virtual void restackWindow(Window w, RequestSource source, Window above, int detail, Time timestamp);
+        virtual void gotTakeActivity(Window w, Time timestamp, long flags );
     private:
         Workspace* workspace;
     };
@@ -601,7 +636,12 @@ inline const ClientList& Workspace::stackingOrder() const
 
 inline void Workspace::showWindowMenu(QPoint pos, Client* cl)
     {
-    showWindowMenu(pos.x(), pos.y(), cl);
+    showWindowMenu(QRect(pos, pos), cl);
+    }
+
+inline void Workspace::showWindowMenu(int x, int y, Client* cl)
+    {
+    showWindowMenu(QRect(QPoint(x, y), QPoint(x, y)), cl);
     }
 
 inline
@@ -610,6 +650,12 @@ void Workspace::setWasUserInteraction()
     was_user_interaction = true;
     }
 
+inline
+bool Workspace::wasUserInteraction() const
+    {
+    return was_user_interaction;
+    }
+
 inline
 bool Workspace::managingTopMenus() const
     {
@@ -631,6 +677,11 @@ inline bool Workspace::sessionSaving() const
     return session_saving;
     }
 
+inline bool Workspace::forcedGlobalMouseGrab() const
+    {
+    return forced_global_mouse_grab;
+    }
+
 template< typename T >
 inline Client* Workspace::findClient( T predicate )
     {
