@@ -79,7 +79,8 @@ OptionListItem * OptionListItem::findChildItem( const QString& optionName )
 }
 
 LayoutConfig::LayoutConfig(QWidget *parent, const char *name)
-  : KCModule(parent, name), m_rules(0)
+  : KCModule(parent, name), 
+    m_rules(NULL)
 {
   QVBoxLayout *main = new QVBoxLayout(this, 0, KDialog::spacingHint());
 
@@ -88,11 +89,12 @@ LayoutConfig::LayoutConfig(QWidget *parent, const char *name)
 
   connect( widget->chkEnable, SIGNAL( toggled( bool )), this, SLOT(changed()));
   connect( widget->chkShowSingle, SIGNAL( toggled( bool )), this, SLOT(changed()));
+  connect( widget->chkShowFlag, SIGNAL( toggled( bool )), this, SLOT(changed()));
   connect( widget->comboModel, SIGNAL(activated(int)), this, SLOT(changed()));
 
-  connect( widget->btnAdd, SIGNAL(clicked()), this, SLOT(changed()));
+  connect( widget->listLayoutsSrc, SIGNAL(doubleClicked(QListViewItem*,const QPoint&, int)),
+									this, SLOT(add()));
   connect( widget->btnAdd, SIGNAL(clicked()), this, SLOT(add()));
-  connect( widget->btnRemove, SIGNAL(clicked()), this, SLOT(changed()));
   connect( widget->btnRemove, SIGNAL(clicked()), this, SLOT(remove()));
 
   connect( widget->comboVariant, SIGNAL(activated(int)), this, SLOT(changed()));
@@ -122,7 +124,7 @@ LayoutConfig::LayoutConfig(QWidget *parent, const char *name)
 #endif
 
   //Read rules - we _must_ read _before_ creating xkb-options comboboxes
-  ruleChanged("xfree86");
+  ruleChanged();
 
   makeOptionsTab();
 
@@ -146,13 +148,17 @@ void LayoutConfig::add()
     QListViewItem* sel = widget->listLayoutsSrc->selectedItem();
     if( sel == 0 )
 	return;
-
+    
+    widget->listLayoutsSrc->takeItem(sel);
     widget->listLayoutsDst->insertItem(sel);
-    sel->moveItem(widget->listLayoutsDst->lastItem());
-    widget->listLayoutsSrc->setSelected(sel, true);
-    layoutSelChanged(sel);
+    if( widget->listLayoutsDst->childCount() > 1 )
+	sel->moveItem(widget->listLayoutsDst->lastItem());
+// disabling temporary: does not work reliable in Qt :(
+//    widget->listLayoutsSrc->setSelected(sel, true);
+//    layoutSelChanged(sel);
 
     updateStickyLimit();
+    changed();
 }
 
 void LayoutConfig::remove()
@@ -169,12 +175,14 @@ void LayoutConfig::remove()
     if( sel->itemAbove() )
 	newSel = sel->itemAbove();
 
+    widget->listLayoutsDst->takeItem(sel);
     widget->listLayoutsSrc->insertItem(sel);
     if( newSel )
 	widget->listLayoutsSrc->setSelected(newSel, true);
     layoutSelChanged(newSel);
 
     updateStickyLimit();
+    changed();
 }
 
 void LayoutConfig::moveUp()
@@ -232,7 +240,6 @@ void LayoutConfig::latinChanged()
 
 void LayoutConfig::layoutSelChanged(QListViewItem *sel)
 {
-
     widget->comboVariant->clear();
     widget->comboVariant->setEnabled( sel != 0 );
     widget->chkLatin->setChecked( false );
@@ -245,12 +252,14 @@ void LayoutConfig::layoutSelChanged(QListViewItem *sel)
 
     QString kbdLayout = lookupLocalized( m_rules->layouts(), sel->text(1) );
 
-    if (  ! m_rules->isSingleGroup(kbdLayout) || kbdLayout == "us" ) {
-        widget->chkLatin->setEnabled(  false );
+// need better algorithm here for determining if needs us group
+    if (  ! m_rules->isSingleGroup(kbdLayout) 
+	    || kbdLayout.startsWith("us") || kbdLayout.startsWith("en") ) {
+        widget->chkLatin->setEnabled( false );
     }
     else {
         char* inc = m_includes[ kbdLayout ];
-        if ( inc && strcmp(inc, "us")==0 ) {
+        if ( inc && (strncmp(inc, "us", 2)==0 || strncmp(inc, "en", 2)==0) ) {
             widget->chkLatin->setChecked(true);
         }
         else {
@@ -260,7 +269,6 @@ void LayoutConfig::layoutSelChanged(QListViewItem *sel)
 
     QStringList vars = m_rules->getVariants(kbdLayout);
 
-
     if( vars.count() == 0 ) {	// cowardly running away
         updateLayoutCommand();
         return;
@@ -292,6 +300,8 @@ QWidget* LayoutConfig::makeOptionsTab()
   connect(listView, SIGNAL(clicked(QListViewItem *)), SLOT(changed()));
   connect(listView, SIGNAL(clicked(QListViewItem *)), SLOT(updateOptionsCommand()));
 
+  connect(widget->chkEnableOptions, SIGNAL(toggled(bool)), SLOT(changed()));
+
   connect(widget->checkResetOld, SIGNAL(toggled(bool)), SLOT(changed()));
   connect(widget->checkResetOld, SIGNAL(toggled(bool)), SLOT(updateOptionsCommand()));
 
@@ -405,10 +415,10 @@ void LayoutConfig::load()
   bool use = config->readBoolEntry( "Use", false );
 
   // find out which rule applies
-  QString rule = "xfree86"; //config->readEntry("Rule", "xfree86");
+  //QString rule = "xfree86"; //config->readEntry("Rule", "xfree86");
 
   // update other files
-  ruleChanged(rule);
+  ruleChanged();
 
   // find out about the model
   QString model = config->readEntry("Model", "pc104");
@@ -432,6 +442,7 @@ void LayoutConfig::load()
     for ( ; src_it.current(); ++src_it ) {
 	QListViewItem* srcItem = src_it.current();
 	if ( *it == lookupLocalized(m_rules->layouts(), src_it.current()->text(1)) ) {
+    	    widget->listLayoutsSrc->takeItem(srcItem);
     	    widget->listLayoutsDst->insertItem(srcItem);
 	    srcItem->moveItem(widget->listLayoutsDst->lastItem());
 	    break;
@@ -450,6 +461,9 @@ void LayoutConfig::load()
   bool showSingle = config->readBoolEntry( "ShowSingle", false );
   widget->chkShowSingle->setChecked(showSingle);
 
+  bool showFlag = config->readBoolEntry( "ShowFlag", true );
+  widget->chkShowFlag->setChecked(showFlag);
+
   bool enableXkbOptions = config->readBoolEntry( "EnableXkbOptions", true );
   widget->chkEnableOptions->setChecked( enableXkbOptions );
   bool resetOld = config->readBoolEntry("ResetOldOptions", false);
@@ -499,12 +513,12 @@ void LayoutConfig::load()
   emit KCModule::changed( false );
 }
 
-void LayoutConfig::ruleChanged(const QString &rule)
+void LayoutConfig::ruleChanged()
 {
-  if( rule == m_rule )
-    return;
+//  if( rule == m_rule )
+//    return;
 
-  m_rule = rule;
+//  m_rule = rule;
 
   QString model; //, layout;
   if (m_rules)
@@ -514,7 +528,7 @@ void LayoutConfig::ruleChanged(const QString &rule)
     }
 
   delete m_rules;
-  m_rules = new KeyRules(rule);
+  m_rules = new KeyRules();
 
   QStringList tmp;
   widget->comboModel->clear();
@@ -535,7 +549,7 @@ void LayoutConfig::ruleChanged(const QString &rule)
     {
       QCheckListItem *item = new QCheckListItem(widget->listLayoutsSrc, "");
       QString addLayout = it2.currentKey();
-      item->setPixmap(0, findPixmap(addLayout));
+      item->setPixmap(0, LayoutIcon::findPixmap(addLayout, true));
       item->setText(1, i18n(it2.current()) );
       item->setText(2, "(" + addLayout + ")" );
       ++it2;
@@ -650,6 +664,7 @@ void LayoutConfig::save()
 
   config->writeEntry("Use", widget->chkEnable->isChecked());
   config->writeEntry("ShowSingle", widget->chkShowSingle->isChecked());
+  config->writeEntry("ShowFlag", widget->chkShowFlag->isChecked());
 
   int modeId = widget->grpSwitching->id(widget->grpSwitching->selected());
   if( modeId < 1 || modeId > 2 )
@@ -672,7 +687,7 @@ void LayoutConfig::save()
 void LayoutConfig::defaults()
 {
   widget->chkEnable->setChecked(false);
-  ruleChanged("xfree86");
+  ruleChanged();
 
   widget->comboModel->setCurrentText("pc104");
   //layoutCombo->setCurrentText("us");
