@@ -78,7 +78,7 @@ void TrayWindow::setCurrentLayout(const QString& layout)
 
     KIconEffect iconeffect;
 
-    setPixmap( iconeffect.apply(findPixmap(layout), KIcon::Panel, KIcon::DefaultState) );
+    setPixmap( iconeffect.apply(LayoutIcon::findPixmap(layout, m_showFlag), KIcon::Panel, KIcon::DefaultState) );
 }
 
 void TrayWindow::setError(const QString& layout)
@@ -87,7 +87,7 @@ void TrayWindow::setError(const QString& layout)
     QToolTip::remove(this);
     QToolTip::add(this, msg);
 
-    setPixmap(findPixmap("error"));
+    setPixmap(LayoutIcon::findPixmap("error", m_showFlag));
 }
 
 void TrayWindow::setLayouts(const QStringList& layouts, const KeyRules& rules)
@@ -105,7 +105,7 @@ void TrayWindow::setLayouts(const QStringList& layouts, const KeyRules& rules)
     QStringList::ConstIterator it;
     for (it=layouts.begin(); it != layouts.end(); ++it)
     {
-        const QPixmap pix=iconeffect.apply(findPixmap(*it), KIcon::Small, KIcon::DefaultState);
+        const QPixmap pix = iconeffect.apply(LayoutIcon::findPixmap(*it, m_showFlag), KIcon::Small, KIcon::DefaultState);
         contextMenu()->insertItem(pix, i18n((rules.layouts()[*it])), cnt++);
         mDescriptionMap.insert(*it, i18n((rules.layouts()[*it])));
     }    
@@ -136,7 +136,8 @@ KXKBApp::KXKBApp(bool allowStyles, bool GUIenabled)
     prevWinId(0),
     m_rules(NULL),
     m_tray(NULL),
-    kWinModule(NULL)
+    kWinModule(NULL),
+    m_forceSetXKBMap( false )
 {
     m_extension = new XKBExtension;
     if( !m_extension->init() ) {
@@ -222,12 +223,12 @@ bool KXKBApp::settingsRead()
 	}
     }
 
-    QString rule = "xfree86"; //config->readEntry("Rule", "xfree86");
-    m_rules = new KeyRules( rule );
+    m_rules = new KeyRules();
     m_model = config->readEntry("Model", "pc104");
     m_layout = config->readEntry("Layout", "");
     m_defaultLayout = m_layout;
 
+
     m_list = config->readListEntry("Additional");
     if (!m_list.contains(m_layout))
     {
@@ -274,6 +275,8 @@ bool KXKBApp::settingsRead()
 	connect(m_tray, SIGNAL(toggled()), this, SLOT(toggled()));
     }
 
+    bool showFlag = config->readBoolEntry("ShowFlag", true);
+    m_tray->setShowFlag(showFlag);
     m_tray->setLayouts(m_list, *m_rules);
     m_tray->setCurrentLayout(m_layout);
     m_tray->show();
@@ -297,19 +300,26 @@ void KXKBApp::layoutApply()
 // Activates the keyboard layout specified by 'layout'
 bool KXKBApp::setLayout(const QString& layout)
 {
-    bool res;
+    bool res = false;
     const char* baseGr = m_includes[layout]; 
     m_group = m_rules->getGroup(layout, baseGr);
 
-    if (m_compiledLayoutFileNames.contains(layout))
+    if ( m_compiledLayoutFileNames.contains(layout) && !m_forceSetXKBMap )
     {
         res = m_extension->setCompiledLayout(m_compiledLayoutFileNames[layout]);
-        m_extension->setGroup(m_group);
+//	kdDebug() << "setting compiled for " << layout << ": " << res << endl;
+        if( res )
+	    m_extension->setGroup(m_group);
     }
-    else
+
+    if ( !res ) // try not compiled layout, store compiled if success
     {
         res = m_extension->setLayout(m_model, layout, m_variants[layout], m_group, baseGr);
+//	kdDebug() << "setting non-compiled for " << layout << ": " << res << endl;
+        if( res )
+            m_extension->getCompiledLayout(m_compiledLayoutFileNames[layout]);
     }
+
     if( res )
         m_layout = layout;
     
@@ -337,16 +347,16 @@ void KXKBApp::precompileLayouts()
     for (QStringList::ConstIterator it = m_list.begin(); it != end; ++it)
     {
 	QString layout(*it);
-	const char* baseGr = m_includes[layout]; 
-	int group = m_rules->getGroup(layout, baseGr);
-        if( m_extension->setLayout(m_model, layout, m_variants[layout], group, baseGr) ) {
-        QString compiledLayoutFileName = tempDir + layout + ".xkm";
-        if( m_extension->getCompiledLayout(compiledLayoutFileName) )
-    	    m_compiledLayoutFileNames[layout] = compiledLayoutFileName;
-	}
-	else {
-    	    kdDebug() << "Error precompiling layout " << layout << endl;
-	}
+//	const char* baseGr = m_includes[layout]; 
+//	int group = m_rules->getGroup(layout, baseGr);
+//    	if( m_extension->setLayout(m_model, layout, m_variants[layout], group, baseGr) ) {
+    	    QString compiledLayoutFileName = tempDir + layout + ".xkm";
+//    	    if( m_extension->getCompiledLayout(compiledLayoutFileName) )
+    		m_compiledLayoutFileNames[layout] = compiledLayoutFileName;
+//	}
+//	else {
+//    	    kdDebug() << "Error precompiling layout " << layout << endl;
+//	}
     }
 }
 
@@ -486,6 +496,18 @@ void KXKBApp::slotSettingsChanged(int category)
     keys->updateConnections();
 }
 
+/*
+ Viki (onscreen keyboard) has problems determining some modifiers states
+ when kxkb uses precompiled layouts instead of setxkbmap. Probably a bug
+ in the xkb functions used for the precompiled layouts *shrug*.
+*/
+void KXKBApp::forceSetXKBMap( bool set )
+{
+    if( m_forceSetXKBMap == set )
+        return;
+    m_forceSetXKBMap = set;
+    layoutApply();
+}
 
 static QString windowClass(WId winId)
 {
@@ -593,7 +615,7 @@ void LayoutMap::setLayout(WId winId, const LayoutInfo& info)
 
 
 const char * DESCRIPTION =
-  I18N_NOOP("A utility to switch keyboard maps.");
+  I18N_NOOP("A utility to switch keyboard maps");
 
 extern "C" int kdemain(int argc, char *argv[])
 {
