@@ -1,3 +1,4 @@
+#include <qwindowdefs.h>
 #include <qfile.h>
 #include <qtextstream.h>
 #include <qregexp.h>
@@ -16,11 +17,23 @@
 
 #include "rules.h"
 
-const QString X11_DIR( "/usr/X11R6/lib/X11/" );
+const char* X11DirList[2] = {"/usr/X11R6/lib/X11/", "/usr/local/X11R6/lib/X11/"};
+const char* rulesFileList[2] = {"xkb/rules/xfree86", "xkb/rules/xorg"};
 
-KeyRules::KeyRules(QString rule):
+KeyRules::KeyRules():
     m_layouts(90)
 {
+  for(int ii=0; ii<2; ii++)
+    if( QDir(X11DirList[ii]).exists() ) {
+	X11_DIR = X11DirList[ii];
+	break;
+    }
+
+  if( X11_DIR.isEmpty() ) {
+    kdDebug() << "Cannot find X11 directory!" << endl;
+    return;
+  }
+
   // ugly check for XFree 4.3 or older
   if( QDir(X11_DIR + "xkb/symbols/pc").exists() ) {
 	m_xfree43 = true;
@@ -29,8 +42,28 @@ KeyRules::KeyRules(QString rule):
 	m_xfree43 = false;
   }
 
-  loadRules(X11_DIR + QString("xkb/rules/%1").arg(rule));
-  loadOldLayouts(X11_DIR + QString("xkb/rules/xfree86"));
+  QString rulesFile;
+  Display *dpy = qt_xdisplay();
+  XkbRF_VarDefsRec vd;
+  char *tmp= NULL;
+  if (XkbRF_GetNamesProp(dpy,&tmp,&vd) && tmp) 
+    rulesFile = X11_DIR + QString("xkb/rules/%1").arg(tmp);
+  else {
+    // old way
+    for(int ii=0; ii<2; ii++)
+    if( QFile(X11_DIR + QString(rulesFileList[ii])).exists() ) {
+	rulesFile = X11_DIR + rulesFileList[ii];
+	break;
+    }
+  }
+
+  if( rulesFile.isEmpty() ) {
+    kdDebug() << "Cannot find rules file in " << X11_DIR << endl;
+    return;
+  }
+
+  loadRules(rulesFile);
+  loadOldLayouts(rulesFile);
   loadGroups(::locate("config", "kxkb_groups"));
 }
 
@@ -51,9 +84,7 @@ static struct {
     { 0, 0 }
 };
 
-  XkbRF_RulesPtr rules;
-
-  rules = XkbRF_Load(QFile::encodeName(file).data(), "", true, true);
+  XkbRF_RulesPtr rules = XkbRF_Load(QFile::encodeName(file).data(), "", true, true);
 
   if (rules == NULL) {
      kdDebug() << "Unable to load rules" << endl;
@@ -176,7 +207,7 @@ unsigned int KeyRules::getGroup(const QString& layout, const char* baseGr)
     return it == m_initialGroups.end() ? 0 : it.data();
 }
 
-
+/*
 QStringList KeyRules::rules(QString path)
 {
   QStringList result;
@@ -193,7 +224,7 @@ QStringList KeyRules::rules(QString path)
 
   return result;
 }
-
+*/
 
 /* pretty simple algorithm - reads the layout file and
     tries to find "xkb_symbols"
