@@ -96,7 +96,7 @@ void KonqOperations::del( QWidget * parent, int method, const KURL::List & selec
   {
       switch ( method ) {
           case TRASH:
-              KMessageBox::sorry(0, i18n("You can't trash the trash bin."));
+              KMessageBox::sorry(0, i18n("You cannot trash the trash bin."));
               return;
           case DEL:
           case SHRED:
@@ -419,6 +419,7 @@ void KonqOperations::doDrop( const KFileItem * destItem, const KURL & dest, QDro
             pi->data = data;
             pi->destURL = dest;
             pi->mousePos = ev->pos();
+            pi->dialogText = i18n( "File name for dropped contents:" );
             op->setPasteInfo( pi );
             QTimer::singleShot( 0, op, SLOT( slotKIOPaste() ) );
         }
@@ -429,7 +430,7 @@ void KonqOperations::doDrop( const KFileItem * destItem, const KURL & dest, QDro
 void KonqOperations::slotKIOPaste()
 {
     assert(m_pasteInfo); // setPasteInfo should have been called before
-    KIO::CopyJob *job = KIO::pasteDataAsync( m_pasteInfo->destURL, m_pasteInfo->data );
+    KIO::CopyJob *job = KIO::pasteDataAsync( m_pasteInfo->destURL, m_pasteInfo->data, m_pasteInfo->dialogText );
     if ( job )
     {
         setOperation( job, COPY, KURL::List(), job->destURL() );
@@ -563,6 +564,7 @@ void KonqOperations::doFileCopy()
             return;
         }
 
+	m_method = TRASH;
         if ( askDeleteConfirmation( mlst, DEFAULT_CONFIRMATION ) )
             action = QDropEvent::Move;
         else
@@ -602,7 +604,7 @@ void KonqOperations::doFileCopy()
 
         QPopupMenu popup;
         if (!mlst.isEmpty() && (sMoving || (sReading && sDeleting)) && !linkOnly )
-            popup.insertItem( i18n( "&Move Here" ), 2 );
+            popup.insertItem(SmallIconSet("goto"), i18n( "&Move Here" ), 2 );
         if ( sReading && !linkOnly)
             popup.insertItem(SmallIconSet("editcopy"), i18n( "&Copy Here" ), 1 );
         popup.insertItem(SmallIconSet("www"), i18n( "&Link Here" ), 3 );
