@@ -16,8 +16,6 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: konq_sound.cc,v 1.17 2003/07/26 10:41:28 mueller Exp $
-
 #include <kartsdispatcher.h>
 #include <kdebug.h>
 #include <kplayobjectfactory.h>
@@ -36,6 +34,7 @@ public:
 	virtual const QStringList &mimeTypes();
 	virtual void play(const QString &fileName);
 	virtual void stop();
+	virtual bool isPlaying();
 
 private:
 	QStringList m_mimeTypes;
@@ -102,6 +101,11 @@ void KonqSoundPlayerImpl::stop()
 	m_player = 0;
 }
 
+bool KonqSoundPlayerImpl::isPlaying()
+{
+	return m_player ? (m_player->state() == Arts::posPlaying) : false;
+}
+
 class KonqSoundFactory : public KLibFactory
 {
 public:
