@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -51,7 +51,7 @@ int NSPluginLoader::s_refCount = 0;
 
 
 NSPluginInstance::NSPluginInstance(QWidget *parent, const QCString& app, const QCString& id)
-  : EMBEDCLASS(parent), DCOPStub(app, id), NSPluginInstanceIface_stub(app, id)
+  : DCOPStub(app, id), NSPluginInstanceIface_stub(app, id), EMBEDCLASS(parent)
 {
     shown = false;
     _loader = NSPluginLoader::instance();
@@ -103,7 +103,7 @@ NSPluginLoader::NSPluginLoader()
   // load configuration
   KConfig cfg("kcmnspluginrc", false);
   cfg.setGroup("Misc");
-  _useArtsdsp = cfg.readBoolEntry( "useArtsdsp", true );
+  _useArtsdsp = cfg.readBoolEntry( "useArtsdsp", false );
 }
 
 
@@ -178,7 +178,7 @@ void NSPluginLoader::scanPlugins()
           QStringList::Iterator suffix;
           for (suffix = suffixes.begin(); suffix != suffixes.end(); ++suffix) {
 
-              // strip whitspaces and any preceeding '.'
+              // strip whitspaces and any preceding '.'
               QString stripped = (*suffix).stripWhiteSpace();
 
               unsigned p=0;
